# Readme

Here we provide supplementary data to the following publication
> P. M. Lenggenhager, J. Maciejko, and T. Bzdušek, "Non-Abelian Hyperbolic Band Theory from Supercells", Phys. Rev. Lett. (2023).

If you use any of the data or code within this collection, please cite the above publication in addition to citing the data collection itself. :
> P. M. Lenggenhager, J. Maciejko, and T. Bzdušek, "Supplementary data and code for: Non-Abelian Hyperbolic Band Theory from Supercells", DOI: https://doi.org/10.5281/zenodo.10142168.

## Copyright and License

The material in this collection is distributed under the CC BY-SA 4.0 License, see
the attached [LICENSE](LICENSE.txt) for the full legal text.

## Authors

&ensp;&ensp;**Patrick M. Lenggenhager** (plengg@pks.mpg.de)\
&ensp;&ensp;**Joseph Maciejko** (maciejko@ualberta.ca)\
&ensp;&ensp;**Tomáš Bzdušek** (tomas.bzdusek@uzh.ch)

## Directory structure and description of files

- `data/`
    - `bloch/`: Abelian Bloch Hamiltonians as TAB/linebreak separated matrices of symbolic Mathematica expressions with momenta `k1`, `k2`, ...
        - `H_[model]_Tg.n.dat`: Abelian Bloch Hamiltonian for `model` on the
            primitive cell corresponding to the quotient `Tg.n`
        - `H_[model]_Tg.n_sc-Tg'.n'.dat`: Abelian Bloch Hamiltonian for `model`
            defined on the primitive cell corresponding to the quotient `Tg.n` and
            extended to the supercell corresponding to the quotient `Tg'.n'`
    - `cells/`: cell, model, and supercell model graphs as HyperCell files
        - `(2,q,p)_Tg.n_3.hcc`: cell graph for the quotient `Tg.n`, corresponding
            to the primitive cell of the $\{p,q\}$ tessellation, centered at the
            $z$-vertex
        - `[model]_Tg.n_3.hcm`: model graph for `model` defined on the cell
            corresponding to the quotient `Tg.n`, centered at the $z$-vertex
        - `[model]_Tg.n_3_sc-Tg'.n'.hcs`: model graph for `model` defined on the
            primitive cell corresponding to the quotient `Tg.n`, centered at the
            $z$-vertex, extended to the supercell corresponding to the quotient
            `Tg'.n'`
    - `dos/`: TAB/linebreak separated tables with energy in the first column and
        density of states in the second column
        - `dos_[model]_Tg.n.dat`: density of states for `model` on the cell
            corresponding to the quotient `Tg.n`
        - `dos_[model]_Tg.n_[sampling].dat`: density of states for `model` on the
            cell corresponding to the quotient `Tg.n` with `sampling` being the
            number of random momenta used to compute the density of states; the
            value `0` indicates evaluation at $\vec{k}=0$.
- `cells_[model].g`: GAP script to construct the cell graphs for `model` using
    the HyperCells package
- `bloch.nb`: Mathematica notebook to construct the Abelian Bloch Hamiltonians
    using the HyperBloch package and compute the density of states by random
    sampling

## Dependencies

1. **HyperCells** (GAP package): https://github.com/patrick-lenggenhager/HyperCells
2. **HyperBloch** (Mathematica package): https://github.com/patrick-lenggenhager/HyperBloch

The code used to produce the data in this collection consists of two parts. The
first part is a set of [GAP](https://www.gap-system.org/) scripts that use the
[HyperCells](https://github.com/patrick-lenggenhager/HyperCells) package to
construct the (super)cells and model graphs. The second part is a Mathematica
notebook that uses the [HyperBloch](https://github.com/patrick-lenggenhager/HyperBloch)
package to construct the hyperbolic Bloch Hamiltonian and compute the density of
states.

## Requirements

- [GAP](https://www.gap-system.org/) (tested with versions 4.11, 4.12)
- [Mathematica](https://www.wolfram.com/mathematica/) (tested with version 13.2, 13.3)