# load the HyperCells package (https://github.com/patrick-lenggenhager/HyperCells)
LoadPackage( "HyperCells" );

# set up (proper) triangle group
tg := ProperTriangleGroup( [ 2, 3, 8 ] );

# specify the quotient defining the primitive cell
qpc := TGQuotient( [ 2, 1 ] );

# construct symmetric primitive cell
cgpc := TGCellGraph( tg, qpc, 3 : simplify := 5 );
Export( cgpc, "data/cells/(2,3,8)_T2.1_3.hcc" ); # export

# kagome model
model := KagomeModelGraph( cgpc : simplify := 5 );
Export( model, "data/cells/8-kagome_T2.1_3.hcm" ); # export

# specify supercell sequences
scseqs := [
    [
        [  2,  1 ],
        [  5,  1 ],
        [ 17,  2 ],
        [ 33,  1 ]
    ]
];

# iterate over seuqences
for scseq in scseqs do
    # iterate over supercells
    for n in [ 2..Length(scseq) ] do
        # construct symmetric cell
        sc := TGCellSymmetric( tg, TGQuotient( scseq[n] ), 3 );

        # construct supercell model
        scmodel := TGSuperCellModelGraph( model, sc : simplify := 0 );
        Export( scmodel, StringFormatted( "data/cells/8-kagome_T2.1_3_sc-T{1}.{2}.hcs", scseq[n][1], scseq[n][2] ) );
    od;
od;