# load the HyperCells package (https://github.com/patrick-lenggenhager/HyperCells)
LoadPackage( "HyperCells" );

# set up (proper) triangle group
tg := ProperTriangleGroup( [ 2, 8, 8 ] );

# specify the quotient defining the primitive cell
qpc := TGQuotient( [ 2, 6 ] );

# construct symmetric primitive cell
cgpc := TGCellGraph( tg, qpc, 3 : simplify := 5 );
Export( cgpc, "data/cells/(2,8,8)_T2.6_3.hcc" ); # export

# elementary nearest-neighbor model
model := TessellationModelGraph( cgpc, true : simplify := 5 );
Export( model, "data/cells/{8,8}-tess_T2.6_3.hcm" ); # export

# specify supercell sequences
scseqs := [
    [
        [  2,  6 ],
        [  3, 11 ],
        [  5, 13 ],
        [  9, 20 ],
        [ 17, 29 ],
        [ 33, 44 ],
        [ 65, 78 ]
    ],
    [
        [  2,  6 ],
        [  3, 11 ],
        [  5, 13 ],
        [  9, 22 ],
        [ 17, 35 ],
        [ 33, 58 ],
        [ 65, 81 ]
    ],
    [
        [  2,  6 ],
        [ 10, 22 ],
        [ 37, 37 ],
        [ 73, 71 ]
    ]
];

# iterate over seuqences
for i in [1..Length(scseqs)] do
    scseq := scseqs[i];

    # iterate over supercells
    for n in [ 2..Length(scseq) ] do
        if i < 3 then
            # construct symmetric cell
            sc := TGCellSymmetric( tg, TGQuotient( scseq[n] ), 3 );
        else # no mirror symmetries, use non-symmetric supercell
            # construct cell
            sc := TGCell( tg, TGQuotient( scseq[n] ) );
        fi;

        # construct supercell model
        scmodel := TGSuperCellModelGraph( model, sc : simplify := 0 );
        Export( scmodel, StringFormatted( "data/cells/{{8,8}}-tess_T2.6_3_sc-T{1}.{2}.hcs", scseq[n][1], scseq[n][2] ) );
    od;
od;