(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   4991741,      88489]
NotebookOptionsPosition[   4957482,      87988]
NotebookOutlinePosition[   4957911,      88005]
CellTagsIndexPosition[   4957868,      88002]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Note the information on how to cite this repository and the original \
publication it accompanies.\
\>", "Text",
 CellChangeTimes->{{3.909126076181246*^9, 3.9091261129399385`*^9}, {
  3.9101530421260424`*^9, 
  3.9101530530626984`*^9}},ExpressionUUID->"25e347e7-d5f6-499d-95a7-\
78e4f26e23c4"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 CellChangeTimes->{{3.9091097426525187`*^9, 
  3.909109744558095*^9}},ExpressionUUID->"2e5cf166-0f8d-4a79-9131-\
7743a7213544"],

Cell["\<\
We use the HyperBloch paclet (see \
https://github.com/patrick-lenggenhager/HyperBloch for the package repository)\
\>", "Text",
 CellChangeTimes->{{3.9090557695186057`*^9, 3.909055799580909*^9}, {
  3.9090558354238296`*^9, 3.909055853138175*^9}, {3.909109971438822*^9, 
  3.909109986822879*^9}},ExpressionUUID->"5e46b4de-4782-4109-aabf-\
ab09980bd127"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<PatrickMLenggenhager`HyperBloch`\>\"", 
  "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.909055744829231*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"1a6e7216-2d05-4afb-bde5-8f1765bb7aba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.9090559481327915`*^9, 3.909055952399536*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"734cb0e3-96ac-4020-b0f3-2ab2eb1c581b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elementary nearest-neighbor model on the {8,8} lattice", "Section",
 CellChangeTimes->{{3.9091097560137053`*^9, 3.9091097636740923`*^9}, {
  3.909109820746976*^9, 3.909109821007987*^9}, {3.9101530821292405`*^9, 
  3.9101530911518974`*^9}},ExpressionUUID->"5c8fe938-4a81-4d15-b4c6-\
d17ad1f32d3f"],

Cell[CellGroupData[{

Cell["Import cells", "Subsection",
 CellChangeTimes->{{3.909109766864945*^9, 3.909109771535059*^9}, {
  3.909109823230064*^9, 
  3.9091098236720653`*^9}},ExpressionUUID->"0aa1239d-4d07-4b4a-a942-\
f7e95e4123cb"],

Cell["\<\
We first import the cell, model, and supercell model graphs as produced by \
the HyperCells package (see \
https://github.com/patrick-lenggenhager/HyperCells for the package \
repository):\
\>", "Text",
 CellChangeTimes->{{3.90910977524686*^9, 3.9091097920317583`*^9}, {
  3.9091099483552275`*^9, 
  3.909109968542066*^9}},ExpressionUUID->"89c60f61-ecd2-4ee9-ab1a-\
cf8bcfab8422"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcell", "=", 
   RowBox[{"ImportCellGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<(2,8,8)_T2.6_3.hcc\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9090560618564167`*^9, 3.9090560733680687`*^9}, {
  3.9090561514000225`*^9, 3.9090561514836597`*^9}, {3.9091128212745233`*^9, 
  3.909112832496519*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"48113e68-9341-4006-9c86-c6c9e6fff331"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcmodel", "=", 
   RowBox[{"ImportModelGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<{8,8}-tess_T2.6_3.hcm\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.909055936914714*^9, 3.909055963188888*^9}, {
  3.9090560238348665`*^9, 3.909056040271286*^9}, {3.909112837065897*^9, 
  3.909112838796729*^9}, {3.9091137679617558`*^9, 3.909113768077687*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"d928ec5c-db9e-4c18-8b7e-b50ba50f1a71"],

Cell["\<\
We consider the following sequence of supercells, defined in terms of \
quotients given in \
https://www.math.auckland.ac.nz/~conder/TriangleGroupQuotients101.txt by M. \
Conder:\
\>", "Text",
 CellChangeTimes->{{3.9091138575774813`*^9, 
  3.909113909312521*^9}},ExpressionUUID->"00495ca5-cb98-4b4a-9d1f-\
156d8cf17d98"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<T3.11\>\"", ",", "\"\<T5.13\>\"", ",", "\"\<T9.20\>\"", ",", 
     "\"\<T17.29\>\"", ",", "\"\<T33.44\>\"", ",", "\"\<T65.78\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"80851ff6-620b-4dad-b4e6-d9efccfe3f3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{8,8}-tess_T2.6_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
  3.9091142248348513`*^9, 3.909114238346472*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"678328f8-6dfb-41e5-b97a-d97cc7cc6387"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the primitive cell T2.6", "Subsection",
 CellChangeTimes->{{3.9091098104889455`*^9, 
  3.90910982999617*^9}},ExpressionUUID->"2e46cb30-aab4-4ca6-84e9-\
be7dc3526191"],

Cell["\<\
We define the model on the primitive cell given by the quotient group T2.6. \
The primitive cell (Wigner-Seitz unit cell) forms an octagon with a single \
site at its center and nearest neighbors in adjacent copies of the cell:\
\>", "Text",
 CellChangeTimes->{{3.909109834065158*^9, 3.909109920885654*^9}, {
  3.909109996816284*^9, 3.9091100631664762`*^9}, {3.9091138866924057`*^9, 
  3.909113887462228*^9}},ExpressionUUID->"341dd1bd-e500-4566-8ca2-\
7e964d21b4c8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VisualizeModelGraph", "[", 
  RowBox[{"pcmodel", ",", "\[IndentingNewLine]", 
   RowBox[{"Elements", "\[Rule]", 
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ShowCellGraphFlattened", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ShowCellBoundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ShowEdgeIdentification", "\[Rule]", "True"}], "}"}]}]}], 
     "\[IndentingNewLine]", "|>"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"CellGraph", "\[Rule]", "pcell"}], ",", "\[IndentingNewLine]", 
   RowBox[{"NumberOfGenerations", "\[Rule]", "2"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9090560452383413`*^9, 3.9090560491912336`*^9}, {
  3.909056084328685*^9, 3.9090561117988863`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"6d2b05f0-47f9-4b24-89ab-81a2e9ebdbb4"],

Cell[BoxData[
 GraphicsBox[{{InsetBox[
     FormBox[
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJzs3ctu886+5vdGkkGGuYXcRaYZZtpBLqAb2WlksgPsDhDkrnI7tiTrYFkH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         "], {{0, 300.}, {300., 0}}, {0, 255},
         ColorFunction->RGBColor,
         ImageResolution->288.],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
         Automatic],
        Selectable->False],
       DefaultBaseStyle->"ImageGraphics",
       ImageSize->300,
       ImageSizeRaw->{300., 300.},
       PlotRange->{{0, 300.}, {0, 300.}}],
      TraditionalForm], Scaled[{0.5, 0.5}], Scaled[{0.5, 0.5}], Scaled[1]], 
    CircleBox[{0, 0}]}, {
    {RGBColor[
      NCache[
       Rational[2, 3], 0.6666666666666666], 0, 0], AbsoluteThickness[2], 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAr9NamZ/o6j8AAAAAAAAAAJjtMh1G
peo/gDysYMisbD/QzEYUgGLqP4CD9wxVVX0/F6elFVQg6j8g6s3aq32GP/bP
KqnI3uk/4NxzZnCjjj+muNhG5J3pP9B63CeVjZM/X4A1Vq1d6T+APRnTAfKX
PyUlqS0qHuk/IG/uO49+nD8VZd0RYd/oPyjRwDllmaA//l8fNVih6D9oyztQ
HgejP9wIw7YVZOg/2H5XhTWIpT+8doiinyfoP9iCrpNrHKg/PiQD8Pvr5z/I
PsVSf8OqP8QsA4Iwsec/ACl4vS19rT9LlgAmQ3fnP/SHTPyYJLA/eraIkzk+
5z/oY92sopOxP2rBrWsZBuc/AEgVt48Lsz9+kHg46M7mP/w/CwE7jLQ/Kq9c
bKuY5j88JPCTfhW2P6a7rmFoY+Y/vMbNnzOntz/9KB1aJC/mPzyPW38yQbk/
7W8rfuT75T98JOi7UuO6P5y7r9ytyeU/pMBXEWuNvD8VH1NqhZjlP0DLNnJR
P74/FWAUAXBo5T+gUuAL2/i/P5JjzV9yOeU/jP1bJe7cwD8USLspkQvlP9J8
O28UwcE/pDkJ5tDe5D+01kXfyajCPwILXv81s+Q/mrRFl/eTwz9Cn2zDxIjk
P5r+WmGGgsQ/Ai+HYoFf5D8WR0WyXnTFP8tzNe9vN+Q/n6O2q2hpxj8nxM1d
lBDkP/u3rh6MYcc/jioRhPLq4z87uN2NsFzIPwCByhiOxuM/JCUPML1ayT/q
mnCzaqPjP0AGnPKYW8o/iIbLy4uB4z9+Y+R7Kl/LP7zunLn0YOM/AsDPLVhl
zD8bpku0qEHjP+VWVCgIbs0/UGOS0qoj4z8F2gRMIHnOPxO3MQr+BuM/YXKk
PIaGzz8WJEDU
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.840896415254426, 0.3483106997487611}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwlUn0s1HEcPpeXo06b5LWaWuVlGq46ETNmYkbYUZSXvMyt2WRppzSW1cnb
1EzTH+6oGO6qoRJpD6MXTXGd83I49/seduZlJUoWpa8/Pnv22Weft+d5DiZn
RqWxWSyW81b8x0ULb7NNYx2uSk9R/Bb/1K1unqAzJ6vLuofAwmp69ZGCoNS1
7KIsj8Dhy5/F36+3UB8ihRdBncSwUF5LUJXwK/rCCoOghnbu2xICy6VPsXee
MVhei5AfExHwq3jlgUIG9WN+l1mpBLypozPSgwysizmunlEEoqpcgUStxZVM
s1alP0HCe7epoAotOjqiq0d4BC7FneU1oVqklRSkBR4h0Pml5LTs0GLtfkmy
vS2BtWw11UQ0hXt8+Yd4c4I2Tc4b/qwGRUEBT3YZEWSoDvgZRGsgcG3VOW0w
cHrcGHitZxKWLwRhrT8Z5NWkOtd6TCIhMfa2/DuD9Lz2yArpBJZDukz2LjFw
r+91jONO4FBtMG9xnkG26ZytYe44rJ4LvU9u5YbilIdSvRrvbmzXlQYam9Mx
avhsgParktk7Z3rGcG7hPJ0/LuYyMo8xfLTb3p+fmGwqkY5iMKOF3mces3+p
jzsKkuRP7xfbN/zwvTmCCRcZ/U/ECRdx5ocRmVRM/x92V3z2jBvG3PFblJ/0
s6wAdZ8Kpb4Cyp9EHrZn00uFl/0cym/B4fTs5qYhrHUbU/4dMgeK2PuGELHg
S/UxGsgR/i1T4sFsONVvOviS5SuWEjZZbVTf6kL3/BPZX6EJYFP9K8tHxHf1
CqyHrVN/2KXyVhCvQH8WQ/0j7JZd1ysHMVjZRP3Vy9U17w4dBN/Rk/ou9kyj
j1g8gH92nXPj
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152636819, -0.34831069975480705}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwtUmtIk2EYnWtmDU0jS80glUQly5RKNpWDbthQQpIZuRzFVFBL6oempSnk
NrSQBdYPyfY5cRZtXZxhhYWRNbEytXldU/e9YkheKNrMTK3Fux8PD4eH53bO
CVVcyMzncjicKFf8z7LOWP7G5hnkuLO+peh1QA+BKkUfo58nkJ9T5xiqCMwC
m7NliMCYJGK6BQTkoHPx93MC5uP3rNMOFtnCdbVRRyC69DZb9YjFm0qTz6sb
BJGJ0RpxAQsuL814oIzgfHPILBPKgh8kKOLkuXB5qVRrtaP2j0d0fKYLm6Om
UxvsYPx4HZZkgjuGTk1zuh1pdRl3x+IIFmvk5aZNdjiUlfnicIKmK9/yvMqm
sfepShEcRND7q7jr6Ncp2KraeuXbCJwCf3hkTUFlSmz19nT1Sxlxac8krr14
OBO5ziJAJ4vSxU7CcSbjeMcyC9HA4xMNjA0FEVKl8QeLW5KuCJmPDU37u7x2
LrEo3ZgO4lV8wVSjKG5xnsXNT7JGZs6KrJe5wiMubNCOBCactMLhrmukq/zZ
ngm8c/ez/Z6sIXYC99zzfddkW7XMOCRn6f4kya6lPp9xLLjvE+bqfiZVjoHb
Qe8v1h8r2zI/iovV9D9t2If+eNkozO7/C2+vJlv7RmBSUX78UyU7NgQjCL5O
+avwU5S0PxiGcjvlt8b4vo67x4XXKP/1OSUFf+stCNxN9QkLl/t3cizY50n1
W3kSXX245DNWrlJ903jD6tq5IbQmUP0RFuPolg8h5RD1x4L5/uU5yyCECdQ/
hafs7b7pg/AWU3+FKFoT1eoBLD+j/vsHUu5K6Q==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974997103, 0.8408964152537602}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAADDekL063F2Zn+jqv4BPLGHI
rGy/VuY1HUal6r/AjzQNVVV9v+G1SRSAYuq/ICrr2qt9hr+kgKgVVCDqvwAP
kGZwo46/MJotqcje6b+wKOonlY2Tv8Nz20bknem/kJsm0wHyl7+dLDhWrV3p
v1CY+zuPfpy/yMKrLSoe6b+oWMc5ZZmgv2v03xFh3+i/8FJCUB4Ho79Z4SE1
WKHov2ATXoU1iKW/l3zFthVk6L8AMbWTaxyovzjdiqKfJ+i/EBPMUn/Dqr/g
fQXw++vnv5Avf70tfa2/+3kFgjCx579oKlD8mCSwv4zXAiZDd+e/XCvhrKKT
sb897IqTOT7nvxg6GbePC7O/MuyvaxkG579cYg8BO4y0v9Cwejjozua/OHz0
k34Vtr+TxV5sq5jmv6RZ0p8zp7e/uMiwYWhj5r8kYmB/MkG5v1AtH1okL+a/
WDztu1Ljur8cbC1+5PvlvywiXRFrjby/TLCx3K3J5b8MezxyUT++v+sMVWqF
mOW/HFXmC9v4v7++RxYBcGjlv0AqXyXu3MC/wEXPX3I55b/+1j5vFMHBv30l
vSmRC+W/QmBJ38mowr8CEwvm0N7kv2RvSZf3k8O/E+Ff/zWz5L9S7F5hhoLE
v8pybsPEiOS/ZGlJsl50xb/IAIligV/kvwD8uqtoaca/mUQ372835L/gR7Me
jGHHv8uUz12UEOS/8IDijbBcyL/Z+xKE8urjv+InFDC9Wsm/yFPMGI7G478d
RKHymFvKvwdwcrNqo+O/dt3peypfy7/SXs3Li4Hjv/N21S1YZcy/FMueufRg
47+SS1ooCG7Nv16HTbSoQeO/Fg0LTCB5zr9iSpTSqiPjv1vkqjyGhs+/16Qz
Cv4G47806Gdu
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.34831069975223156, -0.840896415266262}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAACMOb0q2VqZn+jqP4DPr2DI
rGy/vvIyHUal6j+AgfkMVVV9v6XRRhSAYuo/gAXP2qt9hr+hq6UVVCDqP4AW
dWZwo46/OtQqqcje6T+wJ90nlY2Tv6m82Ebknek/QPsZ0wHyl78nhDVWrV3p
P7A+7zuPfpy/uCipLSoe6T9QQsE5ZZmgv3po3RFh3+g/UEY8UB4Ho786Yx81
WKHoP/gDWIU1iKW/+AvDthVk6D+AEq+Taxyov795iKKfJ+g/aNnFUn/Dqr8t
JwPw++vnP/DOeL0tfa2/qC8DgjCx5z/E4Ez8mCSwvy2ZACZDd+c/uMLdrKKT
sb9guYiTOT7nP/isFbePC7O/XsStaxkG5z9MqwsBO4y0v4aTeDjozuY/AJbw
k34Vtr9Sslxsq5jmPxw/zp8zp7e/9L6uYWhj5j9YDlx/MkG5v3wsHVokL+Y/
dKrou1Ljur+kcyt+5PvlP4xNWBFrjby/lr+v3K3J5T88XzdyUT++v1ojU2qF
mOU/yO3gC9v4v7+wZBQBcGjlP8BOXCXu3MC/jGjNX3I55T+w0TtvFMHBv3ZN
uymRC+U/Qi9G38mowr96Pwnm0N7kP+IQRpf3k8O/VhFe/zWz5D+eXlthhoLE
vx2mbMPEiOQ/3qpFsl50xb9wNodigV/kPy4Lt6toaca/1Xs172835D9TI68e
jGHHv9jMzV2UEOQ/WyfejbBcyL/wMxGE8urjPxCYDzC9Wsm/IIvKGI7G4z/1
fJzymFvKv9KlcLNqo+M/+d3keypfy79AksvLi4HjPz4+0C1YZcy/UvucufRg
4z/Y2FQoCG7Nv5izS7SoQeM/rF8FTCB5zr/AcZLSqiPjP7T7pDyGhs+/gsYx
Cv4G4z+tlVis
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.34831069974881834, 0.8408964152537055}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQvee4Idc/tsf2k+6B6f0xm7MOiB9+ZM+StVR/6etH
+xOq22JW1z2yn5dw5+uii4/2f/Fxnr/f8pG9cujXtz93PNqvcvtDaPSXh/Yi
CX/b1ix8tP9f85HI1nUP7dkXbeLd2/1ov7CnTr9LxkP7xxpea3TLH+1vWqPw
dL7iQ/tZtpZZDCmP9i9vLg2Zd+uB/Q15Jh3zoEf7T1zQvO82+YH9fhOWzZcd
H+0X3bqtf4H3A3u/tf5zrxs92t/YE1uxifmB/bsVNakuqo/2f+t8lcJeft9e
7kZrkrTko/1+rHm7zZ7ds/+2aNnxWL5H+5e5itgzht6zP33NZgkP66P9x+Lm
u5QevmvPdm/tY42/D/dLrYzSXGh41/5Ei7/v5m8P9xdcXR84ef4d+wU+IS1r
Pj7c/9Znt3oU7x17j8Dd7KLvHu7/z/BAkqX6tr3IAWejt68f7g84HzVz/otb
9mqPk61MgfyVc69KWIfdsi84CJE/H/iL6+nhm/YMIRD9+SdZH642vGm/OQBi
/tevUZzz5t+wt+iC2N/qIPbuJO8N+wtPIO77FLnws23Ndft39yDuXzTLvZzj
9TX7kjUQ/8WLnT5rHnXN/ssjiP+Ptf9yvHXyqr30Vkj4KJh7CP+zvGp/YRck
/DwZkko2rrpiP80ZEr5qs091MslcsWc2gIS/lFdJxv/ey/Zi/pD4WS8YK7KN
4bL9BmtI/M2Zo1NvUnLJXmkbJH6V3l9u63hx0b6qFBL/CTz6X/bHXrS/kg1J
HwUbVlS+uHzBfloFJP3kOz7YyO99wd6pGZK+MoyX2LS1nbcX/glJfwDnMmIv

       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.348310699748923, -0.8408964152537368}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQve64Idc/tsf7mfeDafubwUv1l75+tH/fqqwD4ocf
2Wt53/m66OKj/Y+K2mJW1z2yT3H4+vbnjkf7Z7o4z99v+ciezedv25qFj/Z/
uvQhNPrLQ/sVfZt493Y/2v+j+khk67qH9vpiXmt0yx/tt3PU6XfJeGjfo22Z
xZACNG+JwtP5ig/tC/iYdMyDHu13qCkNmXfrgf0PZZbNlx0f7Z97UvO+2+QH
9ipz/edeN3q0X2vdtv4F3g/s42bWpLqoPtp/szW2YhPzA3vVk61J0pKP9hvX
vkphL79v3z9l2fFYvkf75X7m7jZ7ds/+0wmbJTysj/YLWonYM4bes99xYe1j
jb8P918Knu9SeviuPVOFv+/mbw/3n5kXpbnQ8K59jENIy5qPD/efO70+cPL8
O/bNrrvZRd893P/Hebd6FO8d+1NbnI3evn64/+iP+5Is1bftA28kW5kC+ZeO
R82c/+KWPd92iPyLaVclrMNu2fN4QfRf8f7F9fTwTXsNd4j51kdYH642vGkv
1Aixv/djFOe8+Tfsee5A3PfWRuzdSd4b9u3XIO7XCV/42bbmun3KEoj/Ns1w
L+d4fc3e4jbE/x6ip8+aR12zX7cWEj6d7b8cb528ar9uMyT8Dph7CP+zvGq/
ywYSvicYk0o2rrpin6EJCf+2uac6mWSu2O/0gMRPtG9Jxv/ey/Y9ppD4uyIa
K7KN4bK90QZI/C5bqFNvUnLJflc+JP75vl5u63hx0d4uDZI+jIT1v+yPvWiv
UQxJPxo7VlS+uHzB/mstJH3xeD3YyO99wf7JZ0j6y3BbYtPWdt4eABNaYhY=

       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152563142, 0.3483106997496378}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAQtNamZ/o6j8AAAAAAKALvRjtMh1G
peo/gLasYMisbL8+zEYUgGLqP8DG9wxVVX2/dKalFVQg6j/gDs7aq32Gv0LP
KqnI3uk/IAV0ZnCjjr/it9hG5J3pP9CQ3CeVjZO/in81Vq1d6T9QVRnTAfKX
v0AkqS0qHuk/8IjuO49+nL8iZN0RYd/oPxjfwDllmaC//F4fNVih6D9o2jtQ
Hgejv8wHw7YVZOg/+I5XhTWIpb+gdYiinyfoPyCUrpNrHKi/FCMD8Pvr5z9I
UcVSf8Oqv44rA4Iwsec/uDx4vS19rb8KlQAmQ3fnP3iSTPyYJLC/LrWIkzk+
5z8Yb92sopOxvxXArWsZBuc/2FMVt48Ls78gj3g46M7mP4hMCwE7jLS/xK1c
bKuY5j98MfCTfhW2vzi6rmFoY+Y/uNTNnzOnt7+JJx1aJC/mP/idW38yQbm/
cm4rfuT75T8ENOi7UuO6vx26r9ytyeU/6NBXEWuNvL+SHVNqhZjlP0zcNnJR
P76/jl4UAXBo5T98ZOAL2/i/vwlizV9yOeU/4gZcJe7cwL+IRrspkQvlP5KG
O28UwcG/GDgJ5tDe5D/e4EXfyajCv3YJXv81s+Q/ML9Fl/eTw7+4nWzDxIjk
P5oJW2GGgsS/ei2HYoFf5D+EUkWyXnTFv0ZyNe9vN+Q/e6+2q2hpxr+mws1d
lBDkP0fErh6MYce/EikRhPLq4z/1xN2NsFzIv4p/yhiOxuM/TjIPML1ayb98
mXCzaqPjP90TnPKYW8q/IIXLy4uB4z+MceR7Kl/Lv17tnLn0YOM/gc7PLVhl
zL/GpEu0qEHjP9VlVCgIbs2/BmKS0qoj4z9l6QRMIHnOv9a1MQr+BuM/MoKk
PIaGz78EylRP
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537366, -0.34831069974930134}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAd/9amZ/o6r8AAAAAAE9RvfgZMx1G
peq/AIO2YMisbL/f+UYUgGLqv0CF/QxVVX2/7dSlFVQg6r9AYdHaq32Gv6z+
KqnI3um/ANF3ZnCjjr9W6NhG5J3pv9C23ieVjZO/JLE1Vq1d6b+QvhvTAfKX
vxpXqS0qHum/kDjxO49+nL9amN0RYd/ov4BbwjllmaC/sJQfNVih6L/QfD1Q
Hgejvxo/w7YVZOi/wFhZhTWIpb+oroiinyfov5CGsJNrHKi/+F0D8Pvr57+Y
bcdSf8Oqv29oA4Iwsee/EIR6vS19rb8L1AAmQ3fnvzTMTfyYJLC/cvaIkzk+
579cv96sopOxv8IDrmsZBue/KLsWt48Ls79Y1Xg46M7mv1jLDAE7jLS/sPZc
bKuY5r8oyPGTfhW2v/4Fr2FoY+a/qIPPnzOnt79Qdh1aJC/mv3xlXX8yQbm/
ZMArfuT75b9YFOq7UuO6v2APsNytyeW/WMpZEWuNvL9QdlNqhZjlvwjvOHJR
P76/8roUAXBo5b+wkOIL2/i/vz7CzV9yOeW/xildJe7cwL+4qrspkQvlv0y2
PG8UwcG/b6AJ5tDe5L9wHUffyajCvx52Xv81s+S/mghHl/eTw7/fDm3DxIjk
v9ZfXGGGgsS/TKOHYoFf5L+GtUayXnTFv/HsNe9vN+S/LB+4q2hpxr9WQs5d
lBDkv5RAsB6MYce/9a0RhPLq47++Td+NsFzIv84JyxiOxuO/cMcQML1ayb9O
KXGzaqPjvy21nfKYW8q/rxrMy4uB47/aHuZ7Kl/Lv9eInbn0YOO/mIfRLVhl
zL9YRky0qEHjv3oqVigIbs2/3gmT0qoj479UuQZMIHnOvyBkMgr+BuO/JV2m
PIaGz78c8Gv7
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152636819, -0.34831069975480705}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwtkm1Ik1EYhvellmWflo36kUHlYmGTUpwfN6ZYaWaJVk4HMpWWGFHMlmju
jxt9UAYOKinXmkbkVHRhw1kKi8TC0t5t6pr6vscMSZQiHWRqGZ0fDw8Ph3PO
/Vz3Ha66mFUs4PF4kpX613e9lAUvB05ATPvJ5MbIxmmCCktJT5iTwCj3zT8Z
JDhWashvqiJoj5yf+WUnaE1MNnXHEuyLWzJYzQSd/d9z8uY4GK+1h7y6RaDR
vsnVt3BwidKs+7UElxKkNSlqDj5xbAmviKDfvHPSFM7h7CJfGpNF8KW8LLve
y6J0o8jGJBEs9krGU2tZhN7MfDQURXC4uaPmcToLh76yOGU3gVWvvNouZMG+
0Ku2iwnSqr4VBWnHcV/3tFe5jsDy+4Ij+usY5Lb4hrUBBLzEUPBzxiDrbJ6I
WOKwJ9eUUuYcRV1BZobNz0HXqJCYZaMIjMiutv7g4GVaT9WafDggdQRtmeVw
JsOxVxHiQ0ldctTMNIdzQlYsqvgMd1eh/NDK3MIoHpimvFDTc7/FvS3utBdS
ej9AsRA86RwBn75fzQRwTbIRGOn/Y/y81fWmYUiovugTW2f7QoYho/rzz5t/
JlQO4Q7dz950RLtq2gMX3X+T5H1/jMKzwuU/H+HDhSRvnxsiys9z/Ojm5Vg3
FJSvKkylaXvuQirlf9f27oZghwtvqT+vCzXqP7cZdFH/NFJlaAePQQX1t9Qu
1R3UfMIG6j+3xmW4PjWIezQffknkXLdyEFdofno+PCufYgYQRfOVX8C2rU8f
gIDmLv5yQ7zB8BF/AceURsI=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.840896415254426, 0.3483106997487611}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwlUmtI03EUnVPTRtPQLC0fiYitjOXQfDRZ2rJMRB0quRyVKQ2p9qGZWmYl
OYoSIftSmdPQQTktHYk48wQippQ6Nx+br/1/Zi5MyfJNzey/D5fL5XLvPfec
458lE+UwGQwGZyv+54S9ISzrtmlUBtpyqHPuxz2dBB3aWm7dHEHLYGlmfTHB
RvvY8isdgVUVq0Qkwe72pfn1VgLPiJ9p55YolOn+KNQ1BDu/dmaUNlJY82lm
f3hEUKA+VC6UUoh6G68+nE8gc98/o/SnENcXkcvIJkhekKdWmczoarMLDhcR
nBdwpuIqzDAZ7TX6GIK+oJby6gQz7mYmvRzhEZTbSwqa7c0IyCrKEQYS+N77
nu2UP4XjL0qz9nkRzDpe1R79NokfMlW3xIXALdldYJc2iZsN/NodjgTS61XC
vM4JpHc0TB/4SyHlUwanJmQC1deSEjUrFCo3G1MqlOOgBKn31YsUrpS0BYnZ
4xhJ1Dp5LFDgxk55Odwaw2DXCd78HIXH3uJnSosJy4uXosK26vhVg+exdBN4
Rlv/SOs6a6bTiKdy2/ws35GqDzFirdC2f+yGeHuVchSsdtt9br/HQg97FC5+
jTQ+zUr17+iiEeT5R9P4P588le88NwzfVdt/woHeL+HiYVSGKej/3ydvxJh6
hvDc9TbNz2XX0+7WyCEwfZJp/niWi/KmNwaIGhxofjef9D5kehvgV8Ok+Q8W
yaWbZXrkdkfS+ggOSna1MPRw056h9fvVFXwnVD4IKV9D61vMMSgeWHQoZFpp
/VlnuUuQ6HBhc5n2h4r9utCiH0CJ2wTtH9k7c5NrwgCyAlS0v+RhdXyFoh8R
Sh7tv3+rUHMk
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.34831069975223156, -0.840896415266262}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAMDOeb37xXiZn+jqPwAaHGDI
rGw/yzdQHUal6j/A1YQMVVV9P+puYxSAYuo/gBWB2qt9hj9SocEVVCDqP4BY
FWZwo44/xCJGqcje6T8wRqUnlY2TP7Bk80bknek/4Pna0gHylz+Fhk9WrV3p
P0D+qTuPfpw/f4bCLSoe6T/o8Zs5ZZmgP/Ii9hFh3+g/8LMUUB4Hoz/gezc1
WKHoP5CcLoU1iKU/fITathVk6D/QQYSTaxyoPwhUn6KfJ+g/wAmaUn/Dqj9V
ZRnw++vnPxBpTL0tfa0//NMYgjCx5z9cljb8mCSwPyymFSZDd+c/pJPHrKKT
sT+4MZ2TOT7nPyDL/7aPC7M/86rBaxkG5z/AR/YAO4y0P2jrizjozuY/zODb
k34Vtj++fm9sq5jmP2Bnup8zp7c/XAPBYWhj5j8oQkl/MkG5P3jsLlokL+Y/
3BbXu1Ljuj/8sjx+5PvlP3geSBFrjbw/PILA3K3J5T94vyhyUT++P2ptY2qF
mOU/AAfUC9v4vz9wOiQBcGjlPw7MViXu3MA/as7cX3I55T9OUzdvFMHBPwZI
yimRC+U/LshC38mowj930xfm0N7kP27TQ5f3k8M/nkNs/zWz5D92XFphhoLE
P7Z7esPEiOQ/APVFsl50xT98tJRigV/kP+OxuKtoacY/nadC72835D86NrIe
jGHHP8Kr2l2UEOQ/VrXijbBcyD+Cyx2E8urjP0CvFTC9Wsk/+uDWGI7G4z/F
KqTymFvKP7W/fLNqo+M/Ei/ueypfyz8GdtfLi4HjP4I+2y1YZcw/7q6oufRg
4z9ok2EoCG7NPxQ9V7SoQeM/3N4TTCB5zj9A153SqiPjPwlJtTyGhs8/Ow49
Cv4G4z89vkfT
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974997103, 0.8408964152537602}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAADiVb3yBFuZn+jqv4BXo2DI
rGw/Ux8zHUal6r/AJ/QMVVV9Px3/RhSAYuq/ANDM2qt9hj8T2qUVVCDqv4Be
c2Zwo44/vgMrqcje6b9wjdwnlY2TP1jt2Ebknem/oKUZ0wHylz8ctjVWrV3p
v4Aw7zuPfpw/DVypLSoe6b84YME5ZZmgP0ud3RFh3+i/gIo8UB4Hoz+lmR81
WKHov6BvWIU1iKU/GkTDthVk6L/Ypq+TaxyoP7iziKKfJ+i/iJfGUn/Dqj8c
YwPw++vnv9i3eb0tfa0/rm0DgjCx578Ya038mCSwP2rZACZDd+e/ZGPerKKT
sT/4+4iTOT7nv2RkFrePC7M/dAmuaxkG57/YeQwBO4y0P0DbeDjozua/BHzx
k34Vtj/Q/Fxsq5jmv+w8z58zp7c/XgyvYWhj5r84JF1/MkG5P/Z8HVokL+a/
pNjpu1Ljuj9Yxyt+5PvlvziUWRFrjbw/qBaw3K3J5b+QvjhyUT++P/R9U2qF
mOW/3GXiC9v4vz/4whQBcGjlvzYXXSXu3MA/rMrNX3I55b+YpjxvFMHBP5iz
uymRC+W/nhBH38mowj/GqQnm0N7kv6r+Rpf3k8M/9X9e/zWz5L/GWFxhhoLE
PzsZbcPEiOS/VrFGsl50xT82rodigV/kv94duKtoacY/cPg172835L8iQrAe
jGHHP3JOzl2UEOS/KFLfjbBcyD+0uhGE8urjv7DOEDC9Wsk/OhfLGI7G479B
v53ymFvKP203cbNqo+O/uSvmeypfyz+IKczLi4Hjvz6X0S1YZcw/c5idufRg
47/fPFYoCG7NP75WTLSoQeO/cM4GTCB5zj8WG5PSqiPjv+x0pjyGhs8/MnYy
Cv4G47+1IVes
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.348310699748923, -0.8408964152537368}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwlUntI02EUnS5bZatFjyUapKDmi1SysbX6yIYuxyQfiVuKIVvJCIelTUkS
QpcaIqUkNXIq9Ycpzhe+Um5ztFoUOTdfc7r9PtOkzUWkkVGafv1xuVwu995z
zzmBucpUuTeNRgvbiu3cKruwZ2PnAgzFC7YzsoeUvmYbMKji+k++cGEUoG/I
aruLQd+wstZixmjkaroWuBiK//h41gcwWhvwyriySgGnlHm/vRmj9dAJSUUH
BTrOKHPkAUZqHb9WkEeBgy9pj1JhtGSOXtQGUjBmTVTQZBg1ySrSG21OSECs
SE4qRsEKriOhzgm3qQM9lvMYmenG2iaRE265s55NxWJkrLlR3E13wlBZlVwQ
jBHPzZAzVA6YEz3K9ffDKH20+tXppXmgDXa/zd63NZ8Zjbwuz0NlvfD5Xh+M
Jg1DgiLDHHiEgwsn/lIoPKsorDlmDnJapOKenxT6PW5KqdPaoSAop7z9O4Xe
P7SGSpl2cH9+wzjsoZC8+pffjjuzEMFOjl1xUcj69OYT7bINMuj5vLitGrW6
j57JsMH1TjHpf9CwfBcNM6Bk/59XX/Kn2mJmINmTTfbzBpW7G7XT0MuQkPsK
FO4xMadhMbGf4Eus7/1xtnQK0qISCH4NS6ra5ZqEWZeO/Ffzzv6RI50Ell8t
+f+IyjfeZpqAx18qCD9OWebBDe4EpHzLJPyF5BcUdr20wnAZk/AbIZqp8g6w
Qm6JL+G/49y9vM0aC/Db4ok+9WLFoT6aBY51phH9VoO4ZacKxyFJOEz0lRsc
6splMxjDGUT/a7G8Vcg2g+bi5sq2P/Iie0qWLWNwvHyJ+MfJ/tq1XzQGRr2O
+Gu9sY+vVn+CXiWf+O8f5uth+g==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.34831069974881834, 0.8408964152537055}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwtUn1IU3EUffmRZq6gzCktcEbUaCVblq6UX+oo08RpGjgblCiJmWIqVloG
6UuTErSMgnwpuSiXnzhTqRsZqZmkbtO51O39zHg4NC0NXGqt9/rjcrlc7r3n
nnOESZmxKQ4EQYjs8S97vpO4ra2fQpp+NoNeUedXZ8VI1p72lt+NYSBifKl2
CKMDheSZ+usYekOXZpdfYfRBEUaBDIM8ZpXU1GBEmOfjExdpMFa18F6XYTR3
631CcQMNacIIzb48jHZGicvlqTTMyGRpRDJG0OQzTQlpcPVxEAfEYuRTkhtX
bbLA10CnVl0IRqUGkflYpQXy26Ifj0ox2t+pLX8SaYHAtoIU+S6MHCtUl1sc
LfCIKU7a7o2R9f5MskueGbTt6h7VJowStmR0Hfo2CVPfg566O9v7pzzQuvhJ
KPv9cmrPKo0uZlDy3O4J+KSOjmr9RaOITqWoRjIB/tlxRZoFGsUzjTGV1Djc
KOhy2TZHo+ZzXbuVvHEg5sOks1YaDfIt3k75X8DITz580F6rGOVDijGBzcb1
hR0GryOnTXCpgpufzrS5TXePgeDe//0zznS9ZAzUw9x92jtxQzVlhDhpA4uv
4bznXB/PCFWSYBb/3aKan8EFo3DS6Rn7n7X3eJ6rdQTcjpLs/xXh/QMByhG4
yr/G8rPjjS3E1GcA0lfB8jeaFb51TWYATRPHL4WScppf6OFmLce/yvyx1EGg
h409nD7ZlTmpf+7owLeD0y/9rMpDS+jAS9bK6kssiAv9c4ZhZZXTP+uEnixh
hoBZ5vyB0/0WQTUEoe4TrH8u8J9fYXSDcFugZv21t9HSvDlyEFYeSFn//RDU
BZHkZ/gLVidkCA==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537366, -0.34831069974930134}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA+hdwmZ/o6r8AAAAAQIWePTG9Rx1G
peq/gMdeYcisbD/GJ1sUgGLqv8CaMg1VVX0/pY25FVQg6r9grd3aq32GP3xC
PqnI3um/oCR3ZnCjjj+wt+tG5J3pvxCG2CeVjZM/oAxIVq1d6b/wUxDTAfKX
P3c/uy0qHum/IDPhO49+nD97Du8RYd/ov1hauDllmaA/opkwNVih6L9AyzFQ
HgejPw7U07YVZOi/8ENMhTWIpT/y1Jiinyfov8BaopNrHKg/ExcT8Pvr578g
drhSf8OqP/q1EoIwsee/GAtrvS19rT/Itw8mQ3fnv4zzRfyYJLA/R3KXkzk+
57+A7tasopOxP7YZvGsZBue/dBUPt48Lsz+Yh4Y46M7mv4BzBQE7jLQ/hEdq
bKuY5r844OqTfhW2P9P3u2FoY+a/9CzJnzOntz+yCypaJC/mv6DAV38yQbk/
APw3fuT75b9AQeW7UuO6PwD0u9ytyeW/FOhVEWuNvD/bBl9qhZjlv+QbNnJR
P74/bvofAXBo5b8g6uAL2/i/P8yz2F9yOeW/GPtcJe7cwD+YUcYpkQvlvxI6
PW8UwcE/+P8T5tDe5L8aYUjfyajCP8SRaP81s+S/IBlJl/eTwz8t6nbDxIjk
v65JX2GGgsQ/6EGRYoFf5L+2hEqyXnTFP5VSP+9vN+S/PN+8q2hpxj/Wctdd
lBDkv4T8tR6MYcc/Oq0ahPLq478SEOaNsFzIP9Xb0xiOxuO/I5oYML1ayT8o
0nmzaqPjv7ehpvKYW8o/gJ7Uy4uB478lLvB7Kl/LP9brpbn0YOO/B8LcLVhl
zD/OjFS0qEHjv9+XYigIbs0/Ijib0qoj47/3YBRMIHnOP5p+Ogr+BuO/tUW1
PIaGzz/vXloa
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152563142, 0.3483106997496378}], {}}}}, {}}, {
    {Arrowheads[{{Small, 0.5}}], 
     {RGBColor[0, 0, 1]}, 
     {RGBColor[1, 0, 0], 
      ArrowBox[LineBox[{{0., 0.}, {0.840896415254426, 0.3483106997487611}}]], 
      ArrowBox[LineBox[{{0., 0.}, {-0.8408964152563142, 
        0.3483106997496378}}]], 
      ArrowBox[LineBox[{{0., 0.}, {0.34831069974997103`, 
        0.8408964152537602}}]], 
      ArrowBox[LineBox[{{0., 0.}, {-0.34831069974881834`, 
        0.8408964152537055}}]]}}, {
     {Hue[0.6, 0.7, 0.5], Opacity[0], Arrowheads[Medium], 
      ArrowBox[BezierCurveBox[{{0., 0.}, {
        0.0699525050864362, -0.01762081331242772}, {
        0.08070734354523137, -0.0366651622439174}, {
        0.08091729928177427, -0.051366979895934445`}, {
        0.05136697989593445, -0.08091729928177427}, {
        0.036665162243917415`, -0.08070734354523137}, {
        0.017620813312427715`, -0.0699525050864362}, {0., 0.}},
        SplineDegree->7]], 
      ArrowBox[BezierCurveBox[{{0., 
        0.}, {-0.017620813312427708`, -0.0699525050864362}, \
{-0.036665162243917394`, -0.08070734354523137}, {-0.05136697989593443, \
-0.08091729928177427}, {-0.08091729928177425, -0.05136697989593446}, \
{-0.08070734354523137, -0.036665162243917415`}, {-0.0699525050864362, \
-0.01762081331242772}, {0., 0.}},
        SplineDegree->7]], 
      ArrowBox[BezierCurveBox[{{0., 0.}, {-0.06995250508643622, 
        0.017620813312427704`}, {-0.08070734354523137, 
        0.03666516224391738}, {-0.08091729928177428, 
        0.05136697989593444}, {-0.05136697989593447, 
        0.08091729928177425}, {-0.03666516224391744, 
        0.08070734354523137}, {-0.017620813312427736`, 0.0699525050864362}, {
        0., 0.}},
        SplineDegree->7]], 
      ArrowBox[BezierCurveBox[{{0., 0.}, {0.017620813312427697`, 
        0.06995250508643622}, {0.036665162243917374`, 0.08070734354523137}, {
        0.05136697989593443, 0.08091729928177428}, {0.08091729928177424, 
        0.05136697989593447}, {0.08070734354523137, 0.03666516224391745}, {
        0.06995250508643619, 0.01762081331242774}, {0., 0.}},
        SplineDegree->7]]}, 
     {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0]}], FaceForm[
      Opacity[0]], DiskBox[{0., 0.}, 0], InsetBox[
       RowBox[{"{", 
        RowBox[{"3", ",", "1"}], "}"}], Offset[{2, 2}, {0., 0.}], 
       ImageScaled[{0, 0}],
       BaseStyle->"Graphics"]}}, 
    {GrayLevel[0], AbsolutePointSize[5], PointBox[{0., 0.}]}}},
  ImageSize->300,
  PlotRange->{{-1.1, 1.1}, {-1.1, 1.1}}]], "Output",
 CellChangeTimes->{
  3.9090560518364916`*^9, {3.9090561101798167`*^9, 3.9090561548715925`*^9}, 
   3.9091127161095977`*^9, 3.910153148939886*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"2b7f5c4c-3604-4cd1-8985-700ccfcb41be"]
}, Open  ]],

Cell["\<\
The elementary nearest-neighbor model has constant hoppings -1 and vanishing \
onsite potential, such that the Abelian Bloch Hamiltonian on the primitive \
cell can be constructed as follows:\
\>", "Text",
 CellChangeTimes->{{3.9091100794507523`*^9, 3.909110119897537*^9}, {
  3.9101532932814474`*^9, 
  3.9101533277179966`*^9}},ExpressionUUID->"c772f7df-d25d-489a-b114-\
9df4ad308a69"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Hpc", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"AbelianBlochHamiltonian", "[", 
       RowBox[{"pcmodel", ",", "1", ",", 
        RowBox[{"0", "&"}], ",", 
        RowBox[{
         RowBox[{"-", "1"}], "&"}]}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.9091127598630133`*^9, 3.9091128051125402`*^9}, {
  3.909112887125308*^9, 3.909112890216216*^9}, {3.909114118715374*^9, 
  3.909114118938531*^9}, {3.910153339519004*^9, 3.9101533492091894`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"27ff0637-f797-47c1-9726-11d490f8ca1d"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "k1", "]"}], "+", 
         RowBox[{"Cos", "[", "k2", "]"}], "+", 
         RowBox[{"Cos", "[", "k3", "]"}], "+", 
         RowBox[{"Cos", "[", "k4", "]"}]}], ")"}]}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.909112806133675*^9, 3.9091128916577287`*^9, 
  3.909113216625798*^9, 3.9091141203995323`*^9, 3.91015335400698*^9},
 CellLabel->
  "Out[10]//MatrixForm=",ExpressionUUID->"90b5f9db-c6a7-41c8-b149-\
37d5817d2f61"]
}, Open  ]],

Cell["We export the matrix", "Text",
 CellChangeTimes->{{3.90911280941973*^9, 
  3.9091128164730463`*^9}},ExpressionUUID->"6f1fa75b-44b5-476e-989d-\
15b68100359b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
       "\"\<H_{8,8}-tess_T2.6.dat\>\""}], "}"}], "]"}], ",", "Hpc", ",", 
    "\"\<Table\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.909112817642894*^9, 3.909112873040862*^9}, {
  3.9091135412614784`*^9, 3.9091135513819184`*^9}, {3.9091141224124656`*^9, 
  3.9091141227837057`*^9}, {3.9101533706269875`*^9, 3.910153387843902*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"8ef56728-4aa6-4c54-b5f0-9af549df0f1c"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909112902255294*^9, 
  3.909112904377528*^9}},ExpressionUUID->"ab3c7313-84ab-4903-817f-\
0cda254dbc01"],

Cell["\<\
We approximate the density of states by randomly sampling momenta, i.e., \
one-dimensional irreducible representations, and diagonalizing the Bloch \
Hamiltonian evaluated at those. For faster evaluation, we compile the \
expression for the Bloch Hamiltonian:\
\>", "Text",
 CellChangeTimes->{{3.9091129164291873`*^9, 3.909112983734069*^9}, {
  3.9101534175388513`*^9, 
  3.910153418071595*^9}},ExpressionUUID->"123d0899-b6f2-408b-a9ed-\
0cd524724576"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hpccf", "=", 
  RowBox[{"AbelianBlochHamiltonian", "[", 
   RowBox[{"pcmodel", ",", "1", ",", 
    RowBox[{"0", "&"}], ",", 
    RowBox[{
     RowBox[{"-", "1"}], "&"}], ",", 
    RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9091129849959536`*^9, 3.9091129967523327`*^9}, {
   3.909114125339196*^9, 3.909114125798375*^9}, 3.910153426194847*^9},
 CellLabel->"In[12]:=",ExpressionUUID->"3ff975b3-8c4f-4dcc-b819-e3562f86870c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["CompiledFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  StyleBox[
                   PaneBox[
                    RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ContentPadding -> False, FrameMargins -> 0, 
                    StripOnInput -> True, BaselinePosition -> Baseline, 
                    ImageSize -> {{1, 300}, Automatic}], LineBreakWithin -> 
                   False], "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ImageSize -> {{1, 500}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Variables: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$21774", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21775", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21776", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21777"}], 
                    "}"}], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21774"}]]}], 
                    "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21774"}]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21775"}]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21775"}]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21776"}]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21776"}]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21777"}]], "-", 
                    SuperscriptBox["\[ExponentialE]", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$21777"}]]}], 
                    "}"}], "}"}], ImageSize -> {{1, 500}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  CompiledFunction[{11, 13.3, 5468}, {
    Blank[Real], 
    Blank[Real], 
    Blank[Real], 
    Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {4, 2, 
   0}}, {{0., {3, 0, 4}}, {
     Complex[0., -1.], {4, 0, 0}}, {
     Complex[0., 1.], {4, 0, 3}}}, {0, 0, 5, 11, 
   1}, {{11, 0, 4, 1}, {17, 0, 1, 2}, {40, 32, 4, 0, 2, 4, 0, 1}, {20, 1, 
    2}, {11, 0, 4, 1}, {17, 3, 1, 4}, {40, 32, 4, 0, 4, 4, 0, 1}, {20, 1, 
    4}, {11, 1, 4, 1}, {17, 0, 1, 5}, {40, 32, 4, 0, 5, 4, 0, 1}, {20, 1, 
    5}, {11, 1, 4, 1}, {17, 3, 1, 6}, {40, 32, 4, 0, 6, 4, 0, 1}, {20, 1, 
    6}, {11, 2, 4, 1}, {17, 0, 1, 7}, {40, 32, 4, 0, 7, 4, 0, 1}, {20, 1, 
    7}, {11, 2, 4, 1}, {17, 3, 1, 8}, {40, 32, 4, 0, 8, 4, 0, 1}, {20, 1, 
    8}, {11, 3, 4, 1}, {17, 0, 1, 9}, {40, 32, 4, 0, 9, 4, 0, 1}, {20, 1, 
    9}, {11, 3, 4, 1}, {17, 3, 1, 10}, {40, 32, 4, 0, 10, 4, 0, 1}, {20, 1, 
    10}, {14, 2, 4, 5, 6, 7, 8, 9, 10, 2}, {34, 2, 1, 1, 2, 4, 0}, {1}}, 
   Function[{
    PatrickMLenggenhager`HyperBloch`Private`k$21774, 
     PatrickMLenggenhager`HyperBloch`Private`k$21775, 
     PatrickMLenggenhager`HyperBloch`Private`k$21776, 
     PatrickMLenggenhager`HyperBloch`Private`k$21777}, {{-
       E^(Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$21774) - 
      E^(Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$21774) - 
      E^(Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$21775) - 
      E^(Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$21775) - 
      E^(Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$21776) - 
      E^(Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$21776) - 
      E^(Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$21777) - 
      E^(Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$21777)}}], 
   Evaluate],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.9091129975570006`*^9, 3.909113219916849*^9, 
  3.909115025816557*^9, 3.9101534280800033`*^9, 3.910156813155707*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"62a83bda-ee71-41fa-8301-c889a62a4160"]
}, Open  ]],

Cell["\<\
The computation of the density of states (DOS) can take advantage of the \
independence of different momentum sectors and can therefore be parallelized:\
\>", "Text",
 CellChangeTimes->{{3.909113016874853*^9, 
  3.909113051344655*^9}},ExpressionUUID->"f12bb32d-9e00-4dac-9f8b-\
9a3ef0b45887"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ComputeDOS", "[", 
   RowBox[{"cfH_", ",", "Npts_", ",", "Nruns_", ",", 
    RowBox[{"{", 
     RowBox[{"Emin_", ",", "Emax_"}], "}"}], ",", "dE_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"data", ",", "tot", ",", 
      RowBox[{"dimk", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"cfH", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"MovingAverage", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"Emin", ",", "Emax", ",", "dE"}], "]"}], ",", "2"}], 
          "]"}], ",", 
         RowBox[{"Total", "@", 
          RowBox[{"ParallelTable", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"HistogramList", "[", 
              RowBox[{
               RowBox[{"Flatten", "@", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"Chop", "@", 
                   RowBox[{"Eigenvalues", "[", 
                    RowBox[{"cfH", "@@", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}], ",", "dimk"}], 
                    "]"}]}], "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"Round", "[", 
                    RowBox[{"Npts", "/", "Nruns"}], "]"}]}], "}"}]}], "]"}]}],
                ",", 
               RowBox[{"{", 
                RowBox[{"Emin", ",", "Emax", ",", "dE"}], "}"}]}], "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "1", ",", "Nruns"}], "}"}], ",", 
            RowBox[{"Method", "\[Rule]", "\"\<FinestGrained\>\""}]}], 
           "]"}]}]}], "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tot", "=", 
      RowBox[{"Total", "@", 
       RowBox[{"data", "[", 
        RowBox[{"[", 
         RowBox[{";;", ",", "2"}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#1", ",", 
         RowBox[{
          RowBox[{"#2", "/", "dE"}], "/", "tot"}]}], "}"}], "&"}], "@@@", 
      "data"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[3]:=",ExpressionUUID->"365c03fd-f61f-4032-9bcf-5f728c146577"],

Cell[TextData[{
 "As stated in the paper, we compute the DOS with an energy resolution of \
0.005 (but for demonstration purposes with a smaller sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "6"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "1a68d322-8267-4258-a5e4-84cf1797833f"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "9"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "6be59342-b753-44f3-a01e-a5bb82ab9063"],
 ")"
}], "Text",
 CellChangeTimes->{{3.909113068779531*^9, 
  3.9091131190954094`*^9}},ExpressionUUID->"1bbd633c-157f-46a0-a45d-\
7b39a32bcebb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dospc", "=", 
   RowBox[{"ComputeDOS", "[", 
    RowBox[{"Hpccf", ",", 
     RowBox[{"10", "^", "6"}], ",", "32", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "8"}], "-", "0.005"}], ",", "8"}], "}"}], ",", "0.005"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091130888235645`*^9, 3.9091130961532984`*^9}, {
  3.90911413019394*^9, 3.9091141332449045`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"d553c574-e670-4b75-b2de-cad7dd597255"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"dospc", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.6); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(6\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909113125377311*^9, 3.9091131344978976`*^9}, {
  3.90911413604417*^9, 3.9091141363413095`*^9}, {3.9091150932516265`*^9, 
  3.9091150966947627`*^9}, {3.909126411615711*^9, 3.909126429281196*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"2f2de91f-e136-4ae2-8a04-14311f78bbf2"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          NCache[
           Rational[1, 180], 0.005555555555555556]], AbsoluteThickness[2], 
         LineBox[CompressedData["
1:eJxdnXfcHVWduN/ey73vvW8vwbL8WHF3WRVlWd05Fiysu6KyKrZFsbA2EMRl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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxdnXfcHVWduN/ey73vvW8vwbL8WHF3WRVlWd05Fiysu6KyKrZFsbA2EMRl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             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-8.002500000000001, 7.997499999999999}, {
             0, 0.15839999999999999`}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[
               Rational[1, 180]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-8.002500000000001, 7.997499999999999}, {
            0, 0.15839999999999999`}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{263.10663223292664`, 344.07239585016373`}, {
       51.755423390411096`, 86.64903358990615}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 180]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxdnXfcHVWduN/ey73vvW8vwbL8WHF3WRVlWd05Fiysu6KyKrZFsbA2EMRl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          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-8.002500000000001, 7.997499999999999}, {
          0, 0.15839999999999999`}}, "Frame" -> {{True, True}, {True, True}}, 
        "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
        "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
        GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[
            Rational[1, 180]], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.6); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(6\\)]\\)\"", TraditionalForm],
  PlotRange->{{-8.002500000000001, 7.997499999999999}, {
    0, 0.15839999999999999`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9091131356996164`*^9, {3.9091151092543554`*^9, 3.9091151641818786`*^9}, 
   3.9091264885492506`*^9, 3.9101535294359417`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"c34cfb51-d425-4333-95f6-5c4d3fa082c7"]
}, Open  ]],

Cell[TextData[{
 "The full data with larger sampling is stored  as ",
 StyleBox["data/DOS/dos_{8,8}-tess_T2.6.dat", "Input"],
 " and we can import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091134847660837`*^9, 3.9091134940495186`*^9}, {
  3.909113659447389*^9, 3.909113670420266*^9}, {3.9091257465881844`*^9, 
  3.909125770268137*^9}, {3.9091262842252073`*^9, 3.909126291202912*^9}, {
  3.9101535429748435`*^9, 
  3.9101535465590334`*^9}},ExpressionUUID->"1f122f01-94f2-4fab-839e-\
c603454b0f31"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<data\>\"", 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos\>\"", "Input"], 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos_{8,8}-tess_T2.6.dat\>\"", "Input"]}], "}"}], "]"}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.6); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(9\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909126193404081*^9, 3.909126208623426*^9}, 
   3.909126263048504*^9, {3.909126423755125*^9, 3.909126426329094*^9}, {
   3.910153550359743*^9, 3.9101535525745273`*^9}, {3.9101542103107257`*^9, 
   3.910154210498105*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"1c687741-654e-42b0-b299-3a6db4f577d4"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          NCache[
           Rational[1, 180], 0.005555555555555556]], AbsoluteThickness[2], 
         LineBox[CompressedData["
1:eJxE3XVYFF0bwGG6u3vFxECxm7FFscDAwC4UA0UEQQQkRZDuTgmDbjjPoq+J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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxE3XVYFF0bwGG6u3vFxECxm7FFscDAwC4UA0UEQQQkRZDuTgmDbjjPoq+J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             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-7.9975000000000005`, 7.997499999999999}, {
             0, 0.1438132}}, "Frame" -> {{True, True}, {True, True}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              PointSize[
               Rational[1, 180]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-7.9975000000000005`, 7.997499999999999}, {
            0, 0.1438132}}, "Frame" -> {{True, True}, {True, True}}, 
          "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
          "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
          GoldenRatio^(-1), "DefaultStyle" -> {
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 180]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxE3XVYFF0bwGG6u3vFxECxm7FFscDAwC4UA0UEQQQkRZDuTgmDbjjPoq+J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          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-7.9975000000000005`, 7.997499999999999}, {
          0, 0.1438132}}, "Frame" -> {{True, True}, {True, True}}, 
        "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
        "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
        GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[
            Rational[1, 180]], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.6); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(9\\)]\\)\"", TraditionalForm],
  PlotRange->{{-7.9975000000000005`, 7.997499999999999}, {0, 0.1438132}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9091262633776493`*^9, 3.9091264330125885`*^9, 3.910153555690276*^9, {
   3.910154203418597*^9, 3.9101542110394254`*^9}, 3.9101542597030473`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"8e36ac29-00c3-4f32-a9db-8e0cc8ec4a55"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the supercells", "Subsection",
 CellChangeTimes->{{3.909113688151761*^9, 
  3.909113691600689*^9}},ExpressionUUID->"03e8e79c-cffb-4f64-b870-\
a5b0c19cb800"],

Cell["\<\
The model is extended to the supercells in the sequence by translation \
symmetry, which allows us to construct the Abelian Bloch Hamiltonians on the \
supercells\
\>", "Text",
 CellChangeTimes->{{3.909114061369022*^9, 
  3.9091140880436444`*^9}},ExpressionUUID->"0fc91d85-0956-4c4c-b117-\
6bb43e0a84ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"AbelianBlochHamiltonian", "[", 
          RowBox[{
           RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
           RowBox[{"0", "&"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "&"}], ",", 
           RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "&"}], "/@", "supercells"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"7b62a3bf-6668-41bf-a804-54392f6274fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<H_{8,8}-tess_T2.6_sc-``.dat\>\"", ",", "#"}], 
           "]"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@",
    "supercells"}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
  3.910154322749093*^9, 3.9101543310279417`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"f6d2b461-3919-4b7d-a29f-efceb258919a"],

Cell[CellGroupData[{

Cell["2-Supercell", "Subsubsection",
 CellChangeTimes->{{3.9091146656978035`*^9, 
  3.909114666868931*^9}},ExpressionUUID->"8281bd5b-57f4-4f14-8c01-\
6406fab36a79"],

Cell["\<\
As a particular example, we inspect the 2-supercell Bloch Hamiltonian,:\
\>", "Text",
 CellChangeTimes->{{3.909114675347989*^9, 3.9091146946850457`*^9}, {
  3.909114782292835*^9, 3.9091147971531286`*^9}, {3.9101543965322475`*^9, 
  3.910154406621562*^9}},ExpressionUUID->"6d38ecac-6b75-4d4a-9a72-\
9cf3638e9ac8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Hscs", "[", "\"\<T3.11\>\"", "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.9091147988929253`*^9, 3.909114805876652*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"a07f4cec-2ae7-4987-9e3c-968888734acb"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "k3"}], ")"}]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "k3", "+", "k5"}], ")"}]}]], "-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "k2", "+", "k5", "+", "k6"}], ")"}]}]], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"(", 
           RowBox[{"k2", "-", "k4"}], ")"}]}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "k6"}]]}], ")"}]}]}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", "k4"}]], "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{"k1", "+", "k4"}], ")"}]}]], "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{"k2", "+", "k4"}], ")"}]}]], "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", " ", 
           RowBox[{"(", 
            RowBox[{"k2", "+", "k6"}], ")"}]}]], "-", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{"k1", "-", "k3", "+", "k4"}], ")"}]}]], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", "k5"}]], "+", 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{"k2", "+", "k3", "+", "k5", "+", "k6"}], ")"}]}]]}], 
           ")"}]}]}], ")"}]}], "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.909114812994567*^9, 3.9101543909014564`*^9},
 CellLabel->
  "Out[23]//MatrixForm=",ExpressionUUID->"af6d6038-05fe-4cfe-80d0-\
63ff2287a109"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909114427990825*^9, 
  3.909114430083145*^9}},ExpressionUUID->"5a8125a9-906f-49ba-9388-\
06fadfc45e2e"],

Cell["\<\
Increasingly better approximations of the true density of states in the \
thermodynamic limit are obtained by considering one-dimensional irreducible \
representations on increasingly larger supercells. Again, we first compile \
the expressions for the Abelian Bloch Hamiltonians to speed up the evaluation:\
\>", "Text",
 CellChangeTimes->{{3.9091144367949524`*^9, 3.909114603985526*^9}, 
   3.91015441714965*^9},ExpressionUUID->"d01eb045-6be8-4225-8b95-\
b0bd44723d24"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hsccfs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{
         RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
         RowBox[{"0", "&"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "&"}], ",", 
         RowBox[{"PCModel", "->", "pcmodel"}], ",", 
         RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091146138495903`*^9, 3.909114652753991*^9}, 
   3.909119478873217*^9, {3.910154420411165*^9, 3.910154425008809*^9}, {
   3.910163107393392*^9, 
   3.9101631087289305`*^9}},ExpressionUUID->"9a419784-bd59-45c9-bdf3-\
199c64448a76"],

Cell[TextData[{
 "Once more, we compute the DOS with an energy resolution of 0.005  and a \
sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "4"], TraditionalForm]],ExpressionUUID->
  "983ca7b5-d733-4f7c-a3f9-ed4bb5fd0224"],
 ":"
}], "Text",
 CellChangeTimes->{{3.9091148872154474`*^9, 3.909114904344953*^9}, {
  3.9101566973402805`*^9, 
  3.910156697549489*^9}},ExpressionUUID->"2b1c8500-dfcc-498f-b96b-\
390b3cf3ffc6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dosscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ComputeDOS", "[", 
        RowBox[{
         RowBox[{"Hsccfs", "[", "#", "]"}], ",", 
         RowBox[{"10", "^", "4"}], ",", "32", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], "-", "0.005"}], ",", "8"}], "}"}], ",", 
         "0.005"}], "]"}]}], "&"}], "/@", "supercells"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9091148504724855`*^9, 3.909114863025732*^9}, {
  3.9101548693475285`*^9, 3.910154869724236*^9}, {3.9101549493832054`*^9, 
  3.9101549496375976`*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"e9f06fc8-fdde-49e0-b51c-d473777b09d2"],

Cell["\<\
We plot the successively better approximations of the (normalized) density of \
states as obtained from successively larger supercells:\
\>", "Text",
 CellChangeTimes->{{3.9091258353931103`*^9, 3.9091258729641294`*^9}, {
  3.909126315654191*^9, 
  3.9091263169689493`*^9}},ExpressionUUID->"90089e1d-6a12-4649-b7d8-\
9d0249e27781"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Association", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<T2.6\>\"", "->", "dospc"}], "}"}], "]"}], ",", "dosscs"}],
     "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(4\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "7"}], "]"}], "/", "7."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091194227381277`*^9, 3.9091194385257072`*^9}, {
  3.909125701919447*^9, 3.909125705158804*^9}, {3.9091264450645742`*^9, 
  3.9091264526411266`*^9}, {3.910154999941857*^9, 3.9101550239169064`*^9}, {
  3.9101562589192905`*^9, 3.910156259119133*^9}, {3.910157116954313*^9, 
  3.9101571172428455`*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"a4530974-f78b-4741-9abe-c0ff20504da3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8990594285714286, 0.5637948571428573]], 
         LineBox[CompressedData["
1:eJxdnXfcHVWduN/ey733vW9/3wTUZbHsimv9sbpzFCurK/auKOqyVgRxWWwB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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], 
         LineBox[CompressedData["
1:eJxdnAuMneWBnmfOXM5czlzOXD3GIbitLFraldUNFWKTzjRaN6kVlewWtUs3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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.9882154285714286, 0.5505617142857142, 0.08483494285714285]], 
         LineBox[CompressedData["
1:eJxdnA2QXWdhnnfv/u/e3b13d7UrE8Wx247r1g2jaVDH44TerScOVJOJSapp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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8974812857142858, 0.3693308571428572, 0.14526651428571424`]], 
         LineBox[CompressedData["
1:eJxdnQuQXGeZnmd6Lj2XnpnunhnJsIK1kpTixFmXksUpl3ZJdygciIpaeTdO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          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.6695744285714289, 0.22438285714285722`, 0.3381279999999999]], 
         LineBox[CompressedData["
1:eJxdnQuUXVd9n2fuvN/33hlJhghi9aG6cUPVBnexHMi5YcWFarEwSd0WJ9TL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          "]]}, Annotation[#, "Charting`Private`Tag#5"]& ], 
       TagBox[{
         Hue[0.8503398874989481, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.31953685714285723`, 0.11640000000000005`, 0.4341454285714288]], 
         LineBox[CompressedData["
1:eJxdnQu0XWV5rvde+35ftw1aUws9p5SWU8tp5QwHtZ2zHdDaDIfQlnOOtJZh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          "]]}, Annotation[#, "Charting`Private`Tag#6"]& ], 
       TagBox[{
         Hue[0.08640786499873876, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxdnQmQXeV5pntfb3ffrZEdK1iamTAkTBIlsaZc2M45cZnYplIWcZgZEzsq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          "]]}, 
        Annotation[#, "Charting`Private`Tag#7"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(4\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-8.002500000000001, 7.997499999999999}, {
       0, 0.23036858974358973`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"T2.6\"", "\"T3.11\"", "\"T5.13\"", "\"T9.20\"", "\"T17.29\"", 
       "\"T33.44\"", "\"T65.78\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.8990594285714286, 0.5637948571428573]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.7397017142857143, 0.23300614285714288`]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #6}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #7}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm], ",", 
               TagBox[#6, HoldForm], ",", 
               TagBox[#7, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True", 
                 ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091194429099684`*^9, {3.909125698510269*^9, 3.9091257066406164`*^9}, 
   3.909126457110761*^9, 3.9101549712826576`*^9, {3.910155008395378*^9, 
   3.910155025671894*^9}, 3.9101562605065956`*^9, 3.9101571574389143`*^9, 
   3.910160994196726*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"5c943cb8-bc47-47b3-b1e5-2f9098c7ebac"]
}, Open  ]],

Cell[TextData[{
 "The full data is stored  as ",
 StyleBox["data/dos/dos_{8,8}-tess_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it due to the reduced \
noise:"
}], "Text",
 CellChangeTimes->{{3.9091257257973347`*^9, 3.9091257829464827`*^9}, {
  3.9091258161267524`*^9, 3.909125817972119*^9}, {3.9091263241669226`*^9, 
  3.9091263478044133`*^9}, {3.9101544811965094`*^9, 3.9101544880133915`*^9}, {
  3.9101556042258387`*^9, 
  3.910155604445711*^9}},ExpressionUUID->"a8eef5b2-fa3f-4efa-9b0e-\
83e472e2a2ca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{8,8}-tess_``.dat\>\"", ",", "#"}], "]"}]}], 
            "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.6\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(9\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "7"}], "]"}], "/", "7."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091263566114464`*^9, 3.909126393410284*^9}, {
  3.9091264603821816`*^9, 3.909126463017381*^9}, {3.9101544932422967`*^9, 
  3.910154495640236*^9}, {3.910155610950552*^9, 3.910155611196024*^9}, {
  3.9101562410776777`*^9, 3.910156285321762*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"0c167561-a667-494a-9983-facef3c816b3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8990594285714286, 0.5637948571428573]], 
         LineBox[CompressedData["
1:eJxE3XVYFF0bwGG6u3vFxECxm7FFscDAwC4UA0UEQQQkRZDuTgmDbjjPoq+J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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], 
         LineBox[CompressedData["
1:eJxE3Xc8Vu//wHF7rxu3cVttfdrR0HKUhnYqaSqJRMooSUsySsOohCQjGdl7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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.9882154285714286, 0.5505617142857142, 0.08483494285714285]], 
         LineBox[CompressedData["
1:eJxcnXVY1E3XgOluFtilLB4bCzsYCxHFwkQMLDBQMRDFxlYUEcRCRVFECenG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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8974812857142858, 0.3693308571428572, 0.14526651428571424`]], 
         LineBox[CompressedData["
1:eJxcnHVYVNvXgOnuHlDMqyKK3bGPiZ3YBXaLrdiBgYHd3aAgkkPuBXYHBigG
IIqCAtL9DbPX+s3z4T/32XeYmTPnPe85e+8VDaYvGTVLQ01NbbORmlrNf3sa
fLjsWVkP1PCf3NE7a2SJaty+neJfvmoc6JrqZfVXNXaa7JtQmKkaX/HsYfAh
XTWu+Tj5F9X41EnFv2TV2KrmA9+qxgcSCptNfqka1xxejyeq8Q7FxzneV42V
/0A19qr5wCjVuKiZ4gDDVOOaw7scpBpnKz7O+6ZqPLvm3zXVOK3mAy+qxjU/
t9kZ1bjm8AyOq8ajak7gQdX4Wc2/varxAMXpC9ypGtf8XN+tqrGSx4ZaPNbU
4rG8Fo/FtXjMrcVjRi0eU2vxmFCLh1stHsNr8RhUi0e/WjykWjy61uLRoRaP
1rV4ONfi0aQWjwa1eNSpxcO2Fg/zWjyMavHQrcVDoxaPSsf/jYUfqrHwQzUW
fqjGwg/VWPihGgs/VGPhh2os/FCNhR+qsfBDNRZ+qMbKf6AaCz9UY+GHaiz8
UI2FH6qx8EM1Fn6oxsIP1Vj4oRoLP1Rj4YdqLPxQjYUfqrHwoxaPNbV4LK/F
Y3EtHnNr8ZhRi8fUWjwm1OLhVovH8Fo8BtXi0a8WD6kWj661eHSoxaN1LR7O
tXg0qcWjQS0edWrxsK3Fw7wWD6NaPHRr8dCoxaOy7v/Gwg/VWPihGgs/VGPh
h2os/FCNhR+qsfBDNRZ+qMbCD9VY+KEaeyv9UI2V/0A1Fn6oxsKPujDwdsyp
fx8m9hR+qF4XfqjGwg/V3ws/VK8LP1Rj4YdqLPxQjYUfqrHwQzUWfqjGwo9a
PNbU4rG8Fo/FtXjMVR2/8KMWj6mq14UftXi4qV4XftTiMagWj361eEi1eHSt
xaODaiz8qMXDmb5/fk/hRy0eDVRj4YdqLPxQjYUftXgY1eKhq/p74YdqLPyo
87/jEX7UgdXbjAsKG6zoKfxQjYUfdf73fuGH6v3CD9XfCz/q/H8eyXX+P4+3
df4/j5eq9ws/VH8v/FD9vfJ/gur7hR+q14UfqteFH6rXhR+qsfBD9f3CD9X7
hR91/j+P46rXhR+q9ws/VH8v/KDXtwseW+l1L8FjQy0ea1R/L/yoxWNxLR5z
VZ8n/FCNhR+q9ws/6oC7bJZrwfqdPYUfdWD/n7ALxQ82ox+q9ws/VMcj/KDX
fQQPSfV+4QeNDwgeHVTvF36oXhd+qF4Xfqg+T/hRB9r2s/qb23Y/+qEaCz9U
xyP8qANb5R5PVq04JHgYqV4Xfqg+X/ih+jzhhwOOz6EfDrBgWGTdlS+P9myn
9EP1uvDDAT//FPrh8L/fJ/yg919FPxzA7bvZ0uXNT6IfqrHww+F/xy/8UL0u
/HDA83VF8Liv+n7hhwPoJe7pEHH2Ys91Sj9Ufy/8cIAmZmDr+e08+uEAFWc7
Tes4+DL6ofo84YfqdeGHA3ys6poSMvoG+kHHewn9oN9/Af1Q/X7hhwP08Jp7
b6n3GfSDvs8f/XAA+bSeE9pMDkA/HCCjnW9w+2vX0A8HvH6vCx7L6fNuoR8O
MPhb/QXj2t5BPxzg5eMf2u3U/dEP+j0h6Aedj9vohwNEHrjkdCw8BP2g8xeK
fjhAs16NM992DUc/6Hgi0A/6vij0Q/V+JY+uqu8Xfqi+T/jhAPPqjhlqtpKj
H6rPE344wN6Yka8OLYxCPxzgVdmg98cnAfrhADmdNslHnItDP1R/L/wgXgno
B10v8eiHA+TNTd8VVnIP/XCAc401vHZY30U/7PH6j0M/7OFQTsBl7bv30A97
yJ6d5X29AtAPe7AzSDLpn30X/bDH8/cA/bCHnVETnm/3fIB+2MP1Zv82XTJ+
in7Y4/VzH/1QvS78sIfyhYn7X+c+Qz/s0ZfH6Ic9Xk/P0Q97MP+wrlvi0cfo
hz18ae0QWO/WK/TDHobdCT2r9vYF+mEPf+fM2RlY9gb9sIfTjXas2WT7Gv2w
hzYrK2KG+b5BP+yh/ao1cWP2vUU/7GFo6pmFU1snoh/2YPBWt1Pc6UT0g87H
e/TDHq+HRPTDHozfbet8/+Q79IPOxzv0wx4y2xuGdruShH7Ywzpv7WJNxyT0
g85HMvphD4lPv+j1qvyMftjDxh1bSgzqfEQ/7OF3h51hvS99RD/s4e6RQ62C
Az+hH/awevR//524/xX9oPP7Gf2wRx9T0A97iPM3sUr8lop+2MOocr1xpyem
oh/20Hyi1WuDOWnohz3MHhJvPycxFf1Q/L4hm07Pf5OGftiDZmS9wV7L09EP
e+h9a8Cxz5+/ox/2sPXCnzTX/pnoB52vDPTDHormf9pztyAT/bCHFfPrGkLh
T/TDHq42XbXxtOkv9MMekjIG5W9omo1+2EOq+u1vj4b+RT/swd9p8RY/wz/o
hwycnILUrhllox8ycG7eQiPA4C/6IYP7R03aRN76g37IIMo9amLniTnohwwq
/PLeDJ2ei37IoKPv3Ot7InPRDxk0GTJ9YsboPPRDBkapPW6lBP1DP2SQ2ub4
7Sb+/9APGeSvlFUlGhegHzK8/vLRDxlMMOj08uGCAvRDBpoBsz5Mn1yEfsig
8/bmHdZdKEQ/ZNA34N7x75+K0A8ZXl+l6IcM0ptM6GFzsBj9kIG78c3ElFll
6IcMDn/oEvP+SBn6IYPKtfpaudoV6IcMuFeTfiu3V6IfMjj1Y057zWuV6IcM
PDv36OJ2thr9kEG5u8whKrka/ZDB5oiMR0tWqTHhhwzyvLzCx59WY8IPGfSK
+3p382Y1JvxQ/L5j8dMd+6gz4YcMLCv+O1E/WYMJP2SwyOPZkHqemkz4IYPr
/fs0mPJQkwk/ZBCxwbcsy1qHCT9k0MxV/ZL7Ay0m/JBBRpeFC6GNNhN+KPge
3JDl2F6HCT8Uf9/N1WXgbV0m/JBBQ/utu9aW6zHhhwxMXzXcLBnpM+GHDMZl
zWuhE6rPhB8yfH4aMOGHaiz8kMGBJ5qu8k2GTPghg7v7w1Y2aWTMhB8yqFce
mhHRx4QJP2RQveLG4AVrTJnwg86fGRN+KN7fa2+DQffNmPBDBuyO37DpC8yZ
8EMGR7xv317pZ86EHzL4sHeOs0+wheBRaQfVTTcV77e3FDxK7CBxTVJZkqWl
4JFvB2HrLUu/21oJHn/t4NaH9BUD6lsJHpmK1/Ndpx/ubyN4pNvBZb/MCRPH
2QgeX+zAbovRmgJ7G8Ej2Q70om2H7VpiK3i8tYOkFfl9Jm23Ezxe2oEB29pi
TIid4PHEDnKead2N3CETPO7bweIH83Y1r5AJHmAHLaGlSd08e8Ejyg5WfloR
lXbCQfAIswO3N2v7vNpZV/AIsoNH9cY+Nl9fV/C4aQfvhw/8adyrnuBxzQ5C
EtIPumTXEzwu2kHGYM1TM97WFzzO2EHAjfj2RvUaCB7H7SD0rl/9Ea4NBI+D
duCx3OSc/tCGgsdeO9hw5c3J++8aCh477cB1T9KzBzkNBY+tdrDwzA215bsa
oR92MDp0WavWzo3RDzvY5T0xMSa9MfphB2t6u+2w2fgf+qH4/W/udYPDTdAP
O/i+eMHsXXFN0A87MHd3fdN4TlP0ww6OrziyLVmrGfphB1N2S4WmDZ3QDztw
HNDsYWCVE/qhON991t2cGd4c/bCDmwWLd6ZudEY/7KDti6/be2u1QD/swPbc
cZ99a1uiH3YwP3PM6AGZLdEPO3hnbLWm6XkX9MMObrfp07PP4Vbohx3UX7v3
uOWE1uiHHTidft7zt0Eb9MMOTC0qO4ROboN+2OF8qQ36YQfTAn+PnDKrLfph
B73M99itsmuHftjBx/aTHM32tUM/7GDAoHrTfg5uj34ovs/ov79Gge3RD1t4
WK/c9HzzDuiHLRybfD+tk3cH9MMWXm9b2mTyxo7ohy0Uy58sjg/oiH7YwsUv
P0c3/N4J/bAFncDUpHkTO6MftvChRar9r7Fd0A9bGNq/6415MV3QD1voUH3O
xD6oK/phC987D27cwrsb+mELoTZBLvLW3dEPW6ienOz/uKQ7+qF4/5FNbwp/
9UA/bCHjuXOmLu+JftjCuOKNEw7UYeiHLYy6tHmAfScJ/bCFfoEZX9fsktAP
W/BYmzXuaJLEUpV+2MIVi8wpOgG90A9bsOrbOf6QTm/0wxbKmjVyUdvXG/2w
hfmahtHb2vVhz5V+2MID99ANG1/0QT9sYXe3Zsve9OuLftjCzAFaJ0fL+6If
ttD10yHD7aP7oR+2sD6xIFn9Qz/0wxZ89Rqsswvrj37YwtmeeaMuaLuiH7bQ
fUL91vcNB6AftmCkdW2N+ukB6IctzJNHmGv/GoB+2MKC7g1zX7cYhH7Ygubc
nJ9Lzg5ivko/bOH6sYDCfr0Hox+20LsieP6D8UPQD8X5nDLL4tTjIeiHLYTP
6Ta4w/ih6Ict2O6e2WjB3GHohy3Ytxlvk9d7OPqhuL72+roXNBmBftjCqseH
qxufHIF+KK6fT7Ob32s0UvBoYAuGyW/fGi8ZiX7YQl4s77WucCT6YQsbzTfm
txg1Cv1Q8PdoB9rJowQPI1u4Fp218BEbjX7YQvugvmMX/RmNfthCTOdjdeoc
dEM/bGDhsaf9f1a4oR82EPJwzCrDxWPQDxuYdLZ4onOHseiHDRh01O8yKHIs
+mED6fKzD5dNHod+2MDAZW6PJ+mPRz9soKLlYO+EO+PRDxvo8/xAc59xE9AP
G1g2INRl08sJgsdLG1Cf6DfW+tVE9MMGek/Usz0+fBL6YQODbPZ0ffFoEvph
A9bf3K383k1GP2zAUeNS9KadU9APG3i1fnnj7v2noh828CZv55hlWtPQDxuY
qvWhyTR7d/RDcTw5r2bvmeiOftjA7wiD2Alf3NEPG/C2nvI8d4wH+qE4vkGu
R0aCB/phAzcmzl7Yp/509MMGPuma7m5zfjr6YQOjvmbK7mjPQD9s4LWv86nl
R2egHzZQcKOEN2o+E/1QHH/Y2x9XzsxEP2zgkJXr2zLzWeiHDTRcpe6T/WUW
+mEDV1be/hvy32z0wwbaX/FJG/N+NvphA4sWOmTt3DAH/bCBO8cnrxtTdy76
YQPdPJe/nLZvLvphA82/D+ph2Hse+mED90u89AoS56EfNvDwtklH54Pz0Q8b
CHiYNDOz3QL0wwbKhjVtfyVjAfphAzsGbzAd6rsQ/bCBn28CS7p3WIR+KK4/
l8eTVxgvRj9sYPiGdW0nXlqMftiAtpVv6zvnlqAfNrBe/l0+uqsn+qG4PqJb
bMk56Il+2MDqBkb/5mktRT8U1/M4m2O7Fy5FP2zAqxnMXvJ1KfphA5s7TI8f
33UZ+mENsxNaFeZfW4Z+WIPZgm4R9o2Wox/W0Ox1JxOPi8vRD2vQnzP589h6
K9APa2j4+2Skw/kV6Ic1LB+VH3Sz8Ur0wxqm9v2P+4auRD+sYcxYl9sRzVah
H9bgc0Y2vuHNVeiHNRhOv7BgmrQa/bCGRj3KNxclr0Y/rGHwDNMBddesQT+s
4faKXY9n/VnDxP6uNRz7F5YwfPVa9MMajrzfPsHYxQv9sIbJajwrKcCLZSn9
sIZ1lVc6eIxdh34ojj9owJT1DuvZN6Uf1vDs0KCEl4/Xox/WUN7Fn81ZvYG9
V/phDfb2w7WWOm5EP6xheodjQR0fbMT5lTXoha7Q/rRrE/phDcYnUwuHN9mM
fljDB+t2CZ+2bWbdlX5Yw4Pdt1dZ/dyMflhDv8ZuUdqTt7C2Sj+s4fydVslr
gragHwpehmbu2XZbWTOlH9bg2aB907drtqIf1uBxQmPX0j9b0Q9r+Jr4Y2C6
xzZ2UumHNTw+1OXY6nfb0A9raDK4eHvHQdvZfqUf1tDpll8Lg+jt6Ic15PSY
vCzFyZttV/phDentNu5IueONflhDx6cGv9Va7hA8uiq+74RbI/9rO9APa3g+
4fyyITY70Q9rWHhUW37/4k7Bw9kafk3rZH6pwS70wxrW+5d+WxC3S/BoYA23
LjpmT+28G/1QfP/vSb1cnu0WPGytwfHDK9u9k3zQD2vo83lkwMsfPji/soZH
7RwneW/bg35Yw8bWXecfs96LflhDxPrHC55E7RU8Kq2g+Ky17o7p+9APK/iU
Zn/+cdU+wSPfCn4372z78ch+9MMK2gbtT985yFfwyLSC1tCz68oMX/TDCm6u
fzlge/8D6IcVZF3r4ph07IDgkWwFem9H3ksqOYB+WAEPb9RrysCDgsdLK2g8
uJfFyOsH0Q8rKLwyZP5czUOCx30rUPt4Qfo15hD6YQWn7IOfqj87hH5YwbGg
T0YpTQ6jH1YwTXe5+5ddh9EPK3id+Kmsb+lh9MMKTAtGfNox8gj6YQVf2uaN
38CPoB9WcNr8yMF5jY6iH1bwZ/OB19d8j6IfVjDubvuEg0VH0Q8r8PT4vGb1
zGPohxUUTJx57ETCMfTDCgZ9uL56SOfj6IcVLCw6/f1S2HH0wwrA23ns3fYn
0A8r6OS2N7/TxRPoh+L7LnZ66mBzEv2wgi2T0x5pHjyJfljBFbcES6/Kk+iH
Ffz3T675atsp9MMKWm7eHrNW+zT6YQWOXd7I7NaeRj+soOdPS8dk9TPohxU0
KgsrTNx0Bv2wAqf14SYmRWfQDytIrFtv1849Z9EPK5D7bklVNziHfljB2PHT
LHftO4d+KPgv/lt60/w8+qF4f0+jGfEh59EPKyiNSfNztb+AfljBgdBZBj9n
XkA/FNdLxK+XG69cQD+sYKe7Yeu0vAvohxU0+JrjIUkX0Q8rOHuC5fbefhH9
sIJ03bMPbj2/iH5YwSJoY92i3iX0wwp634nyipp2Cf2whPezA4LVIi6hH5Yw
p8Hg1j9KLqEfitftZLtXDr+MflhCC3jj5n/+MvphCQff263onXkZ/bCEaMWn
+/e8gn5YwvO9j+LDfa+gH5bAxnjrTE++gn5YwrJUaYBN66vohyXcvGGY0GT9
VfTDEkpC175Zk3QV/bCEylNFX5xcrqEfljBxQrb0c9M19MMSftWdMsnl9TX0
wxKGywY+q6x3Hf1QfL+FtI5tuo5+WELDlcdCe7y7jn5YwqLd6hGHW95APyxh
9cNYt4feN9APS8j91tTkwtcb6IclOHeOqd+wgx/6YQl7Hq+STdjnh35YQvmC
uZENf/oxV6UflqC3Y3rqR+aPflhC55j7cxNO+6MflnAi5XnJjGp/9MMSmhyf
OChvyE30wxLkfe5Ofxt2E/2whAWWTYu7Wd1CPyyhcVjhmgczbqEfltBvWWb6
gbu30A9LaDrJMv5v8wD0wxLa9Vtyfcb2APTDEvr229NwYmoA+qHgr/mjweie
geiHJWhkbTW8ezAQ/bCE8+8f6S+uDkQ/LCFlsP3llW630Q9LsMvcNHVK1G30
wxIcgzv9PGYUhH5YwqX9SZ1vdQ1CPxQ8O8xo4TIvCP2whMx2F77sPRWEflgC
DCrIrHgShH5Ygua01wEfCoLQD0tYqbc64ZrTHfRDcf3c1v17euwd9MMSRl8f
+mOezx3BQ1dxPa9vWJAUfQf9sASbwEun/mTcQT8sQKv9pLtj7YPRDwuwuqA+
or5rMPphAb4ny1o9WBWMfijGGn3j9/oFox8WkFlh9XDLh2D0wwIOvP1pukwz
BP2wAMu78+r0axOCfije3+6fo5FHCPphAfKa7c0DIeiHBeyWTo29/TAE/bCA
x8HRpzUKQtAPCxg0J/pskmMo+mEBTmPHDS8eHIp+WEDMI7/eN1aHoh8W0ORE
/WSLG6HohwV8VT8X6pkcin5YwNP9maUuamHohwUYHJmaYd86DP2wgMlNHG/m
jAtDPyxgkdqn2S99wtAPxecNe6g3NCIM/bCAyA77K1+nhKEfFuC6XzY00Sgc
/bCAdgmbn5ztGY5+WICHa8svyXPD0Q8LmNBASnU9EI5+WED8YRuXm0Hh6IcF
nJFVzu2cEY5+WMCCkPLzxgYR6IcFbFi4Jf9Epwj0Q/H3MwvH950agX4ojsdr
ZPQ07wj0wwKaqt9vNORWBPphAe/Uw2K3JkegHxbwo/nSNWcqI9APC2i0wPhq
UUM5+mEBM3f+nPRugBz9sIDfam8GHF0mRz8sYOuLap0BvnL0wwJWf23TvShE
jn5YgMaby8MykuXohwUc32C8+nuVHP2wgCedPqWccIxEPyxgsXlsG7/+keiH
BViXabvfmBuJfljAi6EZVe03RaIfiuv7e+7fRecj0Q8LaH8ptFNJQiT6YQFD
Esd+0kyPRD8swKtvtynPtKPQD3PI/xje5assCv0wh8HDOp1a1DkK/TCHq3Mz
prqPjUI/zCGn/qprr9ZGoR/msGNETr7TwSj0wxyOOHtYJPpHoR/mMP1SL4Nz
CVHohzk87LSk+HlSFPphDoYPVtsNzItCP8yheFpvd8kgGv0wh0HyA66ejaLR
D3Po82S4/4au0eiHORw69fo36x+NfpjD4nkf569zj2aFSj/MIbpn7IyEtdHo
hzkEvrplPntTNPphDjszai6AaPTDHB707bKzwY1o9MMcHBdkDekfFY1+mMP7
h32+fn4SjX6Yg7dZVqbl22j0Q/F5oTUb4tHohzmkB/n62WRHox+K4/eN3da3
Ohr9MIcCp/DOMsMY1kPph+L3rFnbdZxVDPphDvNajxsxvUEM+mEOY0bGPPnY
JAb9MIfdzStkX1rEoB/mEDXwzgB5hxj0wxzeuvNndTrFoB/m+PyKQT/MYVqD
2H/zB8WgH4rff/PWIh/XGPTDHAaeL7cNGBCDfpjDjblFPnLF3ws/zCFmQEXG
32Ex6Ic5/Km8WPBtYAz6YQ6vPWSrlg+JETw6mINFzIPE44r3Cz/MYf7EWMfr
fWLQD8Xv//BFY6ZiLPxQHH/Avjk7FGPhhzlYaT7+9lxx/MIPc3jC9vfa2iMG
/TCHRjOqd5xqG4N+mMOKnZofnv4Xg34ojueonlt1/Rj0wxyya8Izshj0wxzO
dExv39caeVSawY91/Ru210AeJWYQ4qj30aUqGv0wg4wbhyIscqPRDzPIjFa7
0CotGv0wg3XfZgSlKa4P4YcZ7Mnucj73UTT6YQajJ/nO6R4ejX6YwZyPVUeP
XotGP8zgwzOzDS3PRaMfZjBxTEabyJ3khxnMe7bp8hpP8sMMXI5afDaZS36Y
gW/U3pH7hpIfZrBs49qIuZ3IDzPoUDDc805D8sMMxnlZbEg3Iz/MwIT9Na9f
GoV+mIG+dGjAwawo9MMMLi4uXxv4JAr9MIMrrxM7hkZEoR9mYDF8VbvL56PQ
DzNQr7l97opCP8wg4eDp7rA4Cv0wA41HXLHCiEI/zMB5yPbgo92j0A8zcOqZ
PudRXbxfrTGDWT3X7TbSwfvVcjNIXBIFUlYk+mEGtk1nNPj6JBL9UPwem2Fv
Ku5Eoh9msEbjZvvlhyLRDzOIf2nZ/PDKSPTDDAx6xpxtNz4S/TCD7U5Lsjd2
jUQ/zGDasj9jVtaPRD/MoHGToc1+6USiH2ZQbn/YdE8aPT/MoCTLr7X5E3p+
mMHltIF17gbI0Q8zGOV9ar3JTnp+mMH+VSm50fPo+WEGD1PCtq8fQc8PM9Bd
2spL7iJHP8zgagePsdsM5eiHGVSdWPenZ3YE+qEYd/TKCn4RgX6YQUHEsEVR
tyPQDzMwdpmjFrk/Av0wg1077t9YsCgC/TAD+Zwhq/cNiRDHX2YK83bqh3q3
iWBLao431xRuxvZ0GmgcwWbVHN8PU+jZcPCe81nhbFLN8aSYwuEqzZFnHoWz
mp+T9doUPOqVLJ91E+cPD03Bz2GbX7wvzhdiTUHrvfurkhU4PwgxBZOjBybo
jgwXPG+YwvGDXsMz2oezujX8zpnCwnzFgtYunFnW8DpiCn2bHu1qURrG9Gv4
+JiCU/jWa/+9D2PVNf82mUJu0gq/cAgT53+lKaxa6+Tc/VwY+11zgAtM4dWg
iXnG3jhf8jCFoJrp6CycH40zhRHgsDpnaBh7WnP+hpjC76PBRktbhLH4mg/s
bQpPC3INflmHsYiaC6yzKeTHdeuzNT+UBdT8YBdTsFhfd2vBl1BW83EfGpmC
+4R5owyiQsX1J1N8foHBmHWXQsX1ZmoKafp28uO+oeL60jaFPpkXBndegfPD
MhOoNHcekDQ5FHmYQLzR+nKnvqHIwwRGPr3/4kmLUORhAvPPHH9rbxWKPEyA
DR96eEZFCPIwAT3uOCX8ZwjyMIGild7p5xJDkIcJrNjsvt+RhyAPE7h1IcQm
KDAEeZjAqJQh39ocD0EeJvDa5eiiY1tCkIcJtIm8Vbf+8hDkYQJH55e5dp0a
gjwU47gFziNHhiAPE+haP7CXVq8Q5GECsxfHmX9uF4I8TOA/24A/nRqHIA8T
+K6zz9/TOgR5mEDC9S5rD+qHIA8TqL6/oVCjMhh5KI7n9iO32TnByMMEro6b
OrQ0Kxh5mMCPmT3MQj8HIw8T+PW7ndE9xfpA8DCBp17rGrg8CUYexnBQR73P
hXvByMMY7h4sKmwLwcjDGLilid2m8GDkYQy7fZouNYoIRh7GMOW9yYG1gcHI
wxiODrh0fOStYORhDAY+XnU8buF6JsQYxmXsXeZ1A9cvN4zhTfz5HVaKseBh
DO4lb/5reS0YeRhD6JLDRTevBiMPYxjVe0xeluLzBA9jGFZQ2qyR4vsFD2OY
Ie+qlqYYCx7GIP2za9U0OBh5GIPP9ZoJQjDyMIbD8/u+c4sORh7G0Fq+592e
B8HIwxgeDvT4kv4sGHkozke9R3uOPScexjB3YEdjKZl4GEO1wUnnbb+JhzH0
8rs1eWoO8TCGs7cvR3coIx7G0OecZZtPWiHIwwiCJ3zft9UmBHkYgffJ8E2z
/gtBHkYg89dd6qO4ngQPIxi7yenGUMX1JngYgUaDy0PrDSY/jKDx8lXr788k
P4xEPG0l+WEEAT1c2cqd5IcRqGn22mx0lvwwgk0LD9XLu0l+GMH8eZbPejwm
P4yg/+n0lCYp5IcRPPi4vf6tLPLDCJw36UUv0w1FHkYwTRlvCkUeiuM7fPbR
5zahyMMIdJMuuTcYFoo8jGBdbHl67PxQ5GEEevJ1VvpbQpGHERTbN20OZ+h+
ZQT3Vjw4YxRC9ysj6Dtug77nO7pfGUGLHTc16/+l+5URTFb39irTC0Meivff
LCq70jgMeRiCs07Vtdn9wpCHIdzek31k/Iww5GEI6s8WfPqxPgx5GMKwc8Gn
Aq+HIQ9DqHl6F0eHIQ9D0D54YXRWUhjyMASD8lUW5lVhyMMQ9qY7zBpfn54f
hmC2urB52670/DCE/lPf39OYRs8PQ2i8zik1cFs48jAEE3WHBR8vhCMPQ/iS
2PpDZVw4K1DyMAToM/LC8O/hyMMQPB1P/HFTrF8FD0N4VO2yodQFn8fjDMFV
I3i9xlB8/g4xhE8fnqp5LI1AHoYwqkVEqP2hCORhCGfOjnUICI1AHorzEX1i
dtSHCORhCDbzds5cVBLBTih5GMLEc7diCxzkyMMQvG+7xXSUcH2rbQgDg5p6
XvTA+UiZAcy7nzLx6W6cf+QawOrtax5fuSlHHgbQO/LRCZtXcuRhAIV9wnvs
yZEjDwPo0bwqZ5dBJOuv5GEAXO52taVLJPIwgOSNbR/snBCJPAzgh9enId5r
cH52wwB2Jw4MjzqD87FzBhBpdbHhidBI5GEA3dOyHth8jkQeBnBm1d4dP9Wi
kIcBeP+q7zasfhTyMICCWOem/btFIQ8DMD/r9nvATJy/ehhA58jtmWEbcb46
zgACNMzeBJ7F+ekQAxgTf+PKMIhCHgYw8PncwnrpUcjDAG6/cyzqrR6NPAzA
0/Xwj9+K+fQlJQ8DqFv63ESjezTyMIA3r055dZ6M83lTA1j+PHGJtRfO37UN
YFz7vUtDT+J8vUwfRuzrHnb+Ds7Pc/VhveOfx8avopGHPmiWtVv2LDMaeeiD
yfDbR2bpxSAPfbAHtTkv6sUgD30w9KgJkMUgD324aNj+l9ooXF+G6EOr80VX
Hy3A9eQNfXj99HlK5i5cP57TB98BT55FX4hBHvpwOqEm4TQGeehDi40l5zq+
jEEe+vDbr17G0rQY5KEP7Q2rHsUVxiAPfbhVp9r/kXEs8tCHsXFzGvduFIs8
9EHnzKCbDzrFIg99GOL14tlWFos8FN/388yvJaNjkYc+7OjyI9VvYSzy0IfC
c0uCUlbHIg99mNnwanL3/bHIQx/k/QoeXDkVizz0wb3jYEu1gFjkoQ+O97v8
zpTHIg892Mz6+1jExSIPPbhr+PCE++dY5KEHu+qE79r2NRZ56MGRrMm6sX9i
kYce9H7wJzUlNxZ56EHz0Ut3TVGLQx56sPG/rKct9eKQhx7M6rhoQZB1HPLQ
gxb55ZetZHHIQw98yhZr5TeIQx56ENXn7f4WzeOQhx583LhvU5liLHgoxmk8
Y2zLOOShB0P3Oe927RGHPPSgOtvV51HrOOShB3bvGl460T0OeejBJZ/XTht7
xyEPPeixe4b8aJc45KF4f89d+qYsDnkofs/JbeWTB8QhDz0Y88B+t7Pi/YKH
HqTsGGnWvWcc8tCDcf0bnR+n+D7BQw+WWr9b2KpdHPLQg4wOs6YcUnyf4KEL
b2JPrP7RKg556EJsQMHHhS3ikIcujN3xLLesaRzy0AVHueKGYheHPHSh4YCc
WdmK8yt46MIfnxWn3C2Jhy7UP581trkm8dCFw+usV7zXIB660KV5p5GD82OR
hy5kPevReH1OLPLQBb8rwyTL1FjkoQsDDtV8QCzy0IURNdPt+7HIQxeSV//u
OPReLPLQhXFHG547GEB+6MKLuO6B4y6RH7rQe+29fWqHyQ9dUNu3OttoDfmh
C6ccpzaIXUZ+6MK3vYVztT3ID134b932Uw3GkB+K11dmj/XuTn7oQnlJ12mX
WpMfuvC6W1T45IaxIh9AWxdkQ4w3tjCJFfkYZTrw1bZ7Xq8C3N/J1YGEmunn
b9zP+aEDE59kdjz+GvdvUnRgY9DPB8PjcL/mtQ5o/X0b0fRyjIh/PdSB5Rd2
fuy4F/djYnXgxuq8jSkbY0R+RIgOtF05blW8e4zIh7ihAzHXY+YsHk73Kx0w
iZ1voN8D97eO6MBNx3djmjTA/SwfHTBssdlJUxf3rzbrwFGLrWMK/0WL/dyV
OnC9sn5KYCruhyzQgdZLTxUE3I8W+SIeOuB8etudlwHRIj9knA7Yh915NOsQ
7v8N0YELYQcvyrxwv6+3DjT9fOyR9pxosX/RWQfCLn/e5z8Y949cdGCJ6c8d
g9vhflEjHei/cHb6an3cH5Ipjm/u4/R5pVEiX8NU8X0jPzqsT41CHjqQJtu4
Zf7zKOShDWNKkjR+3olCHtowVu4zP/w47uf80Ib79/Y0n7sJ929StGHQm4/J
FTNxv+a1Nhjt73RuhWsU8tAGM8u79951wv2YWG1QK/j9ZqVtFPLQhhRj14pW
FZHIQxv2Pn795ukXep5rQ+TKTsNXPsL9lCPacPfGxPj/wnH/xEcbhl0DucGJ
SOShDcP78vCNXpHIQxs+fU12jPWIRB7aYOPaKnR7/0jkoQ2tS9o3bdU2Enlo
Q93ulqca2+D++BBtuDRw+sDIcjny0IaFdWevnftLjjy0oVerlMjWb+TIQxtO
zWQ/pkbLkYc2fM9p9nXDeTny0IaAMTbfbHbKkYc2fJ3ePnXoIjny0IYbG5z+
fZwkRx5a0O71+9Xt+9L8SgvyO37a8tUZ93N+KF4vWnLDyRL3b1K0IMpOM6tz
Fe7XvNaCsz8SZS+ycH/moRbcbNvbpali/id4aMHigeNn5cZHIA8tyG43Z8OT
OxHIQwu6a98eEngC4yXntOChX5v1570xPnJECxJyJ8WxJRgP8dGCjteWRhpO
jUAeWjA6/viaosERyEML5s6Or5fcKQJ5aEH9oSMclzaKQB5a8Ch/hX6abQTy
0IJtTdNfdNOi+a4WTOA9v0b/w3hRby0YEbnGpfdPjA911oKATQ0KMz9gPMhF
C5IXL+3T+0k48tCCHe9MOkB0OPLQAree00xs/MKRhxZMe9Yt3/Z8OPLQAuN9
Tbd29g1HHpowL63ut4F7wpGHJji917oVtCIceWiCzky3OKMF4chDEzZqVeXm
K9YHgocmpBf6fz02gfavNGFVr3Y9t44MRx6acDNj+eHYQeHIQxNCndOPfuwV
jjw04djsYf82dgpHHprgtmXgt/ttwpGHJsw8dDAkqGk48tCExr2mDDzeKBx5
aMKIviudZtYNRx6a0GrXgKHRduHIQxPyPI/9OWcbjjw0YY/GhobDLcKRhyYM
bjPyhYdeOPLQhAjtoxp1jIiHJvyOaZB514R4aMKQYYdGf9MnHprQWT31XG99
4qEJvdvM/bBcj3hoQreVGSHdTYmHJlxdP6qThxHxUJw/bxk/ak48NOC09se6
o4yIhwaYvt43JseaeGhAfLfSgiQb4qEB6//0XLjfjnhoQL+bA6+VyoiHBkSu
qvx8rBHx0AAP+x2+u5yIhwbsP7++9dfWxEMDjl/tnTq+O/HQgEYZn10bS8RD
A/Z5r3deNIR4KL5//gjfR6OIhwaEP5x9acb0cFyfa8ArtWYHGs0hHhrwsnXY
VZNlxEMDuj2fcm2LF/HQgIsH46r77QgX+YRDFH+///aJhceJhwaAZ8nfC5eJ
hwY0cMlx97pDPDQgZWDfEtt44qEBDhMyuyS9Jh4aUPyxYT3/r8RDA65buPV5
/Y94aECX16N3j6siHurgX1PeZBaBPNRBzynxrnPjCOShDi2bp6041DICeaiD
eZsl9TT70P1KHfq1ZYf+jKP7lTosXNytkdpiul+pQ5sBZaE+G+l+pQ4FvXMD
5x2h+5U6HCz9VJp8me5X6uBZ5Xmxeyzdr9TBxFG9049XdL9Shx6mf198/EP3
K3U4OyK9S3hpBPJQh+oO81+ussH99AXqMO7GpoljFfdfwUPx+YPezi5mcuSh
DlJCa/fHY+TIQx0mLP8kU/ek54c6HBrxy8bTm54f6mA2OUN/+1l6fqjDMD/1
LrZh9PxQhy/b2yTdfU7PD3Xwcjlbv/w3PT/UIVSK7uOjHok81MHH7+TESXUj
kYcarDF9taFLu0jkoQaD6i/R3DUkEnmowanNUSnRHhg/TlGDo+sPrvy8GePF
r9Xgu27JpnrnMT78UA0Cng0aeD8sEnmowfP3QUd3vIpEHmowfuypI1v/0vNc
DbwGBvTy08X47jk1CNcofXSmLsZzjyjG03b9GNwlCnmoQepAw+NjxkchD8Xn
108v8lwchTzU4PTci4HV26OQhxqsfer1/uOFKOShBgmOi9OYPAp5qMGFvl3/
Fb2PQh5qMLltkqNuDsaLeqtB65rHtyHNr9TAMc/e364uza/UYM9jB/cf3Wh+
pQYRRSdNSsbR/EoN6vTvlVuyKhp5qMHPUepntu2NRh5qoPn6cFu/izg/LKzm
3PVS9xORGC9OreZbNps1HvQe53/PqvlQLfd/hVl4PPJq3uCB2dXpehifvVzN
7Rc0DtRrhPFW32o+I/LquwOdMX7qVc2vDuqi1W4wzp9nV3PLI9kNj03F+fLI
av7i2qMHzVbger5HNY+8lTB78x5cvzer5mWbpTlvruH816qaR12ZH60fh/Nd
tWo+TvZBf+0LXI9nVfGYeI+QRWkYT/1QxXdkrKg6VIrx0YQqXv/C2BbJRrHi
fAZWcV2PxcXL6sWK/OKTVTzu5fW+j1rh+tm7ivdNvjrOSsL1smcV/xrWNSds
bKy4PidX8dSFTu+nzYoV80vXKu43rZ3B4eWxYr3Vrop3Nph4aOg2XF85VvGl
fjkXfx2MFdeXQRUfM2TQj8orseJ6KqzkZV2jJl2+jeul1Eru6DmlTaMYXB89
q+Qj7++b9OxlLPKo5Ov27CyukxSLPCr5hwtvNfdkxgr+vpX8gGm9DZ3/4Prf
q5KzQGPr9IpY5FHJJ21ZP/OFSRzyqOTuK3f7FijGyp/bo5Jf7dbTzNQW14vN
KnnKgl45+xTrdcGjkltt3zHhbv045FHJD480mKbVNk74kFXB+8WsrPrTFtff
Hyq4emqf3ccU62PBo4KbRX2tSFWspwWPCt523lkN/4Fx4no+WcG93cfEVgzD
9bN3BS9+4nFm5ghcL3tW8OqpBqanpsQhjwp+91LDYU0nxIn7g2sFt4UjWzQn
4vq3XQVfduOrd8AE3H9wrOCh9zc9DVC8LnhUcOX+6/g45FHOF9bXCPk5DvcT
Usv54tjBihkE7h88K+d/j33fPGVoHPIo5/vej3ynNTJO7GdeLufflo2oq6M4
fsGjnNftffRUjxG4/vcq5zr/Dnbp1jMOeZRzp8F6d/b3JB7l3C+ph+P5DsSj
nIt6GeJRzvt+H347x5F4lHO9lh/fTKhDPMp5UHSruk7mxKOMX/CoH6ehSzzK
+NfWq+YcqoxFHmV8ku6t+At55EcZ13UeFmbzIxZ5lPGgW+2dtD+TH2X8ZOqp
YyFvyI8y3ty5u+OvBPKjjLf0MX4GEbHIo4wvDerUpvF18qOM/0hJGWZ+jPwo
4ycKdZeE7iI/yni7jD4jOniRH6U888nYoQ/mkB+lfGNNOtIE8qOU7/NquU+L
kR+lvFfdfnv3KXwWPEp5+if3oQZ25Ecp/6tt+Oy2IflRyi8M+TP2WyHdr0r5
kNReIVlf6H5Vyje1dLtc8RjX8z1K+arVJQ8WRNL9qpS/nfqrAb9M96tS3rvR
huo9e+l+pfj+oY/s5i3HfJGsEq7Md5tA96sS/rpgUR2jEXS/KuGHvmwZbN4c
82UCS3hOaqfmKbaY/3KyhNfT8XsSUI37r96K1x/f7R3wC/dbPUt40eiaAlHM
/5lcwvv3+PXrUTjm87iW8CG3m22OPYv5IO1K+HTd7Xs7bsD8DscSvollvTq/
EPM1DEr42VcdPleMwPyLwmJ+vP/Wacnd6PlRzLfXGXRZLqPnRzEPruT9tmrR
86OYdz6pkd78WxTyKOblkRVpAS9wP8C3mB/YFHS2S1gU8ijmS/0nrj5xGtf7
s4u5hk/2l4wNuL4fWcy91h41052J6/kexbyfTLvO2WGY39WsmPeKtGjSpiU+
362KufaF066mxvg8Vyvmk5MLxlqW4Xo8q4i7fDN4bp+K+WofiniPAcMP9rmH
+WcJRbxVk+yDMX6YnxFYxF/ZnVk96ijmW5ws4sOHdvbfvQLzJ7yL+PFhHe4l
TMT5jmcR1w8utcyl/LjJRbx1n5a23ZxxPuNaxG+UvmSzjTC+0K6I93vPD3gV
yJFHES8+3Kbnsy9y5FHE11vpq7s9w/yLwkKeWrD7uEYA5lOkFvK/18PqfT0i
Rx6FvM7tjK5t1+F8T17Iy51+xTSYK0cehTwgSSs2ZQjGW3wLeVLI3rUJnTC+
4lXI+76f+UG3Ea73ZxfytKKo8jfmcuRRyHsNHhe0rwTnxz0K+aFJhxcP/o75
j80U3/9levvU5zj/tSrkm+YVZSyNxfmuWiGfUQWG5tdwPZ5VwHNnBzfOOIzx
pg8FPMxzgvfzzZjPkVDA3cpGF7xeHoE8CvhLr96wwAPzJ08W8LaGA8Ymj4pA
HgV8z84zMzK643rAs4AnDinu6tcK5/+TC/jQ1fuGrGqI833XAr7w66E3Dc0j
kEcBT0r6zz9CB+fzjgV86+3M9wvKcD1loHi/cXKG2g9cPxXm8/5nhgW/ywhH
Hvm8ze/q+BbJuF59ls+X1qlbMe8RrofkiteTE+d1hnDkkc8v7Jvc6WpMOPLI
54OHPrsXFxiOPPL56vTOgxvfwvXl7HzuUv2gz/YruJ4cmc8PtFndssF5XD/2
yOdZl9qa+p/D+GGzfL4wZ/SYuRdwfWiVz49NPb3v6AlcD6rl88e3tjXTOo7r
v6x/vItL+jWdU+HI4x+vt33zev2juL5L+MddKnNPNDmI67nAf3yaRUJV/2O4
fjv5j68/nPsi62Q48vjHfy1q+Gv3WVwve/7jQ9dXtx59BdfHk//xwOQng6uu
43rY9R/vHt2g7Ug/zKdp94/Lbq8dMycM17uO//h8ucXT1VHE4x9/WbTPbTsQ
jzze+XiLzs+fEY88/muLb7xPIvHI46G7loXs/kw88vjx1a1jx+cTjzxu/mB4
+pcK4pHHq+SV/x4bYD6RVx7Xu9dhV307XF/OzuOugadHTXXG9eTIPL768ItV
3dqQH3m8l1N19ZX+5Ecef+q8vmHBePIjj9+fuk0WOI/8yON/0rL3Xt1IfuTy
P5f6dNP4nx+5PPA/F/NIf/Ijl6eq9TW0v0d+5PKI7LB+Pd+SH7k8rqZ8No/8
yOWi/wPu73nm8qtOQ5xKG+J+3uRcfjlozyXdnnLkkcvHNGSvnd3kyCOXe7B6
sGEN3a9yue0ITQ+NQ3S/yuWjzlzev/+mHOfrOdxQrW+Q+2u52O9PyOHytelX
WufIxf79yRzevonJ74UWkSK+7pnDx97r++W5C8ZnXXN4WGnjOvVGRYr4t2MO
7z4q6YLPqkgRjyj8yze/KfxV9zDunz77y++muj9xiI5Enn+5u+4L2ciPkcjv
L1+8dN/LmdWRIr4y8i+fEvtW5vQfPU/+8i7+uwsODsJ4bfUffi1xmlvxIoy/
fvjDlw+xKa53MkrEJwL/cK+qCSeax0bh+f3DTXava7EhM0rEcyb/4Rk3EzvV
M6bn7x++flH2I9de0SLeYvCH3zcOXGIzi56v2bzfYMfhT32jRTxEns3Hna4e
VzcS47G+2XypbEvC72SMr87O5qeSe2d116b1VTafXhT8J7QDzU+yua3LzSCZ
O62fsrj3Nrs+R3xiGCh5ZPEzvyK/zYmIQR5Z3D5/+5KbvzE+4pnFr84r9Dpj
gvFA1yxetrfs468esayOkkcWHzv1+I4d8zE+VPibjz7PHhmfovnab37myjn/
n49p/fKbOzWoPB3zv/XKb155ecmb9s3i2Aglj9/8vdbIYvUBNP/9zQPdbhrM
3UDz3d989fF33vP8aH77i9sVdHmz4nUcu6Xk8YsfO/o0q6UBRx6/eP922g1M
23G8vn/x8S4GS09P48jjF58bYBzl5MOZnpLHL5793/qraWEceWTy92/nNruS
xfF+kcnPHW/1VscIkEcmr1u0d3+hI7CZSh6ZvPjU2uc67QF5ZPL2rx5MKhkM
yCOTp10aaBczFZDHT+42MPDWxlWAPH7yQ21PrAzbA8jjJy+4szTE5Qogj5+8
zeePa2bLAXn85E3ndjYIewrI4yef0MJ3U9BnQB4/+MER+6dU5gPy+MGdtLde
naYbL+Jpl3/whdvby/rax7M1ygP8wXXPvX+k7xKPPH5w7SZNprr1ikceP/ib
n1X9nEfFI48fnJ+3b/V5ZjzyyOBj1Xp/DFsejzwy+BnfBxWdfOKRRwafYiNP
rXMqHnlkcMeo34M334xHHhk875l1jnl0PPLI4HciQ517voxHHt+52VPDMe8/
xSOP79xGvmPG9V/xyOM719mqJutaFI88vvOPXywPnNZJQB7f+cyoBTODLROQ
x3f+4cdE06h6CcgjnbuWVdnKXBKQRzpf49jE+VXnBOSRzpcVf9n+c1AC8kjn
Nit7JW0fnoA80nnhwUFzbMYlII90vvWd67GtMxOQRxr/yz7MeLggAXmkcf+s
Ux9nLE9AHmm8T8XczzfXJSCPNJ7WOm3IlG0JyCONf0/Uu3TYJwF5pHHl/vTB
BOSRxuNTOi+fcCwBeaTyFrcM7nY8kYA8Unn58Stt759JQB6pPNF9pqX/1QTk
kcptYvYte3cxAXmk8rbnisO+X09AHqn8kvXyBS0VY8HjG997zWRo+8sJyOMb
P3djUovyKwnI4xt/X8/DLkgxFjy+cb55qnz5ReLxja/98uHQ+XPE4xtv3uvj
xKizCeyt8vi/8iDPTi3rKo5/s/J4v/Lr0f2bdFP83tbK4/vKlz93cdq1h47n
C5etGVj8QnG+9iq//wvXsn0VFKs4n52V3/eFWx1xTdHzTGCZSt6f+bmvP/ro
zCW+n/nAY58/W7knsL5Knp/55L5LhviPTGC5yhOewo+1cjzyo18Cu6DklcLH
x0e+utae+KTw87J5wzSdiUcKD9/vfnJRXTr/n3jHrL05ewwT2Hjl+f7Ez+Sf
9WtQTtf7J/6p6+GDJr/p+v7IJf2Gva6/p+v5I3fLffLdJz6emSnP10f+t1VN
wDcer9dkvijv67Kbx+Lx+kzmmu2Otu+wKR6vx2T+8E9qiue8ePZIef0l8W3H
ZiaquZH/Sdzn1sePc7qS70l8z6jeQf6O8cjjA58VcPHtVK145PGBW90v7LLr
JyCPDzzE4LS6yyNAHu+5f8122E1AHu+53vibq4buAuTxnpc5zww0mg/I4x1v
F2j578wAuv+945P2dUzK+A+Qxzsu6m8BebzlLgHOhk/vcXy+vOUfw7ctDF3N
2TjlCXzLvcIrU8+25UxbyeMtf/S6zoTSjDgWouSRyEfsrymoi2MeSh6JPPu1
QcLT3nHMVMkjkY89fta3Jl8iVsnjDTexNB6VeySWLVDyeMPPx9cEJGOZvZLH
G75lsWOP9mkx7JGSx2t+PdH6YcqBGLZKyeM1X+EU2LzcJYY1VvJ4zd3OTFBf
8SKavVHyeMVjIkcfNV8WzTYrebziNi4jiq+ZRDMXJY9X/PLwwpXN/aOYXHn8
L7nesIcBh/sq1r/K433JK71eHjJXrG89lcf3gs84utpr0HLF/Eh5PM95cLQ0
cIt2JHNSfv9zbnb5/W+Pc3Lmrfy+Z/y25dCx5c3lLE3J+yl/7vDsqU5cBBMN
557yYOc387YOjWCnlDyfcJFvHM6KlPwe88mpGiuXzFesT5S8HnOdFpE+93PC
WKCSzyN+aoPj5e7Lw5iBkscj3vRkTUO2MDZbef4f8sehB/u77wxlCcrz/YDv
bdHTX0cnlNVTnt8H/AYbO/jothC2Tnk+7/N6Ll3+HjEJYR+U5+8ePxlos//9
zmDWTnm+7vHdkTUbysHMV3m93uXRk+fF5Wy/w7KU12cC/3rkxvO/1UFsgPJ6
TOCuKQGrpq4IYleU118832vd4cSO1NtMNJAGvsynnfPmF4FssvL6Aj5vUMVp
j9AA5qk8fs4fLx0S3SPgFmumPN44PtPgfefT+2+yVOXxxfAVFTopfkv82Snl
8URz28fGK03c/Ngo5fdH8fu5Dy8bdLjBDJTfJ+cNi2UxbubXWYKSdwSf+t+8
AU3yrjIvJd9w/jxyiZneyyusnZJnGO/gsDLu1/XLLFvJL4Sfq1vzgL3Erih5
BfOJnatnBYy7yCYr+dzh0wtd7XRaXGBWSh5B/Iv/geMfi8+yE8rzG8C9S1ap
Z1w9zfSUAR5/3sDH0s+rz0m2Rvn7b/ARU3l07pdjLFN5fV3l2U/qZmtuOsLG
K6+Xy9xx6gPNzbJD7JmS/wXexFbvuv9KX7ZZFORw442v317c7cPcRUMZ3v3Z
UJ9+Cd5MEgU5vF7DTV4bijczSbmBv5v3nBPvdaj5GqZWv+YHb+QuhWleT+ov
Ymq2NSd8Jr8Qe56vnD+aqVkox4zGm5ULiI3sf3+v5Lub0eddUF6/Bxl9H4gC
IUbH8005oT/D6HjXi9/D6Pfoid/L6PeeEOeD0floJs4Xo/MlV15//ozO5wBx
vhmd7yTl+uM2Ix7tBS9GvNYLnox43hO8GfE2EtcDo+vBTVwvjK6XM+J6YnQ9
pSnvp3JG11szcT0yuh49xfXK6HqVi+uZ0fUsGq7HMbreBwgfGPkwQPjCyJds
5fcBI58OCN8Y+dZe+MjIxyThKyNf1wufGflcT/jOyPcEcT9gdD+YLe4XjO4X
BuJ+wuh+EijuN4zuN6PE/YjR/ahIyeMho/vVKXE/Y3Q/6ynud4zud2nifsjo
frhD3C8Z3S+bi/spo/vpC3G/ZXS/XSbux4zuxzbifs3ofh0l7ueM7udTxf2e
0f1eQzwPGD0PronnBaPnxX/iecLoebJKPG8YPW8eiucRo+eRTDyvGD2vFojn
GaPnWax43jF63pmK5yGj56GHeF4yel6GiOcpo+eptnjeMnrejhPPY0bPYz/x
vGb0vC5X8khk9DwfKp73jJ7358V8gNF8IE/MFxjNF/qI+QSj+cRRMd9gNN/4
KeYjjOYjXcR8hdF8ZY+YzzCaz3wW8x1G851WYj7EaD60RcyXGM2XEsV8itF8
SvBIYjTfEjySGM3HBI8kRvM1wSOZ0XxO8EhmNN8TPJIZzQcFj4+M5ouCx0dG
80nB4yOj+abg8YnRfFTw+MRovip4fGI0nxU8PjGa7woeKYzmw4JHCqP5suCR
wmg+LXh8ZjTfFjw+M5qPCx6fGc3XBY8vjObzgscXRvN9weMLo/WA4PGV0XpB
8PjKaD0heHxltN6wEOsRRusRXK8wWq/geobRekbMb78xWu+Ei/UQo/XQF7Fe
YrRewvUUo/WUmD+nMlpvTRTrMUbrsa1ivcZovYbrOUbrOTE/T2W03qtS8khl
tB5sItaLjNaLuJ5ktJ7E9Saj9SauRxmtR5+I9Sqj9SquZxmtZ3G9y2i9i+th
RuvhxWK9zGi9jOtpRutpXG8zWm/jepzRelzw+M5ovY7reUbreVzvM1rvCx7f
Ge0HCB7fGe0XCB7fGe0n4H4Do/0GwSOD0X6E4JHBaL9C8MhgtJ+B+x2M9jve
if0QRvshgkcGo/2SpmI/hdF+Cu63MNpvwf0YRvsxF8V+DaP9GsHjB6P9nHyx
38Novwf3gxjtB/UT+0WM9osEj5+M9pOOi/0mRvtNuB/FaD/ql9ivYrRfJXhk
MtrP6ib2uxjtd+F+GKP9sH1iv4zRfpngkcloP+2r2G9jtN+G+3GM9uPaiP06
Rvt1gscvRvt528R+H6P9PtwPZLQfKHj8YrRfKHj8YrSfKHj8ZrTfiPuRjPYj
14r9Skb7lcKP34z2MwWP34z2OwWP34z2Q3G/lNF+qeCRxWg/VfDIYrTfKnhk
MdqPxf1aRvu1gkcWo/1cwSOb0X6v4JHNaD9Y8MhmtF8seGQz2k8WPLIZ7TcL
HtmM9qMFjz+M9qsFjz+M9rMFjz+M9rsFjz+M9sMFjz+M9ssFjz+M9tMFjz+M
9tsFj7+M9uMFj7+M9usFj7+M9vMFj7+M9vsFj7+M4gGCx19G8QLBI4dRPEHw
yGEUbxA8chjFIwSPHEbxCsEjh1E8Q/DIYRTvEPv7uYziIRgvYRQvwXgKo3iK
uF/mMoq3iPhBLqN4DMZrGMVrMJ7DKJ4j7qe5jOI9Ij6RyygehPEiRvEijCcx
iieJ+20uo3iTiH8oxhiPwngVo3gVxrMYxbPE/TiPUbxLxFfyGMXDRLwij1G8
DONpjOJpGG9jFG8TPPMYxeNEPCSPUbwO43mM4nkY72MU7xPPpzxG8UDB4x+j
eCHGExnFEzHeyCjeKHj8YxSPFDz+MYpXYjyTUTwT452M4p2Cxz9G8VDB4x+j
eCnGUxnFUzHeyijeKnj8YxSPFTz+MYrXYjyXUTwX472M4r2CRz6jeLDgkc8o
XozxZEbxZIw3M4o3YzyaUTxa8MhnFK8WPPIZxbMx3s0o3o3xcEbxcMEjn1G8
XPAoYBRPx3g7o3g7xuMZxeMFjwJG8XrBQ/F+jOdjvJ9RvB/zARjlAwgeBYzy
BQSPAkb5BJhvwCjfAPMRGOUjCB4FjPIVBI8CRvkMmO/AKN8B8yEY5UMIHoWM
8iUEj0JG+RSYb8Eo3wLzMRjlY2C+BqN8DcGjkFE+h+BRyCjfA/NBGOWDYL4I
o3wRwaOQUT6J4FHEKN8E81EY5aNgvgqjfBXBo4hRPovgUcQo3wXzYRjlw2C+
DKN8GcGjiFE+jeBRxCjfBvNxGOXjYL4Oo3wdwaOIUT6P4FHEKN8H84EY5QNh
vhCjfCHBo5hRPpHgUcwo3wjzkRjlI2G+EqN8JcGjmFE+k+BRzCjfSfAoZpQP
hflSjPKlMJ+KUT6V4FHMKN9K8ChhlI+F+VqM8rUwn4tRPpfgUcIo30vwKGGU
D4b5YozyxTCfjFE+meBRwijfTPBQvI75aJivxihfDfPZGOWzCR4ljPLdBI8S
RvlwmC/HKF8O8+kY5dMJHqWM8u0Ej1JG+XiYr8coXw/z+Rjl8wkepYzy/QSP
Ukb5gIJHKaN8QcwnZJRPiPmGjPINBY9SRvmIgkcZo3xFzGdklM+I+Y6M8h0F
jzJG+ZCCRxmjfEnMp2SUT4n5lozyLQWPMkb5mIJHGaN8TcznZJTPifmejPI9
BY8yRvmggofi8zBfFPNJGeWTYr4po3xTwaOcUT6q4FHOKF8V81kZ5bNiviuj
fFfBo5xRPqzgUc4oX1bwKGeUT4v5tozybTEfl1E+ruBRzihfV/CoYJTPi/m+
jPJ9MR+YUT6w4FHBKF9Y8KhglE+M+caM8o0xH5lRPrLgUcEoX1nwqGCUz4z5
zozynTEfmlE+tOBRwShfWvCoYJRPjfnWjPKtMR+bUT624FHJKF9b8KhklM+N
+d6M8r0xH5xRPrjgUckoX1zkx1QyyifHfHNG+eaYj84oHx3z1RnlqwselYzy
2QWPKkb57pgPzygfHvPlGeXLCx5VjPLpBY8qRvn2mI/PKB8f8/UZ5esLHlWM
8vkFjypG+f5YD8CoHgDrBRjVC2A9AaN6AsGjilG9AdYjMKpHwHoFRvUKWM/A
qJ5B8KhmVO+A9RCM6iGwXoJRvQTWUzCqpxA8qhnVW2A9BqN6DKzXYFSvgfUc
jOo5BI9qRvUeoh5dTaJ6EKwXkaheBOtJJKonEf051CSqN8F6FInqUbBeRaJ6
FaxnkaieRdTnqUlU7yLqv9UkqofBehmJ6mWwnkaiehqst5Go3gbrcSSqx8F6
HYnqdbCeR6J6Hqz3kajep5moB5KoHgjrhSSqF8J6IonqibDeSKJ6I6xHkqge
CeuVJKpXwnomieqZsN5JononL1EPJVE9lOChLlG9FNZTSVRPhfVWEtVbCR7q
EtVjYb2WRPVaWM8lUT0X1ntJVO8leKhLVA8meKhLVC+G9WQS1ZNhvZlE9WZY
jyZRPRrWq0lUr4b1bBLVs2G9m0T1blgPJ1E9nOChLlG9HNbTSVRPh/V2EtXb
YT2eRPV4WK8nUb0e1vNJVM+H9X4S1fstFfWAEtUDYr2gRPWCO0Q9oUT1hAdE
vaFE9YanRD2iRPWIWK8oUb0i1jNKVM8YKeodJap3vCvqISWqh8R6SYnqJZNE
PaVE9ZRpot5SonrLbFGPKVE9pqif1ZCoXhPrOSWq5zQU9Z4S1Xtai3pQiepB
64l6UYnqRZuLelKJ6knbi3pTiepNe4p6VInqUUV9vYZE9apYzypRPesUUe8q
Ub3rHFEPK1E9rOChIVG9LNbTSlRPK3hoSlRvK3hoSlSPK3hoSlSvi/W8EtXz
Yr2vRPW+goemRPXAgoemRPXCgoemRPXEgoemRPXGgoemRPXIgoemRPXKWM8s
UT0z1jtLVO8seGhKVA8teGhKVC8teGhKVE8teGhKVG8teGhKVI8teGhKVK8t
eGhKVM+N9d4S1XsLHpoS1YMLHpoS1YsLHpoS1ZNjvblE9eaCh5ZE9eiCh5ZE
9eqCh5ZE9exY7y5RvfttUQ8vUT284KElUb284KElUT294KElUb294KElUT2+
4KElUb2+4KElUT0/1vtLVO+P/QAk6gcgeGhJ1C9A8NCSqJ+A4KElUb8BwUNL
on4EgoeWRP0KBA8tifoZCB5aEvU7wH4IEvVDEDy0JOqXIHhoSdRPQfDQkqjf
AvZjkKgfg+ChLVG/BsFDW6J+DoKHtkT9HrAfhET9IAQPbYn6RQge2hL1kxA8
tCXqNyF4aEvUj0Lw0JaoX4XgoS1RPwvBQ1uifhfYD0OifhjYL0OifhmCh7ZE
/TQED22J+m0IHtoS9eMQPLQl6tcheGhL1M9D8NCWqN8H9gORqB8I9guRqF+I
4KEtUT8RwUNbon4jgoe2RP1IsF+JRP1KBA8difqZCB46EvU7ETx0JOqHgv1S
JOqXInjoSNRPRfDQkajfiuChI1E/FsFDR6J+LYKH4vuwn4vgoSNRvxfBQ0ei
fjDYL0aifjHqop+MRP1kBA8difrNCB46EvWjETx0JOpXg/1sJOpnI3joSNTv
RvDQkagfDvbLkahfDvbTkaifjuChI1G/HcFDR6J+PIKHjkT9erCfj0T9fAQP
XYn6/QgeuhL1AxI8dCXqFyR46ErUT0jw0JWo35DgoXgd+xEJHroS9SsSPHQl
6mckeOhK1O9I8NCVqB+S4KErUb8kwUNXon5KgoeuRP2WBA9difoxCR66EvVr
Ejx0JernJHjoStTvSfDQlagflOChK1G/KMFDV6J+UoKHrkT9pgQPXYn6UQke
uhL1qxI8dCXqZyV46ErU70rw0JOoH5bgoSdRvyzBQ0+iflqCh55E/bYEDz2J
+nEJHnoS9esSPPQk6ucleOhJ1O9L8NCTqB+Y4KEnUb8wwUPxfuwnJnjoSdRv
TPDQk6gfmeChGGO/MsFDT6J+ZoKHnkT9zgQPPYn6oQkeehL1SxM8FL8H+6kJ
HnoS9VsTPPSkD+X7VtX0YxM8FMcbFrOspl+b4KEnUT83wUNPon5vgoeeRP3g
BA99ifrFCR76EvWTEzz0Jeo3939dnXWclPXah0lhJ3Y6l46VEumU8QtIuKBI
dyqNSLPSUksp3SDC4YA0KEjoi0gKBrEoIIpSgqQICAfh+A7P9779fc7sf/fn
mb6eS4fZ2fsijyToPjrySILuqyOPJOg+O/JIgu67I48k6D488kiC7ssjjyTo
Pj3ySILu2yOPJOg+PvJIgu7rI4/4/ck+P/JIgu77I48k6D5A8kiC7gskjyTo
PkHySILuGySPJOg+QvJIgu4rJI8k6D5D8kiC7jskjyToPkTySILuSyQPG3Sf
InnYoPsWycMG3cdIHjbovkbysEH3OZKHDbrvkTxs0H2Q5GGD7ovkvgobdJ8k
edig+ybJwwbdR0keNui+SvKwQfdZkocNuu+SPGzQfZjkYYPuyyQPG3SfJnnY
oPs2ycMG3cdJHjbovs6mFg8bdJ8nedig+z7JwwbdB0oeNui+UPKwQfeJkocd
um+UPOzQfaTkYYfuK/23xcMO3WdKHnbovlPysEP3oZKHHbovlTzs0H2q5GGH
7lslDzt0Hyt52KH7WsnDDt3nSh526L5X8rBD98GShx26L5Y87NB9suRhh+6b
JQ87dB8tedih+2rJww7dZ0sedui+W/KIvx6yD5c87NB9ueRhh+7TJQ87dN8u
eTig+3jJwwHd10seDug+X/JwQPf9kkf8+rIPmDwc0H3B5OGA7hMmDwd03zB5
OKD7iMnDAd1XTB4O3Ks69NMOUendDHZg3ss9Ugfm2io8HNB9yOThgO5LJg8H
dJ8yeTig+5bJwwHdx0weDui+ZvJwQPc5k0f88cm+Z/JwQPdBk4cDui+aPBzQ
fdLk4YDumyYPB3QfNXk4ofuqycMJ3WdNHk7ovmvycEL3YZOHE7ovmzyc0H3a
5OGE7tsmDyd0Hzd5OKH7usnDCd3nTR5O6L5v8nBC94GThxO6L5w8nNB94uTh
hO4bJw8ndB85eTih+8rJwwndZ04eTui+c/JwQvehk4cTui+dPJzQferkEX89
ZN86eTih+9jJwwnd104eydB97uSRDN33Th7J0H3w5JEM3RdPHsnQffLkkQzd
N08eydB99OSRDN1XTx7J0H325JEM3XdPHsnQffjkkQzdl08e8Vn26ZNH/PHI
vn3ySIbu4yePZOi+fvJIhu7zJ49k6L5/8kiG9gDIIxnaCyCPZGhPgDySob0B
8kiG9gjIIxnaKyCPZGjPgDxc0N4BebigPQTycEF7CeThgvYUyMMF7S2Qhwva
YyAPF7TXQB4uaM+BPOK3L70H8nBBexDk4YL2IsjDBe1JkIcL2psgDxe0R0Ee
Lmivgjxc0J4FebigvQvycEF7GOThgvYyyMMF7WmQhwva2yAPF7THQR4uaK+D
PFzQngd5uKC9D+v1yuaG9kDYK3RDeyHs4bqhPRHpjUB7I9b71ZAb2iOxPm/O
E5+lV8KeuxvaM7E+f051Q3sn7Pm6oT0U6/GWcUN7KexxuaE9FfaC3dDeivRY
oD0W6/yq44b2WqzP39Pc0J4Le/duaO/F+jy+mRvag2Hv2A3txVj8OrihPRnp
zUB7M9bnLT3c0B6N9flqXze0V2PxHeiG9mys30eku6G9G/ac3dAejsVjrBva
y2HP0w3t6bAX7Yb2dqTHA+3xWDzmu6G9Hv75kBva87F4LHdDez8Wj1VuaA+I
vev485FekMVjsxvaE2Kvzg3tDbGn7Yb2iKRXBO0VWTwOuKE9I4vHETe0d8Te
vRvaQ7J4nHRDe0nsHbuhPSWLxzk3tLckPSZoj8nicdUN7TVZPG65oT0ni8dd
N7T3ZPF46Ib2oNhzdkN7UfTDA+1J0Q8PtDdFPzzQHpX0qqC9Kvrhgfas6IcH
2ruiHx5oD4t+eKC9LPrhgfa06IcH2tuiHx5oj4t+xB+P9Lrohwfa86IfHmjv
i354oD0w+uGB9sKs/54180B7YvTDA+2N0Q8PtEcmvTJor4y9cQ+0Z0Y/PNDe
Gf3wQHto9MMD7aXRj/jzl54a/fBAe2v0wwPtsdEPD7TXJj03aM+NfnigvTf6
4YH24OiHB9qLs/57uir+/KUnRz/itye9Ofrhgfbo6IcH2qujHx5oz45+xJ+P
9O7oR/zxSw+PfnigvTz64YH29CweJz3Q3h798EB7fPTDA+31Sc8P2vNjb9wD
7f3RDw+0B0g/PNBeIP3wQHuC9MMD7Q3SDy+0R0g/vNBeIf3wQnuG0juE9g7p
hxfaQ6QfXmgvkX54oT1Fi0eqF9pbpB9eaI+RfnihvUbpOUJ7jvTDC+090g8v
tAdJP7zQXiT98EJ7kvTDC+1N0g8vtEdJP7zQXiX98EJ7ltK7hPYu6YcX2sOk
H15oL5N+xC8vPU364YX2NumHF9rjpB9eaK+TfnihPU/6EX880vuUHii0B0o/
vNBeKP3wQnui9MML7Y3SDy+0R0o/vNBeKf2I3570TKV3Cu2d0g8vtIdKP7zQ
Xir98EJ7qvTDC+2t0g8vtMdKP7zQXiv98EJ7rvTDC+29Sg8W2oOlH15oL5Z+
xK8vPVn6EZ+lN0s/vNAeLf2In9/Sq6UfPmjPln74oL1b+uGD9nCllwvt5dIP
H7SnSz980N4u/fBBe7z0wwft9dIPH7TnSz980N6v9IChPeARlh8+aC+Yfvig
PWH64YP2hq33v2k+aI+YfvigveKg5YcP2jOmHz5o79j68+QOPmgPWXrJ0F4y
31/5oD1l+uGD9pbphw/aY95l+eGD9prphw/ac95v+eGD9p7phw/ag/7W8sMH
7UVLTxrak6YfPmhv2nr/vcQH7VHTDx+0V93D8sMH7VnTDx+0dz3A8sMH7WFL
Lxvay7Z47PJBe9r0I85Tetv0wwftcVs8jsTPH+l10w8ftOdt8Tjpg/a+6Uf8
/qUHbvE454P2wqUnDu2J8/2VD9obpx/x81l65PQjzl965RaPhz5oz5x+xI9L
79zikc0P7aFLLx3aS7d4OPzQnrr01qG9dfrhh/bYLR55/NBeO/3wQ3vuFo9U
P7T3Tj/80B68xaOMH9qLl548tCdPP/zQ3jz98EN79PQjfn3p1dMPP7RnTz/8
0N49/fAjdsWX70zWJeKHH/mqnoiE314sfvjBv79dLH74UfSPHdmPjVskfvix
stle37AnC8UPP95pd+HL7DMXih9+tFxe+auU4ELxw4/Kzabdrbx8gfjhx574
vy72VVggfvjR58/Fl1Zsmy9++JF2avXQhlXmix9+3Iv/c3bB3nnihx/9Ov+U
PvSNeeJH/P72Vdg788+54ocfN8fMOL5q+lzxw4/FnjkzexaeK374ca7cnVYj
P58jfvjhuvfa2YmN54gffhzPPPvopf/MFj/86JhrYKdzk2aLH37M23zW8WPq
bPHDj0XRj77K+vUs8cOPLD98gN+azxI//Li/smGvHtlniR9+FGlQ09t49Uzx
I36+fFK4ZvuXZ4ofcf4nG+8//XCG+OHH9VVV852eN0P88GPdiKP1x9edIX74
UWZPrNrgy9PFDz/KbX7vYkbadPHDj2slqoR+mPOe+OHH2QvRZYf/+6744ceD
pYFcE7u8K34EsH3E4d5Hdk0TPwIYVaZar3mBaeJHAF+Wz9d2wrip4kcAtX9q
vOHor1PEjwDynToWmtZ2ivgRwMVrbWuW/nqy+BHA+uX5bnSoMln8CGDE2v/8
0nv3JPEjgN86VvasKDhJ/Aigz9ycOw4szxA/Avim9bIBDYMZ4kcAPy9oVnjt
qoniRwCVvrJdy/LcRPEjfv/lR038ccsE8SOA2zXaDfix+ATxI4DK69eUsn06
XvwIILXBg/GV0saLHwEcnlV13tDvxokf8fvL/PXli53HiR8BdF6QbVL/m2PF
jwD6Fazw7Mn0sfz8qG8Abru7043wWPEjgGVbnj+Tvvkd8SOAOkWa7crZ7h3x
I4CDkzcN8V8ZI34EcCpQfu/ZcWPEjwCcC8/fb5Q6RvwIIPfWQTnPThotfgTQ
5emvxw6OEj8CiEYb5eifb5T4EcBfVde+2H3oSPEjgK9npe09eniE+BHAwM31
249IGSF+BDD8ycqKnVsMFz8CaJfl8+unNwwTPwKY8/341s7Sw8SPAOb9sW1v
o6Fvix8BbBo06XDXm+niRwANXnfVz5ueLn4EULjGX2P+PDNU/AjA3uWD3h0x
VPwIYMqSSKtC64aIHwE0b1F60/ZiQ8SPADq8VPTz6VsHix/xx9/k7uZ1RQaL
HwEUurZwZ8qyQeRxK4Ck7u1+apF/kPgRQLHjlZM7Lx8ofsR59a6+PVp4oPgR
QLe9z9+/u2qA+BHEmIpdvmhVbYD4EcSwYnu6vfVzf/EjiLYtg/Mm9+kvfgQx
tKDjj545+osfQaR9Wuqd2zP7iR9BjNhxaUfTav3EjyBy+qeX2fL+W+JHEI1G
Di/XZkVf8SOIj0sfbjfI2Vf8COLKiY0PX6j4pvgRxMQGI12vTO8jfgTx6NVn
K6y83Fv8CGLDodNvXC3fW/wI4tCm5EolZ/YSP4I48HBY7nuZPcWPIEpcSqth
r9VT/Aiier+BRzu+20P8CGLL/HbDm+ftIX4E8WaflOsZI7uLH0FUWDnlQvPv
u4kfQawcvOnWx0W7iR9BFBqSdcqNc13FjyBm+eudfOTpKn4EcWzbyV9XLnlD
/Aji3ocPPy9c4g3xI4jj00suGjj3dfEjiCY/X41syfm6+BHE2VyuyWWXdRE/
gviwTbc+tQt0ET+CqJVWb07jPZ3FjyAmBNp/83vzzuJHENe22/6v9blO4kcQ
A24f6za1TSfxI4gOVj+zk/gRxIk7Gc0H5OgofsQf/4iBRV6o20H8CCJfthWf
js5oL34EEfilk3/Nd+3Ej/j5EZxa7dsv24of8cfXJndofqO24kcQWdusaRE4
1kb8iD+e+ltLjz7aWvwIovY3M0pMadla/Aji8XMNJuzd0kr8COLlAc0Ot01q
JX4EcXHH0kMD2rUUP4KwVUqqmrazhfgRP5+XPmhTsmIL8SN+/h1qPsTet7n4
EUSfeV/VvfK4mfgRwmdV5uXJM7OZ+BFChc0vtXjzZlPxI4RVn17v8+WLTcWP
EFp2Lr8n55km4kcIozyj7pZq0kT8CPH3afcbix8h2M+cPOl8q7H4EcKps91K
7C/cWPwIYcjh2X8XWfia+BEC/17mNfEjhGjZVsE7tRqJHyGEJr9RuHePV/l5
O0L4pHv1BhVbvSJ+hNCkfVfvosMNxY8Qaj3+qNfBVg3FjxBWz9twv06tBuJH
CNl73L7y1tI08SOE3i8U+v14qTTxI4SeO7Z7cv5WX/wIwZFjVXrWxfXFjxBe
aF2gzAF7ffEjhKWxO00+yFlP/Ahheu6Cw8Pb6vL3EekhjMi8dybrqTriRwjV
zs6yj29aR/wI4Y36ORY23fGS+BHC5OrFBpyo85L4EcLBTltHjvq2tvgRQq/s
9k/Hla8tfoTwqFjh0lnerSV+hOB/qcoXs56pJX6EsNJ7tf0zG2qKHyF0fvt6
y7mnIX6EUGfj5Z/TJ0H8iL+eK8bUj1aG+BHn/2BU6xl5XhQ/Qrj8TcmruT6P
kceeECrOGX3i/m81xI8Q/m53Zu3hhy+IHyFsDW4uvaPMC+JHCJeqNChSakJ1
8SN+/b/fT45uriZ+hPBK3Wof9vysqvgRP39KnY/+1qKq+BHCMxvPn+7Zpor4
EcLyc1eaFrpUWfwI4cGOI32/2FBJ/IifX+P6p7YbVYk8HoYwr92BC5UnVBQ/
QjiU/y/XshIVxY8wijuK3nJsrCB+hFE/LX/HKw0qiB9h/FChbT73u+XFjzBq
eqaGh4TLix9hdNx4rXH7ruXEjzByZ06tuH1pWfEjDJf3ScWt7cqKH/H7W/xN
7JqtrPgRRoG3p833tS4jfoSxqWztWO3Zz4sfYXzn9Kc/u6y0+BFGr6vNm9a/
+pz4EUbo/flT3n37OfEjjHLf/jy+Vo5S4kcY6+71zTg/qqT4EUbf2sPXvfFJ
CfEjjHz1ix3a+N/i4kcY7SfjvqtQcfEjjPmD5ow7k6OY+BGGp1O9E0W6Pyt+
hHGpb+9uk3anih9hPHdif/U9s1PFjzDSazWbGBxVVPwIY9KENpmfXSwifoTR
dOuA58uULCJ+hNFnyYdZBk4qLH6EUW/q6a8P3i4kfoQxcuWJhQe+KyR+hNF5
YPL7Sa8UEj/C2LpvTYHX6hUUP8LY8OEXFRz5C4ofYVxukH3R6ycLiB9hfLz3
4szSN/KLH2F83+jlK86a+cWPML7M3+KwZ0Re8SOMZk//PDQjr/gRxuCzg3Zd
WJAifsSf/57nkvPeiYof8df7YM9JJR5HxI8wbn+dY9/OiRHxIwzbi2NLNf84
LH6EcXrQ3dptx4fFj/j59Gno1UlvhcSPMMLvONLvRYPiRxj/WnO1dZuWQfEj
jG1363WZXTcofoSx/tTFQfUL+MWP+PGnH4eH/OJHGJnppx+d9vnEjzD+fnb0
g/eiPvEjglPTupec8pFX/IhgzoRNmwav8YgfEby4Zc2rXXp7xI8I9tWcVjDt
gFv8iODOsGGftFrsFj8i+HvQhw16p7vEjwjy/7X18vbayeJH/PrvbRucWtgp
fkQw40j2ejtG28WPCF7e9NmiP07ZxA8z048IWl5/+guaJPEjAu5/SBI/IigU
HTvp7b9yix8RFKter/TLm3KJHxE8njnyer4Kz4gfEVyu2qfPnrI5xY/45etl
XdHpYA7xI4LtI6c/uh54RvyIYHXd2gXbH8oufkTwZuevG+bvl138iMD3uOiC
AmeyiR8RVJn3RZd8tbOKHxHU3P3zvjFjsogf+vplET8iGLP96QecWcSPCP7q
FEnZdebvGP2IoF+VGlWbLf07Rj8iWPR0HduqJzH6EcHnw1LrDB7/JEY/Injy
dlKO33M+jtGPCGafqvrZ93MexehHBJ2c6zJ/7PooRj8iuJjaukZw5oMY/Yig
2SV3/4El/hOjHxG8tGH//Etn/4zRj/jzG1+i4vAP7sfoRwTZN3Q91aXdnzH6
EUFrW+Wjh3rfi9GPCGwnc1XevfhujH5EcHdw5L+Zznsx+hHB+bLzN6Wu/SNG
PyJwnK+x/sfNf8ToRwSpDbu0udz0Tox+RFBpeo/VU3f+HqMfcb5rnv6B0+8x
+hHBrk672lRpcztGPyI4MDe57M71N2P0I4KSJUpl22C7FaMfERQvvjnLKseN
GP2IYm3xvu+ssd+M0Y8ozmfd9MuXr9wiD0cUpy+n3R357A3y8ETx72eHjFrs
+o08QlEM6pXXvuf+FfLIE8Wfvc5O3XfvKnkUjKL3qzvzDj56mTxSoxj7wc0L
9epeJY+SUdRaX3/eTz9dIo8yUWTfmb/BsIEXyaNiFFcbjl7c68QF8qgWRbeG
X0S7Z54nD0RRoo3/uK37BfKoE0WTv3K3XNzmPHmkRbF7bbI/85fz5NEoihrD
euzvP+FH8mgWxY6OsdZl2/1EHq2jGNq0aNEFB34mjw5R7Hv6ddONZ8nj9Siu
VczYVmvFD+TRI4pRE995aMvzA3n0jSLzq3O5az75iTwGRuX8OkMe6VEMn5Dz
QfZ8p8ljZPz5VbBvrb7yNHmM1dfrO/LIiML53bgqBxZ+J35EsXPGiuLzPskU
P6IoVrPI1ZPVvhc/onL+ZYofUbxyfkmfDmUyxY8oKgxJ39383ZPiRxRlBz/+
7NXpJ8SPKBYXnpg+OnRc/IjiVvfuGRsfnRA/onh1y9alWU5+K35Eca5Mysb8
64+JH1F4Tg2vnjn3sPihr+834oe+HofFjyj+6pP53vHfvxY/olhd7I/RK5xf
iR/6ehwQP8xx+hFFxq7W34zvd1D80NfjoPgRRdh2OrnujX3iRxQ3ul2fsPrx
HvEjilm3N/wr57794kcU5er4b/1ebrf4kYL3i2QbNjGwT/xIwZ0eFydte7hf
/EiR90tfiB8pGLuj85Ehg/aKHymY9lnjY7P67BI/UnC78ugdr72/W/xIwbFH
ad/Pb7tH/DCXpx8pOHr415zls+4SP1LQM2/zV9yDPxc/UuR8+Fj8SMHjpZU7
VmrwsfiRgqHjnPfuF9wqfpjbox8p6BTpWu/eiO3iR4q8fp+IH+b69MPcH/1I
Qap7T6jfL5vED3P/9EPvb634kYIGvxTo3bLcFvEjRXxcL37o41ktfqTgcvnp
H1VYtUr8SJHzaYP4kSL//1wrfujtLYlZ3zeamSLnz7/FjxS8d3PbBw8OfiB+
KK8V4kcKfvhvtR8/bvphjL8f1OfzL/FD72+R+GGO0w99PZaJH/r6rRQ/9HxZ
Ln6Y26Mf5vL0I0V8WSh+6OOdJX6Y4/TDzNb3zy6a508/9PnPED/M/dOPFDn/
3xc/9PpzxQ9znH7kkfk98SOP3P4Y8SOP3P4U8vDk+efx0w9znH6Y26MfZubv
B83t04888nqNFz/y/PP86Ic5Tj/Mcfphbo9+mMdDP8z16YceHyZ+mOvTjzxy
/maIH3r9QeTxurk+/TAz/dC5jfhhrk8/zOOhH3r5XuKHuT36YS5PP8zt0w9z
+/TD3B79MJenH+Y4/TDXpx/m8vTDzPTDXJ9+mOP0wxynH+Y4/ciDLPJDP8z9
0w9zefphLk8/zHH6Ya5PP8z9048EHncTeDw0M/1I4JEt7z/Xpx9mph95/3l8
9MPM9MNcnn7k/V8eBc1MP8xMP/L+83joh7l9+mFm+mFm+mFm+mFm+mFm+mFm
+pH3f3m0NsfpR97/5fG6OU4/zHH+ftAct/aNDDQzv19iZmt/x0gzW/sTxprZ
2j+QYWZrn8I0M/P9lZm5LtzM/H6Jma19HcvNzO8nmsdv7SNZZ45b+yQ2J/DY
Zi5v7ZfYZY5bP3vMbO2bOGBmfr/EzNb+kaNm5vcTzWztozhjZmufwzkz8/2V
ma39DlfNzN8PJvC4m8DjYQKPJwk8suX7Z7Z45DKzxcNhZr6/MrPFI2Rmfr/E
zBaPgmbm9xPNbPEoaWaLRxkz0w8zWzyqmdn6gZktHnXMzO9fmdni0cjM/P6u
mS0erc1s8ehgZr6/MrPFo4eZ6YeZ6YeZ6YeZ6YeZ6UcCj4wEHtMSeMxM4DE/
gceSBB7LE3isSuCxLoHH5gQe2xJ47ErgsSeBx4EEHkcSeBxN4HEygceZBB7n
EnhcTOBxNYHHrQQedxN4PEzg8SSBR7b8/8z0w8z0w8z0w8z0w8z0w8z0w8z0
w8z0w8z0w8z0w8z0w8zWD8xMP8xMP8xMP8xMP8xMP8xMP8xMP8xMP8xMP8xM
P8xMP8xMP8xMPxJ4ZCTwmJbAY2YCj/kJPJYk8FiewGOVma39PesSeGxO4LEt
gceuBB57EngcSOBxJIHH0QQeJxN4nEngcS6Bx8UEHlcTeNxK4HE3gcfDBB5P
zPz/+1Owxw==
          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.6695744285714289, 0.22438285714285722`, 0.3381279999999999]], 
         LineBox[CompressedData["
1:eJxcnXVUVFsXwOmOocFOni124jl2P7sVW7EQA8Uu7O5OrGdgIDCUZ4vd3d2F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          "]]}, Annotation[#, "Charting`Private`Tag#5"]& ], 
       TagBox[{
         Hue[0.8503398874989481, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.31953685714285723`, 0.11640000000000005`, 0.4341454285714288]], 
         LineBox[CompressedData["
1:eJxcnWV0VMkSgOM6SWYmtrC4uzsk3bgu7u7u7osuurg7i+vGPXQR3N0WDRpI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          "]]}, Annotation[#, "Charting`Private`Tag#6"]& ], 
       TagBox[{
         Hue[0.08640786499873876, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxcnXVUVVkXwOmOV4DB2B1j5yjn6Ojo2IGt2DF2jo6tY8/Y3d1i0DzUs62x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          "]]}, 
        Annotation[#, "Charting`Private`Tag#7"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(9\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-7.9975000000000005`, 7.997499999999999}, {0, 0.1457487}},
      PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"T2.6\"", "\"T3.11\"", "\"T5.13\"", "\"T9.20\"", "\"T17.29\"", 
       "\"T33.44\"", "\"T65.78\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.8990594285714286, 0.5637948571428573]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.7397017142857143, 0.23300614285714288`]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #6}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #7}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm], ",", 
               TagBox[#6, HoldForm], ",", 
               TagBox[#7, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True", 
                 ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091264714520893`*^9, 3.9101545008181863`*^9, 3.910155616253199*^9, {
   3.9101562517976747`*^9, 3.9101562871700735`*^9}},
 CellLabel->"Out[65]=",ExpressionUUID->"8f51d0c5-b390-445b-994a-a99bcb07a01e"]
}, Open  ]],

Cell["\<\
We observe convergence of the density of states with increasing size of the \
supercell.\
\>", "Text",
 CellChangeTimes->{{3.909125877711278*^9, 3.909126045253215*^9}, {
  3.9101545181845226`*^9, 
  3.9101545262977867`*^9}},ExpressionUUID->"ae7108a1-7632-46b1-8b5a-\
b1df6e84a0a4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Convergence with momentum sampling", "Subsection",
 CellChangeTimes->{{3.910155431393157*^9, 
  3.9101554411912293`*^9}},ExpressionUUID->"38c8a010-1f34-4695-b901-\
623f646a4b37"],

Cell[TextData[{
 "We study the convergence of the DOS with the number of momenta from the \
Abelian Brillouin zone of the 64-supercell T65.78 sampled. The resulting data \
is stored  as ",
 StyleBox["data/dos/dos_{8,8}-tess_T65.78_<n>.dat", "Input"],
 ", where ",
 StyleBox["<n>", "Input"],
 " is the number of randomly sampled momenta. Note that for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "0"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "e98b7422-d505-4465-adde-30e9004c7486"],
 ", we do not use random sampling and instead evaluate the Bloch Hamiltonian \
at ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["k",
     FontWeight->"Bold",
     FontSlant->"Plain"], "=", "0"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "818d1af6-f7c6-4c09-8ee9-b9ad76cc4f48"],
 ". We import and plot it:"
}], "Text",
 CellChangeTimes->{{3.910155446902151*^9, 
  3.910155726445115*^9}},ExpressionUUID->"a38eb184-837a-42a3-bd8b-\
d4d62527deac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"MovingAverage", "[", 
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos\>\"", "Input"], 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos_{8,8}-tess_T65.78_0.dat\>\"", "Input"]}], "}"}], 
       "]"}], "]"}], ",", "32"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLabel", "->", "\"\<T65.78\>\""}], ",", 
   RowBox[{"Filling", "->", "Axis"}], ",", 
   RowBox[{"FillingStyle", "->", 
    RowBox[{"Opacity", "[", "1", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9101563109926796`*^9, 3.910156458078571*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"df1e17a4-24b1-4751-838d-b11d96db12a7"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[GraphicsComplexBox[CompressedData["
1:eJxl3W2M3fl91/1J2mmSSdvZJpNtnKZOkRGYggzUQXJFnURGXI7UQeoEiVFh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       "], {{{}, 
         {RGBColor[0.368417, 0.506779, 0.709798], Opacity[1], EdgeForm[None], 
          GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwVztdCCGAAQOG/UimVUkIpCu2SVREiW0STklEPwIvYe6SUvS5tFVGIhsTz
+Lr4rs/J6TrTeDoyhBBNLq8iQvjHX2b4wzS/mWKSCcb5xU/G+MF3vjHKCF/5
wjCf+cQQgwzwkQ+85x1vecNrIqL8kMNylpFNFkvJJIMlLGYR6SwkjVQWkEIy
80kikQTmEU8cc4klhmjmEEXkbD8mhFq2s40atrKFzVSziY1UUUkFG1jPOtay
hnJWU0YpJRRTRCEF5JPHKlaygtzZflwIXXRyipOc4DgdHKOdNo5yhFZaaKaJ
Rho4zCHqOcgB6tjPPvayh93sYic7qOVsfAgvecFznvGUJzzmEQ95wH366eMe
vfRwl27ucJtb3OQG17nGVa5wmUtc5ALnOcd/wUBIcw==
            "]]]}, {}, {}}, {{}, {}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.006944444444444445], AbsoluteThickness[2], 
           LineBox[CompressedData["
1:eJwl20MQGDy7BtC/tm3btm3btq2vtm3btm3btu32ns5dnMkmu0z05kmChu0q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            "]]},
          Annotation[#, "Charting`Private`Tag#1"]& ]}}],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", 
        GraphicsComplex[CompressedData["
1:eJxl3W2M3fl91/1J2mmSSdvZJpNtnKZOkRGYggzUQXJFnURGXI7UQeoEiVFh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         "], {{{}, {
            EdgeForm[], 
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[1]], 
            GraphicsGroup[{
              Polygon[CompressedData["
1:eJwVztdCCGAAQOG/UimVUkIpCu2SVREiW0STklEPwIvYe6SUvS5tFVGIhsTz
+Lr4rs/J6TrTeDoyhBBNLq8iQvjHX2b4wzS/mWKSCcb5xU/G+MF3vjHKCF/5
wjCf+cQQgwzwkQ+85x1vecNrIqL8kMNylpFNFkvJJIMlLGYR6SwkjVQWkEIy
80kikQTmEU8cc4klhmjmEEXkbD8mhFq2s40atrKFzVSziY1UUUkFG1jPOtay
hnJWU0YpJRRTRCEF5JPHKlaygtzZflwIXXRyipOc4DgdHKOdNo5yhFZaaKaJ
Rho4zCHqOcgB6tjPPvayh93sYic7qOVsfAgvecFznvGUJzzmEQ95wH366eMe
vfRwl27ucJtb3OQG17nGVa5wmUtc5ALnOcd/wUBIcw==
               "]]}]}, {}, {}}, {{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwl20MQGDy7BtC/tm3btm3btq2vtm3btm3btu32ns5dnMkmu0z05kmChu0q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              "]]}, "Charting`Private`Tag#1"]}}], <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-7.92, 7.92}, {0, 4.233870967741935}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {{{}, {
               EdgeForm[], 
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                Opacity[1]], 
               GraphicsGroup[{{
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQ/U0jpv/QV7EDDFBwBgR8EPygHXKtrwPFDpyzfD6n
+NxJ++uLC2y5whF8kG6NGAT/YZXIOvdEBD8NDBD8N4FAA7MRfKBpQCMRfLB7
ShH8aqBxD6sQfLCjGhB8oOOABiL4INNsuxD8CSDn9SP4YOOmIPizZoIAgg/y
7Y55CP4SsAMRfE2Qh1cg+CDjRNYh+MYgsBnBBwffDgTfDuTAvQg+2HmHEHwP
kHHHEXxwfJxB8MHxcREtPq6jxccdtPh4iBYfz9Di4zVafHxA8AGIOyFZ
                   "]], 
                  Polygon[CompressedData["
1:eJxd0SEIwlAQBuCHYFnZCyuWgVqWDFo0DMGyYtmqJmFWB7Zlra4q2GZeXhzL
sqhVk+jysnqH7Od5MMZXfu7+116sPL8hhOh8P/p7qbktXZmJ37hsvfYsyitr
rmfF6HFcF8+xv6SBA1u7xgEcGolzD+FNSYnwjuIieH+ggWMOhCnNSGBeL4U5
LofPPPCFA+EbLwi/+GCY4yr4zfN3T1PWputtTar36TDXYcB8bgvmc0z4ROt2
YV7HkmofPbg/oJFqP0OYn8eWal8TmOt1pNrfFP4Aq6cj8g==
                   "]], 
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQPUFknfvDqi37GaBg3VeNmP5DW+1h/AyIvP37vd/v
Vb8XcFAwBoHNcP6NwB1yra83wvkTCmy5ri/egOADZQN3rIPzGYCmf9VYA+cX
zQSBlXD+o2uLgSYsh/ODwPYvgfOPgO1bCOdngs2fB+d7g82bCefrgPVPgfOl
wOr74Pw7wiD5FjjfBswvQbgXDLbsgfH3iILl98P4MmB+C5wfKQ82H84/A7Ef
zn8FcR+czwFWPw/OFwkC+w/OXwTxP5xvdB0cPnD+IUj4wfkBkPCF8x9Awh/O
3wGJHzifAWzfRjjfAxK/cD4AsqYvew==
                   "]], 
                  Polygon[CompressedData["
1:eJxV0CEMAVEYB/CbTbnyBEVhKCYoBAJuCkG5KwrFhohppp56KtNOPvUmIp6r
p55iRiV732P3333b29uv/Pd9/3R/rA0ikiRl+KO/ZxzfuS5TpP9czUlV7sQC
a3ZSf6oxxa3ctzP3Ub84fNpwy5/HrSZ84mlGA67JHk+ERVwZLhVpYKvJAwtw
vksLwju+npeFUzzOTsKbNZ8EHBeB8EqcC4v1ZHhJcVH41wL8ydFCLPBLpYvg
G9Xhw6JPD3apPwc+U19H+ED92PCe1rdY+H6The9ds/B9Bgvfo8MLUQg8pbgJ
PBrSwF9uWAzF
                   "]], 
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQfe4MEPiIOTBAwTeNmP5DXxH8Iluu64s/iDmcs3w+
p/jcSfs3gTvkWl8j+OlpQPAMwX9UJbLO/SGCHws0TeMOgn9jcQHQRAQ/GGTc
RQQf7J4zCL7HQ6CBxxH8I19BDkTw7YDOK9iL4O8EGhe4A8E3MQaCzQj+eneQ
gQi+Fsi7KxD8JSDnLUbwFUDGzUPwZ80EAQRfDOjbqikI/oRDIAci+NxA59l2
Ifhtr0EBiOAzggK5AcGvAQVfFYIPjo9SBB8cHwVo8ZGNFh9paPGRiBYfMWjx
EY4WH4EIPgC65BB5
                   "]]}}]}, {}, {}}, {{}, {}, 
              Annotation[{
                Hue[0.67, 0.6, 0.6], 
                Directive[
                 PointSize[0.006944444444444445], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJxd3X1M3ftBx/GzTdzGplw3dpU5maZG60PqQ2dSo90WjHaJmIxrIlHZHxhF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                 "]]}, "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-7.92, 7.92}, {0, 4.233870967741935}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {{{}, {
              EdgeForm[], 
              Directive[
               RGBColor[0.368417, 0.506779, 0.709798], 
               Opacity[1]], 
              GraphicsGroup[{{
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQ/U0jpv/QV7EDDFBwBgR8EPygHXKtrwPFDpyzfD6n
+NxJ++uLC2y5whF8kG6NGAT/YZXIOvdEBD8NDBD8N4FAA7MRfKBpQCMRfLB7
ShH8aqBxD6sQfLCjGhB8oOOABiL4INNsuxD8CSDn9SP4YOOmIPizZoIAgg/y
7Y55CP4SsAMRfE2Qh1cg+CDjRNYh+MYgsBnBBwffDgTfDuTAvQg+2HmHEHwP
kHHHEXxwfJxB8MHxcREtPq6jxccdtPh4iBYfz9Di4zVafHxA8AGIOyFZ
                  "]], 
                 Polygon[CompressedData["
1:eJxd0SEIwlAQBuCHYFnZCyuWgVqWDFo0DMGyYtmqJmFWB7Zlra4q2GZeXhzL
sqhVk+jysnqH7Od5MMZXfu7+116sPL8hhOh8P/p7qbktXZmJ37hsvfYsyitr
rmfF6HFcF8+xv6SBA1u7xgEcGolzD+FNSYnwjuIieH+ggWMOhCnNSGBeL4U5
LofPPPCFA+EbLwi/+GCY4yr4zfN3T1PWputtTar36TDXYcB8bgvmc0z4ROt2
YV7HkmofPbg/oJFqP0OYn8eWal8TmOt1pNrfFP4Aq6cj8g==
                  "]], 
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQPUFknfvDqi37GaBg3VeNmP5DW+1h/AyIvP37vd/v
Vb8XcFAwBoHNcP6NwB1yra83wvkTCmy5ri/egOADZQN3rIPzGYCmf9VYA+cX
zQSBlXD+o2uLgSYsh/ODwPYvgfOPgO1bCOdngs2fB+d7g82bCefrgPVPgfOl
wOr74Pw7wiD5FjjfBswvQbgXDLbsgfH3iILl98P4MmB+C5wfKQ82H84/A7Ef
zn8FcR+czwFWPw/OFwkC+w/OXwTxP5xvdB0cPnD+IUj4wfkBkPCF8x9Awh/O
3wGJHzifAWzfRjjfAxK/cD4AsqYvew==
                  "]], 
                 Polygon[CompressedData["
1:eJxV0CEMAVEYB/CbTbnyBEVhKCYoBAJuCkG5KwrFhohppp56KtNOPvUmIp6r
p55iRiV732P3333b29uv/Pd9/3R/rA0ikiRl+KO/ZxzfuS5TpP9czUlV7sQC
a3ZSf6oxxa3ctzP3Ub84fNpwy5/HrSZ84mlGA67JHk+ERVwZLhVpYKvJAwtw
vksLwju+npeFUzzOTsKbNZ8EHBeB8EqcC4v1ZHhJcVH41wL8ydFCLPBLpYvg
G9Xhw6JPD3apPwc+U19H+ED92PCe1rdY+H6The9ds/B9Bgvfo8MLUQg8pbgJ
PBrSwF9uWAzF
                  "]], 
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQfe4MEPiIOTBAwTeNmP5DXxH8Iluu64s/iDmcs3w+
p/jcSfs3gTvkWl8j+OlpQPAMwX9UJbLO/SGCHws0TeMOgn9jcQHQRAQ/GGTc
RQQf7J4zCL7HQ6CBxxH8I19BDkTw7YDOK9iL4O8EGhe4A8E3MQaCzQj+eneQ
gQi+Fsi7KxD8JSDnLUbwFUDGzUPwZ80EAQRfDOjbqikI/oRDIAci+NxA59l2
Ifhtr0EBiOAzggK5AcGvAQVfFYIPjo9SBB8cHwVo8ZGNFh9paPGRiBYfMWjx
EY4WH4EIPgC65BB5
                  "]]}}]}, {}, {}}, {{}, {}, 
             Annotation[{
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.006944444444444445], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]], 
               Line[CompressedData["
1:eJxd3X1M3ftBx/GzTdzGplw3dpU5maZG60PqQ2dSo90WjHaJmIxrIlHZHxhF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                "]]}, "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
        "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[
     GraphicsComplex[CompressedData["
1:eJxl3W2M3fl91/1J2mmSSdvZJpNtnKZOkRGYggzUQXJFnURGXI7UQeoEiVFh
+sCIukWWqFtqhEgfDBAXyUAcISMuRxdGrSPVFcGlckucKiZbJ+CmuAH3zrvp
7M147fHNeO3xzJy5OTPjpft7//b7lj/XeRB4SZV3znmfz5zzP+f8z/yZv/8z
n/rJd46MjFz94MjIW//vxcPz/2zi4kdeGOmXvzBz+urggv7C8YNjN8/rj5xc
nLp8Tn/+7FsXPfHWP3hGf+7qYO/Maf2n/9jxg6f0W//c7pO6XWb1p9s/qNf+
9F+7ekK3H++4fvjWP3dMH20X/da1PXxEv3V1987ot368sWn9qT/95xan9O9d
/9PLpP5k+wd1u7qH9MfaFdbtnzug97eLbj32RY+90WNP9NgdPXZFj4noMR49
xqLHaPQYiR7D3eXWY6BbjyXdeizqlmNBt5tvXrerO6fbj3dTtx43dOtxXbce
13TrcVW3Hld063FZtxyXNPvQ7EOzD80+NPvQ7EOzD80+NPvQ7TKr2Uf0OBE9
jkePY9HjaPQ4Ej1mosd09JiKHpPR43D0OBQ9DkaPA9Fjf/TYFz32Ro890WN3
9NgVPSaix3j0GIseo9FjJHoMv7/MPjT70OxDsw/NPjT70OxDsw/NPjT70OxD
sw/NPjT70OxDsw/NPnT7585p9qHZh2Yfmn1o9qHbZVazj+hxInocjx7HosfR
6HEkesxEj+noMRU9JqPH4ehxKHocjB4Hosf+6LEveuyNHnuix+7osSt6TESP
8egxFj1Go8dI9Bh+uMw+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ
7EOzD80+NPvQ7EOzD80+NPvQ7EO3y6xmH9HjRPQ4Hj2ORY+j0eNI9JiJHtPR
Yyp6TEaPw9HjUPQ4GD0ORI/90WNf9NgbPfZEj93RY1f0mIge49FjLHqMRo+R
6DH8vjL70OxDsw/NPvSttg/NPjT70OxDt3lc1+xDsw/NPjT70OxDsw/NPjT7
0OxDsw/NPjT70OxDsw/dLrOafUSPE9HjePQ4Fj2ORo8j0WMmekxHj6noMRk9
DkePQ9HjYPQ4ED32R4990WNv9NgTPXZHj13RYyJ6jEePsegxGj1GosfwQ2X2
odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2
odmHZh+6XWY1+4geJ6LH8ehxLHocjR5HosdM9JiOHlPRYzJ6HI4eh6LHwehx
IHrsjx77osfe6LEneuyOHruix0T0GI8eY9FjNHqMRI/hrjL70OxDsw/NPjT7
0OxDsw/NPjT70OxDsw/NPjT70OxDsw/NPjT70OxDsw/NPjT70OxDsw/dLrOa
fUSPE9HjePQ4Fj2ORo8j0WMmekxHj6noMRk9DkePQ9HjYPQ4ED32R4990WNv
9NgTPXZHj13RYyJ6jEePsegxGj1Gosfwg2X2odmHZh+afWj2odmHZh+afWj2
odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2odmHZh+6XWY1+4geJ6LH8ehx
LHocjR5HosdM9JiOHlPRYzJ6HI4eh6LHwehxIHrsjx77osfe6LEneuyOHrui
x0T0GI8eY9FjNHqMRI/h95bZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZ
h2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn3odpnV7CN6nIgex6PHsehxVHN8Hj1m
osd09JiKHpPR43D0OBQ9DkaPA9Fjf/TYFz32Ro890WN39NgVPSaix3j0GIse
o9FjJHoMny+zD80+nn/hmz989//7x9/8xsfZh2YfmtevNPvQ7EOzD80+NPvQ
7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EO3G3lWsw/NPjT7iB7HosfR
6HEkesxEj+noMRU9Jr0/sA/NPjT70OxDsw/NPjT70OxDsw/NPjT70OxDsw/N
PjQX3e7Oww+U2YdmH5p9aPah2YdmH/qP2z40+9DsQ7MPzT40+9DsQ7MPzT50
u7oXNPvQ7EOzD80+dLv7ndbsQ3+m7UO3y6xuN98/0+3qnogex3X7545Fj6PR
40j0mIke09FjKnpM6nbzHY4eh3T78Q5GjwP6h1qQ6LEveuzV7e6yJ3rs1hwO
Ro+J6DEePcaix2j0GIkew4ly6zHQ7EO3HouafWj2odmHZh+afWj2oVuPa5p9
6NbjimYfuvW4pNmHZh+6/XjnNfvQrcdZzT40+9DsQ7MP3S6zmn1EjxPR43j0
OBY9jkaPI9FjJnpMR4+p6DEZPQ5Hj0PR42D0OBA99kePfdFjb/TYEz12R49d
0WMieoxHj7HoMRo9RqLH8P1l9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o
9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yful1mNfuIHieix/HocSx6HNWvtX1E
j5noMR09pqLHZPQ4HD0ORY+D0eNA9NgfPfZFj73RY0/02B09dkWPiegxHj3G
osdo9BiJHsP3ldmHZh+afWj2oVuPec0+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ
7EOzD80+NPvQ7EOzD80+NPvQ7TKr2Uf0OBE9jkePY9HjaPQ4Ej1mosd09JiK
HpPR43D0OBQ9DkaPA9Fjf/TYFz32Ro890WN39NgVPSaix3j0GIseo9FjJHoM
v6fMPjT70OxDsw/NPjT70OxDsw/NPjT70OxDsw/NPjT70OxDsw/N8YdmH5p9
aPahP9t+QM0+NPvQ7TKr2Uf0OBE9jkePY9HjaPQ4Ej1mosd09JiKHpPR43D0
OBQ9DkaPA9Fjf/TYFz32Ro890WN39NgVPSaix3j0GIseo9FjJHoMnyuzD80+
NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+
NPvQ7TKr2Uf0OBE9jkePY9HjaPQ4Ej1mosd09JiKHpPP9dez7n+cfWj2odmH
Zh+afWj2odmHZh+afWj2odmHZh+afWj2od9sl/Eye9AP2v1fc3/X3L819+fx
Z2+vq+PP3j6Xx5+9PS5qns/o/7dd4fFnr9/p8Wevz0nN/Ulz/9E/2e4v+u/x
gFtuV3dqvO4P/0/rr3+k3aCavpqemn76/e0K6/e0Ppoe311ebf+gpoemh6aH
pof+7dZDf6n9gPq/tB6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6a
Hpoe31Wmh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aH
poemh6aHpoemx3eW6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHp
oemh6aHpoemh6aHpoemh6fHeMj00PTQ9ND00PTQ9ND00PfQvtxtQ00PTQ9ND
00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND02OsTA9ND00PTQ9ND83juaaHpoem
h6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6bHe8r00PTQ9ND00PTQ
7EPTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PT491lemh6
aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpo
eryrTA9ND00PTQ9ND00PTQ9ND83juaaHpoemh6aHpoemh6aHpofm+FNzvKn5
fITm8xCaHpoemh6aHt9R5nhQ83qI5v0lzed1ND00PTQ9ND00PTSvR2hev9Z8
XkbTQ9ND8/qB5vUCzesDms+zaHpoemh6aHpojt81D0eai+bzJKNlemh6aHpo
emgezzXH55rjc83rRZrPb2h6aHpoemh6aHpoemh6aHpoemh6aH5faXpoemh6
aC6aHt9epoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoem
h6aHpoemh+ai6fFtZXpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpo
emh6aHpoemh6aHpoemgumh7vLNND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND
00PTQ9ND00PTQ9ND00PTQ9ND00Nz0fR4R5kemh6aHpoemh6aHpoemh6aHpoe
mh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6ai6bHSJkemh6aHpoemh6aHpoe
mh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh66X8p8HvfNr75tji80
t6/+Yrs9NccLmuMDze2juT00119zfTXXT3N9NM/Xn5Y5XtLcXzT3D839QdNf
01vTV9NT00/TS9NHc9HsYSd67EQPzf1bc7ywEz12osdO9NAcf2mOf3eix070
2Ike29FjO3psR4/t6LEdPbajx3b02I4e29FjO3psR4/t6LEdPbaix1b02Ioe
W9FjK3psRY+t6LEVPbaix1b02IoeW9FjGD2G0WMYPYbRQ/N6wDB6DKPHMHoM
o8cwegyjxzB6DKPHZvTYjB6b0WMzemxGj83osRk9NqPHZvTYjB6b0WMzemxE
j43osRE9NqLHRvTYiB4b0WMjemxEj43osRE9NqLHRvRYjx7r0WM9eqxHj/Xo
sR491qPHevRYjx7r0WM9eqxHj7XosRY91qKH5vWateixFj3Wosda9FiLHmvR
Yy16rEWPtegxiB6D6DGIHoPoMYgeg+gxiB6D6DGIHoPoMYgeg+ixGj1Wo8dq
9FiNHqvRYzV6rEaP1eixGj1Wo8dq9FiNHqvRYyV6rESPleixEj1WosdK9FiJ
HivRYyV6rESPleixEj2Wo8dy9FiOHsvRYzl6LEeP5eixHD2Wo8dy9FiOHsvR
Yzl6PIkeT6LHk+jxJHo8iR5PoseT6PEkejyJHk+ix5Po8SR6LEWPpeixFD2W
osdS9FiKHkvRYyl6aN4vWYoeS9FjKXosxe3/uMzxxeO4ffXfbbfn47j99Lvb
7fU4bp9H5f/Wbo9Hcf0fxfV9FNfvUVwfzfs1b8T9R3N8pLl/aN5/eiP6a94f
ehh9Ne+nPYx++sdar4fRRz9t738sRg/N+xOL0UPzfs5i9NC837IYPR6UeT/k
QfTQvH/0IHpo3t95ED3uR4/70eN+9LgfPe5Hj/vR4170uBc97kWPe9HjXvS4
Fz3uRg/NPu5GD80+7kaPu9HjbvRYiB4L0WMheixEj4XosRA97pR5P+xO9NA/
03rciR53osed6HE7etyOHrejx+3ocTt63I4er0eP16PH69Hj9ejxevR4PXq8
Hj1uRY9b0eNW9LgVPW5Fj1vRYz56zEeP+egxHz3mo8d89HgterwWPV6LHq9F
j9eih95pPV4t/+d2++sfb7e3fle7ffVvth/4lfI/aLeffl+7vfQL7fZ5ufyP
2u2hP9yuv/7ddn3nyv+0XT/95/jAfPkP2/3pT8r/ot1/9F9p9xf9SrvBvlX+
N+3+oP9666/vt94vlf9D66v/ZuupV9oN/mL0ejH6aPZxMx4vNI8Pmvu75vnJ
H8fjr/5A66G/1nr8UflnWw/N9z/rb7Yef1j+hdZD/8XWQ7/Ufrw/KP+r1kP/
tdZD3249fr/871oP/YnWQz9uPW6U/2ProX+09dDD1uP/lC+0HvrvtBtQj7b/
1Ufb7f+/vf3a7f1Nb692++pPt9vz98o3GXD5o+320p9rt8//Kj9st8fvlj/Z
rr/+Qru+3yjzgYHfKc+066Mvc4JIeaLdf/Txdn/5n/6+afeP/+Hvj3Z/0Cdb
/6+Xb7XeXyt/rPXVn+cJRHmt9fvt8qdaL32x9XmhPNb+V19vt/9/9/GCE1z8
/d1u36/432u352/577fb78v2ZUD+Pm63z5d8vGo//m/aq13/37BPu76Xvvr4
yvorn3783Cd4gv/r5cvt+vzX8mvtP3ex/GPt5/1i+Wr7+X61/EPt5/mV8i+3
//4XyhPtv/dL5XfzhfrlBxxwla9zQk75x9v//WfLH26/MD5T/krzz3v92uU3
vvK2f6Q9QP78x9/2XPNnyh9q1/ez5b/Ef7/8o/x85X/Y/u/Plb/e7i+/VP4U
1798qz2h+JXyz3H7lTmA/GL5c9z+mj7lF9t/79fLP0Df8k/Tv3yR+8fH6/7W
fp4vlT/G/av8i9z/yt/k/lme4P5bnuH+Xf4C9//yw/b48dXy59mP/332Vb7F
/vx52Gf5B9mvPx/7Lv8s+y9/gN8P5S/z+6P8E/x+KfOG5DWvD7+fyp/k95fX
r/3+1p/j91/5o/x+LL/I78/yL/D7tfwRfv+Wv8bv5/JP8fu7/F5+v5d/jd//
5U/x+GD/1kP/LR5fyv+Jx5/yEx6fyn+Dx6/yv+fxrXyXx7/yD/P4WP7XPH6W
X+bxtfyXefwt/3Men8t/wON3+c/y+F7+Jzz+l3+H5wflXTx/KB/j+UX5Cs8/
yuM8Pykf4flL+RLPb8qjPP8pT/P8qPyrPH8qb/H8Knq8GD1ejB4vRo+XosdL
0eOl6PGt6PGt6PGt6PEn0UP/Ps9vo8dc9JiLHnPR4+Xo8XL0eDl6vBI9Xoke
r0SPV6PHq9Hj1eiheT7/Wrkfv5R5/q/78U+Z4wXN82/N8cV8mefrmuMRzfN7
zfGL5nhAc7xzq8zxg+b4SP9bjj/LvJ6mX+X4tczrca+X/yrHv+V+fFzm+Ef3
4+syx0u6H59Hj9vR43b0uB09bkcP3V9fiB53yv31iehxJ3rciR53osed6LEQ
PRaix0L0WIgeC9FjIXrcjR53o4f+l7y+FD30H/H6VPTQf57Xt6LHvehxL3rc
ix6afdyLHvdjH/ejx/3ocT963I8e96PHg+jxIHo8iB4PoseD6PEgeixGj8Xo
sRg9FqPHYvRYjB6L0eNh9HgYPR5Gj4fRQ/fXp6PHG9HjjejxRvR4I3q8ET3e
iB6Posej6PEoejyKHprXUx5Fj8dlXn95HD00v68eRw/N76vH0UP390fK/f2T
cn9/JXppXv/T/f2bcn9/J3pqXl/U/f2jcn9/KXprXs95Uu7vX5X7+1vx+1Lz
+pDu75+V+/trZV6f1LzepPv7d+X+/l6Z1z815388iR7L0WM5emjOX9H9/cvo
sRw9lqPHcvRYjh7L0WM5eixHj5XosRI9VqLHSvRYiR4r0WMleqxEj5XosRI9
VqLHSvRYiR6r0WM1eqxGj9XosRo9VqPHavRYjR6r0WM1eqxGj9XoMYgeg+gx
iB6D6DGIHoPoMYgeg+gxiB6D6DGIHoPoMYgea9FjLXqsRY+16LEWPdaix1r0
WIsea9FjLXqsRY+16LEePdajx3r0WI8e69FjPXqsR4/16LEePdajx3r0WI8e
69FjI3psRI+N6LERPTaix0b02IgeG9FjI3psRI+N6LERPTajx2b02Iwem9Fj
M3psRo/N6LEZPTajx2b02Iwem9FjM3oMo8cwegyjxzB6DKPHMHoMo8cwegyj
xzB6DKPHMHpsRY+t6LEVPbaix1b02IoeW9FjK3psRY+t6LEVPbaix1b02I4e
29FjO3psR4/t6LEdPbajh+6fb44e29FjO3psR4+d6LETPXaix0702IkeO9Fj
J3rsRI+d6LETPXaix0702IkeT6PH0+jxNHo8jR5Po8fT6KH5vNPT6PE0ejyN
Hk+jx9Po8Wb0eDN6aD7vpfv5D9HjzejxZvTQ/fyLMsdLb0aPN6OH7pdPvP3/
6eeHlPv5I+V+fkm5n39S5vrqfv5Kmeuv+/kv5X5+TLmfP1Pu59eU+/k3ZW4v
3c/fKfP2jOb+oPv5QeV+/lC5n19U7ucflbm9dT9/qdzPbyrz9EtzeUe5nz9V
7udXlemh+/lZ5X7+Vrmf31Wmh+7nh5X7+WPlfn5ZmffbNX+PQffz18r9/LYy
PXQ/P67cz58r9/Pryrz/r/l7rrqfv1fu5/eV+/l/5X5+YJnLO8v9/MIyn0fQ
fN5Ac/677uc3lvv5j+V+fmS5nz9Z7udXln+K8y/L9ND00L/I+Z1l/v6G7ueH
lvv5o2V66C+3Hpoemh76Rc5vLfP3gTTnn+l+/myZy7eV38v5t2V6aHroH2w3
oP4o5/+W+Xscup8/XO7nF5fpoemh6aH5vImmh6aH7udPl/v51WV6aHpoemg+
/6Lpoemh6aH7+eVlLt9epoemh6aHpoemh6aH7ufXl/v592V6aHpoemh6aHpo
euj+/QLl/v0DZXpoemh6aHpoemh6aHro/v0LZS6jZXpoemh6aHpoemh66P79
E+X+/RRlemh6aHpoemh6aHro/v0b5f79HGV6aHpoemh6aHpoemh66P79JGUu
31Gmh6aHpoemh6aHpofu389S7t/fUqaHpoemh6aHpoemh6aHpoemh6aHpoem
h6aHpoemh6aH5vKuMj00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00
PTQ9ND00PTQ9ND00PTQ9NJd3l+mh6aHpoemh6aHpoemh6aHpoemh6aHpoemh
6aHpoemh6aHpoemh6aHpoemh6aHpobm8p0wPTQ9ND00PTQ9ND00PTQ9ND00P
TQ9ND00PTQ9ND00PTQ9ND00PzfNdTQ9ND00PTQ/NZaxMD00PTQ9ND00PTQ9N
D00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ/N5b1lemh6aHpo
emh6aHpoemh66J9oPTQ9ND00PTQ9ND00PTQ99K+1Hpoemh6aHpoemh6aHpoe
mst3lumh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHp
oemh6aHpobl8V5kemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6a
Hpoemh6aHpoemh6aHprLd5fpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh
6aHpoemh6aHpoemh6aHpoemh6aG5jJfpoemh6aHpoemh6aHpoemh6aHpMf6J
t/8eBD00PTQ9ND00PTQ9ND30b7Ue+uuth+b5rqaHpoemh6aH5lo/9+z1GdU8
PXru2es3rnk9/rlnr+8uTb/nnr3+ezQ9dfvn9mn66pbvgKa3bvffQ5r+ut2f
J3X/+y/P3p7Tz9X9ged7ut2+RzTvB2j+vrLm/qP5+8ya16d1u8xq7l+6Xd1T
mvub5nQczf1PczqR7n//p9x6XNA839StxyXN+xGavx+s+X2i+fvDmt8vuv99
pDL37+gxFz3mo8dC9FiMHkvRYxA9htFj5HvK7EOzD80+NPvQ7EOzD93/PlaZ
fWj2odmHZh+afWj2odmHZh+6//2wMvvQ7EOzD80+NPvQ7EOzD80+dLvMRo+T
0eNU9Dit2+PLmehxNnqcix7no8eF6HExelyKHpejx5XocTV6XIse16PHjehx
M3rMRY/56LEQPRajx1L0GESPYfQYeV+ZfWj2odmH5vFesw/NPjT70OxDsw/N
PjT70OxDsw/NPjT70P3vT5bZh2Yfmn1o9qHZh2Yfmn1o9qHbZTZ6nIwep6LH
6ehxJnqcjR7nosf56HEhelyMHpeix+XocSV6XI0e16LH9ehxI3rcjB5z0WM+
eixEj8XosRQ9Bro9PxxGj5H3l9mHZh+afWj2odmH/oG2D80+NPvQ7EOzD80+
NPvQ7EOzD92en07q/veLy+xDsw/NPjTPxzX70D/X9qHZh+b5un7HW/8zGz1O
6nY8cip6nI4eZ6LH2ehxLnqcjx4XNM//o8clzfFZ9LiiOT6IHteix3X9t9s+
osdN3Y6H5qLHfPRYiB6L0WMpegyixzB6jEyU2Yfm+FCzD80+NPvQ7EOzD80+
dOuxT7MP3Xoc0OxDtx6HNPvQ7EO3HlOafWiOTzX70OxDsw/NPjT70OxDs4/o
cTJ6nIoep6PHmehxNnqcix7no8eF6HExelyKHpejx5XocTV6XIse16PHjehx
M3rMRY/56LEQPRajx1L0GESPYfQY+UCZfWj2odmHZh+afWj2odmHZh+afWj2
odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2odmHZh+afUSPk9HjVPQ4rZ9v
+4geZ6PHuehxPnpciB4Xo8el6HE5elyJHlejx7XocT163IgeN6PHXPSYjx4L
0WMxeixFj0H0GEaPkefL7EOzD80+dOsxodmHZh+afWj2odmHZh+afWj2odmH
Zh+afWj28Xx//eob/fUrzT40+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7MPzT40
+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7OP6HEzesxFj/nosRA9FqPHUvQYeH9g
H5p9fG+ZfWj2odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2odmH5vhDsw/N
PjT70D/d9qHZh2Yfmn1o9qHZR/Q4GT1ORY/T0eNM9DgbPc5Fj/PR40L0uBg9
LkWPy9HjSvS4Gj2uRY/r0eNG9LgZPeaix3z0WIgei9FjKXoMoscweox8sMw+
NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+
NPvQ7EOzD80+osfJ6HEqepyOHmeix9nocS56nI8eF6LHxehxKXpcjh5XosfV
6HEtelyPHjeix83oMRc95qPHQvRYjB5L0WMQPYbRY2RXmX1o9qHZh2Yfmn1o
9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1E
j5PR41T0OB09zkSPs9HjXPQ4Hz0uRI+L0eNS9LgcPa5Ej6vR41r0uB49bkSP
m9FjLnrMR4+F6LEYPZaixyB6DKPHyIfK7EOzD80+NPvQ7EOzD80+NPvQ7EOz
D80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7CN6nIwep6LH6ehx
JnqcjR7nosf56HEhelyMHpeix+XocSV6XI0e16LH9ehxI3rcjB5z0WM+eixE
j8XosRQ9BtFjGD1Gvq/MPjT70OxDsw/NPjT70OxDsw/NPjT70OxDsw/NPjT7
0OxDsw/NPjT70OxDsw/NPjT70OxDsw/NPqLHyehxKnqcjh5nosfZ6HEuepyP
Hheix8XocSl6XI4eV6LH1ehxLXpc1xyfR4+b0WMuesxHj4XosRg9lqLHIHoM
o8fIh8vsQ7MPzT40+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7MPzT40r19p9qHZ
h2Yfmn1o9qHZh2Yfmn1o9hE9TkaPU9HjdPQ4Ez3ORo9z0eN89LgQPS5Gj0vR
43L0uBI9rkaPa9HjevS4ET1uRo+56DEfPRaix2L0WIoeg+gxjB4j319mH5p9
aPah2YdmH5p9aPah2YdmH5p9aPah2YdmH5p9aPahefzQ7EPz/rlmH5rPl2j2
ofk+Cc0+NN8vodtlVvN9E5rPl0SP05rPJ0aPs7rdnc9Fj/O63V0uaD5fotv3
b1zSfL5Et6t7RfN9Frr9c9c032+h2935hub7LqLHnOb7U6LHgub7F6LHkub7
MaLHMHqM7C63HqOaz5doPu6seftXczio+X4N3a7uHs33bWg+X6L5PhTN50s0
3/+gW49Dmu/n0C3HpOb7cHTrMa3Zh249jmj2oVuPY5p96NbjhGYful1mo8fJ
6HEqepyOHmeix9nocS56nI8eF6LHxehxKXpcjh5XosfV6HEtelyPHjeix83o
MRc95qPHQvRYjB5L0WMQPYbRY+QjZfah2YdmH5p9aPahufk0+9DsQ7MPzT40
+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7fLbPQ4GT1ORY/T0eNM
9DgbPc5Fj/PR40L0uPj/8wtv+y/wf1/m8UjzeUjN45nuP2+Zx0Pdr2+Z7wvS
7TKr+byn5vFa9x5lHu9171mep3e53x/KN7m/lHk+ovk8rOb5jO731zLPh3S/
v5f5fiDd91Lm+4Six57osTt67IoeE9FjPHqMRY/R6DESPYa7yzyf1f33VZnn
w7r/vivz/Uy6/74s831Omtd7NJ+H1Tzf1/33eZnjBd0fD8r7ebwo98eTMvvQ
7EOzD80+dH+8K7MP3R8vy+xDt8usZh/R40T0OB49jkWPo9HjSPSYiR7T0WMq
ekxGj8PR41D0OBg9DkSP/dFjX/TYGz32RI/d0WNX9JiIHuPRYyx6jEaPkegx
/P4y+9D9+W6Zfej+fLnMPnR/vl1mH5p9aPah2YfuxwNl9qH78USZfeh+PFJm
H7ofz5T78U65Hw+V+/FSuR9PlfvxVpl96HaZ1ewjepyIHsejx7HocTR6HIke
M9FjOnpMRY/J6HE4ehyKHgejx4HosT967Isee6PHnuixO3rsih4T0WM8eoxF
j9HoMRI9hh8u99dDyuxD99dTyuxDsw/NPjT70OxDsw/dXy8qsw/dX28qsw/N
PjT70OxD99fDyuxD99fTyuxD99fjyuxDsw/dLrOafUSPE9HjePQ4Fj2ORo8j
0WMmekxHj6noMRk9DkePQ9HjYPQ4ED32R4990WNv9NgTPXZHj13RYyJ6jEeP
segxGj1Gosfw+8r99fQy+9D99fgy+9D99fwy+9DsQ7MPzfGu7u83lNmH7u9X
lNmHZh+afWj2ofv7KWX2ofv7MWX2ofv7OWX2odmHbpdZzT6ix4nocTx6HIse
R6PHkegxEz2mo8dU9JiMHoejx6HocTB6HIge+6PHvuixN3rsiR67o8eu6DER
Pcajx1j0GI0eI9Fj+KFyfz+2zD50fz+3zD50fz+4zD40+9D9/eYy+9D9/eoy
+9D9/e4y+9DsQ7MPzT50fz++zD50fz+/zD50/zxAmX1o9qHbZVazj+hxInoc
jx7HosfR6HEkesxEj+noMRU9JqPH4ehxKHocjB4Hosf+6LEveuyNHnuix+7o
sSt6TESP8egxFj1Go8dI9BjuKvfP85TZh+6fByqzD90/T1RmH5p96P55pTL7
0P3zTmX2ofvnpcrsQ7MPzT40+9D981xl9qH758HK7EP3z5OV2YdmH7pdZjX7
iB4nosfx6HEsehyNHkeix0z0mI4eU9FjMnocjh6HosfB6HEgeuyPHvuix97o
sSd67I4eu6LHRPQYjx5j0WM0eoxEj+EHy/3zoGX2ofvnScvsQ/fPo5bZh2Yf
un/etcw+dP+8bJl96P552zL70OxDsw/NPnT/PHCZfej+eeIy+9D988hl9qHZ
h26XWc0+oseJ6HE8ehyLHkejx5HoMRM9pqPHVPSYjB6Ho8eh6HEwehyIHvuj
x77osTd67Ikeu6PHrugxET3Go8dY9BiNHiPRY/i95X4+QZl96H4+Qpl96H4+
Q5l9aPah+/kSZfah+/kWZfah+/kaZfah2YdmH5p96H4+SZl96H4+Spl96H4+
S5l9aPah22VWs4/ocSJ6HI8ex6LHUc3xefSYiR7T0WMqekxGj8PR41D0OBg9
DkSP/dFjX/TYGz32RI/d0WNX9JiIHuPRYyx6jEaPkegxfL7cz0crs4/nX4jz
2crsQ/P6lWYfmn1o9qHZh+7n65XZh+7n+5XZh2Yfmn1o9qH7+Yhl9qH7+Yxl
9qH7+ZBl9qHZh2438qxmH7qfr1lmH9HjWPQ4Gj2ORI+Z6DEdPaaix6T3h34+
a5l96H4+bJl9aPah2YdmH7qfr1tmH7qf71tmH7qfL1xmH5p9aC6azyN8oNzP
Zy6zD93Phy6zD80+NPvQfN5Csw/NPnQ/37vMPnQ/X7zMPjT70OxD83677uez
l9mH7ufDl9mH5vMAmn1oPk+g22VW83kEzecVosdxzecdosfR6HEkesxEj+no
MRU9JjWf54gehzSfB4keBzSfJ4ke+6LHXs3nVaLHbs3hYPSYiB7j0WMseoxG
j5HoMZwo83kezT40nwfS7EOzD80+NPvQ7EOzD83nnTT70HxeSrMPzeetNPvQ
7EPzeRXNPjSfd9HsQ7MPzT40+9DtMqvZR/Q4ET2OR49j0eNo9DgSPWaix3T0
mIoek9HjcPQ4FD0ORo8D0WN/9NgXPfZGjz3RY3f02BU9JqLHePQYix6j0WMk
egzfX2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o
9qHZh2Yfmn1o9qHbZVazj+hxInocjx7HosdRzeftosdM9JiOHlPRYzJ6HI4e
h6LHwehxIHrsjx77osfe6LEneuyOHruix0T0GI8eY9FjNHqMRI/h+8rsQ7MP
zT40+9B8HlWzD80+dP++wTL70OxDsw/NPjT70OxDsw/NPjT70OxDsw/NPjT7
0OxDsw/dLrOafUSPE9HjePQ4Fj2ORo8j0WMmekxHj6noMRk9DkePQ9HjYPQ4
ED32R4990WNv9NgTPXZHj13RYyJ6jEePsegxGj1Gosfwe8rsQ7MPzT40+9Ds
Q7MPzT50/77aMvvQ7EOzD80+NPvQ7EOzD80+dP8+3zL70OxDsw/N39PV7EOz
D90us5p9RI8T0eN49DgWPY5GjyPRYyZ6TEePqegxGT0OR49D0eNg9DgQPfZH
j33RY2/02BM9dkePXdFjInqMR4+x6DEaPUaix/C5MvvQ7EOzD80+NPvQ7EOz
D92/77zMPjT70OxDsw/NPjT70OxDsw/dvw++zD40+9DsQ7MPzT40+9DtMqvZ
R/Q4ET2OR49j0eNo9DgSPWaix3T0mIoek8+98PbfB2Afmn1o9qHZh2Yfmn1o
9qH730sosw/NPjT70OxDsw/NPjR/n3y8zB40fz9bc3/X3L819+fxZ2+vq+PP
3j6Xx5+9PS5qns9o/v73+LPX7/T4s9fnpOb+pLn/6J9s9xfN34fXnD8zXvcH
/p685u+za/pqemr66fe3K6z5e+qaHt9d5u+va3poemh6aHro32499JfaD6j5
e/eaHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoe31Wmh6aHpoem
h6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemx3eW
6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHp
oemh6fHeMj00PTQ9ND00PTQ9ND00PfQvtxtQ00PTQ9ND00PTQ9ND00PTQ9ND
00PTQ9ND00PTQ9ND02OsTA9ND00PTQ9ND83juaaHpoemh6aHpoemh6aHpoem
h6aHpoemh6aHpoemh6aHpoemh6bHe8r00PTQ9ND00PTQ7EPTQ9ND00PTQ9ND
00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PT491lemh6aHpoemh6aHpoemh6
aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoeryrTA9ND00PTQ9N
D00PTQ9ND83juaaHpoemh6aHpoemh6aHpofm+FNzvKn5fITm8xCaHpoemh6a
Ht9R5nhQ83qI5v0lzed1ND00PTQ9ND00PTSvR2hev9Z8XkbTQ9ND8/qB5vUC
zesDms+zaHpoemh6aHpojt81D0eai+bzJKNlemh6aHpoemgezzXH55rjc83r
RZrPb2h6aHpoemh6aHpoemh6aHpoemh6aH5faXpoemh6aC6aHt9epoemh6aH
poemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh+ai6fFt
ZXpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpo
emgumh7vLNND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND
00PTQ9ND00Nz0fR4R5kemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoe
mh6aHpoemh6aHpoemh6ai6bHSJkemh6aHpoemh6aHpoemh6aHpoemh6aHpoe
mh6aHpoemh6aHpoemh6aHpoemh66X8p8HvfNr75tji80t6/+Yrs9NccLmuMD
ze2juT00119zfTXXT3N9NM/Xn5Y5XtLcXzT3D839QdNf01vTV9NT00/TS9NH
c9HsYSd67EQPzf1bc7ywEz12osdO9NAcf2mOf3eix0702Ike29FjO3psR4/t
6LEdPbajx3b02I4e29FjO3psR4/t6LEdPbaix1b02IoeW9FjK3psRY+t6LEV
Pbaix1b02IoeW9FjGD2G0WMYPYbRQ/N6wDB6DKPHMHoMo8cwegyjxzB6DKPH
ZvTYjB6b0WMzemxGj83osRk9NqPHZvTYjB6b0WMzemxEj43osRE9NqLHRvTY
iB4b0WMjemxEj43osRE9NqLHRvRYjx7r0WM9eqxHj/XosR491qPHevRYjx7r
0WM9eqxHj7XosRY91qKH5vWateixFj3Wosda9FiLHmvRYy16rEWPtegxiB6D
6DGIHoPoMYgeg+gxiB6D6DGIHoPoMYgeg+ixGj1Wo8dq9FiNHqvRYzV6rEaP
1eixGj1Wo8dq9FiNHqvRYyV6rESPleixEj1WosdK9FiJHivRYyV6rESPleix
Ej2Wo8dy9FiOHsvRYzl6LEeP5eixHD2Wo8dy9FiOHsvRYzl6PIkeT6LHk+jx
JHo8iR5PoseT6PEkejyJHk+ix5Po8SR6LEWPpeixFD2WosdS9FiKHkvRYyl6
aN4vWYoeS9FjKXosxe3/uMzxxeO4ffXfbbfn47j99Lvb7fU4bp9H5f/Wbo9H
cf0fxfV9FNfvUVwfzfs1b8T9R3N8pLl/aN5/eiP6a94fehh9Ne+nPYx++sda
r4fRRz9t738sRg/N+xOL0UPzfs5i9NC837IYPR6UeT/kQfTQvH/0IHpo3t95
ED3uR4/70eN+9LgfPe5Hj/vR4170uBc97kWPe9HjXvS4Fz3uRg/NPu5GD80+
7kaPu9HjbvRYiB4L0WMheixEj4XosRA97pR5P+xO9NA/03rciR53osed6HE7
etyOHrejx+3ocTt63I4er0eP16PH69Hj9ejxevR4PXq8Hj1uRY9b0eNW9LgV
PW5Fj1vRYz56zEeP+egxHz3mo8d89HgterwWPV6LHq9Fj9eih95pPV4t/+d2
++sfb7e3fle7ffVvth/4lfI/aLeffl+7vfQL7fZ5ufyP2u2hP9yuv/7ddn3n
yv+0XT/95/jAfPkP2/3pT8r/ot1/9F9p9xf9SrvBvlX+N+3+oP9666/vt94v
lf9D66v/ZuupV9oN/mL0ejH6aPZxMx4vNI8Pmvu75vnJH8fjr/5A66G/1nr8
UflnWw/N9z9r/v7PH5b5e0j6L7Ye+qX24/1B+V+1HvqvtR76duvx++V/13ro
T7Qe+nHrcaP8H1sP/aOthx62Hv+nfKH10H+n3YB6tP2vPtpu///t7ddu7296
e7XbV3+63Z6/V77JgMsfbbeX/ly7ff5X+WG7PX63/Ml2/fUX2vX9RpkPDPxO
eaZdH32ZE0TKE+3+o4+3+8v/9PdNu3/8D39/tPuDPtn6f718q/X+Wvljra/+
PE8gymut32+XP9V66Yutzwvlsfa/+nq7/f+7jxec4OLv73b7fsX/Xrs9f8t/
v91+X7YvA/L3cbt9vuTjVfvxf9Ne7fr/hn3a9b301cdX1l/59OPnPsET/F8v
X27X57+WX2v/uYvlH2s/7xfLV9vP96vlH2o/z6+Uf7n9979Qnmj/vV8qv5sv
1C8/4ICrfJ0Tcso/3v7vP1v+cPuF8ZnyV5p/3uvXLr/xlbf9I+0B8uc//rbn
mj9T/lC7vp8t/yX+++Uf5ecr/8P2f3+u/PV2f/ml8qe4/uVb7QnFr5R/jtuv
zAHkF8uf4/bX9Cm/2P57v17+AfqWf5r+5YvcPz5e97f283yp/DHuX+Vf5P5X
/ib3z/IE99/yDPfv8he4/5cftsePr5Y/z37877Ov8i3258/DPss/yH79+dh3
+WfZf/kD/H4of5nfH+Wf4PdLmTckr3l9+P1U/iS/v7x+7fe3/hy//8of5fdj
+UV+f5Z/gd+v5Y/w+7f8NX4/l3+K39/l9/L7vfxr/P4vf4rHB/u3Hvpv8fhS
/k88/pSf8PhU/hs8fpX/PY9v5bs8/pV/mMfH8r/m8bP8Mo+v5b/M42/5n/P4
XP4DHr/Lf5bH9/I/4fG//Ds8Pyjv4vlD+RjPL8pXeP5RHuf5SfkIz1/Kl3h+
Ux7l+U95mudH5V/l+VN5i+dX0ePF6PFi9HgxerwUPV6KHi9Fj29Fj29Fj29F
jz+JHvr3eX4bPeaix1z0mIseL0ePl6PHy9HjlejxSvR4JXq8Gj1ejR6vRg/N
8/nXyv34pczzf92Pf8ocL2ief2uOL+bLPF/XHI9ont9rjl80xwOa451bZY4f
NMdH+t9y/Fnm9TT9KsevZV6Pe738Vzn+Lffj4zLHP7ofX5c5XtL9+Dx63I4e
t6PH7ehxO3ro/vpC9LhT7q9PRI870eNO9LgTPe5Ej4XosRA9FqLHQvRYiB4L
0eNu9LgbPfS/5PWl6KH/iNenoof+87y+FT3uRY970eNe9NDs4170uB/7uB89
7keP+9HjfvS4Hz0eRI8H0eNB9HgQPR5EjwfRYzF6LEaPxeixGD0Wo8di9FiM
Hg+jx8Po8TB6PIweur8+HT3eiB5vRI83oscb0eON6PFG9HgUPR5Fj0fR41H0
0Lye8ih6PC7z+svj6KH5ffU4emh+Xz2OHrq/P1Lu75+U+/sr0Uvz+p/u79+U
+/s70VPz+qLu7x+V+/tL0Vvzes6Tcn//qtzf34rfl5rXh3R//6zc318r8/qk
5vUm3d+/K/f398q8/qk5/+NJ9FiOHsvRQ3P+iu7vX0aP5eixHD2Wo8dy9FiO
HsvRYzl6rESPleixEj1WosdK9FiJHivRYyV6rESPleixEj1WosdK9FiNHqvR
YzV6rEaP1eixGj1Wo8dq9FiNHqvRYzV6rEaPQfQYRI9B9BhEj0H0GESPQfQY
RI9B9BhEj0H0GESPQfRYix5r0WMteqxFj7XosRY91qLHWvRYix5r0WMteqxF
j/XosR491qPHevRYjx7r0WM9eqxHj/XosR491qPHevRYjx4b0WMjemxEj43o
sRE9NqLHRvTYiB4b0WMjemxEj43osRk9NqPHZvTYjB6b0WMzemxGj83osRk9
NqPHZvTYjB6b0WMYPYbRYxg9htFjGD2G0WMYPYbRYxg9htFjGD2G0WMremxF
j63osRU9tqLHVvTYih5b0WMremxFj63osRU9tqLHdvTYjh7b0WM7emxHj+3o
sR09dP98c/TYjh7b0WM7euxEj53osRM9dqLHTvTYiR470WMneuxEj53osRM9
dqLHTvR4Gj2eRo+n0eNp9HgaPZ5GD83nnZ5Gj6fR42n0eBo9nkaPN6PHm9FD
83kv3c9/iB5vRo83o4fu51+UOV56M3q8GT10v3zi7f9PPz+k3M8fKffzS8r9
/JMy11f381fKXH/dz38p9/Njyv38mXI/v6bcz78pc3vpfv5OmbdnNPcH3c8P
Kvfzh8r9/KJyP/+ozO2t+/lL5X5+U5mnX5rLO8r9/KlyP7+qTA/dz88q9/O3
yv38rjI9dD8/rNzPHyv388vKvN+u+XsMup+/Vu7nt5Xpofv5ceV+/ly5n19X
5v1/zd9z1f38vXI/v6/cz/8r9/MDy1zeWe7nF5b5PILm8waa8991P7+x3M9/
LPfzI8v9/MlyP7+y/FOcf1mmh6aH/kXO7yzz9zd0Pz+03M8fLdNDf7n10PTQ
9NAvcn5rmb8PpDn/TPfzZ8tcvq38Xs6/LdND00P/YLsB9Uc5/7fM3+PQ/fzh
cj+/uEwPTQ9ND83nTTQ9ND10P3+63M+vLtND00PTQ/P5F00PTQ9ND93PLy9z
+fYyPTQ9ND00PTQ9ND10P7++3M+/L9ND00PTQ9ND00PTQ/fvFyj37x8o00PT
Q9ND00PTQ9ND00P3718ocxkt00PTQ9ND00PTQ9ND9++fKPfvpyjTQ9ND00PT
Q9ND00P3798o9+/nKNND00PTQ9ND00PTQ9ND9+8nKXP5jjI9ND00PTQ9ND00
PXT/fpZy//6WMj00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00l3eV
6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHp
oemhuby7TA9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9N
D00PTQ9ND00PzeU9ZXpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpo
emh6aHponu9qemh6aHpoemguY2V6aHpoemh6aHpoemh6aHpoemh6aHpoemh6
aHpoemh6aHpoemh6aHpoemh6aHpoemgu7y3TQ9ND00PTQ9ND00PTQ9ND/0Tr
oemh6aHpoemh6aHpoemhf6310PTQ9ND00PTQ9ND00PTQXL6zTA9ND00PTQ9N
D00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PzeW7yvTQ
9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND0
0Fy+u0wPTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9N
D00PTQ9ND81lvEwPTQ9ND00PTQ9ND00PTQ9ND02P8U+8/fcg6KHpoemh6aHp
oemh6aF/q/XQX289NM93NT00PTQ9ND001/q5Z6/PqObp0XPPXr9xzevxzz17
fXdp+j337PXfo+mp2z+3T9NXt3wHNL11u/8e0vTX7f48qfvff3n29px+ru4P
PN/T7fY9onk/QPP3lTX3H83fZ9a8Pq3bZVZz/9Lt6p7S3N80p+No7n+a04l0
//s/5dbjgub5pm49Lmnej9D8/WDN7xPN3x/W/H7R/e8jlbl/R4+56DEfPRai
x2L0WIoeg+gxjB4j31NmH5p9aPah2YdmH5p96P73scrsQ7MPzT40+9DsQ7MP
zT40+9D974eV2YdmH5p9aPah2YdmH5p9aPah22U2epyMHqeix2ndHl/ORI+z
0eNc9DgfPS5Ej4vR41L0uBw9rkSPq9HjWvS4Hj1uRI+b0WMuesxHj4XosRg9
lqLHIHoMo8fI+8rsQ7MPzT40j/eafWj2odmHZh+afWj2odmHZh+afWj2odmH
7n9/ssw+NPvQ7EOzD80+NPvQ7EOzD90us9HjZPQ4FT1OR48z0eNs9DgXPc5H
jwvR42L0uBQ9LkePK9HjavS4Fj2uR48b0eNm9JiLHvPRYyF6LEaPpegx0O35
4TB6jLy/zD40+9DsQ7MPzT70D7R9aPah2YdmH5p9aPah2YdmH5p96Pb8dFL3
v19cZh+afWj2oXk+rtmH/rm2D80+NM/X9Tve+p/Z6HFSt+ORU9HjdPQ4Ez3O
Ro9z0eN89Ligef4fPS5pjs+ixxXN8UH0uBY9ruu/3fYRPW7qdjw0Fz3mo8dC
9FiMHkvRYxA9htFjZKLMPjTHh5p9aPah2YdmH5p9aPahW499mn3o1uOAZh+6
9Tik2YdmH7r1mNLsQ3N8qtmHZh+afWj2odmHZh+afUSPk9HjVPQ4HT3ORI+z
0eNc9DgfPS5Ej4vR41L0uBw9rkSPq9HjWvS4Hj1uRI+b0WMuesxHj4XosRg9
lqLHIHoMo8fIB8rsQ7MPzT40+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7MPzT40
+9DsQ7MPzT40+9DsQ7MPzT40+9DsI3qcjB6nosdp/XzbR/Q4Gz3ORY/z0eNC
9LgYPS5Fj8vR40r0uBo9rkWP69HjRvS4GT3mosd89FiIHovRYyl6DKLHMHqM
PF9mH5p9aPahW48JzT40+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7OP5/vrV9/o
r19p9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yf
mn1o9qHZh2Yfmn1Ej5vRYy56zEePheixGD2WosfA+wP70Ozje8vsQ7MPzT40
+9DsQ7MPzT40+9DsQ7MPzT40+9DsQ7MPzT40xx+afWj2odmH/um2D80+NPvQ
7EOzD80+osfJ6HEqepyOHmeix9nocS56nI8eF6LHxehxKXpcjh5XosfV6HEt
elyPHjeix83oMRc95qPHQvRYjB5L0WMQPYbRY+SDZfah2YdmH5p9aPah2Ydm
H5p9aPah2YdmH5p9aPah2YdmH5p9aPah2YdmH5p9aPah2YdmH5p9aPYRPU5G
j1PR43T0OBM9zkaPc9HjfPS4ED0uRo9L0eNy9LgSPa5Gj2vR43r0uBE9bkaP
uegxHz0Wosdi9FiKHoPoMYweI7vK7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+
NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7EOzD80+NPvQ7CN6nIwep6LH6ehxJnqc
jR7nosf56HEhelyMHpeix+XocSV6XI0e16LH9ehxI3rcjB5z0WM+eixEj8Xo
sRQ9BtFjGD1GPlRmH5p9aPah2YdmH5p9aPah2YdmH5p9aPah2YdmH5p9aPah
2YdmH5p9aPah2YdmH5p9aPah2YdmH9HjZPQ4FT1OR48z0eNs9DgXPc5HjwvR
42L0uBQ9LkePK9HjavS4Fj2uR48b0eNm9JiLHvPRYyF6LEaPpegxiB7D6DHy
fWX2odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2odmHZh+afWj2odmHZh+a
fWj2odmHZh+afWj2ET1ORo9T0eN09DgTPc5Gj3PR43z0uBA9LkaPS9HjcvS4
Ej2uRo9r0eO65vg8etyMHnPRYz56LESPxeixFD0G0WMYPUY+XGYfmn1o9qHZ
h2Yfmn1o9qHZh2Yfmn1o9qHZh2Yfmn1o9qF5/UqzD80+NPvQ7EOzD80+NPvQ
7EOzj+hxMnqcih6no8eZ6HE2epyLHuejx4XocTF6XIoel6PHlehxNXpcix7X
o8eN6HEzesxFj/nosRA9FqPHUvQYRI9h9Bj5/jL70OxDsw/NPjT70OxDsw/N
PjT70OxDsw/NPjT70OxDsw/N44dmH5r3zzX70Hy+RLMPzfdJaPah+X4J3S6z
mu+b0Hy+JHqc1nw+MXqc1e3ufC56nNft7nJB8/kS3b5/45Lm8yW6Xd0rmu+z
0O2fu6b5fgvd7s43NN93ET3mNN+fEj0WNN+/ED2WNN+PET2G0WNkd7n1GNV8
vkTzcWfN27+aw0HN92vodnX3aL5vQ/P5Es33oWg+X6L5/gfdehzSfD+Hbjkm
Nd+Ho1uPac0+dOtxRLMP3Xoc0+xDtx4nNPvQ7TIbPU5Gj1PR43T0OBM9zkaP
c9HjfPS4ED0uRo9L0eNy9LgSPa5Gj2vR43r0uBE9bkaPuegxHz0Wosdi9FiK
HoPoMYweIx8psw/NPjT70OxDsw/NzafZh2Yfmn1o9qHZh2Yfmn1o9qHZh2Yf
mn1o9qHZh2Yfmn1o9qHZh2Yful1mo8fJ6HEqepyOHmeix9nocS56nI8eF6LH
Rf1/Adg5AWg=
      "], {{{}, {
         EdgeForm[], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[1]], 
         GraphicsGroup[{
           Polygon[CompressedData["
1:eJwVztdCCGAAQOG/UimVUkIpCu2SVREiW0STklEPwIvYe6SUvS5tFVGIhsTz
+Lr4rs/J6TrTeDoyhBBNLq8iQvjHX2b4wzS/mWKSCcb5xU/G+MF3vjHKCF/5
wjCf+cQQgwzwkQ+85x1vecNrIqL8kMNylpFNFkvJJIMlLGYR6SwkjVQWkEIy
80kikQTmEU8cc4klhmjmEEXkbD8mhFq2s40atrKFzVSziY1UUUkFG1jPOtay
hnJWU0YpJRRTRCEF5JPHKlaygtzZflwIXXRyipOc4DgdHKOdNo5yhFZaaKaJ
Rho4zCHqOcgB6tjPPvayh93sYic7qOVsfAgvecFznvGUJzzmEQ95wH366eMe
vfRwl27ucJtb3OQG17nGVa5wmUtc5ALnOcd/wUBIcw==
            "]]}]}, {}, {}}, {{}, {}, 
        Annotation[{
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwl20MQGDy7BtC/tm3btm3btq2vtm3btm3btu32ns5dnMkmu0z05kmChu0q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           "]]}, "Charting`Private`Tag#1"]}}], <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-7.92, 7.92}, {0, 4.233870967741935}}, 
        "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {{{}, {
            EdgeForm[], 
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[1]], 
            GraphicsGroup[{{
               Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQ/U0jpv/QV7EDDFBwBgR8EPygHXKtrwPFDpyzfD6n
+NxJ++uLC2y5whF8kG6NGAT/YZXIOvdEBD8NDBD8N4FAA7MRfKBpQCMRfLB7
ShH8aqBxD6sQfLCjGhB8oOOABiL4INNsuxD8CSDn9SP4YOOmIPizZoIAgg/y
7Y55CP4SsAMRfE2Qh1cg+CDjRNYh+MYgsBnBBwffDgTfDuTAvQg+2HmHEHwP
kHHHEXxwfJxB8MHxcREtPq6jxccdtPh4iBYfz9Di4zVafHxA8AGIOyFZ
                "]], 
               Polygon[CompressedData["
1:eJxd0SEIwlAQBuCHYFnZCyuWgVqWDFo0DMGyYtmqJmFWB7Zlra4q2GZeXhzL
sqhVk+jysnqH7Od5MMZXfu7+116sPL8hhOh8P/p7qbktXZmJ37hsvfYsyitr
rmfF6HFcF8+xv6SBA1u7xgEcGolzD+FNSYnwjuIieH+ggWMOhCnNSGBeL4U5
LofPPPCFA+EbLwi/+GCY4yr4zfN3T1PWputtTar36TDXYcB8bgvmc0z4ROt2
YV7HkmofPbg/oJFqP0OYn8eWal8TmOt1pNrfFP4Aq6cj8g==
                "]], 
               Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQPUFknfvDqi37GaBg3VeNmP5DW+1h/AyIvP37vd/v
Vb8XcFAwBoHNcP6NwB1yra83wvkTCmy5ri/egOADZQN3rIPzGYCmf9VYA+cX
zQSBlXD+o2uLgSYsh/ODwPYvgfOPgO1bCOdngs2fB+d7g82bCefrgPVPgfOl
wOr74Pw7wiD5FjjfBswvQbgXDLbsgfH3iILl98P4MmB+C5wfKQ82H84/A7Ef
zn8FcR+czwFWPw/OFwkC+w/OXwTxP5xvdB0cPnD+IUj4wfkBkPCF8x9Awh/O
3wGJHzifAWzfRjjfAxK/cD4AsqYvew==
                "]], 
               Polygon[CompressedData["
1:eJxV0CEMAVEYB/CbTbnyBEVhKCYoBAJuCkG5KwrFhohppp56KtNOPvUmIp6r
p55iRiV732P3333b29uv/Pd9/3R/rA0ikiRl+KO/ZxzfuS5TpP9czUlV7sQC
a3ZSf6oxxa3ctzP3Ub84fNpwy5/HrSZ84mlGA67JHk+ERVwZLhVpYKvJAwtw
vksLwju+npeFUzzOTsKbNZ8EHBeB8EqcC4v1ZHhJcVH41wL8ydFCLPBLpYvg
G9Xhw6JPD3apPwc+U19H+ED92PCe1rdY+H6The9ds/B9Bgvfo8MLUQg8pbgJ
PBrSwF9uWAzF
                "]], 
               Polygon[CompressedData["
1:eJxTTMoPSmViYGBQAmIQfe4MEPiIOTBAwTeNmP5DXxH8Iluu64s/iDmcs3w+
p/jcSfs3gTvkWl8j+OlpQPAMwX9UJbLO/SGCHws0TeMOgn9jcQHQRAQ/GGTc
RQQf7J4zCL7HQ6CBxxH8I19BDkTw7YDOK9iL4O8EGhe4A8E3MQaCzQj+eneQ
gQi+Fsi7KxD8JSDnLUbwFUDGzUPwZ80EAQRfDOjbqikI/oRDIAci+NxA59l2
Ifhtr0EBiOAzggK5AcGvAQVfFYIPjo9SBB8cHwVo8ZGNFh9paPGRiBYfMWjx
EY4WH4EIPgC65BB5
                "]]}}]}, {}, {}}, {{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxd3X1M3ftBx/GzTdzGplw3dpU5maZG60PqQ2dSo90WjHaJmIxrIlHZHxhF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              "]]}, "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"T65.78\"", TraditionalForm],
  PlotRange->{{-7.92, 7.92}, {0, 4.233870967741935}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.910156315990061*^9, 3.9101564306546116`*^9}, {
  3.91015646453283*^9, 3.9101564749888444`*^9}},
 CellLabel->"Out[5]=",ExpressionUUID->"b8f815d7-aba7-4296-b0b2-83c2ef0d1789"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos\>\"", "Input"], 
         StyleBox[",", "Input"], 
         StyleBox[
          RowBox[{"ToString", "@", 
           RowBox[{"StringForm", "[", 
            RowBox[{"\"\<dos_{8,8}-tess_T65.78_``.dat\>\"", ",", "#"}], 
            "]"}]}], "Input"]}], "}"}], "]"}], "]"}], "&"}], "/@", 
    RowBox[{"Association", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<10\>\"", "->", "\"\<10\>\""}], ",", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[\(10\), \(2\)]\)\>\"", "->", 
        "\"\<10^2\>\""}], ",", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[\(10\), \(3\)]\)\>\"", "->", 
        "\"\<10^3\>\""}], ",", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[\(10\), \(4\)]\)\>\"", "->", 
        "\"\<10^4\>\""}], ",", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[\(10\), \(7\)]\)\>\"", "->", 
        "\"\<10^7\>\""}]}], "}"}], "]"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.01"}], ",", "0.21"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "->", "\"\<T65.78\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "5"}], "]"}], "/", "5."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.910155735825778*^9, 3.910155791197442*^9}, {
  3.910155864815923*^9, 3.9101559579728274`*^9}, {3.91015599876518*^9, 
  3.9101560324150867`*^9}, {3.910156065669032*^9, 3.91015608123988*^9}, {
  3.9101561179149127`*^9, 3.910156125200875*^9}, {3.910156220339597*^9, 
  3.9101562209536443`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"ab533ebd-9df3-428e-83e4-f4760fcc719d"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8423264, 0.4188294]], 
         LineBox[CompressedData["
1:eJxd2D+I23Uch/EjS6BkCZzGP2klS7iSJVizBKtZgpIlWLIESgaDkikWsoSK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          "]], 
         LineBox[{{-5.235859999999999, 0.21}, {-5.2325, 
          0.}, {-5.227499999999999, 0.}, {-5.2225, 0.}, {-5.217499999999999, 
          0.}, {-5.2141399999999996`, 0.21}}], 
         LineBox[{{-5.210859999999999, 0.21}, {-5.2075, 
          0.}, {-5.204139999999999, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQHeGTY7furMiBh1Ui69wfnrLnur64wPaUyAEGKGh5
HbhD7iiCDwYHEHywtl0I/jeNmP5DWxH8AlugiRsQfJBxrasR/DQQWIbgPwAZ
uBDBB5r2VWMOgn8N6Dyu6Qh+ENC41xMR/DMg0IPge4A81o7gA02L6W9C8G1A
Hq5F8EHGBVYg+AJPFrTMLEOEDwCoo1Na
          "]], 
         LineBox[{{-5.109179999999999, 0.21}, {-5.1075, 
          0.}, {-5.102499999999999, 0.}, {-5.0975, 0.}, {-5.092499999999999, 
          0.}, {-5.0891399999999996`, 0.21}}], 
         LineBox[{{-5.085859999999999, 0.21}, {-5.0825, 
          0.}, {-5.077499999999999, 0.}, {-5.0725, 0.}, {-5.067499999999999, 
          0.}, {-5.0625, 0.}, {-5.057499999999999, 0.}, {-5.0525, 
          0.}, {-5.047499999999999, 0.}, {-5.0424999999999995`, 
          0.}, {-5.040819999999999, 0.21}}], 
         LineBox[{{-5.034179999999999, 0.21}, {-5.032499999999999, 
          0.}, {-5.0275, 0.}, {-5.022499999999999, 0.}, {-5.0175, 
          0.}, {-5.014139999999999, 0.21}}], 
         LineBox[{{-5.010859999999999, 0.21}, {-5.0075, 
          0.}, {-5.0024999999999995`, 0.}, {-4.997499999999999, 0.}, {-4.9925,
           0.}, {-4.987499999999999, 0.}, {-4.9825, 0.}, {-4.977499999999999, 
          0.}, {-4.9725, 0.}, {-4.967499999999999, 0.}, {-4.9624999999999995`,
           0.}, {-4.95914, 0.21}}], 
         LineBox[{{-4.9558599999999995`, 0.21}, {-4.952499999999999, 
          0.}, {-4.9475, 0.}, {-4.944139999999999, 0.21}}], 
         LineBox[{{-4.940859999999999, 0.21}, {-4.9375, 
          0.}, {-4.932499999999999, 0.}, {-4.9275, 0.}, {-4.922499999999999, 
          0.}, {-4.9174999999999995`, 0.}, {-4.9125, 0.}, {-4.907499999999999,
           0.}, {-4.9025, 0.}, {-4.899139999999999, 0.21}}], 
         LineBox[{{-4.885859999999999, 0.21}, {-4.882499999999999, 
          0.}, {-4.8774999999999995`, 0.}, {-4.872499999999999, 0.}, {-4.8675,
           0.}, {-4.862499999999999, 0.}, {-4.8575, 0.}, {-4.854139999999999, 
          0.21}}], 
         LineBox[{{-4.850859999999999, 0.21}, {-4.8475, 
          0.}, {-4.842499999999999, 0.}, {-4.8374999999999995`, 0.}, {-4.8325,
           0.}, {-4.830819999999999, 0.21}}], 
         LineBox[{{-4.82086, 0.21}, {-4.817499999999999, 0.}, {-4.81414, 
          0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQfaqzTDTITvjAwyqRde4PT9mDKSvhAwxQ8E0jpv+Q
KYJfYMt1fbEBgv86cIdcqzaCnwYCagj+A5CBigg+0LSvGjII/rXFQBPFEfwg
oHGvBRH8MyDAg+C7gxzKjuADTYvpZ0LwbYDOK/grBOeDjAv8geAbGQPBZwR/
HcjAdwg+yLtfXyD4O+8v1LjwXAgePgAsiVC1
          "]], 
         LineBox[{{-4.71862, 0.21}, {-4.717499999999999, 
          0.}, {-4.7124999999999995`, 0.}, {-4.7075, 0.}, {-4.702499999999999,
           0.}, {-4.6975, 0.}, {-4.692499999999999, 0.}, {-4.6875, 
          0.}, {-4.682499999999999, 0.}, {-4.6775, 0.}, {-4.672499999999999, 
          0.}, {-4.6674999999999995`, 0.}, {-4.665819999999999, 0.21}}], 
         LineBox[{{-4.659179999999999, 0.21}, {-4.657499999999999, 
          0.}, {-4.6525, 0.}, {-4.647499999999999, 0.}, {-4.64414, 0.21}}], 
         LineBox[{{-4.64086, 0.21}, {-4.637499999999999, 
          0.}, {-4.632499999999999, 0.}, {-4.6274999999999995`, 
          0.}, {-4.622499999999999, 0.}, {-4.6175, 0.}, {-4.612499999999999, 
          0.}, {-4.6075, 0.}, {-4.604139999999999, 0.21}}], 
         LineBox[{{-4.600859999999999, 0.21}, {-4.5975, 
          0.}, {-4.592499999999999, 0.}, {-4.5891399999999996`, 0.21}}], 
         LineBox[{{-4.585859999999999, 0.21}, {-4.5825, 
          0.}, {-4.577499999999999, 0.}, {-4.5725, 0.}, {-4.567499999999999, 
          0.}, {-4.5625, 0.}, {-4.557499999999999, 0.}, {-4.5525, 
          0.}, {-4.547499999999999, 0.}, {-4.5424999999999995`, 0.}, {-4.5375,
           0.}, {-4.532499999999999, 0.}, {-4.52914, 0.21}}], 
         LineBox[{{-4.52586, 0.21}, {-4.522499999999999, 0.}, {-4.5175, 
          0.}, {-4.514139999999999, 0.21}}], 
         LineBox[{{-4.510859999999999, 0.21}, {-4.507499999999999, 
          0.}, {-4.50414, 0.21}}], 
         LineBox[{{-4.500859999999999, 0.21}, {-4.497499999999999, 
          0.}, {-4.49414, 0.21}}], 
         LineBox[{{-4.49086, 0.21}, {-4.487499999999999, 0.}, {-4.4825, 
          0.}, {-4.477499999999999, 0.}, {-4.4725, 0.}, {-4.4691399999999994`,
           0.21}}], 
         LineBox[{{-4.460859999999999, 0.21}, {-4.4575, 
          0.}, {-4.454139999999999, 0.21}}], 
         LineBox[{{-4.450859999999999, 0.21}, {-4.4475, 
          0.}, {-4.442499999999999, 0.}, {-4.4375, 0.}, {-4.432499999999999, 
          0.}, {-4.427499999999999, 0.}, {-4.422499999999999, 
          0.}, {-4.4174999999999995`, 0.}, {-4.4125, 0.}, {-4.407499999999999,
           0.}, {-4.405819999999999, 0.21}}], 
         LineBox[{{-4.399179999999999, 0.21}, {-4.397499999999999, 
          0.}, {-4.3925, 0.}, {-4.389139999999999, 0.21}}], 
         LineBox[{{-4.385859999999999, 0.21}, {-4.382499999999999, 
          0.}, {-4.3774999999999995`, 0.}, {-4.3725, 0.}, {-4.3675, 
          0.}, {-4.362499999999999, 0.}, {-4.3575, 0.}, {-4.352499999999999, 
          0.}, {-4.3475, 0.}, {-4.342499999999999, 0.}, {-4.3374999999999995`,
           0.}, {-4.33414, 0.21}}], 
         LineBox[{{-4.3308599999999995`, 0.21}, {-4.327499999999999, 
          0.}, {-4.32414, 0.21}}], 
         LineBox[{{-4.32086, 0.21}, {-4.317499999999999, 0.}, {-4.3125, 
          0.}, {-4.307499999999999, 0.}, {-4.302499999999999, 
          0.}, {-4.297499999999999, 0.}, {-4.2924999999999995`, 0.}, {-4.2875,
           0.}, {-4.284139999999999, 0.21}}], 
         LineBox[{{-4.280859999999999, 0.21}, {-4.2775, 
          0.}, {-4.272499999999999, 0.}, {-4.26914, 0.21}}], 
         LineBox[{{-4.26586, 0.21}, {-4.262499999999999, 
          0.}, {-4.2591399999999995`, 0.21}}], 
         LineBox[{{-4.24086, 0.21}, {-4.237499999999999, 0.}, {-4.2325, 
          0.}, {-4.227499999999999, 0.}, {-4.2225, 0.}, {-4.2191399999999994`,
           0.21}}], 
         LineBox[{{-4.215859999999999, 0.21}, {-4.2124999999999995`, 
          0.}, {-4.2075, 0.}, {-4.202499999999999, 0.}, {-4.1975, 
          0.}, {-4.192499999999999, 0.}, {-4.1875, 0.}, {-4.184139999999999, 
          0.21}}], 
         LineBox[{{-4.180859999999999, 0.21}, {-4.177499999999999, 
          0.}, {-4.172499999999999, 0.}, {-4.1674999999999995`, 0.}, {-4.1625,
           0.}, {-4.157499999999999, 0.}, {-4.1525, 0.}, {-4.149139999999999, 
          0.21}}], 
         LineBox[{{-4.145859999999999, 0.21}, {-4.1425, 
          0.}, {-4.137499999999999, 0.}, {-4.132499999999999, 0.}, {-4.12914, 
          0.21}}], 
         LineBox[{{-4.125859999999999, 0.21}, {-4.1225, 0.}, {-4.1175, 
          0.}, {-4.114139999999999, 0.21}}], 
         LineBox[{{-4.110859999999999, 0.21}, {-4.1075, 
          0.}, {-4.102499999999999, 0.}, {-4.0975, 0.}, {-4.092499999999999, 
          0.}, {-4.0891399999999996`, 0.21}}], 
         LineBox[{{-4.085859999999999, 0.21}, {-4.0825, 
          0.}, {-4.077499999999999, 0.}, {-4.0725, 0.}, {-4.067499999999999, 
          0.}, {-4.0625, 0.}, {-4.057499999999999, 0.}, {-4.052499999999999, 
          0.}, {-4.0491399999999995`, 0.21}}], 
         LineBox[{{-4.0408599999999995`, 0.21}, {-4.0375, 
          0.}, {-4.034139999999999, 0.21}}], 
         LineBox[{{-4.030859999999999, 0.21}, {-4.0275, 
          0.}, {-4.024139999999999, 0.21}}], 
         LineBox[{{-4.020859999999999, 0.21}, {-4.0175, 
          0.}, {-4.014139999999999, 0.21}}], 
         LineBox[{{-4.005859999999999, 0.21}, {-4.0024999999999995`, 
          0.}, {-3.9974999999999996`, 0.}, {-3.9924999999999993`, 
          0.}, {-3.9891399999999995`, 0.21}}], 
         LineBox[{{-3.9858599999999993`, 0.21}, {-3.9824999999999995`, 
          0.}, {-3.9791399999999997`, 0.21}}], 
         LineBox[{{-3.9758599999999995`, 0.21}, {-3.9724999999999997`, 
          0.}, {-3.9674999999999994`, 0.}, {-3.9641399999999996`, 0.21}}], 
         LineBox[{{-3.9558599999999995`, 0.21}, {-3.9524999999999992`, 
          0.}, {-3.9474999999999993`, 0.}, {-3.9424999999999994`, 
          0.}, {-3.9374999999999996`, 0.}, {-3.9341399999999997`, 0.21}}], 
         LineBox[{{-3.9308599999999996`, 0.21}, {-3.9274999999999993`, 
          0.}, {-3.9224999999999994`, 0.}, {-3.9174999999999995`, 
          0.}, {-3.9141399999999993`, 0.21}}], 
         LineBox[{{-3.910859999999999, 0.21}, {-3.9074999999999993`, 
          0.}, {-3.9024999999999994`, 0.}, {-3.8974999999999995`, 
          0.}, {-3.8941399999999997`, 0.21}}], 
         LineBox[{{-3.8908599999999995`, 0.21}, {-3.8874999999999997`, 
          0.}, {-3.8841399999999995`, 0.21}}], 
         LineBox[{{-3.8758599999999994`, 0.21}, {-3.8724999999999996`, 
          0.}, {-3.8674999999999993`, 0.}, {-3.8624999999999994`, 
          0.}, {-3.8574999999999995`, 0.}, {-3.8524999999999996`, 
          0.}, {-3.8474999999999997`, 0.}, {-3.8424999999999994`, 
          0.}, {-3.8374999999999995`, 0.}, {-3.8324999999999996`, 
          0.}, {-3.8274999999999992`, 0.}, {-3.8224999999999993`, 
          0.}, {-3.8191399999999995`, 0.21}}], 
         LineBox[{{-3.8158599999999994`, 0.21}, {-3.8124999999999996`, 
          0.}, {-3.8091399999999997`, 0.21}}], 
         LineBox[{{-3.8058599999999996`, 0.21}, {-3.8024999999999993`, 
          0.}, {-3.7974999999999994`, 0.}, {-3.7924999999999995`, 
          0.}, {-3.787499999999999, 0.}, {-3.7824999999999993`, 
          0.}, {-3.7774999999999994`, 0.}, {-3.7724999999999995`, 
          0.}, {-3.7674999999999996`, 0.}, {-3.7624999999999997`, 
          0.}, {-3.7591399999999995`, 0.21}}], 
         LineBox[{{-3.7558599999999993`, 0.21}, {-3.7524999999999995`, 
          0.}, {-3.7474999999999996`, 0.}, {-3.7424999999999993`, 
          0.}, {-3.7374999999999994`, 0.}, {-3.7341399999999996`, 0.21}}], 
         LineBox[{{-3.7308599999999994`, 0.21}, {-3.7274999999999996`, 
          0.}, {-3.72414, 0.21}}], 
         LineBox[{{-3.7058599999999995`, 0.21}, {-3.7024999999999992`, 
          0.}, {-3.6974999999999993`, 0.}, {-3.6941399999999995`, 0.21}}], 
         LineBox[{{-3.6908599999999994`, 0.21}, {-3.6874999999999996`, 
          0.}, {-3.6824999999999997`, 0.}, {-3.6774999999999993`, 
          0.}, {-3.6724999999999994`, 0.}, {-3.6674999999999995`, 
          0.}, {-3.662499999999999, 0.}, {-3.6591399999999994`, 0.21}}], 
         LineBox[{{-3.655859999999999, 0.21}, {-3.6524999999999994`, 
          0.}, {-3.6474999999999995`, 0.}, {-3.6424999999999996`, 
          0.}, {-3.6374999999999997`, 0.}, {-3.6324999999999994`, 
          0.}, {-3.6308199999999995`, 0.21}}], 
         LineBox[{{-3.615859999999999, 0.21}, {-3.6124999999999994`, 
          0.}, {-3.6074999999999995`, 0.}, {-3.6024999999999996`, 
          0.}, {-3.5974999999999997`, 0.}, {-3.5941399999999994`, 0.21}}], 
         LineBox[{{-3.5908599999999993`, 0.21}, {-3.5874999999999995`, 
          0.}, {-3.5824999999999996`, 0.}, {-3.5774999999999992`, 
          0.}, {-3.5724999999999993`, 0.}, {-3.5674999999999994`, 
          0.}, {-3.5624999999999996`, 0.}, {-3.5574999999999997`, 
          0.}, {-3.5524999999999993`, 0.}, {-3.5491399999999995`, 0.21}}], 
         LineBox[{{-3.5408599999999995`, 0.21}, {-3.537499999999999, 
          0.}, {-3.5324999999999993`, 0.}, {-3.5291399999999995`, 0.21}}], 
         LineBox[{{-3.5258599999999993`, 0.21}, {-3.5224999999999995`, 
          0.}, {-3.5191399999999997`, 0.21}}], 
         LineBox[{{-3.5158599999999995`, 0.21}, {-3.5124999999999997`, 
          0.}, {-3.5091399999999995`, 0.21}}], 
         LineBox[{{-3.5058599999999993`, 0.21}, {-3.5024999999999995`, 
          0.}, {-3.4991399999999997`, 0.21}}], 
         LineBox[{{-3.490859999999999, 0.21}, {-3.4874999999999994`, 
          0.}, {-3.4841399999999996`, 0.21}}], 
         LineBox[{{-3.4808599999999994`, 0.21}, {-3.4774999999999996`, 
          0.}, {-3.47414, 0.21}}], 
         LineBox[{{-3.4708599999999996`, 0.21}, {-3.4674999999999994`, 
          0.}, {-3.4641399999999996`, 0.21}}], 
         LineBox[{{-3.4608599999999994`, 0.21}, {-3.4574999999999996`, 
          0.}, {-3.4524999999999992`, 0.}, {-3.4474999999999993`, 
          0.}, {-3.4424999999999994`, 0.}, {-3.4374999999999996`, 
          0.}, {-3.4341399999999993`, 0.21}}], 
         LineBox[{{-3.430859999999999, 0.21}, {-3.4274999999999993`, 
          0.}, {-3.4224999999999994`, 0.}, {-3.4174999999999995`, 
          0.}, {-3.4124999999999996`, 0.}, {-3.4091399999999994`, 0.21}}], 
         LineBox[{{-3.3991799999999994`, 0.21}, {-3.3974999999999995`, 
          0.}, {-3.3958199999999996`, 0.21}}], 
         LineBox[{{-3.389179999999999, 0.21}, {-3.3874999999999993`, 
          0.}, {-3.3841399999999995`, 0.21}}], 
         LineBox[{{-3.3808599999999993`, 0.21}, {-3.3774999999999995`, 
          0.}, {-3.3724999999999996`, 0.}, {-3.3674999999999997`, 
          0.}, {-3.3624999999999994`, 0.}, {-3.3574999999999995`, 
          0.}, {-3.3524999999999996`, 0.}, {-3.3474999999999993`, 
          0.}, {-3.3424999999999994`, 0.}, {-3.3374999999999995`, 
          0.}, {-3.3324999999999996`, 0.}, {-3.3291399999999998`, 0.21}}], 
         LineBox[{{-3.3208599999999993`, 0.21}, {-3.3174999999999994`, 
          0.}, {-3.3124999999999996`, 0.}, {-3.307499999999999, 
          0.}, {-3.3024999999999993`, 0.}, {-3.2974999999999994`, 
          0.}, {-3.2924999999999995`, 0.}, {-3.2874999999999996`, 
          0.}, {-3.2824999999999993`, 0.}, {-3.2774999999999994`, 
          0.}, {-3.2724999999999995`, 0.}, {-3.2691399999999993`, 0.21}}], 
         LineBox[{{-3.265859999999999, 0.21}, {-3.2624999999999993`, 
          0.}, {-3.2591399999999995`, 0.21}}], 
         LineBox[{{-3.2508599999999994`, 0.21}, {-3.2474999999999996`, 
          0.}, {-3.2424999999999997`, 0.}, {-3.2374999999999994`, 
          0.}, {-3.2324999999999995`, 0.}, {-3.2274999999999996`, 
          0.}, {-3.2258199999999997`, 0.21}}], 
         LineBox[{{-3.2191799999999993`, 0.21}, {-3.2174999999999994`, 
          0.}, {-3.2141399999999996`, 0.21}}], 
         LineBox[{{-3.2108599999999994`, 0.21}, {-3.2074999999999996`, 
          0.}, {-3.2041399999999998`, 0.21}}], 
         LineBox[{{-3.2008599999999996`, 0.21}, {-3.1974999999999993`, 
          0.}, {-3.1924999999999994`, 0.}, {-3.1874999999999996`, 
          0.}, {-3.1841399999999993`, 0.21}}], 
         LineBox[{{-3.180859999999999, 0.21}, {-3.1774999999999993`, 
          0.}, {-3.1724999999999994`, 0.}, {-3.1674999999999995`, 
          0.}, {-3.1624999999999996`, 0.}, {-3.1574999999999993`, 
          0.}, {-3.1524999999999994`, 0.}, {-3.1491399999999996`, 0.21}}], 
         LineBox[{{-3.1458599999999994`, 0.21}, {-3.142499999999999, 
          0.}, {-3.1391399999999994`, 0.21}}], 
         LineBox[{{-3.135859999999999, 0.21}, {-3.1324999999999994`, 
          0.}, {-3.1274999999999995`, 0.}, {-3.1224999999999996`, 
          0.}, {-3.1174999999999997`, 0.}, {-3.11582, 0.21}}], 
         LineBox[{{-3.1058599999999994`, 0.21}, {-3.1024999999999996`, 
          0.}, {-3.1008199999999997`, 0.21}}], 
         LineBox[{{-3.0941799999999993`, 0.21}, {-3.0924999999999994`, 
          0.}, {-3.0874999999999995`, 0.}, {-3.0824999999999996`, 
          0.}, {-3.0774999999999997`, 0.}, {-3.0724999999999993`, 
          0.}, {-3.0674999999999994`, 0.}, {-3.0641399999999996`, 0.21}}], 
         LineBox[{{-3.0491799999999993`, 0.21}, {-3.0474999999999994`, 
          0.}, {-3.0424999999999995`, 0.}, {-3.0374999999999996`, 
          0.}, {-3.0341399999999994`, 0.21}}], 
         LineBox[{{-3.030859999999999, 0.21}, {-3.0274999999999994`, 
          0.}, {-3.0224999999999995`, 0.}, {-3.017499999999999, 
          0.}, {-3.0124999999999993`, 0.}, {-3.0074999999999994`, 
          0.}, {-3.0024999999999995`, 0.}, {-2.9974999999999996`, 
          0.}, {-2.9924999999999997`, 0.}, {-2.9874999999999994`, 
          0.}, {-2.9824999999999995`, 0.}, {-2.9774999999999996`, 
          0.}, {-2.9724999999999993`, 0.}, {-2.9674999999999994`, 
          0.}, {-2.9624999999999995`, 0.}, {-2.9591399999999997`, 0.21}}], 
         LineBox[{{-2.9558599999999995`, 0.21}, {-2.9524999999999997`, 
          0.}, {-2.9474999999999993`, 0.}, {-2.9424999999999994`, 
          0.}, {-2.9391399999999996`, 0.21}}], 
         LineBox[{{-2.9358599999999995`, 0.21}, {-2.932499999999999, 
          0.}, {-2.9291399999999994`, 0.21}}], 
         LineBox[{{-2.9258599999999992`, 0.21}, {-2.9224999999999994`, 
          0.}, {-2.9191399999999996`, 0.21}}], 
         LineBox[{{-2.9158599999999995`, 0.21}, {-2.9124999999999996`, 
          0.}, {-2.9091399999999994`, 0.21}}], 
         LineBox[{{-2.905859999999999, 0.21}, {-2.9024999999999994`, 
          0.}, {-2.8991399999999996`, 0.21}}], 
         LineBox[{{-2.8958599999999994`, 0.21}, {-2.892499999999999, 
          0.}, {-2.8874999999999993`, 0.}, {-2.8824999999999994`, 
          0.}, {-2.8775, 0.}, {-2.8725, 0.}, {-2.8674999999999997`, 
          0.}, {-2.86414, 0.21}}], 
         LineBox[{{-2.8608599999999997`, 0.21}, {-2.8575, 0.}, {-2.85582, 
          0.21}}], 
         LineBox[{{-2.84586, 0.21}, {-2.8425, 0.}, {-2.8375, 0.}, {-2.8325, 
          0.}, {-2.8274999999999997`, 0.}, {-2.82414, 0.21}}], 
         LineBox[{{-2.8208599999999997`, 0.21}, {-2.8175, 0.}, {-2.8125, 
          0.}, {-2.80914, 0.21}}], 
         LineBox[{{-2.80586, 0.21}, {-2.8024999999999998`, 0.}, {-2.7975, 
          0.}, {-2.7925, 0.}, {-2.7891399999999997`, 0.21}}], 
         LineBox[{{-2.7808599999999997`, 0.21}, {-2.7775, 0.}, {-2.7725, 
          0.}, {-2.76914, 0.21}}], 
         LineBox[{{-2.76586, 0.21}, {-2.7624999999999997`, 0.}, {-2.7575, 
          0.}, {-2.7525, 0.}, {-2.7475, 0.}, {-2.7424999999999997`, 
          0.}, {-2.7375, 0.}, {-2.73582, 0.21}}], 
         LineBox[{{-2.72586, 0.21}, {-2.7225, 0.}, {-2.7175, 0.}, {-2.7125, 
          0.}, {-2.7075, 0.}, {-2.7041399999999998`, 0.21}}], 
         LineBox[{{-2.7008599999999996`, 0.21}, {-2.6975, 0.}, {-2.6925, 
          0.}, {-2.6875, 0.}, {-2.6825, 0.}, {-2.6774999999999998`, 
          0.}, {-2.6725, 0.}, {-2.6675, 0.}, {-2.6624999999999996`, 
          0.}, {-2.6574999999999998`, 0.}, {-2.6525, 0.}, {-2.6475, 
          0.}, {-2.64582, 0.21}}], 
         LineBox[{{-2.6358599999999996`, 0.21}, {-2.6325, 0.}, {-2.6275, 
          0.}, {-2.62414, 0.21}}], 
         LineBox[{{-2.62086, 0.21}, {-2.6174999999999997`, 0.}, {-2.6125, 
          0.}, {-2.60914, 0.21}}], 
         LineBox[{{-2.58586, 0.21}, {-2.5825, 0.}, {-2.5774999999999997`, 
          0.}, {-2.5725, 0.}, {-2.56914, 0.21}}], 
         LineBox[{{-2.56586, 0.21}, {-2.5625, 0.}, {-2.5575, 
          0.}, {-2.5524999999999998`, 0.}, {-2.5475, 0.}, {-2.54414, 0.21}}], 
         LineBox[{{-2.54086, 0.21}, {-2.5374999999999996`, 
          0.}, {-2.5324999999999998`, 0.}, {-2.5275, 0.}, {-2.5225, 
          0.}, {-2.52082, 0.21}}], 
         LineBox[{{-2.5141799999999996`, 0.21}, {-2.5124999999999997`, 
          0.}, {-2.5075, 0.}, {-2.5025, 0.}, {-2.49914, 0.21}}], 
         LineBox[{{-2.4858599999999997`, 0.21}, {-2.4825, 0.}, {-2.4775, 
          0.}, {-2.47582, 0.21}}], 
         LineBox[{{-2.4691799999999997`, 0.21}, {-2.4675, 0.}, {-2.4625, 
          0.}, {-2.4575, 0.}, {-2.4541399999999998`, 0.21}}], 
         LineBox[{{-2.4508599999999996`, 0.21}, {-2.4475, 0.}, {-2.4425, 
          0.}, {-2.4375, 0.}, {-2.4325, 0.}, {-2.4274999999999998`, 
          0.}, {-2.4225, 0.}, {-2.4175, 0.}, {-2.4124999999999996`, 
          0.}, {-2.40914, 0.21}}], 
         LineBox[{{-2.4058599999999997`, 0.21}, {-2.4025, 0.}, {-2.3975, 
          0.}, {-2.3925, 0.}, {-2.38914, 0.21}}], 
         LineBox[{{-2.3858599999999996`, 0.21}, {-2.3825, 0.}, {-2.3775, 
          0.}, {-2.37414, 0.21}}], 
         LineBox[{{-2.37086, 0.21}, {-2.3674999999999997`, 0.}, {-2.3625, 
          0.}, {-2.3575, 0.}, {-2.35414, 0.21}}], 
         LineBox[{{-2.35086, 0.21}, {-2.3474999999999997`, 0.}, {-2.3425, 
          0.}, {-2.33914, 0.21}}], 
         LineBox[{{-2.33586, 0.21}, {-2.3325, 0.}, {-2.3274999999999997`, 
          0.}, {-2.3225, 0.}, {-2.3175, 0.}, {-2.3125, 
          0.}, {-2.3091399999999997`, 0.21}}], 
         LineBox[{{-2.29918, 0.21}, {-2.2975, 0.}, {-2.2925, 0.}, {-2.2875, 
          0.}, {-2.2824999999999998`, 0.}, {-2.2775, 0.}, {-2.27414, 0.21}}], 
         LineBox[{{-2.25418, 0.21}, {-2.2525, 0.}, {-2.2475, 
          0.}, {-2.2424999999999997`, 0.}, {-2.2375, 0.}, {-2.2325, 
          0.}, {-2.2275, 0.}, {-2.2224999999999997`, 0.}, {-2.2175, 
          0.}, {-2.2125, 0.}, {-2.2075, 0.}, {-2.2024999999999997`, 
          0.}, {-2.1975, 0.}, {-2.1925, 0.}, {-2.1875, 
          0.}, {-2.1824999999999997`, 0.}, {-2.1808199999999998`, 0.21}}], 
         LineBox[{{-2.17418, 0.21}, {-2.1725, 0.}, {-2.17082, 0.21}}], 
         LineBox[{{-2.16418, 0.21}, {-2.1625, 0.}, {-2.1574999999999998`, 
          0.}, {-2.1525, 0.}, {-2.15082, 0.21}}], 
         LineBox[{{-2.14086, 0.21}, {-2.1374999999999997`, 0.}, {-2.1325, 
          0.}, {-2.1275, 0.}, {-2.1225, 0.}, {-2.1174999999999997`, 
          0.}, {-2.1125, 0.}, {-2.1075, 0.}, {-2.1025, 
          0.}, {-2.0974999999999997`, 0.}, {-2.0925, 0.}, {-2.0875, 
          0.}, {-2.08414, 0.21}}], 
         LineBox[{{-2.0758599999999996`, 0.21}, {-2.0725, 0.}, {-2.06914, 
          0.21}}], 
         LineBox[{{-2.06586, 0.21}, {-2.0625, 0.}, {-2.0574999999999997`, 
          0.}, {-2.0524999999999998`, 0.}, {-2.0475, 0.}, {-2.04414, 0.21}}], 
         LineBox[{{-2.04086, 0.21}, {-2.0375, 0.}, {-2.0324999999999998`, 
          0.}, {-2.02914, 0.21}}], 
         LineBox[{{-2.02086, 0.21}, {-2.0175, 0.}, {-2.0124999999999997`, 
          0.}, {-2.0075, 0.}, {-2.00414, 0.21}}], 
         LineBox[{{-1.9908599999999999`, 0.21}, {-1.9874999999999998`, 
          0.}, {-1.9841399999999998`, 0.21}}], 
         LineBox[{{-1.98086, 0.21}, {-1.9775, 0.}, {-1.9724999999999997`, 
          0.}, {-1.9674999999999998`, 0.}, {-1.9625, 0.}, {-1.96082, 0.21}}], 
         LineBox[{{-1.9541799999999998`, 0.21}, {-1.9524999999999997`, 
          0.}, {-1.9474999999999998`, 0.}, {-1.9425, 0.}, {-1.9375, 
          0.}, {-1.9324999999999997`, 0.}, {-1.9274999999999998`, 
          0.}, {-1.9224999999999999`, 0.}, {-1.9175, 0.}, {-1.9125, 
          0.}, {-1.9074999999999998`, 0.}, {-1.9041399999999997`, 0.21}}], 
         LineBox[{{-1.89586, 0.21}, {-1.8925, 0.}, {-1.8874999999999997`, 
          0.}, {-1.8824999999999998`, 0.}, {-1.8775, 
          0.}, {-1.8724999999999998`, 0.}, {-1.8674999999999997`, 
          0.}, {-1.8624999999999998`, 0.}, {-1.8575, 0.}, {-1.85414, 0.21}}], 
         LineBox[{{-1.85086, 0.21}, {-1.8475, 0.}, {-1.84414, 0.21}}], 
         LineBox[{{-1.84086, 0.21}, {-1.8375, 0.}, {-1.8341399999999999`, 
          0.21}}], 
         LineBox[{{-1.83086, 0.21}, {-1.8275, 0.}, {-1.8224999999999998`, 
          0.}, {-1.8175, 0.}, {-1.8125, 0.}, {-1.8074999999999999`, 
          0.}, {-1.8024999999999998`, 0.}, {-1.7974999999999999`, 
          0.}, {-1.7941399999999998`, 0.21}}], 
         LineBox[{{-1.7808599999999999`, 0.21}, {-1.7774999999999999`, 
          0.}, {-1.7725, 0.}, {-1.76914, 0.21}}], 
         LineBox[{{-1.7658599999999998`, 0.21}, {-1.7624999999999997`, 
          0.}, {-1.7574999999999998`, 0.}, {-1.7541399999999998`, 0.21}}], 
         LineBox[{{-1.7508599999999999`, 0.21}, {-1.7474999999999998`, 
          0.}, {-1.7424999999999997`, 0.}, {-1.7374999999999998`, 
          0.}, {-1.7325, 0.}, {-1.7274999999999998`, 
          0.}, {-1.7241399999999998`, 0.21}}], 
         LineBox[{{-1.7208599999999998`, 0.21}, {-1.7174999999999998`, 
          0.}, {-1.7125, 0.}, {-1.7075, 0.}, {-1.70414, 0.21}}], 
         LineBox[{{-1.6808599999999998`, 0.21}, {-1.6774999999999998`, 
          0.}, {-1.6741399999999997`, 0.21}}], 
         LineBox[{{-1.67086, 0.21}, {-1.6675, 0.}, {-1.6624999999999999`, 
          0.}, {-1.6574999999999998`, 0.}, {-1.6524999999999999`, 
          0.}, {-1.6475, 0.}, {-1.6424999999999998`, 
          0.}, {-1.6374999999999997`, 0.}, {-1.6324999999999998`, 
          0.}, {-1.6291399999999998`, 0.21}}], 
         LineBox[{{-1.6186199999999997`, 0.21}, {-1.6174999999999997`, 
          0.}, {-1.6124999999999998`, 0.}, {-1.6075, 
          0.}, {-1.6024999999999998`, 0.}, {-1.5991399999999998`, 0.21}}], 
         LineBox[{{-1.5958599999999998`, 0.21}, {-1.5924999999999998`, 
          0.}, {-1.5875, 0.}, {-1.5841399999999999`, 0.21}}], 
         LineBox[{{-1.58086, 0.21}, {-1.5775, 0.}, {-1.5724999999999998`, 
          0.}, {-1.5675, 0.}, {-1.5625, 0.}, {-1.5574999999999999`, 
          0.}, {-1.5524999999999998`, 0.}, {-1.5474999999999999`, 
          0.}, {-1.5441399999999998`, 0.21}}], 
         LineBox[{{-1.54086, 0.21}, {-1.5374999999999999`, 
          0.}, {-1.5324999999999998`, 0.}, {-1.5274999999999999`, 
          0.}, {-1.5225, 0.}, {-1.5174999999999998`, 
          0.}, {-1.5141399999999998`, 0.21}}], 
         LineBox[{{-1.5108599999999999`, 0.21}, {-1.5074999999999998`, 
          0.}, {-1.5025, 0.}, {-1.4974999999999998`, 
          0.}, {-1.4941399999999998`, 0.21}}], 
         LineBox[{{-1.4808599999999998`, 0.21}, {-1.4774999999999998`, 
          0.}, {-1.4741399999999998`, 0.21}}], 
         LineBox[{{-1.4708599999999998`, 0.21}, {-1.4674999999999998`, 
          0.}, {-1.4625, 0.}, {-1.4575, 0.}, {-1.4525, 
          0.}, {-1.4474999999999998`, 0.}, {-1.4425, 0.}, {-1.4375, 
          0.}, {-1.4324999999999999`, 0.}, {-1.4274999999999998`, 
          0.}, {-1.4224999999999999`, 0.}, {-1.4175, 
          0.}, {-1.4124999999999999`, 0.}, {-1.4074999999999998`, 
          0.}, {-1.4024999999999999`, 0.}, {-1.3975, 
          0.}, {-1.3958199999999998`, 0.21}}], 
         LineBox[{{-1.3891799999999999`, 0.21}, {-1.3874999999999997`, 
          0.}, {-1.3824999999999998`, 0.}, {-1.3775, 
          0.}, {-1.3724999999999998`, 0.}, {-1.3708199999999997`, 0.21}}], 
         LineBox[{{-1.3458599999999998`, 0.21}, {-1.3424999999999998`, 
          0.}, {-1.3375, 0.}, {-1.3341399999999999`, 0.21}}], 
         LineBox[{{-1.33086, 0.21}, {-1.3275, 0.}, {-1.3224999999999998`, 
          0.}, {-1.3175, 0.}, {-1.3125, 0.}, {-1.3074999999999999`, 
          0.}, {-1.3041399999999999`, 0.21}}], 
         LineBox[{{-1.30086, 0.21}, {-1.2974999999999999`, 0.}, {-1.2925, 
          0.}, {-1.2874999999999999`, 0.}, {-1.2858199999999997`, 0.21}}], 
         LineBox[{{-1.2791799999999998`, 0.21}, {-1.2774999999999999`, 
          0.}, {-1.2725, 0.}, {-1.2674999999999998`, 
          0.}, {-1.2624999999999997`, 0.}, {-1.2574999999999998`, 
          0.}, {-1.2525, 0.}, {-1.2474999999999998`, 
          0.}, {-1.2441399999999998`, 0.21}}], 
         LineBox[{{-1.2408599999999999`, 0.21}, {-1.2374999999999998`, 
          0.}, {-1.2325, 0.}, {-1.22914, 0.21}}], 
         LineBox[{{-1.2258599999999997`, 0.21}, {-1.2224999999999997`, 
          0.}, {-1.2191399999999997`, 0.21}}], 
         LineBox[{{-1.21586, 0.21}, {-1.2125, 0.}, {-1.2075, 0.}, {-1.2025, 
          0.}, {-1.1974999999999998`, 0.}, {-1.1925, 0.}, {-1.1875, 
          0.}, {-1.1824999999999999`, 0.}, {-1.1791399999999999`, 0.21}}], 
         LineBox[{{-1.17586, 0.21}, {-1.1724999999999999`, 0.}, {-1.1675, 
          0.}, {-1.1624999999999999`, 0.}, {-1.1574999999999998`, 
          0.}, {-1.1524999999999999`, 0.}, {-1.1491399999999998`, 0.21}}], 
         LineBox[{{-1.1408599999999998`, 0.21}, {-1.1374999999999997`, 
          0.}, {-1.1358199999999998`, 0.21}}], 
         LineBox[{{-1.1291799999999999`, 0.21}, {-1.1275, 0.}, {-1.12414, 
          0.21}}], 
         LineBox[{{-1.1158599999999999`, 0.21}, {-1.1124999999999998`, 
          0.}, {-1.1091399999999998`, 0.21}}], 
         LineBox[{{-1.1058599999999998`, 0.21}, {-1.1024999999999998`, 
          0.}, {-1.0974999999999997`, 0.}, {-1.0924999999999998`, 
          0.}, {-1.0875, 0.}, {-1.0825, 0.}, {-1.07914, 0.21}}], 
         LineBox[{{-1.07086, 0.21}, {-1.0675, 0.}, {-1.0625, 
          0.}, {-1.0574999999999999`, 0.}, {-1.0524999999999998`, 
          0.}, {-1.0491399999999997`, 0.21}}], 
         LineBox[{{-1.04086, 0.21}, {-1.0374999999999999`, 
          0.}, {-1.0324999999999998`, 0.}, {-1.0291399999999997`, 0.21}}], 
         LineBox[{{-1.02586, 0.21}, {-1.0225, 0.}, {-1.0174999999999998`, 
          0.}, {-1.0124999999999997`, 0.}, {-1.0074999999999998`, 
          0.}, {-1.0025, 0.}, {-0.9974999999999998, 0.}, {-0.9941399999999998,
           0.21}}], 
         LineBox[{{-0.9908599999999999, 0.21}, {-0.9874999999999998, 
          0.}, {-0.9841399999999998, 0.21}}], 
         LineBox[{{-0.9808599999999998, 0.21}, {-0.9774999999999998, 
          0.}, {-0.9724999999999998, 0.}, {-0.9674999999999998, 
          0.}, {-0.9624999999999999, 0.}, {-0.9574999999999999, 
          0.}, {-0.9524999999999999, 0.}, {-0.9474999999999999, 
          0.}, {-0.9424999999999999, 0.}, {-0.9374999999999999, 
          0.}, {-0.9358199999999999, 0.21}}], 
         LineBox[{{-0.9291799999999999, 0.21}, {-0.9274999999999999, 
          0.}, {-0.9241399999999999, 0.21}}], 
         LineBox[{{-0.9208599999999999, 0.21}, {-0.9174999999999999, 
          0.}, {-0.9124999999999999, 0.}, {-0.9091399999999998, 0.21}}], 
         LineBox[{{-0.9058599999999999, 0.21}, {-0.9024999999999999, 
          0.}, {-0.8974999999999999, 0.}, {-0.8924999999999998, 
          0.}, {-0.8891399999999998, 0.21}}], 
         LineBox[{{-0.8858599999999999, 0.21}, {-0.8824999999999998, 
          0.}, {-0.8775, 0.}, {-0.8758199999999999, 0.21}}], 
         LineBox[{{-0.8691799999999997, 0.21}, {-0.8674999999999997, 
          0.}, {-0.8624999999999998, 0.}, {-0.8574999999999999, 
          0.}, {-0.8524999999999998, 0.}, {-0.8474999999999997, 
          0.}, {-0.8424999999999998, 0.}, {-0.8391399999999999, 0.21}}], 
         LineBox[{{-0.8358599999999999, 0.21}, {-0.8325, 0.}, {-0.82914, 
          0.21}}], 
         LineBox[{{-0.8208599999999998, 0.21}, {-0.8174999999999999, 
          0.}, {-0.8125, 0.}, {-0.81082, 0.21}}], 
         LineBox[{{-0.8041799999999998, 0.21}, {-0.8024999999999998, 
          0.}, {-0.7991399999999999, 0.21}}], 
         LineBox[{{-0.7958599999999999, 0.21}, {-0.7925, 
          0.}, {-0.7874999999999999, 0.}, {-0.7824999999999998, 
          0.}, {-0.7791399999999998, 0.21}}], 
         LineBox[{{-0.7708599999999999, 0.21}, {-0.7674999999999998, 
          0.}, {-0.7624999999999997, 0.}, {-0.7574999999999998, 
          0.}, {-0.7541399999999999, 0.21}}], 
         LineBox[{{-0.7436199999999997, 0.21}, {-0.7424999999999997, 
          0.}, {-0.7374999999999998, 0.}, {-0.7324999999999999, 
          0.}, {-0.7274999999999998, 0.}, {-0.7224999999999997, 
          0.}, {-0.7174999999999998, 0.}, {-0.7124999999999999, 
          0.}, {-0.7074999999999998, 0.}, {-0.7024999999999997, 
          0.}, {-0.6991399999999998, 0.21}}], 
         LineBox[{{-0.6958599999999998, 0.21}, {-0.6924999999999999, 
          0.}, {-0.6875, 0.}, {-0.68414, 0.21}}], 
         LineBox[{{-0.6658599999999999, 0.21}, {-0.6624999999999999, 
          0.}, {-0.6574999999999998, 0.}, {-0.6524999999999999, 0.}, {-0.6475,
           0.}, {-0.6424999999999998, 0.}, {-0.6374999999999997, 
          0.}, {-0.6324999999999998, 0.}, {-0.6291399999999999, 0.21}}], 
         LineBox[{{-0.6191799999999997, 0.21}, {-0.6174999999999997, 
          0.}, {-0.6141399999999998, 0.21}}], 
         LineBox[{{-0.6058599999999998, 0.21}, {-0.6024999999999998, 
          0.}, {-0.5974999999999997, 0.}, {-0.5924999999999998, 
          0.}, {-0.5874999999999999, 0.}, {-0.5824999999999998, 
          0.}, {-0.5808199999999998, 0.21}}], 
         LineBox[{{-0.5741799999999998, 0.21}, {-0.5724999999999998, 
          0.}, {-0.5674999999999999, 0.}, {-0.5625, 0.}, {-0.5574999999999999,
           0.}, {-0.5524999999999998, 0.}, {-0.5491399999999999, 0.21}}], 
         LineBox[{{-0.5458599999999999, 0.21}, {-0.5425, 
          0.}, {-0.5374999999999999, 0.}, {-0.5341399999999998, 0.21}}], 
         LineBox[{{-0.5208599999999999, 0.21}, {-0.5174999999999998, 
          0.}, {-0.5124999999999997, 0.}, {-0.5074999999999998, 0.}, {-0.5025,
           0.}, {-0.49749999999999983`, 0.}, {-0.4924999999999997, 
          0.}, {-0.4874999999999998, 0.}, {-0.48249999999999993`, 
          0.}, {-0.4774999999999998, 0.}, {-0.4724999999999997, 
          0.}, {-0.4674999999999998, 0.}, {-0.4641399999999999, 0.21}}], 
         LineBox[{{-0.4608599999999999, 0.21}, {-0.4574999999999998, 
          0.}, {-0.4524999999999997, 0.}, {-0.4474999999999998, 
          0.}, {-0.44413999999999987`, 0.21}}], 
         LineBox[{{-0.43585999999999997`, 0.21}, {-0.4324999999999999, 
          0.}, {-0.42749999999999977`, 0.}, {-0.4224999999999999, 
          0.}, {-0.41913999999999996`, 0.21}}], 
         LineBox[{{-0.41085999999999984`, 0.21}, {-0.40749999999999975`, 
          0.}, {-0.40249999999999986`, 0.}, {-0.39749999999999996`, 
          0.}, {-0.39249999999999985`, 0.}, {-0.38749999999999973`, 
          0.}, {-0.38249999999999984`, 0.}, {-0.37749999999999995`, 
          0.}, {-0.37249999999999983`, 0.}, {-0.3674999999999997, 
          0.}, {-0.3641399999999998, 0.21}}], 
         LineBox[{{-0.36085999999999985`, 0.21}, {-0.35749999999999993`, 
          0.}, {-0.35413999999999984`, 0.21}}], 
         LineBox[{{-0.34085999999999983`, 0.21}, {-0.3374999999999999, 
          0.}, {-0.3324999999999998, 0.}, {-0.3291399999999997, 0.21}}], 
         LineBox[{{-0.3208600000000001, 0.21}, {-0.3175000000000003, 
          0.}, {-0.3125000000000003, 0.}, {-0.3075000000000003, 
          0.}, {-0.30250000000000027`, 0.}, {-0.29750000000000026`, 
          0.}, {-0.29414000000000023`, 0.21}}], 
         LineBox[{{-0.2908600000000003, 0.21}, {-0.28750000000000026`, 
          0.}, {-0.2825000000000003, 0.}, {-0.2791400000000003, 0.21}}], 
         LineBox[{{-0.2758600000000003, 0.21}, {-0.2725000000000003, 
          0.}, {-0.2675000000000003, 0.}, {-0.2625000000000003, 
          0.}, {-0.2575000000000003, 0.}, {-0.25414000000000025`, 0.21}}], 
         LineBox[{{-0.2508600000000003, 0.21}, {-0.24750000000000028`, 
          0.}, {-0.24250000000000027`, 0.}, {-0.23750000000000027`, 
          0.}, {-0.23250000000000026`, 0.}, {-0.22750000000000029`, 
          0.}, {-0.22250000000000028`, 0.}, {-0.2175000000000003, 
          0.}, {-0.2141400000000003, 0.21}}], 
         LineBox[{{-0.2108600000000003, 0.21}, {-0.2075000000000003, 
          0.}, {-0.2025000000000003, 0.}, {-0.1991400000000003, 0.21}}], 
         LineBox[{{-0.19586000000000028`, 0.21}, {-0.19250000000000028`, 
          0.}, {-0.18750000000000028`, 0.}, {-0.18414000000000028`, 0.21}}], 
         LineBox[{{-0.1708600000000003, 0.21}, {-0.1675000000000003, 
          0.}, {-0.16250000000000028`, 0.}, {-0.15750000000000028`, 
          0.}, {-0.15250000000000027`, 0.}, {-0.15082000000000026`, 0.21}}], 
         LineBox[{{-0.14418000000000028`, 0.21}, {-0.1425000000000003, 
          0.}, {-0.1375000000000003, 0.}, {-0.13250000000000028`, 
          0.}, {-0.12750000000000028`, 0.}, {-0.12414000000000028`, 0.21}}], 
         LineBox[{{-0.12086000000000027`, 0.21}, {-0.11750000000000027`, 
          0.}, {-0.11250000000000028`, 0.}, {-0.10914000000000029`, 0.21}}], 
         LineBox[{{-0.10586000000000029`, 0.21}, {-0.10250000000000029`, 
          0.}, {-0.09750000000000028, 0.}, {-0.09638000000000028, 0.21}}], 
         LineBox[{{-0.08418000000000028, 0.21}, {-0.08250000000000028, 
          0.}, {-0.07750000000000029, 0.}, {-0.07250000000000029, 
          0.}, {-0.06750000000000028, 0.}, {-0.06250000000000028, 
          0.}, {-0.05750000000000027, 0.}, {-0.05250000000000027, 
          0.}, {-0.047500000000000264`, 0.}, {-0.04414000000000026, 0.21}}], 
         LineBox[{{-0.03586000000000026, 0.21}, {-0.03250000000000028, 
          0.}, {-0.029140000000000294`, 0.21}}], 
         LineBox[{{-0.0258600000000003, 0.21}, {-0.022500000000000298`, 
          0.}, {-0.017500000000000293`, 0.}, {-0.014140000000000291`, 0.21}}], 
         LineBox[{{-0.010860000000000286`, 0.21}, {-0.007500000000000284, 
          0.}, {-0.0025000000000002798`, 0.}, {0.0024999999999997247`, 0.}, {
          0.007499999999999729, 0.}, {0.010859999999999731`, 0.21}}], 
         LineBox[{{0.014139999999999736`, 0.21}, {0.017499999999999738`, 
          0.}, {0.022499999999999742`, 0.}, {0.025859999999999744`, 0.21}}], 
         LineBox[{{0.02913999999999974, 0.21}, {0.032499999999999724`, 0.}, {
          0.035859999999999705`, 0.21}}], 
         LineBox[{{0.04413999999999971, 0.21}, {0.04749999999999971, 0.}, {
          0.052499999999999714`, 0.}, {0.05749999999999972, 0.}, {
          0.06249999999999972, 0.}, {0.06749999999999973, 0.}, {
          0.07249999999999973, 0.}, {0.07749999999999974, 0.}, {
          0.08249999999999974, 0.}, {0.08417999999999974, 0.21}}], 
         LineBox[{{0.09637999999999973, 0.21}, {0.09749999999999973, 0.}, {
          0.1024999999999997, 0.}, {0.1058599999999997, 0.21}}], 
         LineBox[{{0.10913999999999971`, 0.21}, {0.11249999999999971`, 0.}, {
          0.11749999999999972`, 0.}, {0.12085999999999972`, 0.21}}], 
         LineBox[{{0.12413999999999972`, 0.21}, {0.12749999999999972`, 0.}, {
          0.13249999999999973`, 0.}, {0.13749999999999973`, 0.}, {
          0.14249999999999974`, 0.}, {0.14417999999999975`, 0.21}}], 
         LineBox[{{0.15081999999999973`, 0.21}, {0.15249999999999975`, 0.}, {
          0.15749999999999972`, 0.}, {0.1624999999999997, 0.}, {
          0.1674999999999997, 0.}, {0.1708599999999997, 0.21}}], 
         LineBox[{{0.18413999999999972`, 0.21}, {0.18749999999999972`, 0.}, {
          0.19249999999999973`, 0.}, {0.19585999999999973`, 0.21}}], 
         LineBox[{{0.19913999999999973`, 0.21}, {0.20249999999999974`, 0.}, {
          0.20749999999999974`, 0.}, {0.21085999999999974`, 0.21}}], 
         LineBox[{{0.21413999999999975`, 0.21}, {0.21749999999999975`, 0.}, {
          0.22249999999999975`, 0.}, {0.22749999999999976`, 0.}, {
          0.23249999999999976`, 0.}, {0.23749999999999977`, 0.}, {
          0.24249999999999977`, 0.}, {0.24749999999999978`, 0.}, {
          0.2508599999999998, 0.21}}], 
         LineBox[{{0.25413999999999975`, 0.21}, {0.25749999999999973`, 0.}, {
          0.2624999999999997, 0.}, {0.2674999999999997, 0.}, {
          0.2724999999999997, 0.}, {0.2758599999999997, 0.21}}], 
         LineBox[{{0.27913999999999967`, 0.21}, {0.2824999999999997, 0.}, {
          0.2874999999999997, 0.}, {0.29085999999999973`, 0.21}}], 
         LineBox[{{0.2941399999999997, 0.21}, {0.2974999999999997, 0.}, {
          0.3024999999999997, 0.}, {0.3074999999999997, 0.}, {
          0.3124999999999997, 0.}, {0.3174999999999997, 0.}, {
          0.32085999999999976`, 0.21}}], 
         LineBox[{{0.3291399999999997, 0.21}, {0.33249999999999974`, 0.}, {
          0.33749999999999974`, 0.}, {0.3408599999999998, 0.21}}], 
         LineBox[{{0.35413999999999973`, 0.21}, {0.35749999999999976`, 0.}, {
          0.3608599999999998, 0.21}}], 
         LineBox[{{0.36413999999999974`, 0.21}, {0.36749999999999977`, 0.}, {
          0.3724999999999998, 0.}, {0.3774999999999998, 0.}, {
          0.38249999999999973`, 0.}, {0.3874999999999997, 0.}, {
          0.3924999999999997, 0.}, {0.3974999999999997, 0.}, {
          0.4024999999999997, 0.}, {0.4074999999999997, 0.}, {
          0.4108599999999997, 0.21}}], 
         LineBox[{{0.4191399999999997, 0.21}, {0.4224999999999997, 0.}, {
          0.4274999999999997, 0.}, {0.4324999999999997, 0.}, {
          0.43585999999999975`, 0.21}}], 
         LineBox[{{0.4441399999999997, 0.21}, {0.44749999999999973`, 0.}, {
          0.45249999999999974`, 0.}, {0.45749999999999974`, 0.}, {
          0.46085999999999977`, 0.21}}], 
         LineBox[{{0.4641399999999997, 0.21}, {0.46749999999999975`, 0.}, {
          0.47249999999999975`, 0.}, {0.47749999999999976`, 0.}, {
          0.48249999999999976`, 0.}, {0.48749999999999977`, 0.}, {
          0.49249999999999977`, 0.}, {0.4974999999999998, 0.}, {
          0.5024999999999997, 0.}, {0.5074999999999998, 0.}, {
          0.5124999999999997, 0.}, {0.5174999999999996, 0.}, {
          0.5208599999999997, 0.21}}], 
         LineBox[{{0.5341399999999997, 0.21}, {0.5374999999999996, 0.}, {
          0.5424999999999998, 0.}, {0.5458599999999997, 0.21}}], 
         LineBox[{{0.5491399999999997, 0.21}, {0.5524999999999998, 0.}, {
          0.5574999999999997, 0.}, {0.5624999999999998, 0.}, {
          0.5674999999999997, 0.}, {0.5724999999999998, 0.}, {
          0.5741799999999998, 0.21}}], 
         LineBox[{{0.5808199999999998, 0.21}, {0.5824999999999998, 0.}, {
          0.5874999999999997, 0.}, {0.5924999999999998, 0.}, {
          0.5974999999999997, 0.}, {0.6024999999999998, 0.}, {
          0.6058599999999997, 0.21}}], 
         LineBox[{{0.6141399999999998, 0.21}, {0.6174999999999997, 0.}, {
          0.6191799999999997, 0.21}}], 
         LineBox[{{0.6291399999999998, 0.21}, {0.6324999999999998, 0.}, {
          0.6374999999999997, 0.}, {0.6424999999999996, 0.}, {
          0.6474999999999997, 0.}, {0.6524999999999996, 0.}, {
          0.6574999999999998, 0.}, {0.6624999999999996, 0.}, {
          0.6658599999999997, 0.21}}], 
         LineBox[{{0.6841399999999997, 0.21}, {0.6874999999999998, 0.}, {
          0.6924999999999998, 0.}, {0.6958599999999998, 0.21}}], 
         LineBox[{{0.6991399999999998, 0.21}, {0.7024999999999997, 0.}, {
          0.7074999999999997, 0.}, {0.7124999999999997, 0.}, {
          0.7174999999999997, 0.}, {0.7224999999999997, 0.}, {
          0.7274999999999997, 0.}, {0.7324999999999997, 0.}, {
          0.7374999999999997, 0.}, {0.7424999999999997, 0.}, {
          0.7436199999999997, 0.21}}], 
         LineBox[{{0.7541399999999997, 0.21}, {0.7574999999999997, 0.}, {
          0.7624999999999997, 0.}, {0.7674999999999997, 0.}, {
          0.7708599999999998, 0.21}}], 
         LineBox[{{0.7791399999999997, 0.21}, {0.7824999999999998, 0.}, {
          0.7874999999999998, 0.}, {0.7924999999999998, 0.}, {
          0.7958599999999998, 0.21}}], 
         LineBox[{{0.7991399999999997, 0.21}, {0.8024999999999998, 0.}, {
          0.8041799999999998, 0.21}}], 
         LineBox[{{0.8108199999999998, 0.21}, {0.8124999999999998, 0.}, {
          0.8174999999999998, 0.}, {0.8208599999999998, 0.21}}], 
         LineBox[{{0.8291399999999998, 0.21}, {0.8324999999999998, 0.}, {
          0.8358599999999997, 0.21}}], 
         LineBox[{{0.8391399999999997, 0.21}, {0.8424999999999997, 0.}, {
          0.8474999999999997, 0.}, {0.8524999999999997, 0.}, {
          0.8574999999999997, 0.}, {0.8624999999999997, 0.}, {
          0.8674999999999997, 0.}, {0.8691799999999997, 0.21}}], 
         LineBox[{{0.8758199999999997, 0.21}, {0.8774999999999997, 0.}, {
          0.8824999999999997, 0.}, {0.8858599999999998, 0.21}}], 
         LineBox[{{0.8891399999999997, 0.21}, {0.8924999999999997, 0.}, {
          0.8974999999999997, 0.}, {0.9024999999999997, 0.}, {
          0.9058599999999998, 0.21}}], 
         LineBox[{{0.9091399999999997, 0.21}, {0.9124999999999998, 0.}, {
          0.9174999999999998, 0.}, {0.9208599999999998, 0.21}}], 
         LineBox[{{0.9241399999999997, 0.21}, {0.9274999999999998, 0.}, {
          0.9291799999999998, 0.21}}], 
         LineBox[{{0.9358199999999998, 0.21}, {0.9374999999999998, 0.}, {
          0.9424999999999998, 0.}, {0.9474999999999998, 0.}, {
          0.9524999999999998, 0.}, {0.9574999999999998, 0.}, {
          0.9624999999999997, 0.}, {0.9674999999999997, 0.}, {
          0.9724999999999997, 0.}, {0.9774999999999997, 0.}, {
          0.9808599999999997, 0.21}}], 
         LineBox[{{0.9841399999999997, 0.21}, {0.9874999999999997, 0.}, {
          0.9908599999999997, 0.21}}], 
         LineBox[{{0.9941399999999997, 0.21}, {0.9974999999999997, 0.}, {
          1.0024999999999997`, 0.}, {1.0074999999999998`, 0.}, {
          1.0124999999999997`, 0.}, {1.0174999999999996`, 0.}, {
          1.0224999999999997`, 0.}, {1.0258599999999998`, 0.21}}], 
         LineBox[{{1.0291399999999997`, 0.21}, {1.0324999999999998`, 0.}, {
          1.0374999999999996`, 0.}, {1.0408599999999997`, 0.21}}], 
         LineBox[{{1.0491399999999997`, 0.21}, {1.0524999999999998`, 0.}, {
          1.0574999999999997`, 0.}, {1.0624999999999998`, 0.}, {1.0675, 0.}, {
          1.07086, 0.21}}], 
         LineBox[{{1.0791399999999998`, 0.21}, {1.0824999999999998`, 0.}, {
          1.0874999999999997`, 0.}, {1.0924999999999998`, 0.}, {
          1.0974999999999997`, 0.}, {1.1024999999999996`, 0.}, {
          1.1058599999999996`, 0.21}}], 
         LineBox[{{1.1091399999999998`, 0.21}, {1.1124999999999998`, 0.}, {
          1.1158599999999999`, 0.21}}], 
         LineBox[{{1.1241399999999997`, 0.21}, {1.1274999999999997`, 0.}, {
          1.1291799999999999`, 0.21}}], 
         LineBox[{{1.1358199999999998`, 0.21}, {1.1374999999999997`, 0.}, {
          1.1408599999999998`, 0.21}}], 
         LineBox[{{1.1491399999999998`, 0.21}, {1.1524999999999999`, 0.}, {
          1.1574999999999998`, 0.}, {1.1624999999999996`, 0.}, {
          1.1674999999999998`, 0.}, {1.1724999999999999`, 0.}, {1.17586, 
          0.21}}], 
         LineBox[{{1.1791399999999996`, 0.21}, {1.1824999999999997`, 0.}, {
          1.1874999999999998`, 0.}, {1.1925, 0.}, {1.1974999999999998`, 0.}, {
          1.2024999999999997`, 0.}, {1.2074999999999998`, 0.}, {1.2125, 0.}, {
          1.21586, 0.21}}], 
         LineBox[{{1.2191399999999997`, 0.21}, {1.2224999999999997`, 0.}, {
          1.2258599999999997`, 0.21}}], 
         LineBox[{{1.2291399999999997`, 0.21}, {1.2324999999999997`, 0.}, {
          1.2374999999999998`, 0.}, {1.2408599999999999`, 0.21}}], 
         LineBox[{{1.2441399999999996`, 0.21}, {1.2474999999999996`, 0.}, {
          1.2524999999999997`, 0.}, {1.2574999999999998`, 0.}, {
          1.2624999999999997`, 0.}, {1.2674999999999996`, 0.}, {
          1.2724999999999997`, 0.}, {1.2774999999999999`, 0.}, {
          1.2791799999999998`, 0.21}}], 
         LineBox[{{1.2858199999999997`, 0.21}, {1.2874999999999996`, 0.}, {
          1.2924999999999998`, 0.}, {1.2974999999999999`, 0.}, {1.30086, 
          0.21}}], 
         LineBox[{{1.3041399999999996`, 0.21}, {1.3074999999999997`, 0.}, {
          1.3124999999999998`, 0.}, {1.3175, 0.}, {1.3224999999999998`, 0.}, {
          1.3274999999999997`, 0.}, {1.3308599999999997`, 0.21}}], 
         LineBox[{{1.3341399999999999`, 0.21}, {1.3375, 0.}, {
          1.3424999999999998`, 0.}, {1.3458599999999998`, 0.21}}], 
         LineBox[{{1.3708199999999997`, 0.21}, {1.3724999999999996`, 0.}, {
          1.3774999999999997`, 0.}, {1.3824999999999998`, 0.}, {
          1.3874999999999997`, 0.}, {1.3891799999999996`, 0.21}}], 
         LineBox[{{1.3958199999999996`, 0.21}, {1.3974999999999997`, 0.}, {
          1.4024999999999999`, 0.}, {1.4074999999999998`, 0.}, {
          1.4124999999999996`, 0.}, {1.4174999999999998`, 0.}, {
          1.4224999999999999`, 0.}, {1.4274999999999998`, 0.}, {
          1.4324999999999997`, 0.}, {1.4374999999999998`, 0.}, {1.4425, 0.}, {
          1.4474999999999998`, 0.}, {1.4524999999999997`, 0.}, {
          1.4574999999999998`, 0.}, {1.4625, 0.}, {1.4674999999999998`, 0.}, {
          1.4708599999999998`, 0.21}}], 
         LineBox[{{1.4741399999999996`, 0.21}, {1.4774999999999996`, 0.}, {
          1.4808599999999996`, 0.21}}], 
         LineBox[{{1.4941399999999996`, 0.21}, {1.4974999999999996`, 0.}, {
          1.5024999999999997`, 0.}, {1.5074999999999998`, 0.}, {
          1.5108599999999999`, 0.21}}], 
         LineBox[{{1.5141399999999996`, 0.21}, {1.5174999999999996`, 0.}, {
          1.5224999999999997`, 0.}, {1.5274999999999999`, 0.}, {
          1.5324999999999998`, 0.}, {1.5374999999999996`, 0.}, {
          1.5408599999999997`, 0.21}}], 
         LineBox[{{1.5441399999999998`, 0.21}, {1.5474999999999999`, 0.}, {
          1.5524999999999998`, 0.}, {1.5574999999999997`, 0.}, {
          1.5624999999999998`, 0.}, {1.5675, 0.}, {1.5724999999999998`, 0.}, {
          1.5774999999999997`, 0.}, {1.5808599999999997`, 0.21}}], 
         LineBox[{{1.5841399999999999`, 0.21}, {1.5875, 0.}, {
          1.5924999999999998`, 0.}, {1.5958599999999998`, 0.21}}], 
         LineBox[{{1.5991399999999996`, 0.21}, {1.6024999999999996`, 0.}, {
          1.6074999999999997`, 0.}, {1.6124999999999998`, 0.}, {
          1.6174999999999997`, 0.}, {1.6186199999999997`, 0.21}}], 
         LineBox[{{1.6291399999999998`, 0.21}, {1.6324999999999998`, 0.}, {
          1.6374999999999997`, 0.}, {1.6424999999999996`, 0.}, {
          1.6474999999999997`, 0.}, {1.6524999999999999`, 0.}, {
          1.6574999999999998`, 0.}, {1.6624999999999996`, 0.}, {
          1.6674999999999998`, 0.}, {1.6708599999999998`, 0.21}}], 
         LineBox[{{1.6741399999999997`, 0.21}, {1.6774999999999998`, 0.}, {
          1.6808599999999998`, 0.21}}], 
         LineBox[{{1.7041399999999998`, 0.21}, {1.7074999999999998`, 0.}, {
          1.7125, 0.}, {1.7174999999999998`, 0.}, {1.7208599999999998`, 
          0.21}}], 
         LineBox[{{1.7241399999999996`, 0.21}, {1.7274999999999996`, 0.}, {
          1.7324999999999997`, 0.}, {1.7374999999999998`, 0.}, {
          1.7424999999999997`, 0.}, {1.7474999999999996`, 0.}, {
          1.7508599999999996`, 0.21}}], 
         LineBox[{{1.7541399999999998`, 0.21}, {1.7574999999999998`, 0.}, {
          1.7624999999999997`, 0.}, {1.7658599999999998`, 0.21}}], 
         LineBox[{{1.7691399999999997`, 0.21}, {1.7724999999999997`, 0.}, {
          1.7774999999999999`, 0.}, {1.7808599999999999`, 0.21}}], 
         LineBox[{{1.7941399999999998`, 0.21}, {1.7974999999999999`, 0.}, {
          1.8024999999999998`, 0.}, {1.8074999999999997`, 0.}, {
          1.8124999999999998`, 0.}, {1.8175, 0.}, {1.8224999999999998`, 0.}, {
          1.8274999999999997`, 0.}, {1.8308599999999997`, 0.21}}], 
         LineBox[{{1.8341399999999999`, 0.21}, {1.8375, 0.}, {1.84086, 
          0.21}}], 
         LineBox[{{1.8441399999999997`, 0.21}, {1.8474999999999997`, 0.}, {
          1.8508599999999997`, 0.21}}], 
         LineBox[{{1.85414, 0.21}, {1.8575, 0.}, {1.8624999999999998`, 0.}, {
          1.8674999999999997`, 0.}, {1.8724999999999996`, 0.}, {
          1.8774999999999997`, 0.}, {1.8824999999999998`, 0.}, {
          1.8874999999999997`, 0.}, {1.8924999999999996`, 0.}, {
          1.8958599999999997`, 0.21}}], 
         LineBox[{{1.9041399999999997`, 0.21}, {1.9074999999999998`, 0.}, {
          1.9124999999999996`, 0.}, {1.9174999999999998`, 0.}, {
          1.9224999999999999`, 0.}, {1.9274999999999998`, 0.}, {
          1.9324999999999997`, 0.}, {1.9374999999999998`, 0.}, {1.9425, 0.}, {
          1.9474999999999998`, 0.}, {1.9524999999999997`, 0.}, {
          1.9541799999999998`, 0.21}}], 
         LineBox[{{1.9608199999999998`, 0.21}, {1.9625, 0.}, {
          1.9674999999999998`, 0.}, {1.9724999999999997`, 0.}, {
          1.9774999999999998`, 0.}, {1.9808599999999998`, 0.21}}], 
         LineBox[{{1.9841399999999998`, 0.21}, {1.9874999999999998`, 0.}, {
          1.9908599999999999`, 0.21}}], 
         LineBox[{{2.0041399999999996`, 0.21}, {2.0075, 0.}, {
          2.0124999999999997`, 0.}, {2.0174999999999996`, 0.}, {2.02086, 
          0.21}}], 
         LineBox[{{2.02914, 0.21}, {2.0324999999999998`, 0.}, {
          2.0374999999999996`, 0.}, {2.0408599999999995`, 0.21}}], 
         LineBox[{{2.0441399999999996`, 0.21}, {2.0475, 0.}, {
          2.0524999999999998`, 0.}, {2.0574999999999997`, 0.}, {2.0625, 0.}, {
          2.06586, 0.21}}], 
         LineBox[{{2.06914, 0.21}, {2.0725, 0.}, {2.0758599999999996`, 
          0.21}}], 
         LineBox[{{2.0841399999999997`, 0.21}, {2.0875, 0.}, {2.0925, 0.}, {
          2.0974999999999997`, 0.}, {2.1025, 0.}, {2.1075, 0.}, {2.1125, 
          0.}, {2.1174999999999997`, 0.}, {2.1224999999999996`, 0.}, {
          2.1274999999999995`, 0.}, {2.1325, 0.}, {2.1374999999999997`, 0.}, {
          2.1408599999999995`, 0.21}}], 
         LineBox[{{2.15082, 0.21}, {2.1525, 0.}, {2.1574999999999998`, 0.}, {
          2.1624999999999996`, 0.}, {2.1641799999999995`, 0.21}}], 
         LineBox[{{2.17082, 0.21}, {2.1725, 0.}, {2.17418, 0.21}}], 
         LineBox[{{2.1808199999999998`, 0.21}, {2.1824999999999997`, 0.}, {
          2.1875, 0.}, {2.1925, 0.}, {2.1975, 0.}, {2.2024999999999997`, 
          0.}, {2.2074999999999996`, 0.}, {2.2125, 0.}, {2.2175, 0.}, {
          2.2224999999999997`, 0.}, {2.2275, 0.}, {2.2325, 0.}, {2.2375, 
          0.}, {2.2425, 0.}, {2.2475, 0.}, {2.2525000000000004`, 0.}, {
          2.2541800000000003`, 0.21}}], 
         LineBox[{{2.27414, 0.21}, {2.2775000000000003`, 0.}, {2.2825, 0.}, {
          2.2875, 0.}, {2.2925000000000004`, 0.}, {2.2975000000000003`, 0.}, {
          2.2991800000000002`, 0.21}}], 
         LineBox[{{2.30914, 0.21}, {2.3125, 0.}, {2.3175000000000003`, 0.}, {
          2.3225000000000002`, 0.}, {2.3275, 0.}, {2.3325000000000005`, 0.}, {
          2.3358600000000003`, 0.21}}], 
         LineBox[{{2.3391400000000004`, 0.21}, {2.3425000000000002`, 0.}, {
          2.3475, 0.}, {2.35086, 0.21}}], 
         LineBox[{{2.35414, 0.21}, {2.3575000000000004`, 0.}, {
          2.3625000000000003`, 0.}, {2.3675, 0.}, {2.37086, 0.21}}], 
         LineBox[{{2.37414, 0.21}, {2.3775000000000004`, 0.}, {
          2.3825000000000003`, 0.}, {2.38586, 0.21}}], 
         LineBox[{{2.3891400000000003`, 0.21}, {2.3925, 0.}, {2.3975, 0.}, {
          2.4025000000000003`, 0.}, {2.40586, 0.21}}], 
         LineBox[{{2.4091400000000003`, 0.21}, {2.4125, 0.}, {
          2.4175000000000004`, 0.}, {2.4225000000000003`, 0.}, {2.4275, 0.}, {
          2.4325, 0.}, {2.4375, 0.}, {2.4425000000000003`, 0.}, {
          2.4475000000000002`, 0.}, {2.45086, 0.21}}], 
         LineBox[{{2.45414, 0.21}, {2.4575000000000005`, 0.}, {
          2.4625000000000004`, 0.}, {2.4675000000000002`, 0.}, {2.46918, 
          0.21}}], 
         LineBox[{{2.47582, 0.21}, {2.4775, 0.}, {2.4825000000000004`, 0.}, {
          2.48586, 0.21}}], 
         LineBox[{{2.49914, 0.21}, {2.5025000000000004`, 0.}, {
          2.5075000000000003`, 0.}, {2.5125, 0.}, {2.51418, 0.21}}], 
         LineBox[{{2.5208200000000005`, 0.21}, {2.5225000000000004`, 0.}, {
          2.5275000000000003`, 0.}, {2.5325, 0.}, {2.5375, 0.}, {
          2.5408600000000003`, 0.21}}], 
         LineBox[{{2.5441400000000005`, 0.21}, {2.5475000000000003`, 0.}, {
          2.5525, 0.}, {2.5575, 0.}, {2.5625, 0.}, {2.5658600000000003`, 
          0.21}}], 
         LineBox[{{2.5691400000000004`, 0.21}, {2.5725000000000002`, 0.}, {
          2.5775, 0.}, {2.5825000000000005`, 0.}, {2.5858600000000003`, 
          0.21}}], 
         LineBox[{{2.6091400000000005`, 0.21}, {2.6125000000000003`, 0.}, {
          2.6175, 0.}, {2.62086, 0.21}}], 
         LineBox[{{2.62414, 0.21}, {2.6275000000000004`, 0.}, {
          2.6325000000000003`, 0.}, {2.63586, 0.21}}], 
         LineBox[{{2.6458200000000005`, 0.21}, {2.6475000000000004`, 0.}, {
          2.6525000000000003`, 0.}, {2.6575, 0.}, {2.6625, 0.}, {
          2.6675000000000004`, 0.}, {2.6725000000000003`, 0.}, {2.6775, 0.}, {
          2.6825, 0.}, {2.6875, 0.}, {2.6925000000000003`, 0.}, {
          2.6975000000000002`, 0.}, {2.70086, 0.21}}], 
         LineBox[{{2.70414, 0.21}, {2.7075000000000005`, 0.}, {
          2.7125000000000004`, 0.}, {2.7175000000000002`, 0.}, {2.7225, 0.}, {
          2.72586, 0.21}}], 
         LineBox[{{2.7358200000000004`, 0.21}, {2.7375000000000003`, 0.}, {
          2.7425, 0.}, {2.7475, 0.}, {2.7525000000000004`, 0.}, {
          2.7575000000000003`, 0.}, {2.7625, 0.}, {2.76586, 0.21}}], 
         LineBox[{{2.76914, 0.21}, {2.7725000000000004`, 0.}, {
          2.7775000000000003`, 0.}, {2.78086, 0.21}}], 
         LineBox[{{2.78914, 0.21}, {2.7925000000000004`, 0.}, {
          2.7975000000000003`, 0.}, {2.8025, 0.}, {2.80586, 0.21}}], 
         LineBox[{{2.80914, 0.21}, {2.8125000000000004`, 0.}, {
          2.8175000000000003`, 0.}, {2.82086, 0.21}}], 
         LineBox[{{2.8241400000000003`, 0.21}, {2.8275, 0.}, {2.8325, 0.}, {
          2.8375000000000004`, 0.}, {2.8425000000000002`, 0.}, {2.84586, 
          0.21}}], 
         LineBox[{{2.8558200000000005`, 0.21}, {2.8575000000000004`, 0.}, {
          2.86086, 0.21}}], 
         LineBox[{{2.8641400000000004`, 0.21}, {2.8675, 0.}, {2.8725, 0.}, {
          2.8775000000000004`, 0.}, {2.8825000000000003`, 0.}, {2.8875, 0.}, {
          2.8925, 0.}, {2.8958600000000003`, 0.21}}], 
         LineBox[{{2.8991400000000005`, 0.21}, {2.9025000000000003`, 0.}, {
          2.90586, 0.21}}], 
         LineBox[{{2.9091400000000003`, 0.21}, {2.9125, 0.}, {
          2.9158600000000003`, 0.21}}], 
         LineBox[{{2.9191400000000005`, 0.21}, {2.9225000000000003`, 0.}, {
          2.92586, 0.21}}], 
         LineBox[{{2.9291400000000003`, 0.21}, {2.9325, 0.}, {
          2.9358600000000004`, 0.21}}], 
         LineBox[{{2.9391400000000005`, 0.21}, {2.9425000000000003`, 0.}, {
          2.9475000000000002`, 0.}, {2.9525, 0.}, {2.95586, 0.21}}], 
         LineBox[{{2.95914, 0.21}, {2.9625000000000004`, 0.}, {
          2.9675000000000002`, 0.}, {2.9725, 0.}, {2.9775, 0.}, {
          2.9825000000000004`, 0.}, {2.9875000000000003`, 0.}, {2.9925, 0.}, {
          2.9975, 0.}, {3.0025000000000004`, 0.}, {3.0075000000000003`, 0.}, {
          3.0125, 0.}, {3.0175, 0.}, {3.0225000000000004`, 0.}, {
          3.0275000000000003`, 0.}, {3.03086, 0.21}}], 
         LineBox[{{3.0341400000000003`, 0.21}, {3.0375, 0.}, {
          3.0425000000000004`, 0.}, {3.0475000000000003`, 0.}, {
          3.0491800000000002`, 0.21}}], 
         LineBox[{{3.0641400000000005`, 0.21}, {3.0675000000000003`, 0.}, {
          3.0725000000000002`, 0.}, {3.0775, 0.}, {3.0825, 0.}, {
          3.0875000000000004`, 0.}, {3.0925000000000002`, 0.}, {3.09418, 
          0.21}}], 
         LineBox[{{3.10082, 0.21}, {3.1025, 0.}, {3.1058600000000003`, 
          0.21}}], 
         LineBox[{{3.1158200000000003`, 0.21}, {3.1175, 0.}, {3.1225, 0.}, {
          3.1275000000000004`, 0.}, {3.1325000000000003`, 0.}, {3.13586, 
          0.21}}], 
         LineBox[{{3.1391400000000003`, 0.21}, {3.1425, 0.}, {
          3.1458600000000003`, 0.21}}], 
         LineBox[{{3.1491400000000005`, 0.21}, {3.1525000000000003`, 0.}, {
          3.1575, 0.}, {3.1625, 0.}, {3.1675000000000004`, 0.}, {
          3.1725000000000003`, 0.}, {3.1775, 0.}, {3.18086, 0.21}}], 
         LineBox[{{3.18414, 0.21}, {3.1875000000000004`, 0.}, {
          3.1925000000000003`, 0.}, {3.1975000000000002`, 0.}, {3.20086, 
          0.21}}], 
         LineBox[{{3.20414, 0.21}, {3.2075, 0.}, {3.2108600000000003`, 
          0.21}}], 
         LineBox[{{3.2141400000000004`, 0.21}, {3.2175000000000002`, 0.}, {
          3.21918, 0.21}}], 
         LineBox[{{3.22582, 0.21}, {3.2275, 0.}, {3.2325000000000004`, 0.}, {
          3.2375000000000003`, 0.}, {3.2425, 0.}, {3.2475, 0.}, {
          3.2508600000000003`, 0.21}}], 
         LineBox[{{3.2591400000000004`, 0.21}, {3.2625, 0.}, {3.26586, 
          0.21}}], 
         LineBox[{{3.26914, 0.21}, {3.2725000000000004`, 0.}, {
          3.2775000000000003`, 0.}, {3.2825, 0.}, {3.2875, 0.}, {3.2925, 
          0.}, {3.2975000000000003`, 0.}, {3.3025, 0.}, {3.3075, 0.}, {
          3.3125000000000004`, 0.}, {3.3175000000000003`, 0.}, {3.32086, 
          0.21}}], 
         LineBox[{{3.32914, 0.21}, {3.3325, 0.}, {3.3375000000000004`, 0.}, {
          3.3425000000000002`, 0.}, {3.3475, 0.}, {3.3525000000000005`, 0.}, {
          3.3575000000000004`, 0.}, {3.3625000000000003`, 0.}, {3.3675, 0.}, {
          3.3725, 0.}, {3.3775000000000004`, 0.}, {3.38086, 0.21}}], 
         LineBox[{{3.3841400000000004`, 0.21}, {3.3875, 0.}, {3.38918, 
          0.21}}], 
         LineBox[{{3.3958200000000005`, 0.21}, {3.3975000000000004`, 0.}, {
          3.3991800000000003`, 0.21}}], 
         LineBox[{{3.4091400000000003`, 0.21}, {3.4125, 0.}, {3.4175, 0.}, {
          3.4225000000000003`, 0.}, {3.4275, 0.}, {3.43086, 0.21}}], 
         LineBox[{{3.43414, 0.21}, {3.4375000000000004`, 0.}, {
          3.4425000000000003`, 0.}, {3.4475000000000002`, 0.}, {3.4525, 0.}, {
          3.4575, 0.}, {3.4608600000000003`, 0.21}}], 
         LineBox[{{3.4641400000000004`, 0.21}, {3.4675000000000002`, 0.}, {
          3.47086, 0.21}}], 
         LineBox[{{3.4741400000000002`, 0.21}, {3.4775000000000005`, 0.}, {
          3.4808600000000003`, 0.21}}], 
         LineBox[{{3.4841400000000005`, 0.21}, {3.4875000000000003`, 0.}, {
          3.49086, 0.21}}], 
         LineBox[{{3.49914, 0.21}, {3.5025000000000004`, 0.}, {3.50586, 
          0.21}}], 
         LineBox[{{3.5091400000000004`, 0.21}, {3.5125, 0.}, {
          3.5158600000000004`, 0.21}}], 
         LineBox[{{3.5191400000000006`, 0.21}, {3.5225000000000004`, 0.}, {
          3.52586, 0.21}}], 
         LineBox[{{3.5291400000000004`, 0.21}, {3.5325, 0.}, {3.5375, 0.}, {
          3.54086, 0.21}}], 
         LineBox[{{3.5491400000000004`, 0.21}, {3.5525, 0.}, {3.5575, 0.}, {
          3.5625000000000004`, 0.}, {3.5675000000000003`, 0.}, {
          3.5725000000000002`, 0.}, {3.5775, 0.}, {3.5825, 0.}, {
          3.5875000000000004`, 0.}, {3.59086, 0.21}}], 
         LineBox[{{3.5941400000000003`, 0.21}, {3.5975, 0.}, {
          3.6025000000000005`, 0.}, {3.6075000000000004`, 0.}, {
          3.6125000000000003`, 0.}, {3.61586, 0.21}}], 
         LineBox[{{3.6308200000000004`, 0.21}, {3.6325000000000003`, 0.}, {
          3.6375, 0.}, {3.6425000000000005`, 0.}, {3.6475000000000004`, 0.}, {
          3.6525000000000003`, 0.}, {3.65586, 0.21}}], 
         LineBox[{{3.6591400000000003`, 0.21}, {3.6625, 0.}, {3.6675, 0.}, {
          3.6725000000000003`, 0.}, {3.6775, 0.}, {3.6825, 0.}, {
          3.6875000000000004`, 0.}, {3.6908600000000003`, 0.21}}], 
         LineBox[{{3.6941400000000004`, 0.21}, {3.6975000000000002`, 0.}, {
          3.7025, 0.}, {3.70586, 0.21}}], 
         LineBox[{{3.7241400000000002`, 0.21}, {3.7275000000000005`, 0.}, {
          3.7308600000000003`, 0.21}}], 
         LineBox[{{3.7341400000000005`, 0.21}, {3.7375000000000003`, 0.}, {
          3.7425, 0.}, {3.7475, 0.}, {3.7525000000000004`, 0.}, {3.75586, 
          0.21}}], 
         LineBox[{{3.7591400000000004`, 0.21}, {3.7625, 0.}, {
          3.7675000000000005`, 0.}, {3.7725000000000004`, 0.}, {
          3.7775000000000003`, 0.}, {3.7825, 0.}, {3.7875, 0.}, {3.7925, 
          0.}, {3.7975000000000003`, 0.}, {3.8025, 0.}, {3.80586, 0.21}}], 
         LineBox[{{3.80914, 0.21}, {3.8125000000000004`, 0.}, {
          3.8158600000000003`, 0.21}}], 
         LineBox[{{3.8191400000000004`, 0.21}, {3.8225000000000002`, 0.}, {
          3.8275, 0.}, {3.8325, 0.}, {3.8375000000000004`, 0.}, {
          3.8425000000000002`, 0.}, {3.8475, 0.}, {3.8525000000000005`, 0.}, {
          3.8575000000000004`, 0.}, {3.8625000000000003`, 0.}, {3.8675, 0.}, {
          3.8725, 0.}, {3.8758600000000003`, 0.21}}], 
         LineBox[{{3.8841400000000004`, 0.21}, {3.8875, 0.}, {
          3.8908600000000004`, 0.21}}], 
         LineBox[{{3.8941400000000006`, 0.21}, {3.8975000000000004`, 0.}, {
          3.9025000000000003`, 0.}, {3.9075, 0.}, {3.91086, 0.21}}], 
         LineBox[{{3.91414, 0.21}, {3.9175, 0.}, {3.9225000000000003`, 0.}, {
          3.9275, 0.}, {3.93086, 0.21}}], 
         LineBox[{{3.93414, 0.21}, {3.9375000000000004`, 0.}, {
          3.9425000000000003`, 0.}, {3.9475000000000002`, 0.}, {3.9525, 0.}, {
          3.95586, 0.21}}], 
         LineBox[{{3.9641400000000004`, 0.21}, {3.9675000000000002`, 0.}, {
          3.9725, 0.}, {3.9758600000000004`, 0.21}}], 
         LineBox[{{3.9791400000000006`, 0.21}, {3.9825000000000004`, 0.}, {
          3.98586, 0.21}}], 
         LineBox[{{3.9891400000000004`, 0.21}, {3.9925, 0.}, {3.9975, 0.}, {
          4.0025, 0.}, {4.00586, 0.21}}], 
         LineBox[{{4.01414, 0.21}, {4.0175, 0.}, {4.020860000000001, 0.21}}], 
         LineBox[{{4.024140000000001, 0.21}, {4.0275, 0.}, {
          4.0308600000000006`, 0.21}}], 
         LineBox[{{4.034140000000001, 0.21}, {4.0375, 0.}, {4.04086, 0.21}}], 
         LineBox[{{4.04914, 0.21}, {4.0525, 0.}, {4.0575, 0.}, {4.0625, 0.}, {
          4.067500000000001, 0.}, {4.0725, 0.}, {4.077500000000001, 0.}, {
          4.0825, 0.}, {4.08586, 0.21}}], 
         LineBox[{{4.08914, 0.21}, {4.0925, 0.}, {4.0975, 0.}, {
          4.102500000000001, 0.}, {4.1075, 0.}, {4.110860000000001, 0.21}}], 
         LineBox[{{4.114140000000001, 0.21}, {4.1175, 0.}, {
          4.1225000000000005`, 0.}, {4.12586, 0.21}}], 
         LineBox[{{4.1291400000000005`, 0.21}, {4.1325, 0.}, {4.1375, 0.}, {
          4.1425, 0.}, {4.145860000000001, 0.21}}], 
         LineBox[{{4.149140000000001, 0.21}, {4.1525, 0.}, {4.157500000000001,
           0.}, {4.1625, 0.}, {4.1675, 0.}, {4.1725, 0.}, {4.1775, 0.}, {
          4.18086, 0.21}}], 
         LineBox[{{4.18414, 0.21}, {4.1875, 0.}, {4.192500000000001, 0.}, {
          4.1975, 0.}, {4.202500000000001, 0.}, {4.2075, 0.}, {4.2125, 0.}, {
          4.21586, 0.21}}], 
         LineBox[{{4.21914, 0.21}, {4.2225, 0.}, {4.227500000000001, 0.}, {
          4.2325, 0.}, {4.237500000000001, 0.}, {4.24086, 0.21}}], 
         LineBox[{{4.25914, 0.21}, {4.2625, 0.}, {4.26586, 0.21}}], 
         LineBox[{{4.26914, 0.21}, {4.272500000000001, 0.}, {4.2775, 0.}, {
          4.2808600000000006`, 0.21}}], 
         LineBox[{{4.284140000000001, 0.21}, {4.2875, 0.}, {4.2925, 0.}, {
          4.2975, 0.}, {4.3025, 0.}, {4.3075, 0.}, {4.3125, 0.}, {
          4.317500000000001, 0.}, {4.32086, 0.21}}], 
         LineBox[{{4.32414, 0.21}, {4.327500000000001, 0.}, {4.33086, 0.21}}], 
         LineBox[{{4.3341400000000005`, 0.21}, {4.3375, 0.}, {4.3425, 0.}, {
          4.3475, 0.}, {4.3525, 0.}, {4.3575, 0.}, {4.362500000000001, 0.}, {
          4.3675, 0.}, {4.3725000000000005`, 0.}, {4.3775, 0.}, {4.3825, 
          0.}, {4.38586, 0.21}}], 
         LineBox[{{4.38914, 0.21}, {4.3925, 0.}, {4.397500000000001, 0.}, {
          4.39918, 0.21}}], 
         LineBox[{{4.40582, 0.21}, {4.407500000000001, 0.}, {
          4.4125000000000005`, 0.}, {4.4175, 0.}, {4.4225, 0.}, {4.4275, 
          0.}, {4.4325, 0.}, {4.4375, 0.}, {4.442500000000001, 0.}, {4.4475, 
          0.}, {4.4508600000000005`, 0.21}}], 
         LineBox[{{4.454140000000001, 0.21}, {4.4575000000000005`, 0.}, {
          4.46086, 0.21}}], 
         LineBox[{{4.46914, 0.21}, {4.4725, 0.}, {4.4775, 0.}, {4.4825, 0.}, {
          4.487500000000001, 0.}, {4.49086, 0.21}}], 
         LineBox[{{4.49414, 0.21}, {4.4975000000000005`, 0.}, {4.50086, 
          0.21}}], 
         LineBox[{{4.5041400000000005`, 0.21}, {4.5075, 0.}, {4.51086, 
          0.21}}], 
         LineBox[{{4.51414, 0.21}, {4.5175, 0.}, {4.522500000000001, 0.}, {
          4.52586, 0.21}}], 
         LineBox[{{4.52914, 0.21}, {4.532500000000001, 0.}, {
          4.5375000000000005`, 0.}, {4.5425, 0.}, {4.5475, 0.}, {4.5525, 
          0.}, {4.5575, 0.}, {4.5625, 0.}, {4.567500000000001, 0.}, {4.5725, 
          0.}, {4.577500000000001, 0.}, {4.5825000000000005`, 0.}, {4.58586, 
          0.21}}], 
         LineBox[{{4.58914, 0.21}, {4.5925, 0.}, {4.5975, 0.}, {4.60086, 
          0.21}}], 
         LineBox[{{4.60414, 0.21}, {4.6075, 0.}, {4.612500000000001, 0.}, {
          4.6175, 0.}, {4.6225000000000005`, 0.}, {4.6275, 0.}, {4.6325, 
          0.}, {4.6375, 0.}, {4.64086, 0.21}}], 
         LineBox[{{4.64414, 0.21}, {4.647500000000001, 0.}, {4.6525, 0.}, {
          4.657500000000001, 0.}, {4.659180000000001, 0.21}}], 
         LineBox[{{4.66582, 0.21}, {4.6675, 0.}, {4.6725, 0.}, {4.6775, 0.}, {
          4.6825, 0.}, {4.6875, 0.}, {4.692500000000001, 0.}, {4.6975, 0.}, {
          4.702500000000001, 0.}, {4.7075000000000005`, 0.}, {4.7125, 0.}, {
          4.7175, 0.}, {4.7186200000000005`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQvfP+Qo0Lz4UcHlaJrHN/eMpeM6b/0NcXQg4MUAAU
rBJ5h+CbGAPBZwR/h1zr68AfCL4d1/XFBX8R/MNfNWL6mYThfA+QRewI/tkz
QMCD4AeBDBRE8G8sLrDlEkfwQc7TkEHwH4HcrYjgp6cBgRqC/yYQaKA2gl9o
C3SgAYL/Dei8Q6YIfg0oGKwQ/FOdZaJBdsLw8AEApFtHRg==
          "]], 
         LineBox[{{4.81414, 0.21}, {4.817500000000001, 0.}, {
          4.820860000000001, 0.21}}], 
         LineBox[{{4.830820000000001, 0.21}, {4.832500000000001, 0.}, {4.8375,
           0.}, {4.842500000000001, 0.}, {4.8475, 0.}, {4.850860000000001, 
          0.21}}], 
         LineBox[{{4.854140000000001, 0.21}, {4.8575, 0.}, {4.862500000000001,
           0.}, {4.8675000000000015`, 0.}, {4.8725000000000005`, 0.}, {
          4.877500000000001, 0.}, {4.8825, 0.}, {4.885860000000001, 0.21}}], 
         LineBox[{{4.899140000000001, 0.21}, {4.902500000000001, 0.}, {
          4.907500000000001, 0.}, {4.912500000000001, 0.}, {4.9175, 0.}, {
          4.922500000000001, 0.}, {4.9275, 0.}, {4.932500000000001, 0.}, {
          4.9375, 0.}, {4.940860000000001, 0.21}}], 
         LineBox[{{4.944140000000001, 0.21}, {4.947500000000001, 0.}, {
          4.952500000000001, 0.}, {4.955860000000001, 0.21}}], 
         LineBox[{{4.959140000000001, 0.21}, {4.9625, 0.}, {4.967500000000001,
           0.}, {4.9725, 0.}, {4.977500000000001, 0.}, {4.9825, 0.}, {
          4.987500000000001, 0.}, {4.9925000000000015`, 0.}, {
          4.9975000000000005`, 0.}, {5.002500000000001, 0.}, {5.0075, 0.}, {
          5.010860000000001, 0.21}}], 
         LineBox[{{5.014140000000001, 0.21}, {5.0175, 0.}, {5.022500000000001,
           0.}, {5.027500000000001, 0.}, {5.032500000000001, 0.}, {
          5.034180000000001, 0.21}}], 
         LineBox[{{5.040820000000001, 0.21}, {5.0425, 0.}, {5.047500000000001,
           0.}, {5.0525, 0.}, {5.057500000000001, 0.}, {5.0625, 0.}, {
          5.067500000000001, 0.}, {5.072500000000001, 0.}, {5.077500000000001,
           0.}, {5.082500000000001, 0.}, {5.08586, 0.21}}], 
         LineBox[{{5.08914, 0.21}, {5.092500000000001, 0.}, {5.0975, 0.}, {
          5.102500000000001, 0.}, {5.1075, 0.}, {5.10918, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQLfRkQcvMMhGHh1Ui69wfnrLfJdf6OrBCxIEBCuy4
ri8uqEXwj3zViOlvQvA9QBrbEfxzZ4CgB8EP2gE0cCKCf2NxgS3XdAQ/tv/Q
V405CP4jkDsWIvgZaUCwDMF/Ewg0cDWCX2QLdOAGBP8b0HmHtiL4NSBv7ULw
weAAgt/2GmjgUQSfG+hd21MIfpRPjt26s4jwAQBUZkn1
          "]], 
         LineBox[{{5.204140000000001, 0.21}, {5.207500000000001, 0.}, {
          5.21086, 0.21}}], 
         LineBox[{{5.21414, 0.21}, {5.217500000000001, 0.}, {5.2225, 0.}, {
          5.227500000000001, 0.}, {5.2325, 0.}, {5.235860000000001, 0.21}}], 
         LineBox[CompressedData["
1:eJxd2T/I23UCx/GapVBdhOfsqbV3XUrVRfyzFKvPUjxcpOoi9ByU84qDFl1E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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.9917508, 0.5901996, 0.09831576]], 
         LineBox[CompressedData["
1:eJxdmD/o4+UBh48sgSNLzmtT23glSzjJEtQMDdVfHMKVLKGSJSAZGizBIRWy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          "]], 
         LineBox[CompressedData["
1:eJxdkzFIAmEUxz9cgqPlRGgJwUUOXKJwieS7JYQWUVoEaSiSphJaQmiJpCWS
hoggwjBagnIJpJbjMBAJWqKjRZSWQGgJoyXo3vv47g/3wXH8ed/7v/e+Hy+x
ulVYjwghbP+jv3dRjDbKUWdYjd1mhz15VckY3lrUEXwcGa+N8u0VrdvyjE4R
mrKqy1oLceSOrVIO2vCalcwS7u/7dvFFaP7Z0NzGvNYt+WOV6m5a646k9poz
Wjck2dVSWndlmU4S8QEZJjCP7za2ptHfm9+eMYX6Bd9uZKL+M51JxLP0UBOI
07j1COot0MB/ZqDJLv+rdUfOzvnn2wz86PliX2bgR+OOP5HPPD4QZx59aObx
rrWjeLwizjxeUI959KCZxxP6UzbIZx4PuE/juveoxzxaiDOPG+Qzj2vMwzwu
cZ95nEMzj1PkM49jaOZxCM08DrQWgnnsoT9qr7KrdVfx2EE/zGM7xGMzxGMD
cbUfyFf7gbjaD+Sr/QjxyEGr/YCf2g/Mw8dGXO0HeDGPNOqr/QjxSOE9Tu76
j4OkGez7P2P0KzY=
          "]], 
         LineBox[{{-4.287266666666667, 0.21}, {-4.282499999999999, 
          0.03125}, {-4.2775, 0.125}, {-4.272499999999999, 0.03125}, {-4.2675,
           0.09375}, {-4.262499999999999, 0.0625}, {-4.257499999999999, 
          0.09375}, {-4.2524999999999995`, 0.15625}, {-4.2475, 0.}, {-4.2425, 
          0.09375}, {-4.237499999999999, 0.09375}, {-4.2325, 
          0.0625}, {-4.227499999999999, 0.0625}, {-4.2225, 
          0.03125}, {-4.217499999999999, 0.0625}, {-4.2124999999999995`, 
          0.125}, {-4.207966666666667, 0.21}}], 
         LineBox[CompressedData["
1:eJxdlFFEg1EYhn8jaWVbikTFREYkJZLmJDJSsomkRGWJaCORkUgpSZMikSwl
kWYkrRJrlmZFKtrNZLvpot10s5tu6v++v/O/7DDH6z3n+b/ve49Zxzwut0FR
FIf6o3319SNd/GaJZHzlQUcmITaiOdvwsyWi8IoLY/LQa09IHRBLWWe45l7q
mOAtgvOMuZY6IlSaP3ohdUh47SoxBB7hlk/hT9A6hk4T8ABapeVse+C/q+UZ
d+C7VFx2E/qJ1jq0gxpdwfepXf8iNJXnnZc6LAjnnIPf1KyuGfCCBJxGPdRu
bhL+ETU8Dp9w4RHwd2kNYp40Pl8/fM6jD/c5j274nEcXfN464HMebaiH82hB
P5xHI/LjPOrhcx514HMeVvA5j6q8PCrA4zxKcZ7zKMF5zqMQmvMw5NX/Y/7X
iuKher/N+nk31fcpdUgMUT0p+NRO9kXqmPa9B7POb6eB3kJzvufgcZ4nUgdE
NeW3j/NllNc2/CLKZw3+L60F8Hj+szj/RQVOQfN8R1E/z3MAvEeaXw94dwTs
hH9JD6wV98+o4Qb0T7hkLe7z+6vEfX5vZqnj2vsqgK/lYdLr1fIw6TwtD+it
3qvoTcqk/7/8AfPvVp0=
          "]], 
         LineBox[{{-3.8572999999999995`, 0.21}, {-3.8524999999999996`, 
          0.}, {-3.8474999999999997`, 0.15625}, {-3.8453499999999994`, 
          0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQLX1se9eNXXwHHlaJrHN/eMreyBgINvMdYIACjZj+
Q19XwPgH7GVbXwfumAfj77AXBuqqmgLjL7DnvL64wLYLxt9g/x8E6mH8I/Zf
QQaWIuRfBe6Qa81G8B+A3JGIMP8a0DiucIT5p88AgQ/CvIMgA50Q7tsuB3Sg
BYK/Fug8ET2EfpBx15UR9s0EAUmEfN8hoIH8CPkWoHflWBF8cDD94oXbnw80
bvEHGJ+BITUNCJ7xwtVHA4NP4w6Mv8Me5N3XFxH6Qc5bdxyh3gZoXMFeGH8B
ND4Q+iHxgVAPiQ+EeZD4QMhD4gOhHxIfCPMh8YFQP+uld8yWXF54egAAwdCs
+A==
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQXWvKzvEsg/fAwyqRde4PT9k/ANGJvAcYwGCH/bXF
BbZc4TD+BvvTZ4DAB8Y/YH/wq0ZMvxOMf8R+u1zr60ALGH+B/Vp3oMl6MP4J
e5Bx15UR5s8EAUmE+r5DQAP5Efa1vA7cIceKUA925i8euHw+0LjFH3jg+lPT
gOAZgh/dDzTwDoIPNK319UUY/4A9yHnrjvPAzbcBGlewF8Y/YW9kDASbEXyg
bw99XQHjH7GXBXp3xzyEe4SBzquagjCfE2icbRdC/j8I1CP4oOA7VIqw/xXI
gdkI/rIXHnr/E3ng8QMAr0KKXw==
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQHTJ/9dob8TwHHlaJrHN/eMr+2uICW65wngMMYHDE
/vQZIPCB8TfYH/yqEdPvhOBvl2t9HWgB45+wX+sONEkPxl9gDzLuujKMz8Aw
EwQkEfr7DgEN5IfxD9i3vA7cIceKkAc76xc3nJ8PNG7xBxh/h31qGhA8g/FP
2Ef3Aw28A+MvsAea1vr6IkI9yHnrjsP4R+xtgMYV7EWoNzIGgs0I9UDfHvq6
AsY/YC8L9O6OeQj1wkDnVU1ByHMCjbPtQsj/B4F6BP8LyMBShPmvQA7MRuh/
APJwIkI9JD4Q7j0Djg+EfyHxAeMzMGicFji+y4IbHp8AL7WYLg==
          "]], 
         LineBox[{{-3.4021499999999993`, 0.21}, {-3.3974999999999995`, 
          0.09375}, {-3.3924999999999996`, 0.09375}, {-3.3874999999999993`, 
          0.09375}, {-3.3824999999999994`, 0.0625}, {-3.3774999999999995`, 
          0.1875}, {-3.3724999999999996`, 0.1875}, {-3.3707, 0.21}}], 
         LineBox[{{-3.366585714285714, 0.21}, {-3.3624999999999994`, 
          0.03125}, {-3.3574999999999995`, 0.09375}, {-3.3524999999999996`, 
          0.0625}, {-3.3474999999999993`, 0.09375}, {-3.3424999999999994`, 
          0.0625}, {-3.3374999999999995`, 0.03125}, {-3.3334142857142854`, 
          0.21}}], 
         LineBox[{{-3.3308999999999997`, 0.21}, {-3.3274999999999997`, 
          0.125}, {-3.3224999999999993`, 0.0625}, {-3.3174999999999994`, 
          0.0625}, {-3.3124999999999996`, 0.15625}, {-3.307499999999999, 
          0.0625}, {-3.3024999999999993`, 0.15625}, {-3.2974999999999994`, 
          0.15625}, {-3.2924999999999995`, 0.09375}, {-3.2874999999999996`, 
          0.03125}, {-3.2824999999999993`, 0.15625}, {-3.2774999999999994`, 
          0.125}, {-3.2724999999999995`, 0.03125}, {-3.267499999999999, 
          0.09375}, {-3.2624999999999993`, 0.09375}, {-3.2574999999999994`, 
          0.125}, {-3.252966666666666, 0.21}}], 
         LineBox[{{-3.2517999999999994`, 0.21}, {-3.2474999999999996`, 
          0.15625}, {-3.2424999999999997`, 0.03125}, {-3.2374999999999994`, 
          0.0625}, {-3.2324999999999995`, 0.125}, {-3.2274999999999996`, 
          0.0625}, {-3.2224999999999993`, 0.09375}, {-3.2174999999999994`, 
          0.09375}, {-3.2124999999999995`, 0.03125}, {-3.2074999999999996`, 
          0.09375}, {-3.2024999999999997`, 0.03125}, {-3.1974999999999993`, 
          0.125}, {-3.1940999999999993`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQHWkvYMzXwXngYZXIOveHp+z/g0A95wEGMNhg/0Uj
pv9QKYy/wP5V4A651myE/AOQvkSE/LXFBbZc4Qj5MyDgA+MfsT/4FWigE4y/
w367XOvrQAuE/Fp3oEv0YPwD9ouAxl1XRpg3YyYQSCLU9x0CGsiP4Le8BjqQ
FaEe7K1fHHA+yLjFHxD81DQgeMYB1x/dDzTwDoy/wx7k3dcXEXw3UEAdh/EP
2NsAjSvYi9C/j2+O8aItHPDwBADir3JT
          "]], 
         LineBox[{{-3.0872199999999994`, 0.21}, {-3.0824999999999996`, 
          0.0625}, {-3.0774999999999997`, 0.09375}, {-3.0724999999999993`, 
          0.15625}, {-3.0674999999999994`, 0.0625}, {-3.063566666666666, 
          0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQ7Z+Rc+hCLceBh1Ui69wfnrL/ohHTf6iU4wADGGyw
fxW4Q641G8bfYf8ApC4Rxl9gf21xgS1XOIx/wv4MCPgg9B/8CjTQCcHfLtf6
OtACxj9gv9YdaLMegr8IaNx1ZYR9M2YCgSTCvr5DQAP5Eea1vAY6kBXBB3vj
FzvcPJBxiz+ww81LTQOCZ+xw9dH9QAPvsMPNB3n39UWE+s1/tbV9T7HDwwcA
lEdjGw==
          "]], 
         LineBox[{{-2.9712199999999993`, 0.21}, {-2.9674999999999994`, 
          0.09375}, {-2.9624999999999995`, 0.09375}, {-2.9574999999999996`, 
          0.03125}, {-2.9524999999999997`, 0.09375}, {-2.9474999999999993`, 
          0.15625}, {-2.9431999999999996`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQfVFi7eJVnewHHlaJrHN/eMr+PwjUsx9gAIMN9l80
YvoPlcL4O+xfBe6Qa82G8Y/YPwDpS4TxF9hfW1xgyxWOUH8GBHxg/AP2B78C
DXRC8LfLtb4OtEDoX+sOdIkewv5FQOOuK8P4J+xnzAQCSYT5fYeABvIj3AM0
bYccK8L8apC3frHB1YOMW/yBDS6fBgLP2OD6gb79qnEHoT4I6N3XFxHqPUAB
dRzGZ2AAGVewF8bfYG8MApsRfE2QgSsQ5oG8u2MewjyQ86qmwPgL7EHG2XYh
3AOmGhD8b+D4QJj3GhwfCPvA8ZiIMO86OD4Q6iHxgeAfAscHjH/Cfgc4PhDy
68DxgbDfwGcZl5sqGzy9AAAQ17Eu
          "]], 
         LineBox[{{-2.76715, 0.21}, {-2.7624999999999997`, 0.09375}, {-2.7575,
           0.0625}, {-2.7525, 0.0625}, {-2.7475, 0.09375}, {-2.74285, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQbVEvzCX4gfXAwyqRde4PT9mngcAz1gMMYLDBPqb/
0FeNOzD+DvugHXKtry/C+AfsPUAaj8P4C+xtua4vLtiLUG8MApsR5mmCDFyB
UA80LXDHPIQ8yBVVU2D8I/Yg42y7EPaBqQaE/DcNoIGlCPuApsm1ZiPMB/sr
ESEPMo4rHGHeGRDwgfFP2AN9G9PvhJAHeTfQAmEeyHkiegj7lwCNu66MUD8T
BCQR9oGCL4Yf4T+Qd+VYEeqrQR7+xQLng4xb/AHGPwGNDxh/ATQ+EHxIfMD4
O+zdwfGBMA8SHwg+JD4Q6iHxgZCHxAeMD4sPhDwkPmD8I/YJ+urVcS0s8PQD
AIJWss8=
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHZCRc+hCLcuBh1Ui69wfnrL/phHTf6iU5QADGGyw
fx24Q641G8bfYQ9WlwjjH7C/vrjAliscIX8GBHwQ8oe+Ag10QpgHNO11oAVC
PdDSKhE9hPolQOOuKyPkZ4KAJIx/wr4fZCA/wrxWkANZEeqrQd74xQzng4xb
/IEZrj4NBJ7B+AvsY0AG3kHwg0AOvAjjH7EHOW/dcYR+kHEFexF8YxDYDOOf
sNcEGbgCxj9gXy1+58+a+czw8AUA7kZ13w==
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQHSG+/SLDPOYDD6tE1rk/PGUPIqumMB9gAIMd9lzX
FxfYdiH4YKoBxj9h/00jpv9QKUL+deAOudZsGP+IPdjcRBh/gz3IOK5wGP+A
/RkQ8EGYd+gr0EAnGH+BPdC014EWCP0g54noIexbAjTuujKCPxMEJBHq+0EG
8iPc0wpyICvC/mqQh38xweVBxi3+AOMvsE8DgWcwPgNDDMjAOzD+DvsgkAMv
Ivgg5607jlAPMq5gL4y/wd4YBDYjzNcEGbgCYT/IuzvmIfRD4gNhPiQ+YPwD
0PhAyH8FxweCD4kPhPmQ+ECYD4kPhHlnwfGB4EPiA8Y/AY0PhPmQ+ED4DxIf
CPt+nTgg8kOWCZ6+ALmyt18=
          "]], 
         LineBox[{{-2.2617, 0.21}, {-2.2575, 0.}, {-2.2525, 
          0.09375}, {-2.2475, 0.09375}, {-2.2424999999999997`, 
          0.03125}, {-2.239322222222222, 0.21}}], 
         LineBox[{{-2.2358599999999997`, 0.21}, {-2.2325, 0.}, {-2.2275, 
          0.0625}, {-2.2224999999999997`, 0.15625}, {-2.2175, 
          0.09375}, {-2.2125, 0.09375}, {-2.2075, 
          0.125}, {-2.2024999999999997`, 0.125}, {-2.1975, 0.0625}, {-2.1925, 
          0.}, {-2.1875, 0.03125}, {-2.1824999999999997`, 
          0.09375}, {-2.1774999999999998`, 0.09375}, {-2.1725, 
          0.125}, {-2.1675, 0.1875}, {-2.1625, 0.0625}, {-2.1574999999999998`,
           0.09375}, {-2.15378, 0.21}}], 
         LineBox[CompressedData["
1:eJxFUzFIw1AQ/RVcsrh0cQmICBWhg4KIWD646ODSLi5ZFOwiaBBc4uJgFwcL
4qJDKdTBqRRcskhLKVikDi52cbCLQ7O41EFsNHff++8g+Tze/Xfv7pKZ3cPC
3oRSajV56PzJLlweLadagyBd3xg86eQVpLOpluKo6ls/5/RnBXf0NcU0+HJ7
lPGmBIe6FOVDdxL4hGS/1T9uaJKrfQru6iLFh7L5Hgm+Ib8QuqXoBZjs1R+R
T3L+g+COXqK4F1zV8yR4B94lgxXBLU32givwJJc7Rz0+TlEv6bbcPkY+tVva
Rz88xx3kk5yzjXrPvSS24I/GV14HT+3mV1Df7AP5Zh+ob/aBemYf4M0+cP+L
/I9+m1LvnfcuONQ9DvDsJwTP9WuCG/qCGwBmuUBw1ey3CJ73mQe/xgMX3NFs
LwOe5dK4b07BXT2k+Uex9ftK8+4Ds702MMvVY6t3wwMUrNQZLzS29bldH/fZ
nhfb+pu8cOgt8gcY23nx+Fzc53ad2PbL9kZjy8/50UFlOG7K//gHFL0syQ==

          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQPffT1WrxO3/3P6wSWef+8JT9GTD4u58BCnbItb4O
3AHjb7BfUmDLdX0xjL/Dvv/QV42Yfhj/gD3YmCqEfBoYwPgL7IPABiLkQaYV
2CLMBxoGNBHGP2EPNk4EIQ+hEfqBjgMa+AfOv7YY5MA/cPVg5x1CyIONW4eQ
nwkGMP4R+xawgX/g7gV7twChH+y8mD9w/4KNc0fIGxmDAEI/OPjk/sD9A/Yu
F8J+sPO+/obzH4AD8DdcPyQ+EPKQ+EDwwd5d/Btu/+e+4BKV6b/h8QkAjI6x
bw==
          "]], 
         LineBox[{{-1.7206, 0.21}, {-1.7174999999999998`, 0.09375}, {-1.7125, 
          0.09375}, {-1.7075, 0.125}, {-1.7025, 
          0.15625}, {-1.6974999999999998`, 0.1875}, {-1.6925, 
          0.125}, {-1.6875, 0.09375}, {-1.6824999999999999`, 
          0.125}, {-1.6774999999999998`, 0.09375}, {-1.6724999999999999`, 
          0.125}, {-1.6675, 0.15625}, {-1.6624999999999999`, 
          0.09375}, {-1.6574999999999998`, 0.09375}, {-1.6524999999999999`, 
          0.09375}, {-1.6475, 0.09375}, {-1.6424999999999998`, 
          0.125}, {-1.6379666666666663`, 0.21}}], 
         LineBox[CompressedData["
1:eJxdkS8IwkAYxYdREYt5YHJZ87gkyy4vCVpdXnbZvCYIRrEow6IMg4jZVZfN
Y3+S2zt3D/zgOB7f9/3uHW8wW9rzlqZpg+rUd3SaBN1ReUm8/t5KHkL3P9NQ
Ly8a6iDa8dY1243eiNRw1lFa/PRVvLHX6FA8UdQhgI2+iZoWbwvFq2AVkfPA
edQLFN+zASTPhEFq2DMK5R+4Pt+TN/n1b/1PrvovGMwVD/aiXM0Dt2c/QHF/
BSD7+K7LfdhzGn0XwFnsj8Z1sS/zyP/y4LzMI1N9mQe1zCNTfmQe1Odhr3Pc
ZSr/LxHVwZM=
          "]], 
         LineBox[{{-1.4772199999999998`, 0.21}, {-1.4725, 
          0.0625}, {-1.4674999999999998`, 0.09375}, {-1.4625, 
          0.09375}, {-1.4575, 0.125}, {-1.4525, 
          0.09375}, {-1.4474999999999998`, 0.03125}, {-1.4425, 
          0.09375}, {-1.4375, 0.0625}, {-1.4324999999999999`, 
          0.15625}, {-1.4274999999999998`, 0.03125}, {-1.4224999999999999`, 
          0.03125}, {-1.4175, 0.0625}, {-1.4124999999999999`, 
          0.1875}, {-1.4074999999999998`, 0.09375}, {-1.4024999999999999`, 
          0.03125}, {-1.398925, 0.21}}], 
         LineBox[CompressedData["
1:eJxFkSEMwjAQRQsSPU3AoUEvlUMCQSIIARxheppZ0DiSOQRBzkEWBCFoZgE7
uW4gob/p3U+a9ufa17v85mQ5mFWFEI3/0vs3me7Hw/L0CpyD97pJD4fyJKBY
tjta1p9lPcz6cZ3rtTTy3Zr1V1m0RpukKOj+E1z2d8j6i4wBLIinaWlk/VGu
E03kOnAB8+YQ1wcA8nsXDXId7bXYA+ewNzvz9bRhpoj3QIOK5kV7iaJ5gDvw
/S3EfgWg9TuJcX2uo72Rov9NHvyfyYO9yYN5Jg9F85g8cuL3PpXu4p1T3j9M
DriL
          "]], 
         LineBox[{{-1.2422999999999997`, 0.21}, {-1.2374999999999998`, 
          0.}, {-1.2325, 0.03125}, {-1.2274999999999998`, 
          0.125}, {-1.2224999999999997`, 0.125}, {-1.2174999999999998`, 
          0.125}, {-1.2125, 0.15625}, {-1.2082, 0.21}}], 
         LineBox[{{-1.2073, 0.21}, {-1.2025, 0.}, {-1.1974999999999998`, 
          0.1875}, {-1.1925, 0.125}, {-1.1875, 0.125}, {-1.1824999999999999`, 
          0.09375}, {-1.1774999999999998`, 0.03125}, {-1.1724999999999999`, 
          0.1875}, {-1.1675, 0.03125}, {-1.1624999999999999`, 
          0.09375}, {-1.1574999999999998`, 0.0625}, {-1.1545499999999997`, 
          0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQfW3hH0ndzE/7H1aJrHN/eMo+pv/QV42YT/sZwGCB
vTtYAsY/Ym9kDAIw/gl7udbXgTvkYPwD9lzXFxfYciH4QMOAJn6E8nfYPwDb
A+NvsD8DBjA+UAXYQIQ8yLTrixH6+0DO60fwwcZVfYTblwYGCP1BYAMR6m3B
DkTwwc7TQPDBxol8hPsPQiPkQb5tff0BHj7XwA78AA8fsPMOIeS5b11U5Vz/
AR6+ABI5hXQ=
          "]], 
         LineBox[CompressedData["
1:eJxdkj0MAUEQhTc6orzWJSQSiY6WbIWalkpCJaG+mta1FBKJFtHR+YlK1LRE
59xPQY1952YSk2wuX2b3zdu3F6+3K42QECL5Xer7TIhkeuqtr4Y2L10Pcojy
1gK1kV2rvNJ7AS9kJx85TzrMNXP3StV4fwlCAe9lJquK+3pPCfJ5pZaPBLyS
dzXOcn88ltuvurlzSW8Af8xt+GEuYr5LejHMc2neU8m9HPJzRDm0f4ILMiMW
w6HzsFfmPuRSzG+UTfonCDLPEJD9ly9zFXky+/nZpB9GXjblc4HBB/WXCPhB
efSVnMn9RlMV93N4gICFwHU1Zv89LPKzwXswR2/VQmtk0f/zAZy81yQ=
          "]], 
         LineBox[{{-0.8622666666666665, 0.21}, {-0.8574999999999999, 
          0.03125}, {-0.8524999999999998, 0.15625}, {-0.8474999999999997, 
          0.09375}, {-0.8424999999999998, 0.03125}, {-0.8374999999999999, 
          0.09375}, {-0.8325, 0.03125}, {-0.8274999999999999, 
          0.09375}, {-0.8224999999999998, 0.09375}, {-0.8174999999999999, 
          0.15625}, {-0.8125, 0.0625}, {-0.8074999999999999, 
          0.03125}, {-0.8024999999999998, 0.09375}, {-0.7974999999999999, 
          0.09375}, {-0.7925, 0.03125}, {-0.7874999999999999, 
          0.15625}, {-0.7831999999999998, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQPaX34ZEstpf7H1aJrHN/eMr+AZh+sZ8BDA7Y75Br
fR24A8Y/Yd936KtGTD+Mv8E+JQ0EYPwd9jZc1xcX2CL4INOqRBD8V4EgE5/D
9R8AGXfoOdy+GTNBAMY/Yl9gCzIQIe8GduhzuHkyIOfJwfgL7L+AjPv6DC5/
BgyeweUXgQ18Bre/AuxAhPoAsIefwe0DG6fxDO4eCI3gX1sMMvApnL8G5N11
T+H6W0DOa0XIg42LeQq3z8gYBJ7C3ccBCj6up3D3QeLjCVw9JD6ewNVD4uMJ
3D5IfDyB2weJjydo8fEELT4ew82DxMdjuDwkPhB8SHwg1EPiAyF/8dv6NSaa
j+HpCQDoV9rl
          "]], 
         LineBox[{{-0.5942999999999997, 0.21}, {-0.5924999999999998, 
          0.1875}, {-0.5874999999999999, 0.125}, {-0.5824999999999998, 
          0.125}, {-0.5774999999999997, 0.09375}, {-0.5724999999999998, 
          0.15625}, {-0.5674999999999999, 0.0625}, {-0.5625, 
          0.125}, {-0.5574999999999999, 0.125}, {-0.5524999999999998, 
          0.1875}, {-0.5488999999999998, 0.21}}], 
         LineBox[{{-0.5420333333333333, 0.21}, {-0.5374999999999999, 
          0.125}, {-0.5324999999999998, 0.0625}, {-0.5277799999999998, 
          0.21}}], 
         LineBox[{{-0.5271499999999999, 0.21}, {-0.5225, 
          0.09375}, {-0.5174999999999998, 0.0625}, {-0.5124999999999997, 
          0.09375}, {-0.5074999999999998, 0.03125}, {-0.5025, 
          0.0625}, {-0.49749999999999983`, 0.0625}, {-0.4924999999999997, 
          0.15625}, {-0.4874999999999998, 0.03125}, {-0.48249999999999993`, 
          0.125}, {-0.4774999999999998, 0.03125}, {-0.4724999999999997, 
          0.125}, {-0.4674999999999998, 0.}, {-0.4624999999999999, 
          0.15625}, {-0.4574999999999998, 0.03125}, {-0.4539249999999997, 
          0.21}}], 
         LineBox[{{-0.44869999999999977`, 0.21}, {-0.4474999999999998, 
          0.1875}, {-0.4424999999999999, 0.0625}, {-0.4375, 
          0.}, {-0.4324999999999999, 0.}, {-0.42749999999999977`, 
          0.0625}, {-0.4224999999999999, 0.15625}, {-0.4175, 
          0.15625}, {-0.41249999999999987`, 0.}, {-0.40749999999999975`, 
          0.1875}, {-0.40249999999999986`, 0.125}, {-0.39749999999999996`, 
          0.125}, {-0.39249999999999985`, 0.}, {-0.3876999999999997, 0.21}}], 
         LineBox[{{-0.38703333333333306`, 0.21}, {-0.38249999999999984`, 
          0.125}, {-0.37749999999999995`, 0.15625}, {-0.37249999999999983`, 
          0.09375}, {-0.3674999999999997, 0.09375}, {-0.3624999999999998, 
          0.09375}, {-0.35749999999999993`, 0.09375}, {-0.3543999999999999, 
          0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQnRB7x4254tr+h1Ui69wfnrK34Lq+uMD22n4GMFhg
/yJwh1zr66tQ/gH7GTNBAMF3AWtE8D9oxPQf+noFyt9gv6TAFmgijM/AEA4y
LhDBZwWTCPWb3UEGXobLJwJN04i5DDefH+Q8LgR/L8i4HZfg7s1OAwEY/4S9
1DqQgZfg6k98BTnwIty+MpDzChB8FZBxcjD+DvtLZ0DgApR/xL4BFExVF+Dm
vxSRPfnU/gI8/ADs1Hc+
          "]], 
         LineBox[{{-0.25215000000000026`, 0.21}, {-0.24750000000000028`, 
          0.09375}, {-0.24378000000000027`, 0.21}}], 
         LineBox[{{-0.24122000000000027`, 0.21}, {-0.23750000000000027`, 
          0.09375}, {-0.23250000000000026`, 0.03125}, {-0.22750000000000029`, 
          0.125}, {-0.22250000000000028`, 0.125}, {-0.2175000000000003, 
          0.15625}, {-0.2125000000000003, 0.125}, {-0.2075000000000003, 
          0.125}, {-0.20410000000000028`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbR0m2dl/9uT+h1Ui69wfnrIPAjNO7mcAgwX26wps
ua4vPgHlb7DnAtMIflr/oa8aMcfh/ENyra8DdxyD8hkY5IGmVonA+Dvsq0HG
FRyF8k/YXz8DAkeg/AP2xjEgA4/A1fcDTZNrPQw3/zXYnYfgfA+QcbaH4PqX
zASBg3D9DJogAw/A5WN2gBx4AC5fAHb/fri8Bti9++D8h2D37YHbNwvsnt1w
vt/FdU6n/HfBww8AqO96Rw==
          "]], 
         LineBox[{{-0.10203333333333361`, 0.21}, {-0.09750000000000028, 
          0.125}, {-0.09410000000000028, 0.21}}], 
         LineBox[{{-0.09122000000000027, 0.21}, {-0.08750000000000027, 
          0.09375}, {-0.08378000000000028, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQrd1fMf/CjS37H1aJrHN/eMr+zeICW67rm/czgMEG
+yWHvmrE9G+C8nfYx4AVboTyj9iLQNTB5WcAdS8uWAvln7DnqAaZuwouX7FD
rvV14Aq4/hcg4w8thfIP2EcYg8BiKH+B/RmQcxYvgJvXAFT9VWMOXD7hOsjB
0+F8hyCQBRPh7neYNRMIOuH2MygArd9RB1fPIA50XlUKlA8EQmC+PYzbIAtW
bw9XPxNsnj3MvAWBYPvsYfYduAZ2D1z9g2iwe+H8Goh/7OHhA/EvXH4GJDzs
YeGhAQkve1h47QDH0yq4/R6Q8Iabd+M/CKyHy5tA4guuvwYSn3D5I5D4hruf
GZIe7GHpAQDcna61
          "]], 
         LineBox[{{0.08377999999999974, 0.21}, {0.08749999999999974, 
          0.09375}, {0.09121999999999975, 0.21}}], 
         LineBox[{{0.09409999999999974, 0.21}, {0.09749999999999973, 0.125}, {
          0.10203333333333303`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQrXJxndMp/132D6tE1rk/PGVf8Dpwh1zrbnsGMNhg
v+MMCOyB8xmAqqpE9kH5B+w9+g991YjZj+ADdb8OPADl77B/oxEDVHEALj9h
JggchMubcF1fXGB7CC5/A+yOQ3D7asDuOQzny4OM0zgC138I7L4jcP1ptiAD
j0L5J+y5wO49Ble/DuS8HTA+A0MQ2P3H4eZ/+w8CCP6sApCBJ+B8O3BAnYTy
F9irh0l29p89CQ8/AC0VdLI=
          "]], 
         LineBox[{{0.20409999999999973`, 0.21}, {0.20749999999999974`, 
          0.125}, {0.21249999999999974`, 0.125}, {0.21749999999999975`, 
          0.15625}, {0.22249999999999975`, 0.125}, {0.22749999999999976`, 
          0.125}, {0.23249999999999976`, 0.03125}, {0.23749999999999977`, 
          0.09375}, {0.24121999999999977`, 0.21}}], 
         LineBox[{{0.24377999999999977`, 0.21}, {0.24749999999999978`, 
          0.09375}, {0.25214999999999976`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/UBE9uRT+wv2D6tE1rk/PGVfBqKqLtgzgMEJ++Nn
QADGP2Iv2fo6cIfcRSh/h322Ldf1xQUw/gb7vV81YvoPIfj8IONELkH5B+wT
00DgEtz8zXIgA2H8BfasQNNsuS7D1Yf3HwKaiOCvBBm3DsZnYPj9HwQuw+3z
3QEy8Apcfn4ByIEI/keQ875egat3Bnv8Ktz8qTNBAMF/HggyEMG3BHnX9hrc
vfGxd9yYK67Bww8A+NpyHw==
          "]], 
         LineBox[{{0.35439999999999977`, 0.21}, {0.35749999999999976`, 
          0.09375}, {0.36249999999999977`, 0.09375}, {0.36749999999999977`, 
          0.09375}, {0.3724999999999998, 0.09375}, {0.3774999999999998, 
          0.15625}, {0.38249999999999973`, 0.125}, {0.387033333333333, 
          0.21}}], 
         LineBox[{{0.38769999999999966`, 0.21}, {0.3924999999999997, 0.}, {
          0.3974999999999997, 0.125}, {0.4024999999999997, 0.125}, {
          0.4074999999999997, 0.1875}, {0.4124999999999997, 0.}, {
          0.4174999999999997, 0.15625}, {0.4224999999999997, 0.15625}, {
          0.4274999999999997, 0.0625}, {0.4324999999999997, 0.}, {
          0.4374999999999997, 0.}, {0.4424999999999997, 0.0625}, {
          0.44749999999999973`, 0.1875}, {0.4486999999999997, 0.21}}], 
         LineBox[{{0.45392499999999975`, 0.21}, {0.45749999999999974`, 
          0.03125}, {0.46249999999999974`, 0.15625}, {0.46749999999999975`, 
          0.}, {0.47249999999999975`, 0.125}, {0.47749999999999976`, 
          0.03125}, {0.48249999999999976`, 0.125}, {0.48749999999999977`, 
          0.03125}, {0.49249999999999977`, 0.15625}, {0.4974999999999998, 
          0.0625}, {0.5024999999999997, 0.0625}, {0.5074999999999998, 
          0.03125}, {0.5124999999999997, 0.09375}, {0.5174999999999996, 
          0.0625}, {0.5224999999999997, 0.09375}, {0.5271499999999997, 
          0.21}}], 
         LineBox[{{0.5277799999999997, 0.21}, {0.5324999999999998, 0.0625}, {
          0.5374999999999996, 0.125}, {0.542033333333333, 0.21}}], 
         LineBox[{{0.5488999999999997, 0.21}, {0.5524999999999998, 0.1875}, {
          0.5574999999999997, 0.125}, {0.5624999999999998, 0.125}, {
          0.5674999999999997, 0.0625}, {0.5724999999999998, 0.15625}, {
          0.5774999999999997, 0.09375}, {0.5824999999999998, 0.125}, {
          0.5874999999999997, 0.125}, {0.5924999999999998, 0.1875}, {
          0.5942999999999997, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQffHb+jUmmo/tH1aJrHN/eMreDcx4bM8ABjvs82y5
ri8ugPEX2M+YCQII+QNfNWL6DyH4rwJ3yLW+RqgXAppaJfIELm8DMs4WwU9J
AwEY/4h9zyGQgTD+AfttQNMCdzyBm3cP7E6Efg6QcVxPofwN9gbGIPAUrj6q
H2TgU7j6ptcgBz6F27cG5Lx1T+H2XQUZdx0h/+8/CCD46jEgA5/B+QEg7wY+
g+uvADmv6hncvoUg4xY/g7vv1BkQeAZ332dQ8H1FqJcBeVfuOVzeFRwfz9Hi
4zncvung+HgOdw8kPhDyL8Hx8RxuPyQ+XsDNswbHxwu0+EDwe8Hx8QKuHxIf
MP4J+/vg+HgBt29K78MjWWwv4ekJAOUfzbs=
          "]], 
         LineBox[{{0.7831999999999998, 0.21}, {0.7874999999999998, 0.15625}, {
          0.7924999999999998, 0.03125}, {0.7974999999999998, 0.09375}, {
          0.8024999999999998, 0.09375}, {0.8074999999999998, 0.03125}, {
          0.8124999999999998, 0.0625}, {0.8174999999999998, 0.15625}, {
          0.8224999999999998, 0.09375}, {0.8274999999999998, 0.09375}, {
          0.8324999999999998, 0.03125}, {0.8374999999999997, 0.09375}, {
          0.8424999999999997, 0.03125}, {0.8474999999999997, 0.09375}, {
          0.8524999999999997, 0.15625}, {0.8574999999999997, 0.03125}, {
          0.8622666666666664, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQzf042jVn7mv7h1Ui69wfnrI/8FUjpv/Qa3sGMDhg
/zJwh1zrawRfCKiqSuQNlM/AYM11fXGBLYKfkgYCMP4R+95DIANh/B3224Cm
Be5AyN8H24uQ5wAZx/UWyl9gb2gMAm/h8lH9IAPfwt3T/BrkQAR/Dch56xD8
qyDjriP4//6DAIKvHgMy8B3c/ACQdwMR/EqQ86pg/A32i0DGLUbInzoDAgj+
Z1DwfX0HN18G5F2593D9ruCAfg9XnwcyruA9PDymzwQBBB8SHwg+JD7ew8OH
ExxeH+DmgYNX7gPcPiNw+H2Au8cNbP8HuHnR4PBEyIO9V4DQ3wIOXwR/Bth9
CPWflRhUtdd8gKcfAIXDxII=
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQzXXroirn+g/2D6tE1rk/PGV/6KtGTP+hD/YMYLDA
/triAluu6zD+EftXgTvkWl8j5P+DAYy/wx5kSpXIRyj/hD3ItK8aH+HyNlzX
gSYi+GDjAhH81DQQgPE32IOdVQXjH7DvAzsQoX4RyHmLEfztION2IPSfAQMY
n4HhAdhAhPwXsAMR+jlBzuP6BLcPbJwcgm9kDAKf4P5zAwfcJ3j4RIO8G/MJ
EX4L/0jqZn6Chy8AW2F/4g==
          "]], 
         LineBox[{{1.1545499999999997`, 0.21}, {1.1574999999999998`, 
          0.0625}, {1.1624999999999996`, 0.09375}, {1.1674999999999998`, 
          0.03125}, {1.1724999999999999`, 0.1875}, {1.1774999999999998`, 
          0.03125}, {1.1824999999999997`, 0.09375}, {1.1874999999999998`, 
          0.125}, {1.1925, 0.125}, {1.1974999999999998`, 0.1875}, {
          1.2024999999999997`, 0.}, {1.2072999999999998`, 0.21}}], 
         LineBox[{{1.2081999999999997`, 0.21}, {1.2125, 0.15625}, {
          1.2174999999999998`, 0.125}, {1.2224999999999997`, 0.125}, {
          1.2274999999999996`, 0.125}, {1.2324999999999997`, 0.03125}, {
          1.2374999999999998`, 0.}, {1.2422999999999997`, 0.21}}], 
         LineBox[CompressedData["
1:eJxFkTEMwUAUhsvGbBa2zqzkbRgRG4MINmHurCsrm7BJiE1HaQwiZlaMjHrt
SN87fe9PLs2fd/3u/vuznWG9FzcMIxMu/FaDWGXw/MDDSm3LjzN4Zmvqqg8Y
pB0kbqtRMen9vQNp+11z0pFfQC6PivwJSgQS3wxpZivyBwhhIdFj/hhxtvBm
c5TMN2UEikfa1I38Ea54vZuc90LcW/Z/SXI+prRSivNQXFN8Aa9XFE+4mmJe
nyRzejZLMX9CF5T5kgLL/3t6QJlfSIrz3AkoPN2HeN2Hz3l1Hz7zdB8+79d9
yDxwu+t2w+e+fyTfrnU=
          "]], 
         LineBox[{{1.3989249999999998`, 0.21}, {1.4024999999999999`, 
          0.03125}, {1.4074999999999998`, 0.09375}, {1.4124999999999996`, 
          0.1875}, {1.4174999999999998`, 0.0625}, {1.4224999999999999`, 
          0.03125}, {1.4274999999999998`, 0.03125}, {1.4324999999999997`, 
          0.15625}, {1.4374999999999998`, 0.0625}, {1.4425, 0.09375}, {
          1.4474999999999998`, 0.03125}, {1.4524999999999997`, 0.09375}, {
          1.4574999999999998`, 0.125}, {1.4625, 0.09375}, {
          1.4674999999999998`, 0.09375}, {1.4724999999999997`, 0.0625}, {
          1.4772199999999995`, 0.21}}], 
         LineBox[CompressedData["
1:eJxdkT8MwVAQxhsbIhazpJPOrOQmzLUySViZO7OysgmJjVj826QxiJhZWVmJ
vi707uld4pKX5st37/fu+pn1VqURMQzDDA5+t5lkfDl9w81Jzcu3I6zT3Ye9
eYNBtYcTlegr9YV6AU+r1ndfoqOXSbsQ8356A4RLe+xnc1ihPkCJHpb+akCz
auIHsIAofgdxXY/nGQyxQj2CWRmB4iOt78r9M453Ef+OuIfc/1BJP27rpBT7
tK6leJ88jldQzCOcLbpJFeod0O9zFPN7NKDoMS0s7+k81F8e0q/zEK3zkPd0
Hj7zdB4+z++uisNE1uf8vyFVtvw=
          "]], 
         LineBox[{{1.6379666666666663`, 0.21}, {1.6424999999999996`, 0.125}, {
          1.6474999999999997`, 0.09375}, {1.6524999999999999`, 0.09375}, {
          1.6574999999999998`, 0.09375}, {1.6624999999999996`, 0.09375}, {
          1.6674999999999998`, 0.15625}, {1.6724999999999999`, 0.125}, {
          1.6774999999999998`, 0.09375}, {1.6824999999999997`, 0.125}, {
          1.6874999999999998`, 0.09375}, {1.6925, 0.125}, {
          1.6974999999999998`, 0.1875}, {1.7024999999999997`, 0.15625}, {
          1.7074999999999998`, 0.125}, {1.7125, 0.09375}, {
          1.7174999999999998`, 0.09375}, {1.7205999999999997`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQ/akvuERl+m/7h1Ui69wfnrJfVGDLdX3xb3sGMNhh
v12u9XXgDhh/g/0ZMEDwH4D1wfgL7L9oxPQf+oqQ57y+GGjiHzgfbJwcjH/C
3sgYBP7A9buBHfIHbn800DSNGBj/gD3YeQUI+RaQca0I/TNmggCMf8R+rTvI
QIT9INP6DyH0XwM57zpC/hXIuNcI+f9ggOCDfFsl8heuHuxdjb9w/9iAnGeL
kAcbF/gXrj8NDP7C3QsOviqEfB/YgX/h/gU7bzFCHmzcjr9o8QHjMzDM/XS1
WvzOX3h8AgAH/Kha
          "]], 
         LineBox[CompressedData["
1:eJxVUyFIQ1EUfRMMWiwrloGI8EFYUBARxxsGVyxbMbiioEXQIVh+MrhicCAG
LWOwYlEEyy+DMQYOsVhcMbhi2IpBi7g9/zv/33fwwudxuPede+8578/sHBZ2
x5RSK+Fnz7nS4KDaH+qen7zL9Z70l1estL6HWiGaeqJbL2UmRzFu61R5kA9S
I5dfWLQhONDrIBJ8r7dCNq8ouKNDspCR908tXVlwTV9d2xCs1G3OEpLPslVa
vP9qx+sS9y3dgNgg2N9u6SeN48O6nnH9V+14GeP2BV2e+T0E70M2n/lzDMg8
xqsTgy4wTq9nhHHzvoOQ+cgP81+vcZWVfpB3SnBbQ75pwUHUf5Z5rJ/mfcyz
LDjWd01wM5pvg/XQe5N52L3NfrBzX3BHw65j9sdxwnrIfcb+kPOS9ZCryn6Q
44Z5PL8Hzofn1WAez+eR/Qp24Rf2g/1vxLD3g/Ww75P7wJ4f1kd+JFx95Adx
5IfgWuyHYPGD+d/0/MXRUiIr/+MfG+YVrg==
          "]], 
         LineBox[{{2.15378, 0.21}, {2.1574999999999998`, 0.09375}, {
          2.1624999999999996`, 0.0625}, {2.1674999999999995`, 0.1875}, {
          2.1725, 0.125}, {2.1774999999999998`, 0.09375}, {
          2.1824999999999997`, 0.09375}, {2.1875, 0.03125}, {2.1925, 0.}, {
          2.1975, 0.0625}, {2.2024999999999997`, 0.125}, {2.2074999999999996`,
           0.125}, {2.2125, 0.09375}, {2.2175, 0.09375}, {2.2224999999999997`,
           0.15625}, {2.2275, 0.0625}, {2.2325, 0.}, {2.2358599999999997`, 
          0.21}}], 
         LineBox[{{2.239322222222222, 0.21}, {2.2425, 0.03125}, {2.2475, 
          0.09375}, {2.2525000000000004`, 0.09375}, {2.2575000000000003`, 
          0.}, {2.2617000000000003`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQ/evEAZEfskwOD6tE1rk/PGW/pMCW67oykwMDGByx
BwpWiejB+Bvsd8q1vg60gPF32B/+qhHT7wTjn7A/ewYIfGD8A/Y3FgMNDEfw
H4HsSYTxGRjeBO6Qa81G2PcNaNyhUoT5YKoBwee+DjSwC2GeKMiBUxDy8kDn
7ZiHMF8LaNzXFQjzTYyBYDOMv8Dejgto4F6E/zxAAXEcoT8I6LzXFxHmxwKN
07iD4KenAcEzhPpCYPAt/oAwvxoUrL8Q9rcBnSfHygx3/wSgcTH8zHD5WTOB
QBLG3wCNDxh/BzQ+EHxIfCDUQ+IDxl8AjQ8Y/wQ0PhD2Q+IDoR8SHwj3QOID
YR+YakCYB4kPhDwkPhD8SPHtFxnmMcPTFwCWeKP7
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQXSN+58+a+cwOD6tE1rk/PGWvFdN/6OsKZgcGMDhg
b2IMBJth/BP2dlzXFxfshfE32HuANB5H8IN2yLW+vgjjH7GPBRqncQfGX2Cf
ngYEzxD8QluggR8Q+qtBzvgF4++wb3sduEOOlQXOnwA0LoafBa5+1kwgkITx
T9gvKQAaqIxQv94d6EA9GP+A/U6g8wItEPKHgcb1OyHMO3sGCHwQ6m8sBhoY
jlD/CBROiQj5N0DntWYj5L8BjTtUijAvICPn0IVaFnj4AgD1Hmpx
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQnaivXh3XwuLwsEpknfvDU/bc1xcX2HaxODCAwRF7
UaBo1RQY/4C9fOvrwB3zYPwN9lox/Ye+rkDImxgDwWYYf4e9HRfQwL0IeQ+Q
RccR/KAdcq2vLyLUxwKN07gD4y+wT08DgmcIfqEt0MAPMP4J+2qQs38hzGsD
Ok+OlRXOnwA0LoYfxt9gP2smEEjC+DvslxQADVRGqF8P9K6IHox/xH4n0HmB
FjD+AvvDQOP6nRDqz54BAh8Y/4T9DWDwcYUj5B+BwjURYd8boPNasxHmfQMa
d6gUIQ+mGhD2Q+IDYR4kPhDykPhA+A8SHwjzIfGBkIfEB8I+SHwg1EPiA2Ef
JD4Q6iHxgTDPsl6YS/ADKzz9AAD5SqBt
          "]], 
         LineBox[{{2.7428500000000002`, 0.21}, {2.7475, 0.09375}, {
          2.7525000000000004`, 0.0625}, {2.7575000000000003`, 0.0625}, {
          2.7625, 0.09375}, {2.76715, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQbeCzjMtNlc3hYZXIOveHp+zXuwNZemwODGBwxH6n
XOvrQAsYf4f94a8aMf1OMP4J+7NngMAHIX9jcYEtVziC/whkbiKMv8D+TeAO
udZsGH+D/TegcYdKEeoZQVQDwn7u60ADuxB8UaArq6YgzJMHOm/HPBj/gL0m
0LivKxDmmRgDwWaEfXZcQAP3IvgeII8fh/EZGIKAznt9EWFeLNA4jTsI89LT
gOAZwj2FtkADPyDUV4OC8RdCfRvQeXKs7HD5CUDjYvjZ4fpnzQQCSXa4+iXA
4LuuDOOfgMYHjL8BGh8w/gJofCDMh8QHgg+JD4T5kPhA6IfEB8I9kPhAqIfE
B8L+yxJrF6/qZIenFwBVyZpd
          "]], 
         LineBox[{{2.9432000000000005`, 0.21}, {2.9475000000000002`, 
          0.15625}, {2.9525, 0.09375}, {2.9575, 0.03125}, {
          2.9625000000000004`, 0.09375}, {2.9675000000000002`, 0.09375}, {
          2.97122, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQvfWvtrbvKXaHh1Ui69wfnrIP2iHX+voiuwMDGOyw
j+0/9FXjDoy/wD49DQiewfgb7Attua4v/oBQXw0y5heMf8C+7XXgDjlWDrj6
CUDjYvgR/FkzgUCSA27+kgKggcoccPPWuwNdpscBN28n0HmBFgj+YaBx/U4I
886eAQIfBP/GYqCB4TD+CftHIH8mIux7A3ReazbCvm9A4w6VIvQHZuQculDL
AQ8fAHhsWb0=
          "]], 
         LineBox[{{3.063566666666667, 0.21}, {3.0675000000000003`, 0.0625}, {
          3.0725000000000002`, 0.15625}, {3.0775, 0.09375}, {3.0825, 
          0.0625}, {3.0872200000000003`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQfYBvjvGiLRwOD6tE1rk/PGVvx3V9ccFeDgcGMDhi
7wGSOA7jH7AP2iHX+voijL/DPrb/0FeNOwh+ehoQPEPoL7QFGvgBxt9gXw2y
5heC3/Y6cIccKyecPwFoXAw/J1z/rJlAIIngLykAGqiMUL/eHehAPRj/gP1O
oPMCLRDqDwON63eC8XfYnz0DBD4I+RuLgQaGI8x7BAqHRBh/gf0boPNasxHy
34DGHSpFyDOCqAaEfLS9gDFfByc8PAHQKGKA
          "]], 
         LineBox[{{3.1941, 0.21}, {3.1975000000000002`, 0.125}, {3.2025, 
          0.03125}, {3.2075, 0.09375}, {3.2125000000000004`, 0.03125}, {
          3.2175000000000002`, 0.09375}, {3.2225, 0.09375}, {3.2275, 
          0.0625}, {3.2325000000000004`, 0.125}, {3.2375000000000003`, 
          0.0625}, {3.2425, 0.03125}, {3.2475, 0.15625}, {3.2518000000000002`,
           0.21}}], 
         LineBox[{{3.252966666666667, 0.21}, {3.2575000000000003`, 0.125}, {
          3.2625, 0.09375}, {3.2675, 0.09375}, {3.2725000000000004`, 
          0.03125}, {3.2775000000000003`, 0.125}, {3.2825, 0.15625}, {3.2875, 
          0.03125}, {3.2925, 0.09375}, {3.2975000000000003`, 0.15625}, {
          3.3025, 0.15625}, {3.3075, 0.0625}, {3.3125000000000004`, 
          0.15625}, {3.3175000000000003`, 0.0625}, {3.3225000000000002`, 
          0.0625}, {3.3275, 0.125}, {3.3309, 0.21}}], 
         LineBox[{{3.333414285714286, 0.21}, {3.3375000000000004`, 0.03125}, {
          3.3425000000000002`, 0.0625}, {3.3475, 0.09375}, {
          3.3525000000000005`, 0.0625}, {3.3575000000000004`, 0.09375}, {
          3.3625000000000003`, 0.03125}, {3.3665857142857143`, 0.21}}], 
         LineBox[{{3.3707000000000003`, 0.21}, {3.3725, 0.1875}, {
          3.3775000000000004`, 0.1875}, {3.3825000000000003`, 0.0625}, {
          3.3875, 0.09375}, {3.3925000000000005`, 0.09375}, {
          3.3975000000000004`, 0.09375}, {3.4021500000000002`, 0.21}}], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQrXVa4PguC26Hh1Ui69wfnrI//FUjpt+J24EBCs6e
AQIfGP+E/fXFBbZc4TD+EftHIH2JMP4C+zeBO+Ras2H8A/bfgMYdKoXxd9gz
gqgGhHpukIFdCL4o0BVVUxD65VtfB+6Yh5DXBBr3dQVC3sQYCDYjzLfjAhq4
F6HeA+Sx4wj3BgOd9/oiQn0s0DiNOwj16WlA8Azh30JboIEfEOqrQcH0C8bf
YN8GdJ4cKw+cPwFoXAw/jH/AftZMIJBEyC8FBt91ZRifgWE90LsiejD+Avud
QOcFWsD4J6DxgdAPiQ8EHxIfMP4R+7D5q9feiOeBxycAi9qEaA==
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQveKFh97/RB6Hh1Ui69wfnrJ/E7hDrjWbx4EBDHbY
f9OI6T9UiuAzgqgGGH+DPff1xQW2XQi+KNCUqikw/gF7+dbXgTvmIeQ1gcZ9
XQHjH7E3MQaCzTD+CXs7LqCBexF8D5DDjiPsDwY67/VFhPmxQOM07sD4C+zT
04DgGYJfaAs08AOCXw3y5i+Ee9qAzpNj5YWbPwFoXAw/L1x+1kwgkOSF619a
ADRQGaF+PdC7Inow/gn7nUDnBVog1B8GGtfvBOMfsT97Bgh8YPwD9qDg4wpH
2PcIFA+JCPPrTdk5nmXwwuMHALSweBQ=
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQPeeld8yWXF6Hh1Ui69wfnrL/phHTf6iU14EBDDbY
M4KoBhh/gT339cUFtl0w/g57UaCuqikI9fKtrwN3zIPxj9hrAo37ugIhb2IM
BJsR+u24gAbuRZjvAXLIcYT64B1yra8vIsyLBRqncQehPz0NCJ4h1BfaAg38
AOMzMFSDvPULob8N6Dw5Vj64+glA42L4EfxZM4FAEsZfYL+0AGigMkJ+PdC7
InoI+Z1A5wVawPgH7A8Djet3QvDPngECHxj/iD0o+LjCEfofgcI9EcbfYf8G
6LzWbIR9kPhA8CHxgTAPEh8IeUh8IMyHxAfCfEh8INwHiQ8Yn4FB9tj2rhu7
+ODpAQAqLJI+
          "]], 
         LineBox[{{3.8453500000000003`, 0.21}, {3.8475, 0.15625}, {
          3.8525000000000005`, 0.}, {3.8573000000000004`, 0.21}}], 
         LineBox[CompressedData["
1:eJxdVF8ow1EY/VlJoW2KpDQtpaGkUFLcpTSJNJQUChml/ElKk5JCpFAkkqYh
pVhJDSkNkUh4mIclPHiZBy88ePLd7+fuxK1ft9P57rnfd87tZ23tqWk3aJrm
oE/uC1UHgaOQ0f7iTtxxvFyJDhetN6Nd4+UTfcWxQe8H8JAs+1bYI8bDTr8l
2vSL/WI28GlrNCl8KZaXaKWA3+glwXRTRG/XQTfnKHwmDixjYWehwifilORm
SnH+5ppWJc4HvSRYD/5VztGC8+/U3liXwh7xRXKBAeAouY1AL04KTkEvicZ1
z6M+jdrzr4LPJLnPLfD5ebT2oFdC9vUeo75cGn0BXEvthe8wfxPJ2ULoX88D
enoe4PU8FNY09stg/ntfjDlSz/7FA9fI+xNQ/yj9TFb4UsjxbKmoZ3+tqJft
uTLAs9/ZCnv0fnOhx/4XgOf+ixT2Cd7s0Of3VQZ9aWdxBXh+b9XgpZy7Djy/
vwaFz/T8msGvy/fYhvNZcuBO9CPlErvBc7794KV9zkHMw3kPQ5/zGAXPeUwA
cx7T0OM85oA5j0VgzmPlXx5r4DmPTWDOYxuY8/Dhfs5jHzzncQh9fUN+nMc5
/OQ8rqDHedyifvL+6TnuwRz5v/wAaMcuew==
          "]], 
         LineBox[{{4.207966666666667, 0.21}, {4.2125, 0.125}, {4.2175, 
          0.0625}, {4.2225, 0.03125}, {4.227500000000001, 0.0625}, {4.2325, 
          0.0625}, {4.237500000000001, 0.09375}, {4.2425, 0.09375}, {
          4.2475000000000005`, 0.}, {4.2525, 0.15625}, {4.2575, 0.09375}, {
          4.2625, 0.0625}, {4.2675, 0.09375}, {4.272500000000001, 0.03125}, {
          4.2775, 0.125}, {4.282500000000001, 0.03125}, {4.287266666666667, 
          0.21}}], 
         LineBox[CompressedData["
1:eJxdkz9IQlEUxi8ugbT4MFqicAmjJaiWwO5bomgJpUWQhiJrKqMljJbAWgJr
iCgijKIlKJdAahEzEClagmyRrCUwWsJoCTr3XO/74B2Qy+d558+9P77A9GJk
1iOEsOmnzt3L6s1rt8+uJf0Xo7Wy/AznOlO9PpWmyMulkPf5pM/onPwJxtKF
QehVVTZkdFHyYRudkRt1ajhitBDULREaR3670AjGJozOyjZql5yEPtiniEJ3
pajhFOafJmjBGfTrofUa88irdv4F1A/0UywjT7eth1dQP6wWXDO6JG9pvfQ6
3mNMPdQm7vNwT7GF/hHVcAe6Qtf17kGr9YKHmP+m3v0Yei5OcYZ9mMc56plH
1sXjCvsxj2vk9d+oZx534MU8yvieeTxCM48nF48XzGMeVeSZxzs08/jAfZjH
l4vHt4vHL/ZjHn+oZx4ey9HMo8Vy+jGPVsvpxzx8yDOPduSZR4fRQjCPgNF5
zaMb87Q/jC41/YG89ofRxaY/MJ8PG/O1P6C1P6C1P7Cf9ge09ge+1/6A1v7A
fSpHUSsTtxy//wMrbAtw
          "]], 
         LineBox[CompressedData["
1:eJxdmk2oo2cdR6/ZFGo37Uw7foxTZzOMdjP4sRkc73VRKt2U1m4KYxcW6+BC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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8647229999999999, 0.3364763999999999, 0.1829199600000001]], 
         LineBox[CompressedData["
1:eJxdnX2QVuWZp5vmo5umoWnAoBmiUrPDOENVll1Dlcuuebuyy2pR2WLiUmXY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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.4558917999999999, 0.16060319999999997`, 0.4593580000000001]], 
         LineBox[CompressedData["
1:eJxdnQu0XVV57897n8c+5+zXIVUjyui9KcqoplXG8MbiWm2lIqO3VOQOm5Zm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          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxdnXmcltP7x2ffl2edkhahpEgoEs05SkqiUBKVdhGJREISiYRKifRFWkja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          "]]}, 
        Annotation[#, "Charting`Private`Tag#5"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"T65.78\"", TraditionalForm], 
     PlotRange -> {{-7.9975000000000005`, 7.997499999999999}, {-0.01, 0.21}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"10\"", "\"\\!\\(\\*SuperscriptBox[\\(10\\), \\(2\\)]\\)\"", 
       "\"\\!\\(\\*SuperscriptBox[\\(10\\), \\(3\\)]\\)\"", 
       "\"\\!\\(\\*SuperscriptBox[\\(10\\), \\(4\\)]\\)\"", 
       "\"\\!\\(\\*SuperscriptBox[\\(10\\), \\(7\\)]\\)\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.8423264, 0.4188294]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.9917508, 0.5901996, 0.09831576]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.910155931719056*^9, 3.910155959748472*^9}, {
   3.9101560003186345`*^9, 3.9101560154468517`*^9}, 3.9101560698861113`*^9, 
   3.910156121791444*^9, 3.9101562223461304`*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"b1c53614-aec9-4e72-b957-7cef649e89f1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison of different sequences", "Subsection",
 CellChangeTimes->{{3.910156507967055*^9, 
  3.9101565164501762`*^9}},ExpressionUUID->"0c79cecf-b3aa-46a9-9d9c-\
7e118e6bc6f7"],

Cell["\<\
We can also consider alternative sequences of supercells to verify \
independence of the limit on the particular choice of (valid) sequence.\
\>", "Text",
 CellChangeTimes->{{3.9101565178095937`*^9, 
  3.9101565432959876`*^9}},ExpressionUUID->"46376d33-5fae-4488-ab9e-\
c08feb80edc0"],

Cell[CellGroupData[{

Cell["Alternative sequence 1", "Subsubsection",
 CellChangeTimes->{{3.9101565749255075`*^9, 
  3.910156579265273*^9}},ExpressionUUID->"fc354d59-7ef2-4dfe-961d-\
d0d379a59417"],

Cell["The first alternative sequence is:", "Text",
 CellChangeTimes->{{3.910156660637101*^9, 
  3.9101566672747507`*^9}},ExpressionUUID->"327c9d3a-d54a-488a-a38b-\
a5cac7e5834f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<T3.11\>\"", ",", "\"\<T5.13\>\"", ",", "\"\<T9.22\>\"", ",", 
     "\"\<T17.35\>\"", ",", "\"\<T33.58\>\"", ",", "\"\<T65.81\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
  3.910156608462936*^9, 3.9101566170742188`*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"1340367b-a1ce-41d1-bbba-46cba7dcfcce"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{8,8}-tess_T2.6_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
  3.9091142248348513`*^9, 3.909114238346472*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"4afa58e7-e9cf-44cc-832d-cebe051ffb42"],

Cell["We construct and export the Abelian Bloch Hamiltonians", "Text",
 CellChangeTimes->{{3.9101567017353535`*^9, 
  3.9101567119301167`*^9}},ExpressionUUID->"75e9326b-87c7-4575-a6cd-\
dcd82c933f5d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"AbelianBlochHamiltonian", "[", 
          RowBox[{
           RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
           RowBox[{"0", "&"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "&"}], ",", 
           RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "&"}], "/@", "supercells"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"eeed950c-a368-4845-8ad4-e49e5f315fd9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<H_{8,8}-tess_T2.6_sc-``.dat\>\"", ",", "#"}], 
           "]"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@",
    "supercells"}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
  3.910154322749093*^9, 3.9101543310279417`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"6b391cae-718b-4c0f-a58b-15203a9643a1"],

Cell["compile the expressions", "Text",
 CellChangeTimes->{{3.9101567165821447`*^9, 
  3.9101567199242735`*^9}},ExpressionUUID->"9f16f854-df8d-43fc-bfd1-\
45682e021184"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hsccfs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{
         RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
         RowBox[{"0", "&"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "&"}], ",", 
         RowBox[{"PCModel", "->", "pcmodel"}], ",", 
         RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091146138495903`*^9, 3.909114652753991*^9}, 
   3.909119478873217*^9, {3.910154420411165*^9, 3.910154425008809*^9}, {
   3.9101631158203373`*^9, 
   3.910163117150429*^9}},ExpressionUUID->"3722dad1-0047-410a-bef6-\
bd4ff62b68f7"],

Cell[TextData[{
 "and compute the DOS with an energy resolution of 0.005  and a sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "4"], TraditionalForm]],ExpressionUUID->
  "05cb10ef-7d7b-4704-b965-7a16170548df"],
 ":"
}], "Text",
 CellChangeTimes->{{3.9091148872154474`*^9, 3.909114904344953*^9}, {
  3.9101567234788375`*^9, 
  3.910156729219191*^9}},ExpressionUUID->"6950afae-9e13-494f-aaa9-\
5f07ae62525b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dosscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ComputeDOS", "[", 
        RowBox[{
         RowBox[{"Hsccfs", "[", "#", "]"}], ",", 
         RowBox[{"10", "^", "4"}], ",", "32", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], "-", "0.005"}], ",", "8"}], "}"}], ",", 
         "0.005"}], "]"}]}], "&"}], "/@", "supercells"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9091148504724855`*^9, 3.909114863025732*^9}, {
  3.9101548693475285`*^9, 3.910154869724236*^9}, {3.9101549493832054`*^9, 
  3.9101549496375976`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"5a91d423-30a4-40d9-84e0-a02aeab08cce"],

Cell["We plot the density of states for the given sequence", "Text",
 CellChangeTimes->{{3.9091258353931103`*^9, 3.9091258729641294`*^9}, {
  3.909126315654191*^9, 3.9091263169689493`*^9}, {3.910156746327403*^9, 
  3.9101567572332544`*^9}},ExpressionUUID->"c7997f03-ca8b-4d0e-8c49-\
243a48e2a12b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Association", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<T2.6\>\"", "->", "dospc"}], "}"}], "]"}], ",", "dosscs"}],
     "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(4\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "7"}], "]"}], "/", "7."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091194227381277`*^9, 3.9091194385257072`*^9}, {
  3.909125701919447*^9, 3.909125705158804*^9}, {3.9091264450645742`*^9, 
  3.9091264526411266`*^9}, {3.910154999941857*^9, 3.9101550239169064`*^9}, {
  3.9101562589192905`*^9, 3.910156259119133*^9}, {3.91015710890544*^9, 
  3.9101571101124177`*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"d296bc34-ca04-49a5-9284-337c52672829"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8990594285714286, 0.5637948571428573]], 
         LineBox[CompressedData["
1:eJxdnXfcHVWduN/ey733vW9/3wTUZbHsimv9sbpzFCurK/auKOqyVgRxWWwB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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], 
         LineBox[CompressedData["
1:eJxdnA1sndd93snLb/Ly4/JTklXX2gbDm7dAWKPBcJuRC+olE4I57YwtWjPB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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.9882154285714286, 0.5505617142857142, 0.08483494285714285]], 
         LineBox[CompressedData["
1:eJxdnAuQneVhnnfP3nfP7p6zF60gigNtR3WrhtE0ocOQpOeUCYmr8QQnZdrQ
pBoc3FRtMwotTkfjmpS6uHIzjAMdpsQt40G1o5DgOEocxUR1vGts2Vi2I7AV
gwwWF11YJCEkrS6ry0rd8z/nf9/5X4ZJ5p3v/j3f83/nP8fLzb/2m7/0r2s9
PT3/td7T0/n/b35k5vM/33vTQk/3n388+tJn7l/5MeU97/n4iV9cdv7Jn1j9
Z8n5T37+jY/MnHL++7/6u8+dX3T+7P0/M/rSYeebVrt79pDz//7U6j8Hndd8
frXDA86PPnf+vb+637m+Or2f2ef831e7e89e5+KfBeePri7vjT3OF967OsHd
zv9xdXqf2eV8crW7jz/jvOXXV//Z6Vzs1w7nf7W63Pc+6fzy6vRGn3D+pdXu
Tjzm/NffXv3nEef3rW7f57c7f211ub/7MeeCx4PBY1vweCB4bA0eW4LHfcFj
c/C4J3jcHTzuCh6bgsedwaMdPG4PHrcGj43BY0PwWB88bg4e64LHXPBoBo96
8BgKHrXgsfIeZfxwxg9n/HDGD2f8cMYPZ/xwxg9n/HDGD2f8cC7+WXDGD2f8
cMYPZ/xwxg9n/HDGD2f8cMYPZ/xwxg9n/HDGj+CxLXg8EDy2Bo8tweO+4LE5
eNwTPO4OHncFj03B487g0Q4etwePW4PHxuCxIXisDx43B491wWMueDSDRz14
DAWPWvBY+VFl/HDGD2f8cMYPZ/xwxg9n/HDGD2f8cB4r/HDGD+finwVn/HDG
D2f8cMYPZ/xwxg9n/HDGD2f8cMYPZ/xwxg9n/Age24LHA8Fja/DYEjzuCx6b
g8c9wePu4HFX8NgUPO4MHu3gcXvwuDV4bAweG4LH+uBxc/BYFzzmgkczeNSD
x1DwqAWPlXXK+OGMH8744YwfzvjhjB/O+OGMH8744YwfzvjhXPyz4Iwfzvjh
jB/O+OGMH8744YwfzvjhjB/O+OGMH8744YwfwWNb8HggeGwNHluCx33BY3Pw
uCd43B087goem4LHncGjHTxuDx63Bo+NwWND8FgfPG4OHuuCx1zwaAaPevAY
Ch614LHyI8p/WfjhjB/O+OGMH8744YwfzvjhjB/O+OGMH8744dzb+T8Lzvjh
jB/O+OGMH8744YwfzvjhjB/O+OGMH8744YwfzvgRPLYFjweCx9bgsSV43Bc8
NgePe4LH3cHjruCxKXjcGTzaweP24HFr8NgYPDYEj/XB4+bgsS54zAWPZvCo
B4+h4FELHis3KuOHM34444czfjjjhzN+OOOHM34444czfjjjhzN+OOOHM344
44czfty48JPv+2+r/364hR8uxw9n/HDGj7L9wy38cDl+OOOHM34440fw2BY8
HggeW4PHluBxX/DYHDzuCR53B4+7gsem4HFn8GgHj9uDx63BY2Pw2BA81geP
m4PHuuAx54wfwaMePIaCRy14rNygjB/O+OGMH8744YwfzvjhjB/O+OGMH874
4YwfN+g84ofL8cMZP5zxwxk/nPHDGT+c8cMZP5zxwxk/nPHDGT+c8SN4bAse
DwSPrcFjS/C4L3hsDh73BI+7g8ddwWNT8LjTGT+Cx+3B49YbdP7xI3hsCB7r
g8fNwWNd8JgLHk2Phx/BYyh41ILHylpl/HDGD2f8cMYPZ/xwxg9n/HDGD2f8
cMYPZ/xwxg9n/Fir/cAPl+OHM34444fb44czfrg+frgcP1yOHy7HD5fjhzN+
uD5+BI8HgsfWtXpe4Ifb40fw2Bw87gkedwePu4LHJvePH8GjHTxud8aP4LEx
eGwIHuud8SN4rHPGj+DRXBt+uD/8cDl+BI+VuSqP5bkqjyVn/HDGj7kqj8Mu
xw9n/HDGD2f8cH/4MVflsdf18WNO5wM/XI4fzvjh/vDD5f+m8GMu/JgLP1wf
P5z/WeGHM34444fnix8ux4/gsS14PBA8tgaPLe4fP9wffjjjh9vPFn64HD+C
xyb3jx9zC79w8mur/36S+7zt+vgxV31e3Ro8Njrjh/sveKx3OX4Ej3XBY87l
BY+m+8MPZ/xwe/xwe/xYo3L8cMaPNaqPH2vUP364Pn4444czfri/gseBNVUe
+90/frg9fjjjx5oqjz1rqjx2uz5+uH/8cH38cDl+rAk/nPFjTZXHY8744Ywf
zvixpsrjQY+PH8744YwfXh9+BI/71uj84kfZ/vGuH+4PP9weP5zxw/PFD7fH
D9fHD2f8cHv88PzwI3isdzl+eDz8CB5zwaMZPOqeD34Ej1rwWJmN+2O2ymPJ
5fgxu/BPbvzs6r+f6voxq/njx6z2Hz9mqzwOzmp++OHx8MP94YfL8cPzwQ/X
xw+X44fb44fngx9ujx9ujx+ujx/uDz+8Hvxwf/gxW+Wx3f3hR5k/2/XD5fgR
PB7w/uOHx8MPt8eP2fDD7fHDGT9mF2557eyPv3Z2R/f+CB6b3D9+BI+254sf
7g8/ZsOP4LHB7fHDGT9mww/PHz/cH34Ej7rr44f3Hz/cHj9mVB8/ZtQffpT5
010/ZsKPmfBjpsrjkDN+zFR5HJjRfPBjJvxwffxwxg/PDz/cH37MVHnsmgk/
ZnR+8cP944fngx8zVR5PuH/8cDl+lPkPu/fHTJXHx2bEGz88Hn7MhB/BY6vL
8cPl+BE8Nnv9+OGMH66PH+4PP1yOHzM6//jh9eGH9wM/3B9+uD5+uD5+uBw/
XI4fMws/9afTq//+QdcPl+OH54cf7g8/ZhaK+JOf6/oxU31erUyrHD+mVY4f
09o//JjW+vBjWvPDD5fjR5k/3/XD9fHDGT+mtT78mK4+r/ZO67zhh9vjx7T4
4ce09gc/vF78cMYP94cfZfs/7frh9eGHx8MPt8cPZ/zwfPBjuvq8etDrww+3
x4/phSL+1Be6frg9fpgffng8/PB68cPj4Yd54cd03B/TC8/8UeefXV0/3B9+
BI/bp+P+8PzwI3hscH38mA4/XI4fnj9+eHz8cHv8cHv8cH38mA4/psQfP6aq
PJamtB/4MaX54MeU9hM/yvZf7Prh+vjh+vjhcvxwxo8p7R9+uD1+uD5+TFWf
V7s9f/xwxg+3x4+p7v78edcPj4cf3i/88Hrxw/3hh+ePHx4fP9wffkzp/OOH
+8OPqfDDGT88Hn6U7f+y64fHww/PBz+8fvyY0nnBD+8Hfnh8/PD4+OHzhB9T
4YfL8cPzwY+p6vPq5qnq82pdmb/S9cPzwQ9n/Jha+PLRX1n999muH1MLe4sF
7en6ETxWmuGHM3401R9+NBee/ei3vvjRb+3u+tHUevDD7fGjKT744f7ww/3h
R1PrwQ+3xw/3jx8uxw+3xw9n/GguFHh/4StdP5rhR1PnHT+aC53ZffGjf9X1
w+vFj+bCb176X6v/Ptf1w+X40dT+44fXjx+ujx8uxw+Pjx9eP340u+fxS10/
mtX7/L6mzjt+lOMtdP1oVu/zu72f+NGsPq82eXz8aMb9YZ744f3ED68PPzw/
/PD4+OH6+OH+8cP944f3Gz+8P/jh8fDD7fHD7fGjofngR2Ph3z46uPrvQteP
RvV5daoRfjjjR0P944czfjTEGz8a2m/8aGg/8MPt8aOh840fDa0XPxpVHrvd
Hj9cjh/O+NGo8tjh/cAPzx8/GnF/NMIPzxc/vN/40eg+j7/c9aMR90dDfPHD
/eGHx8cP18cPzxc/XB8/GtXn1d3eL/xwffzwfPHD/PGjnP9Xu364Pn40FpZ+
vAP8q10/GuGHM364f/xohB/O+OH14ofXhx9eD354v/DD+/tgZ/6XJ8Xrgc58
T0+q/+L3mWOT1efnq5Marxj/xUmdn3/aGe8bk+Lb6vD+q0ndf7d2+H5hUvu/
ocPz6UnN9+YOv097vOL3kccnq/fJ77h+weOhSe33xc7+/9aknufvdPb730+K
z+HO/n7Q8znY2c9/MSme+zv79/5Jne+9nf26Y1L7X/zvBW/z/IvzeYvz73fO
49/2/vyfzvm7weWPdc7b5KR4bO+crwHPDx4Tmg88JtQfPFwOjwntPzwm1B88
JrSf8JhYKJbzxW90eUwEjwnNDx4TOq/w8HjwmNB+w8PzhYfnC48JnTd4TGh/
4eH5wMPzgYczPCaqn/9vcX/wmNB5gYf3Bx5eHzwmFv7Tr/3d1X/3dnmMa7/g
Ma728BjXeuExrvMIj3GND49xrR8e49pPeLh/eLgcHuO6/+ExXn1+/c64zjc8
3B4e4/IfHuNaPzxcHx7j2m94uH7xPLljXJ+3i+f5ba4PD/cHj3GdF3iMhx9e
Dzyc4VGP51U9nld1rQ8e9fCjLl7wcH141LW/8KgHj3rw8HzgUdf+wMPl8Khr
/fCoa7/g4fHh4fbwqIsvPOrV+/aOcvyvdXnUq59vbvF48Khr/+FRl0/w8Hrh
4fHgMaZyeIzp8yQ8xsKPMfkJj7G4P8bieTWm+cJjLHg4w2NM64GH28NjTOuD
h+vDw/OFx5jOHzzG4nk1Jl7wcDk8xqqfP28bi/vD5fAYi+eV9wce7h8eHh8e
o5o/PEZ1vuExqv2Cx6j2Bx6j4cdo3OejwWNU84PHqPjBw/3BYzT8GA0/RuP+
GNV+wGM07nOPBw+vFx6j8bwa1f7Dw+3hMRrPq9G4z0e1//AYjft8NO7zkfBj
ROuFx4jWB4+R6vvoiyPBY0T9w2NEfOAxEve5MzxGgsdI3B8uh8eI3l/g4fXA
Y0Trh4f7g4fbw8PzhYfbw2Mk/BgJP0b0/IPHiPjBw/3DYySeV8PqHx7DwWM4
Pu8OV99/XhyO+9z9wcPl8BgOHsP6fACP4bg/hvV5CR7D4cdwPK9cDo9hrR8e
w9p/eAzH56vh6vdLdwzLF3gMV78/umVY9z08huN5NRx+DMfnK2d4DOk8w2NI
7eExpO8v4OH68BhSf/Bwe3gMaf3wGBJfeAzF5123h4frw2Mo/BgKHm4PD7eH
h+cLD9eHx5CeX/AY0vMdHkPV749uGdL+w8P7A48hPU/g4fbwGIr7Y1Dzhcdg
3OeDcZ8P6jzAY1Dzh4fL4TEYz6vB8GMw7vPB4DEY9/lg3OfO8BgMPwa1fngM
Bo9B7Sc8BuPzlecDD5fDw/sDj8G4PwbDD68fHoM67/AY0H7BY0Dzh8eA5g8P
Z3gMiC88BrQ+eAxoPvAY0HzhMRD3x4D2Hx4DcZ+7HB4D4ceAzhc8BuI+93rh
4QwPrx8eXg88BuL+8HjwGNB5hofnD48B7T88BuJ51a/9gkd/3B/9cZ/3a77w
6Nd84OFyePSHH/3hh+vDoz/86Jdv8Oivft/+kPuHh8vh0R/vg2X5ji6PfvkF
j/7q70V39MfnXfcHD48HD9eHR7l/f9Dl4XJ4eDx49MXn3T6tHx59Wi88+uL9
oy949Kl/ePRp/vDoCz/6dJ7g4fHh0af1wKMv7o8+nTd49Ik3PPrieeX+4dGn
36vg0Vf9vu8Ot4dHX3xf0hffl3i/4OEMj764z71+eNR0/uFRi+dVTTzhUQs/
auoPHrX4vqSm9cOjFn7UtL/wqMX3VzWtFx616ve7DznDoxZ+uH94OMPD84VH
LZ5XtXhe1eLzVS3uc88HHi6HRy0+79bi+91erR8evcGjN+7z3urvky/26vdq
ePTG5yu3h0ev5gePXu0HPNw/PHrj/aM3eLgcHr3yBR7uHx69cX/06n0FHr3x
ft5b/d/f3OYMj175Ao/euD96g0dvvJ97f+DRE/dHj9rDoyf86NHzAx49Wh88
eoJHT9wfPeGHy+HRE9+X9MT37T3x+apHz0t49Oh8wcP14dGjzx/wcHt49MT7
oNcLj57woyfeB3v0vIOH68PD48HD673cmf/56/Pl/I905vvG9flyvsXvKd++
Pl/WL75vfvb6fOnPzs74n7k+X/L7n53xfvf6fDn+b3e6+8j1+XJ+/67D99ev
z5efd/55h+cvXp8v139Hh9/PuL9/0Jneez2/gs+M69eK/1Wh+z/V2f8T19T/
Dzr7/dI1zefrnek9d22+9OHPOt19/tp8uT+f7uzfp65p/E909uvjbl/8nnW/
8+bO9H7VeVOnu593+3/UOX8/4fn8rc72vcflE53ljjrDY2W+PD/wWFH/8FjR
+uGxovbwWJkvvx+Ax4rWB4+V+fL8wGNF+wcPt4eH68PD48NjReuDhzM8rs6X
7/PwuKrx4HFV9eFxVecNHq4Pj6viBw/Xh8dV7Qc8rgYP9wePq9ofeLg/eFzR
ePC4ovXD48p85fexZ53hcWW+fP+Ex5Xg4f7h4QwP14fHlfDjis4HPK7IF3hc
CR6XxRcelzVfeDjD4/J8+X06PC53x/9Gl8fl+fK+hcdljQePy3qewOOy9hce
l7U+eFzWeYOHMzwuaf7wuKTzBY9L6g8ezvC4pPnB45LOAzwuaT3wuKT9hofL
4eHx4eH+4XFJ64eH5w+PZfUHj+X58vc3eCzr/MBjWf3BY1n84bGs9cBjWePB
Yzl4LAeP5XheuRwey8Hj4nz5+yA8Lmq/4HExeFzU+PC4GDwuar3wuBh+uD94
XIzn1UXtJzzcHzwu6jzDw/XhcUH14XEhnlcXND48Lmj+8Lig/uBxQfsFjws6
L/Bwe3h4fHi4PTzcHh4eDx7nVR8e5+M+P9/1e2+XhzM8zmt/4HE+eLgcHuc1
PjzOz5ff78LjvPjBw/XhcT7uD88XHue0HnicUzk8zmk+8Dgnf+Dh+vA4p/2D
xzmtDx7nwg/3B49zcX+4HB7n5ovi9+3r8ljS+uCxpP2Gx1LcH0vyDR5Let7C
Y2m+mO5vfr3LY0nnHx5Lmj88luJ5tRTPq6XwY6n7PHm+y8P14XFW5x8eZ9Ue
Hmc1P3i4HB5ng8dZ7Qc8zoonPM5qv+FxVucJHme1//A4q/2Ah8vhcSZ4nNF5
hceZ8OOM5gOPM/H5yuXwOBM83B88zmh/4OHx4XFG84XHGfGHxxmdD3icVnt4
nNb+wOO0+MHD9eFxWvOFx2nxhcfp8ON0PK9Oa33wOK3zDI/TOn/w8Pjnivm/
q/U+X8z3XfF+spjfu935fKf14WI+72r89xfjv6vz9HeK8d7VfK8WvE+p/EDB
95R4fa7g6fKHC36n9Pnplwtep8KXU7rv+gsep7T+V4v9f0fr/fNiv50fKfb3
HfH/ULGfLv/pYv+cG8V+OXNeT87z11TfbH2pOJ8nxfvx4jyeFM/fKM7fSa3v
Z4vzdlLrWVecr5PaD3icUH/wOKH1weOE6sPjRPA4ofsfHic0HjyO63zB47ja
w+O4+MPjuPYbHseDx3HNFx7HxR8eb6scHm/r8xI83tZ+weNttYeH68Pj7Xh+
LOo8w2NRvOCxqP2Cx6LmA49F3W/wWBRfeLyl+cDjLfkCj7fEFx5vaX/h8Zae
H/B4S+/v8Dim/uFxTP3D45j4w+OY+ofHMfGCxzHtFzyO6XkFj6PqHx5Hg4cz
PI5qffA4qvnC46jGh8cRnQ94HNH+wuOI3t/gcUTrg8cRzRceR8QTHofFEx6H
xRMehzU+PA7rfMHjcDyvDgePN+fL73fh8abaw+NNjQePN7U+eJT5D7s83tTz
GB5vaj3weEP7B483NB483tB+weMN8YfHG9oPeLwRPF6XL/B4XeXwKPPnujxc
Hx6va/7weF37s1jM/zU9rx8t5vua+N1WzO81PY8Wi/kckq+/V4x/SPv3vmK8
Q9rf5YL3D5WfLvj+UOfvlwueP9R8hv9eZ8Nf1Xx3Fbxe1fc58HlV+zdc8HD9
Z4v9f0XlW4r9fkXnY22xv69ofc8X+/kDrW9bsX8/UH83Ffv1A7XnvB7Ufm0r
zudBze+9xXk8KP9eLs7fy+rvE8V5e1n1byvO18vB4yWVw+Ml9QePl+bL32vg
8X31D4/v67zBwxkef6PzA4+/0fmBx99ofHgcCB4HgscB7Qc8XA6P72l/4fE9
zQceLofHd72/BY/vqj48vis/4fGi9gceL4oXPJzh8YIyPF5Q//B4QeO/UMx/
v873TcV892s/7i/m99fz5e+bLxTz+Y7621iM/x3xfbQY79ua/+mC97fE8wMF
X+ddBc993fafbvEf9PqmxvtAweub6g8+z6t9o+Dx/Hz5ffj9xf5/Q/mFYr+/
Lv4bi/39erf9w61Hi/3cq/06Xezf17SedrFfX9P8OK9fnS9/7zldnM/nPN/i
PD7n+Rbn7yueb3HeFpTvL87Xgto/Vcx/Xv23i/l+WfVfL+b3JZU/Vczn/3XL
H2/dW4y/p5s/3LqpGO9Z1X+94P1F1X+q4PsXKr+34Llb5fwHUL7g+gWvP3P9
gs+fan9uKnjs6uZPthaK/f1j5fZ/7uzXH2l+C8X6nxaPdvEHIr+vvFCcl88o
9/yHTodPzZf/vYCHCj5Pqv+HivP7hDP/QTLNt6f4AeR/aPye4gXkt9Vfz9rO
hn/IuVHklvK6or7z7xX9tdRf8fx5rKXxvl/Mp1XOp+dXivkqP1Sc56fcH+tt
let9qPDt95V72C+XF+fvjzw+++3+r3f++ROPD69WyasNT813ofD1Cy3x5zwo
tzkvqv8Q50nlC8Xnk2e9fs6j5tfmvLo+59n1Oe+t8ry38UHlbXxplb68Xoy3
oPoP4ZvyTfjYKn1cwFe1vxef1f9N+K79YX5l/nzrXp4XrfJ5wXy/Lh5P8bxp
lc8b5v+NVvk8er3g4Qz/5z1fnnea7+vFefqm5vsQz0vN7yaep2oPP+d7eR6r
P3h+R+t5iud5q3ye38vzXuP1cB+0yvvgKe6Llu4L7pNWeZ/cz32j/ti/F7Rf
De4rZfbTeRf3XUvvU9yHmj/z+67638V9qvGZ7/da5X37Ae5j1Wf+Lj9d8Phe
q7zPOV8H1N+jfB5Q+enivB3QfrT5PKHyR/m8If7wK/OXWhv5vKL5wNP5BT7v
qP+NfB7y+ebzkvbnBT5PaXx4vCy+8HhZ5fB4Wf3D46D6g8dB1YfHQe0HPH5g
fnyeVH/w+IH2Fx6vtMrPo/B4Re3h8Uqr/DwLj1e8v3weVjk8Xg0erwaPH2r9
8Phhq/w8Do8ftsrP6/A4pAyPQzrf8DjUKt8H4PGa1geP17Q+eLwW+/W65nMb
7yuaL/tXln+59Qned3R+2M/XdX5e5n1J9Yd5n/L54n2rVb5v/TLvY9o/5vuG
ztvTvM+1yvc55u/+lgseb7TK98H38r6o+X+A90n5uY33Te3fU7yPan+f531V
48HvTe3PWt53dT7gebhVvg9v4X1Z7X+P9+lW+T69wPu2xlvkfVz7AY8jWg88
jogfPI60yvd9eByJ580RrQ8eRzQ+PI4Gj6M6f/A4qvXA46j8g8fR8Ptoq/w+
BB5HNV94HFN9eBzT+PA4Jv7wOKb1weOY+ofHMc0XHm8Fj7da5fdF8HhL/cPj
La0PHm+pf3i8pf7hsdgqv8+Cx6L2Fx6L4gmPRfGEx6J4wmNRvsLjbfkCj7e1
X/B4W/OBx9s6X/B4O3i8rfnAw+3hcVzl8Diu8wGP463y+0p4HBcveBzXfOFx
XPsLjxPqDx4n9DyCxwm1h8cJ7Rc8Tog/PE5ovvA4qfrwOKnx4HFSfOFxUvsF
j5PqDx4nxRce74gXPJzh4QyPd1rl9+HwcDk8nOHxjtYHj1Pab3icCh6n9LyG
xymtDx6ntB/wcDk83hV/eLwbz6t3g8e7rfL3Cni8K/7weFe+sF+ndZ7X8XtJ
7N9pPY9/lt9btH7287TG/w1+r9F8H+b3nPD3tHh+jt+DND7zPa39O8DvSfG8
df2rBY/Tel7N8HuVnh/wOaP1/jS/d6k9vM6I/4f4vUzrg98ZzfcRfm8TL3i6
/M/5vU7l3+b3PPX3Or/3afxz/B4Y9+1ZzRceZ9U/PFwOj7PaH3icFW94nNV8
4HFW84HHWZ0neJwVP3ic1f7Aw+XwOCu+8DgrfvBYapW/58JjSe3hsaT68FjS
+YPHkuYHj6XgsaT5wWNJ/OGxpPMBjyWdZ3gsaT/gsRQ8zrXK39PhcU77D49z
2m94uBwe5zR/eJwLP85p/fA4FzzcHzzOiSc8XB8e53S/wcPl8Div9cHjvPYb
Hufjfjmv8woP14fHec0HHue1Pni4HB7ntd/wOB9+nNd84XFe64HHBY0Pjwva
P3hcUH14XIjPRxfieeX28HB7eHg8eLg9PC7o/MPjQjxvPT483B88Lmp/4HEx
/Lio+vC4qPMPj4saHx4XxQ8eF4PHRc0fHhe13/Bwf/C4qPsfHhd138FjWfsF
j2X5Bo9ljQcPl8NjOfxY1vrgsaz9hMeyPi/BYzk+Dy5rvfBYjs+Hy9pPeHg8
eFxSf/C4pPnD41I8ry7F8+qS9gseLofHJa0HHpeCxyXtPzwuBQ+PD49Lmj88
LgcPZ3hcVn/wuBw8LgePy5ofPC5rPfC4rOctPC7H58HLet7CwxkelzV/eHg8
eFzR5yd4XBF/eFzx9zH871W1PnhckQ/wuBJ+XIn3lys6P/C4ovnC40rcH1f0
/gYP9w+Pq9pfeFzVePC4GvfHVa0HHs7wcH/wuKrx4OH+4OH68Liq/YXH1Xhe
XdX5gsfV4LES98eK1g+PFZ03eKzE82ol3h9dHx4rwWMlPl+taD/g4fHhsaLz
AY8VfZ8Dj2tqDw9neFyL59W14HFN/cPDGR7O8HB7eFzT+uBxTfzg4fbw8Hzg
cU37B4/rWj88rssXeFwPP1wfHtfVPzyuq394XNd84OH+4HFd7+/wuK7zBo/r
cZ97fg/z9yDtsv4n+XuRduV94Yaedjn+/+XvTdqV831LT7s8P3/B36uo/nP8
PUu7/D782/y9S7tc//f5e5h25fn6wZ52Od/j/D1Nuzw/5/h7m3Y5/2sdHP/F
7Uf5ex3Vn+HveTTee/h7n3bl+5WnXf4P+Xshlf80f0+k8p/j743ale/HXnT5
v+TvlbTeX+fvmbQ/9/P3Tu2S30f4eyj1B49e7R88elUOj161h0dvu/w+ER69
Wj88XA4PZ3i4f3j0tksf4NGr9cGjV+uBR5n/sMvD84OH+4eHy+Hh/uHh/uHh
+vDw/sCjN3iU7T/V5eH+4eH28Ohtl/7Ao7dd9aPWLu9beNTUHzxqwaOm+cDD
5fCohR8uh0dN84FHTfsBD7eHhzM83B4eng88asHDGR61duW+f9r9w6MWftTa
5fe78PB84VHTeYOH5wePWvhRCx7eH3j0qT949Gm+8OgTH3g4w6NP64VHn3yB
R1+78jx9f5+ed/Aox/tsl0ef1g8Pt4dHn/YLHn3yBR592l949On5AQ/3Dw+v
Hx5uDw/vBzy8Pnj06XkJD+8HPLxf8PD48PB48OhX//Dob1fe327o13rg4XJ4
9Gu/4NGv+cPD9eHh8eDhDI+yvx1dHu4PHv3hR7/WCw+Xw6Nf64dHv/YLHq4P
j/7woz/uD9eHR3/w6A8/+nX+4eH9gEd/3B8DWi88BnTe4OFyeAzE/TGg+cBj
QOuBx0A8rwbieTWg9cJjIO6PgXb5eQceHg8eHg8eA/IPHp4/PFwOD7eHx0D4
MaD9gofXA48Bff6Ah8eDhzM8BuJ55fXCY1D7D49BzQ8eg5oPPAY1X3g4w2NQ
/OHh9vBwOTwGtT54DGr+8BiM55Xbw2NQfsFjMD5fDWr/4TEYfgyKNzwGw4/B
8GNQvsFjUPcvPFwOj8G4zwd1nuExqPMFjyHxhceQ1g+PoXb5/gmPIc0fHkNx
n7s9PNw/PIY0f3gMtSvvrx8cCh5Dmi88XB8eQ+HHUNwfbg+PoeAxJF7wcH14
eD3wGIrPV54vPLw/8BjSeYeH28PD9eExHM+r4bjPh8OPYe0/PIZ1HuAxHJ+v
3B88hrV/8HCGx7DWD49hnU94DIcfw8HD5fAo23+1y8Pl8Bhul9/vwmM4/PB6
4eFyeLgcHs7wGBZfeAzH/eH+4DGicniMxOfdEfUHj5F25fekW0bifXAk7o8R
nT94jMT74Ij2Hx4jWg883B4eI3pfgYfbw2Mk/BiJ9w+Xw2Mk7o+R4DESz6sR
nWd4uD94jOh5Ao+RuM9HgofXA49R9Q+PUa0fHqPhx2jcH6PqDx6j4geP0Xbl
95n3j8oXeIzq+QUPt4fHaNzno1ofPDwfeIyGH6Nxn48GD48HD68HHt4PeIyK
DzxGg4frw8Pzh4fXC4/R+Lw7FvfHWLyfj2l+8BiL59VY+DEWfozF592xeD/3
+PBwOTw8HjzGNH94jMXzaizu87G4z8fi+5KxuM+d4TEWPMbEDx7eH3iMxfvH
WNznY3Gfj4Uf9Xhe1duV72NvqGt98KhrPfCoa77wqOv8wKPervye/P56fL6q
6/kHD5fDo96ufP/2Wx4PHnU9H+BRDz/q4Uc97g+vFx714OHx4VHX+YZHPfxw
f/BwfXjUxRMeng88xnX+4OEMj3HtPzzGtX54jMfzalz7BY9x3ffwGI/nlevD
w/3BYzzeB8e1Pni4PjzG25Xfpx4fj/tjvF35verp8eAxHjxcDo/x+L5kPO7z
cX0+gMd4+OH+4THeLn8fhMdEu/z9DR4T8flqQu3hMRHPq4n4vmQivi+ZiPt8
Ir4vmYjPVxPxvJqI7xMn9HkJHhNxf0zovMBjQvsJj4n4/moiPu9OxH0+of2C
x0Q8r7w/8JgIPzxfeHi+8HA5PCbjPp+M+3wy/JiM+9zl8JiM+2My3gcn4/uS
Sc0HHpM63/CYjPt8UvsNj0mdR3hM6rzAYzK+b5/UfsLD9eExGTw8H3hMxn0+
GfeH9wcek/F5dzKeV5PV9+daQ/4XPw8NNarnud7QfIufg5oNjVf8nDXXUP/F
zz/rGtr/4uermxvV+229c/Fz1YZG9fuEjc7Fz1O3NrTfxfxvb4hP8XNUqyGe
xc9pdzaq3/ducv3i57O7GlVedze0/8XPZfd4fQW/za5f/Dx2X6PKc4v36487
G7jV9Yuf8x7w/hY/f21z/eLnuwcb1fv2Y55vwWN7o/p56BH3x5/jNHS++fMg
j8+fD3m+BY8djaq/O73egsczjern813OBY/d3q+Cxx6XFzzmza/gsdfzLXjs
c/uCx/5G9f3kQEPvLwWPg43q+/whty94HG5UP58tmn/B45RzwWPJ+13wWPZ+
FDxWGuFHU/3jR7P6/V+9qfXiR1N88cPt8cPt8aMZfjSrPDY0q78PbGyGH83q
8/b2ZpVHy/3jR1OfJ/Gjqf3Gj6a+v8APj48fZf/d7+c3N3X/40ezev9scX38
8P7gh8fHj6Z440ez+n3Gx5o67/jhcvzwfuNHM/xo6nmOHy7HD4+PH95P/GhW
v9/Z1dT5xo+mzhd+OOOH9xM/mtX39X0uxw+3xw/zxI9m9Xl1yO3xw/3jh9eL
H83ww/3hh9vjR7P6fV9tShk/pqrv0/Up9YcfU1oPfjjjx5TuP/yYqv4esH5K
5wk/prQe/HA5fkzp9yr8cDl+TMkH/Jiq/h6yaUqft/HD/eHHlM47fng++OH5
48dU9f1li8fHD4+PH1PV59W2KZ0//JiK+yN4bPd88MPj4Yf7w4+puD/cH35M
Vb9/3un148dU+OHx8cMZP8r6n+r64fb44fHww/PHj6nq8+qAM35MVX+/OuRy
/PB68cP18cP18cPzxw+fJ/yYCj+mdV7wY7r6vwepT+v3OvxwffxwffyY1nzw
w+3xw+3xw+X4Ma39w4/p8MP18cPj48d03B/T2g/8mO7u3ye7fkxrP/HD88cP
94cfHh8/PD/8KPPjXT+mw4/pKo8HPR5+uD1+eDz8cHv8cMYPrw8/yvzprh/T
1efVzunq8+oZrxc/gsduzwc/PB5+BI+9Xh9+eH34MS2/8MPt8WO6ep8fMi/8
8PrwY7p6n59yOX54fPwwP/zwevFjJvyYqf7vc+oux48Z7Q9+zGh9+DGj+eGH
y/FjJvxwOX64HD9mtD78mKk+r1qujx+eH37MiB9+uD/8cDl+zGj/8MMZP1wf
P9wffpT1H+764XL8cDl+uD/8cDl+eH34MaPzhh/eD/wo63+464fL8cPj4YfL
8WOmXf7nAvDD68cP948fLscPrxc/3D9+OOPHTPV5dcD94Yfr44fr40fwWHTG
D7fHj+Cx7Pr44fr4MVt9Xg3NVnnUZ1UfP2bVH364PX7MVnncPCve+OGMH874
MVvlcetslcfts3F/uD1+uD5+zFafV3fNxv3h/vBjtspjszN+zIYf7h8/XI4f
bo8fs+GH2+PHbPV5td3l+DGr84sfweMJl+OHx8MP94cf3i/8cH/4ETx2uz/8
cHv8cHv8CB773B4/gscBl+OH14Mfng9+OOPHbPgxG354PvgRPFZcjh9rlPHD
GT/WVHk0XY4fzvjhjB9rwo81mj9+uD5+uBw/1oQfng9+OOOHx8MPt8cP18cP
Z/xwe/xYU+Vx35rww+3xwxk/3B9+rAk/nPEjeGwPHo8440fweCJ4PBk8djjj
h8fHj+Cxy+X44fXhh+vjhzN+uD5+OOOH+8cPt8cPZ/xwe/xwxo/gccr944f7
ww/Xxw9n/JgLP+ZUjh9z6h8/nPFjLvxwe/yYq/JY73L8cH/44XL8cMaPuSqP
1lyVx51zOr/44f7xw/XxY67K4x6Phx8uxw9n/HD/+OH2+OGMH8744f7ww+X4
4f7xw+X44YwfzvgRPHYEj53O+OH6+OFy/Agee5zxw/PFD5fjh/vDj+BxwPXx
I3gccsYPZ/xwf/gRPJaCx3LwWAketbVVHkNr4/5wOX64HD/Whh/O+LE2/HB/
+OGMH8744YwfzvjhjB/O+LG2yuMul+OHM34444czfjjjx9oqj61rdT7ww/Xx
wxk/1oYfwWO7M364Pn64HD+Cx5Mux4/gsXNt+BE8dgWP3cFjz9rq82o+eOwN
Hvuc8SN4HAgeB4PHoeBxOHgsOuOHM34Ej+XgseKMHzco44czfjjjxw3hh8vx
wxk/nPHDGT+c8cMZPzwefrgcP5zxwxk/nPHDGT+c8cMZP5zxwxk/nPHDGT+c
8cMZP5zxI3hsDx6PBI/HnPEjeDwZPHYEj53B45ngsSt47HbGj+AxHzz23qDn
BX4Ej/3B40DwOBg8DgWPw8FjMXicCh5LwWM5eKwEj9qNyvjhjB/O+OGMH874
4YwfzvjhjB83xvuHy/HDGT+c8cMZP5zxwxk/nPHDGT+c8cMZP5zxwxk/nPHD
GT+c8cMZP4LH9uDxSPB4LHg8caPOI34Ejx3BY2fweCZ47Aoeu4PHnuAxHzz2
Bo99wWN/8DgQPA4Gj0PB43DwWAwep4LHUvBYDh4rwaP2I8r44YwfzvjhjB/O
+OGMH8744YwfzvjhjB/O+OGMH8744YwfzvjhjB/O+OGMH8744YwfzvjhjB/O
+OGMH874ETy2B49HgsdjweOJ4PFk8NgRPHYGj2eCx67gsTt47Ake88Fjb/DY
Fzz2B48DweNg8DgUPA4Hj8XgcSp4LAWP5eCxEjxq65Txwxk/nPHDGT+c8cMZ
P5zxwxk/nPHDGT+c8cMZP5zxwxk/nPHDGT+c8cMZP5zxwxk/nPHDGT+c8cMZ
P5zxI3hsDx6PBI/HgscTwePJ4LEjeOwMHs8Ej13BY3fw2BM85oPH3uCxL3js
Dx4HgsfB4HEoeBwOHovB41TwWAoey8FjJXjUflQZP5zxwxk/nPHDGT+c8cMZ
P5zxwxk/nPHDGT+c8cMZP5zxwxk/nPHDGT+c8cMZP5zxwxk/nPHDGT+c8cMZ
P4LH9uDxSPB4LHg8ETyeDB47gsfO4PFM8NgVPHYHjz3BYz547A0e+4LH/uBx
IHgcDB6Hgsdh5+I/V7/oXPznU04Fj6XgsRw8VoJH7T3K+OGMH8744Ywfzvjh
jB/O+OGMH8744YwfzvjhjB/O+OGMH8744YwfzvjhjB/O+OFc8NjiXPDY6owf
zvjhjB/O+BE8tgePR4LHY8HjieDxZPDYETx2Bo9ngseu4LE7eOwJHvPBY2/w
2Bc89gePA8HjYPA4FDwOB4/F4HEqeCwFj+XgsRI8aj+mjB/O+OGMH8744Ywf
zvjhjB/O+OGMH8744YwfzvjhjB/O+OGMH8744YwfzvjhjB/O+OGMH8744Ywf
zvjhjB/BY3vweCR4PBY8nggeTwaPHcFjZ/B4JnjsCh67g8ee4DEfPPYGj33B
Y3/wOBA8DgaPQ8HjcPBYDB6ngsdS8Fh2Lv6+ZMX5/wONI79g
          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8974812857142858, 0.3693308571428572, 0.14526651428571424`]], 
         LineBox[CompressedData["
1:eJxdnQuwXWd5ns/Z537fe5+LDBGO1XZUt2o8aoM7Hge6dxlcqIaJSKq2uKEa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          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.6695744285714289, 0.22438285714285722`, 0.3381279999999999]], 
         LineBox[CompressedData["
1:eJxdnQuU3Fd933dnH7OP2d157EqQKMTqw6VxQ9UG93CUx0xy4ob65MQkdVuc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          "]]}, Annotation[#, "Charting`Private`Tag#5"]& ], 
       TagBox[{
         Hue[0.8503398874989481, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.31953685714285723`, 0.11640000000000005`, 0.4341454285714288]], 
         LineBox[CompressedData["
1:eJxdnQmQXVd557tfL6/7vdfdb2sZgkKkmYnHiScZTYKnKIXk3qTshLioyEk8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          "]]}, Annotation[#, "Charting`Private`Tag#6"]& ], 
       TagBox[{
         Hue[0.08640786499873876, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxdnQuQXGd5pmd67jM9M30bG4IAO7tRTLxJaRO8RRnIOUlhIK4Udoh3FwWi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          "]]}, 
        Annotation[#, "Charting`Private`Tag#7"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(4\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-8.002500000000001, 7.997499999999999}, {
       0, 0.2604166666666667}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"T2.6\"", "\"T3.11\"", "\"T5.13\"", "\"T9.22\"", "\"T17.35\"", 
       "\"T33.58\"", "\"T65.81\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.8990594285714286, 0.5637948571428573]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.7397017142857143, 0.23300614285714288`]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #6}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #7}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm], ",", 
               TagBox[#6, HoldForm], ",", 
               TagBox[#7, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True", 
                 ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091194429099684`*^9, {3.909125698510269*^9, 3.9091257066406164`*^9}, 
   3.909126457110761*^9, 3.9101549712826576`*^9, {3.910155008395378*^9, 
   3.910155025671894*^9}, 3.9101562605065956`*^9, 3.910156947789962*^9, 
   3.9101571583623576`*^9, 3.910161076470209*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"48b5ca4d-f0c9-4b71-b97e-7c77c6c8baa8"]
}, Open  ]],

Cell[TextData[{
 "and finally consider the full data for this sequences, which is stored as ",
 StyleBox["data/dos/dos_{8,8}-tess_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091257257973347`*^9, 3.9091257829464827`*^9}, {
  3.9091258161267524`*^9, 3.909125817972119*^9}, {3.9091263241669226`*^9, 
  3.9091263478044133`*^9}, {3.9101544811965094`*^9, 3.9101544880133915`*^9}, {
  3.9101556042258387`*^9, 3.910155604445711*^9}, {3.9101567591084995`*^9, 
  3.9101567776566224`*^9}},ExpressionUUID->"a788d98f-d62c-4fe2-9b18-\
a235cebbec81"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{8,8}-tess_``.dat\>\"", ",", "#"}], "]"}]}], 
            "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.6\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(7\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "7"}], "]"}], "/", "7."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.910157103833946*^9},
 CellLabel->"In[45]:=",ExpressionUUID->"5202b7b0-c17e-4fa9-861e-2573dd28c8ff"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8990594285714286, 0.5637948571428573]], 
         LineBox[CompressedData["
1:eJxE3XVYFF0bwGG6u3vFxECxm7FFscDAwC4UA0UEQQQkRZDuTgmDbjjPoq+J
hYgFqGAgBiVd37DzzPX5z3vNtcvu2fM798zO1qt76KzpUQE+Pj5nKT6+0f8a
SrxNshriQNF+w10zzf8YFum4/zLp5YBs7cjCqjBRas5s+l8nBzY3qp05Ol2Z
urP2i73SXw6IJSUd27Vcm5ps7lfZ1cwBkQfbIdxrLJVstVTibRMHdCcuGfRX
mEiN3lxRAweO6wWRMTemUJER9L/3HNjzw83Ga/wMSmn0Bms4YPT+4d37aQaU
f2WXnvkLDtSpTv3vp9McanR4S59wIP/iPGqXz1zKg745nf84sKV2X/9G1QUU
3+g/4IBPmcnLwFOLKPvRGyzhwKVTyjLP2xdT3Xr0APM5kCSW/vG9mSE1Oryk
LA7cu28/LCu5jPpN35x7Jgc8N396+2fncurY6L9UDnxQuXuv0WUF1Th6gwn0
eLTFnGwkV1KjD1cvmgM316zU3ftwJTU6PIkw+vGVqz25dnE1ZTo6gQEcEJxi
2x+tspaqGv3nwwHL//54jBteSxnR03fHkwOm9YX5n+ONqNGH63eVAwvPB4m+
G1pH8Xo4cqBZz2TZeF9jitfDjgP8N8LnJCQbMz2sOXBmaWz7uykbmB5nOGCs
v57M9t/I9LDgwIvs8zpCrzczPQ5zoPzXQ5ccty1Mj30ckJ6h7/fhxBamxy4O
+M34JdtgYcL02EbPX+iYcfGVJkyPzRwoDnVq0l1hyvRYz4HD9sd3RdeaMj1W
c+D0waoNHKutTI9lHJCJdzMcktrG9FjEgZSyAS+h3q1Mj7kccE7ZFFX1ehvT
w4AD1tm5s6ZO2M70mMoBlyMh+n9m7GB6TOTADHOpGrXDO5geuhw4ov/PNkXT
jOmhxYHUs143pZfuZHqocuBR3sfX9kd2Mj3kOSCw/+K/I0k7mR5SHPi8aWwl
EdvN9BDlgP4DiUdpl3cxPQQ48OnasI2i7m6mx5AOfCxMzjMav4fp0asDqskX
VqkLm6MPHVBUrGnTv7UHfejAy6tbGh6+MkcfOjB53Os1Gi570YcOGBiWztqX
vhd96MBElZhXA5b70IcOHFcZDHD8tQ996IBGnKJPsO1+9KED/lEeG8X1D6AP
HYg1KPsTM+0A+tCBjASLS5dCDqAPHXAz8tDa8+IA+tCBKUssLtbvOYg+dODf
2DPpDTYH0Qc9nj+DAe+SD6IPHXC5OG2Pf/VB9EFfP86pSs3gEPrQgbc+x6d6
5xxCHzrwMO1BatvAIfShA8qGe0RFHQ6jDx0IN948pOd3GH3owG7Tdb0LIw6j
Dx14WmCnrSJ7BH3Ql7/YrXlh6xH0oQMTtDjVSqlH0Ac9H0ePSd7uPII+dMD0
1AGRiqEj6EMHmo9sWiJlehR96MACtylzHeKPog8dWN1VCzvEj6EPHRhvolNV
N+sY+tCBxq/jns9oPYY+dGCxWIii0ddj6EMH9r+d8U764zH0oQPTvHMUNh07
jj504Nap+wvG7z6OPnTgPLV48YU3x9GHDiw6qD32sagF+qDnR3lGadV2C/Sh
A7dFrxZc55xAHzqQ/Xq4/In/CfShA9djU2yOHjyBPnRgzpeO3N/JJ9CHDgj2
zz5fZXESfehAk0bc4+FLJ9GHDtxfLKE78/pJ9KEDIQ2Btid0LNGHDpz5qtxk
JmqJPnSgWsHG4NY0S/ShDafefjq9sMMSfWiDr0P4odxHluhDG6jPE43kK06h
D22Ye/G17aOGU+hDGwZn9nxwfHcKfWhDHNHIPjDtNPrQBrOhPYpaaafRhzZs
DBJb+frRafShDfPmakj8XHQGfWhD22Ci0JD7GfShDd8DN8/JSz1DufN8aMNA
k2ivE+cs+tCGiWcnfL7sdxZ9aEOU8AdtUykr9KENqz5Yfp+raYU+/r/N+NCG
NcumnHyz1Qp9aMNIzevEiKtW6IMen+7tmc1uVuhDG3z0ArcZf7JCH9oQ4d08
y7/SCn3Q47H6dSa2xQp9aMMSj4dXVIzPoQ9tkFtd1yN46Rz60Ia+1Vs9J0ae
Qx/a8CdtTJdv7Dn0oQ2xUz7NVkg4hz60YeuL0R3UOfShDamegzeWWJ5HH9pw
sXnzxRvm59GHNixNtn6/csd59KENud5/ki/EnUcfdI/qNeRhxnn0oQ3rjUYm
nv14Hn1owxFNgQC/SdboQxsujfXqtBKwZnqs1oYtUk5LMrZYow9t2Lx2T9uQ
hTX60IYHB/Icrzy3Rh/awHcy75hNmTX60IaWQ9OFgr9Yow9t0Oqvn2L4zxp9
aIP/Drl9KmcuoA9tsE7c6x4cdwF9aENNygeBmOQL6EMbnM6ffX+58AL60IZv
4a/mPPt8AX1oQ9qRVgfv6gvoQxt+zDxrXzbXBn1ow7DU2drPjjboQwtSfw75
P/KyQR9a0C324dr8tzboQwv+HM4Qjvpkgz604G6Ma+WA8EX0oQXPJmQFw/KL
6EMLxrx4PcFr/0X0oQUBfOOvKRVfRB9aYGjG17sh6iL60ILj65wjdxdcRB9a
cHZBo9MXY1v0oQXTUw3nCvLbog8tiGh1PxO1yRZ9aEHBqtdX5M7Yog8tMF5d
kXqowhZ9aME/9S1n1zyzRR9a4LJoxv40aTv0oQXeGzV2NS+0Qx9a0BYm/Li9
zxZ9aIF169Qxw5l26EMLJk6XL54SaYc+tOC63+ZHzz/aoQ8tsFvdRkJ+26EP
Laiz3izdIn8JfWjBKbc56qt2X0IfWjB72c7LfVsvoQ/68o7WGz9uXEIfWnBh
WeESh9eX0IcWzJj22Ngo/xL60AKOg+i1YQ179KEF6vwlNbdX2qMPLejfJvR3
xjl79KEFIoW7qy5ss0cfWjDv6N7A4mZ79EH3WX3iSXqvPfrQgj6pjvvlKx3Q
hxbUCjhsSJ7jgD60wOKda3LGEQf0oQVeO3PdLJMd0IcW/HjVfELzgwP60IK5
10U+tbQ6oA8tkLvms/NNnQP60IKtirOz7069jD604NX7oryXbpfRhxY8meZj
aBBwGX1oQU5Uxcru75fRhxZcVhLn31Z1GX1o4f77MvrQgo8DfXtuznNEH1rA
71Vqr6zuiD7o+RPaIaOf44g+NGHxZa/Bn12O6EMTiCb3ssUbR2o2z4cmuJbu
LLeYcwV9aELxChk+yc1X0IcmnDx6/OLVxCvoQxP2hWwfG+l9BX1owm/7nfvS
cq6gD03oz9KbZyDohD40wbFCa5qpqhP60IRZBl88nus6oQ9N6Ph0PrPWzgl9
0H9PrjQ98HJCH5ow1olz383TiXLg+dCEY0tSGu50OKEPTdj99M5/RdOc0Qf9
eERMbl/Qd0YfmpC6q+XkkrHO6EMTbuw+2L9vpTP60ISFDa+v+1s5ow9NCDu9
4V/sWWf0oQlp6UctHQOc0YcmWImMF5lY54w+NKH9yPzZ/a+c0YcmHDKUTV4O
zuiDfnxhKl3r/jqjD01YuW6+nbKYC/rQhDolv+sn5V2YHtaa4L1dz3bVFBf0
oQlXp/X3pcxxQR+aULY7SDHwnAv60ASKc/S+cLwL+tCE+rjv1Ei4C/rQhAvW
i1fvjHVBH5ownL07QyvZBX1owp2W7qQOcEEf9PgeGEVtrnRBH5pgV1q8NUT+
KvrQhIGQ557Hxa8yPRZpwsTH1o4cmavoQxNe+0oeGhh/FX3Q861RlFZqdhV9
aMKcAl25Prur6EMTJqS0WByzvYo+NMHU02rSqcir6IMen853lyshV9GHJpwN
iuqYVXMVfWiC9NV3TS/4XdGHJpzihNUveH4VfWjCG6uPYm9UXdGHJjQtaDtZ
PNsVfWhAZvF8DU1lV/ShAffkFjou3e+KPjQg2s1234vLruhDAyb/tQv6lOiK
PjTgq9TJI4PxruhDA7J+nU/pq3BFH/Ttcfym1Hx1RR8asE3yo/DCBlf0oQH1
brU6JoOu6EMDJkg/Hn9ljBv60AAHa0W5v5Pd0IcGaCbZbJu73A19aMDymI7m
NTvd0IcGeE/49tf6shv60ICt26WPj6O3GR8a4J4UacRJd0MfGjBsfqV9x003
9KEBLwKMq38Ju6MPDXgyYdXdrgE39EHPx1y7/SGS7uhDA87PzZmqP84dfWjA
vF8+rdeN3dGHBmyO6NYrNHJHHxrwo3nDXJkt7uhDAwaVTj36eskdfWiAp8fJ
1t4od/ShAUtvyireu++OPjTgVfnSCusGd/ShAZ+eXzgq8tkdfWiAgXNI86s+
d/ShAXI7G/q3T/BAHxrwprpO4uBcD/ShAbGTYnOF3TzQhwZYmD2Ymu/qgT40
4PCvCjFyyQN90Pdn7OG1LNIDfWjAMpEvEFnsgT40YNr9KxlHH3igD3o8lodc
7jZ7oA8NWB/yjPvuhwf60ADOy6bl91U90YcGSKs9vvej0wN9aMDVq8u9NBZ7
og8NWKc31uKcpSf6oPtIzLmxdr8n+tCA4EXmIj37PNGHBuTP8/2TH++JPjTg
cvoNyfI8T/RBr/+qhdqnuZ7oQwNWhQcYVD7xRB/qsGGGwzihLk/0oQ7en/Y1
rRL2Qh/qcGbf9SqFrV7oQx2Mtylt61vphT7UwYuqeeh7ygt9qEPs0PxvcNAL
fajD6UUCRbvKvNCHOpybIlZjct8LfahDxoTKqX+/eqEPdejN5Pt0usELfdB/
vz+qeZPkNfShDn+nnrz+YO419KEOuyIWvVfVuIY+1CH1kVzBjQPX0Ic6KH7j
VukfvoY+1EEg6Gh1m+019KEOBV56E886X0Mf6vD+vysH3mVeQx/qAM87vgw/
uoY+1EEiXGJxbe019KEOLWe3btwt4I0+6PtTz84onu+NPtThfPw03fuLvNGH
OpSWHM7eOMUbfaiDaYzMkaX53uiDvj9jIeGFrt7oQx3iFvpHatp5ow91aG/M
ndoU4o0+1KGJWtDf+cgbfahD3uuTSSG13uhDHVb1B87a1OyNPtQhffT0Rv46
+lAHyf+kVkYev44+1GHYru9H7sbr6EMdZpk8Pyi2/jr6oOeXWs1Z6ncdfajD
2kSPCTWV19GHOvSHrbtk+vQ6+lAH+TJLjQl919GHOiy1VFD9OHIdfdB/77My
0Ya+nPGhDl+W75x1aqEP+lCHmltjA9/S24wPdZi4Y824ODMf9KEOgUey05p8
fNCHOtQOxgSqpfugD3VYZq63WRZ80Ac9XwGvZ91O80Ef6iD4aZyJTpUP+lCH
tuK9lz5M9UUfajBxuWLZ5TW+6EMNpp9cvlBziS/6UAMzxbhQ+3O+6EMNNhUG
mPns90UfaqBvPnATzviiDzVomfxs+dTrvuhDDWzEPRsav/iiDzV4NP3WxTT+
G+hDDYxCykKcO33Rhxp8d+3z0Na9gT7UwHPG3upDi26gDzWQT9jTd9H8Bvqg
x9udJv7b4Qb6UIPJy50S1vrcQB9qYC4p47289Ab6UIPFfRGc8Vk30IcaKKbl
5Yl/v4E+6PGG/L2Tq+uHPtRgaLy+8RRxP/RBX17i+SnNyg99qEFXdISw0xE/
9KEGWyY+fj4v0A99qMHry5/ERX380IcaCH25e+bgVT/0oQZbF1tojv/phz7U
YNaRl0d2d/uhD/ry9HEBD7X90Yca/Pv+9NgJAX/0oQZXmixfTBP3Rx9q8Fzt
unH/GH/0oQbTxguXioz1Rx9qUMYvKSy/yR99qIFf7SH+vav90YcabPgkt1nT
3h99qEFah2fWVFt/9KEGAoH9g8vP+KMPNVjWV2pbE+6PPtRg0SN/sVk3/dGH
GkQEXHdYmu6PPuj5MDnB8cj2Rx9qsPfat8UxL/3RB337hUH688v90Yca6K45
bJT+yR99qMFwx2PvLy3+6INeDwPpoeof/dEHvR6vv97dqBCAPuj1OOHBrCF6
m/GhBremgb6MdgD6UIPDkt+3vV0TgD7U4HSCTWzlngD0oQqNejXT+bcGoA9V
cHdVWxnsHYA+VGH3FuuNde4B6EMVRM28pxdHBaAPVbikd/T2oG8A+lCFTbdi
zocmBaAPVUh1Wjdla1UA+lCFjvuHvPXqAtCHKuRv4n/z9XkA+lCFi/cKVkdI
B6IPVZBNManb8DkAfajC2f23lG6OBKAPVXCNtGycLhWIPlRh44LNL12WBaIP
VTDMKT4ZOy4QfdB/v2L0CXQg+qBvf+jx8wDjQPShCptTsqKf7w+kvvB8qMIq
x7pHHk6B6EMV7hwXezjNIRB90ON/qtCrcy0QfajC5Bsbl2SHB1LPeD5UIUvl
p599RCD6UIW4+z4hS+8Eog9V4O2+6gLRhyqMvb+oX6grEH2ogvrX6ZVK3wLR
hyqY3hLfefBnIPqgr9+jXrZNPgh9qMIpgWx5fZ0g9KEKYm4+8xynBaEPVbD6
pfjNlgpCH6oQsSvkhqt5EPpQhaE9RYfmbgii/Hg+VOEhHxUx93gQ+lCFn6sD
/0u8EYQ+VOFrmGRqpnsQ+qBv78p0YpcZhD5UwWnPsYeDgUHog+7zc/OrtS+C
0IcqpBuumbHraRD6UAWwy9zqXRmEPlTBTqvrwcjrIKaHrio0nfpktFosGH2o
AlX5JnWHUDD6UIVaiWsn+SYEow9V+DK1pCtSJ5jpIaUKoerOZspTg9GHKugG
6j6snR2MPlShbNP7OPvdwehDBY5oPeJkXw1GHypwtWS+TY1nMPpQgfTzc6W/
xQWjDxVwTf7XblMRjD5UYOZvg4lD5cHoQwX648zC7pQGow8ViPJd9Onf62D0
oQIuoXcOaLYHow8VeCcYHbzgSzDT44UKVNz78zJLLQR9qEDQpscNPUoh6EMF
mqok4q0VQtCHCqSUc1Unbg1BHypw4WvgP/vlIehDBQabZ2xesSoEfajAgUSD
htWbQtCHCsT5hKa5HgxBHyqwrn6y3dHzIehDBSYvPOf6KyoEfajAjE/9WQ1p
IehDBSYuejptRXYI+lAB3yCp9Y3dIehDBQSO+HJevA5BHyrw21y0/E9vCPpQ
Ac70hX+DZULRBz1fe3RvPVAIRR8qEDY5OuiZZCj6UAGFLV/ETCeHog96fvbN
SHtiGoo+VMDYOOrA33Wh6EMFyqqyTGrPhqIPFUjSWauWeT4UfaiAwauTgSeu
hKIPFXgu9uRRXkAo+lCBncInZ9qFh6IPFfBzdFp44mUo+lCBrgy3+mOfQ9EH
ffsXiURbfSj6UIEdC5OidZ6Eog8V0JzMZ2nfFYo+VICvt/1LkmwY+lCBDVYt
go8Xh6EPFZjjmayyfmIY+lCBSEtPm4gtYehDBT5s/0O9PRyGPlRgUpD4nTTb
MPShAqLdnfx1nmHoQwX6vpbtXucRhj5UwHMNN2Z7Vhj6UIHDxSlv/IvC0Icy
BKSfm9CeFoY+lKHo4Nlyfm4Y+lAGL4MrGj3fw9CHMryfwm20orcZH8pQDN69
nQrh6EMZdsx+0BhoGI4+lMGsfc33ACocfShD2S49w6bj4ehDGZbPbnq0b304
+lAGx69jZnWfDUcfyjA5Ufn5+Phw9KEMitnVfxNuhKMPZdg785HA04JwfH1X
GYbSN/hAbjj6UIYZVTH/1DPD0YcyyI1plo5+F0794vmgr39gylqF5+HoQxlm
x5WvEhGMoD7zfNDjDS45ojUuAn0oQ/2Ru9ULZkRQtTwfyvD4/RTb7Tsi0Icy
hJBaPr49Efj8ih7fQofjedsj0IcyHAvxSk08HoE+lGHkjaGdkU8EtYTnQxne
qPYu+5IYgT6UwejDLHfrnAhqFs+HMoTvvLCm9W4E+lCGJfP2Zui/jKD0eD7o
+Yziul3sjEAfyrC26nen2rcI9EH3DhHa2NYRQUXwfCjDMOfc+1lTItGHMvwO
CqzpXRxJ3eD5UIaDmqOvwEWiD2XYXhzp0bE5knLj+VAGl6gxq3vPR6IPZeiK
++B+3SUSX99Vhnfk1+zjjpHoQxkMgsJ+jUuNRB/KEPHryv7TtZFMj6nKsPCI
4M9DryPRhzKEZQ9us6K3eT10leGD7PE5ab8j0Ycy5ASu3vKL3ub1UKXnY809
az6ZKPRBr88jkj3OM6Lw+ZUyvNi+qVZweRT6oNdH/eMNMqui0IcypMRm/Fhn
GMX0GFICuzjDvQsso9CHEgzqBshnRkYxPTqVoGmKcNCrwij0oQRXG46+1HgW
xfRoVoITXZymKPpyxocSTEs227exLwp9KMGjCbNdY0SjmR7vlUBClkp2E45G
H0ogKhex8aNGNNPjhRIs2Vvl7jwrGn0oAfXqZaT9gmimx39K9PHqzSnvU9Ho
QwnIxg93Q0Oj0YcSKLmsfl/gGo0+lGBP0qU9q85Gow8l8M768jMkJxp9KMH7
hr3aBU3R6EMJLPwn/dX+EI0+lOCkYtXSx5XR6EMJFAK6ZiTrxKAPJTD45/XK
WjIGfSjBp18jtnGGMehDCfz36Vw+vy8GfSjB1lOlxGBzDPpQgrddWWVbjsag
DyVQM1e74WMfgz6UYG+x3v3TV2LQhxKEWkLtnuIY9KEEspEChl+rY9CHEkh9
vTLt57MY9KEEsw71Fw82xqAPJbDVf3DURTMWfShBRbiWfvnvGPShBC8vW49f
siYWfdDjVRY3l6Zi0YcSDH/o/0lZxqIPen10yKSq0tuMDyU4xicYvdApFn0o
gfDkyrDXd2PRhxKc9l+35nllLPqg799IWmHtvVj0oQQ5oy//f4pFH0rQfyZ9
4QyhOPShBC5tCauMdeLQhxKMOzi5bgknDn0oQZ5Ed0m8ehz6UIJ3w5Oz9uyP
Qx9KEK50/5v2hjj0oQS6gjrlHu5x6EMJTH791mi6FIc+FGHJAQsyEh+HPhTB
OiVWOKEsDn0ogkDVg+Bdz+PQhyJM5Xsw26I5Dn0oQphyDf9uoXj0oQj1fhPK
i8Xj0YciNEaf2megGI8+FCF7QXTfG6149EFvb1o07+b8ePShCJ9yj6zauTIe
fSiCn22iU/2qePShCPIZNb9ddsSjD0XIisubWHUyHn0owjxJ2S4VepvxoQjO
KqnrWy/Gow9FkDTwXDDTKR59KMIq5aStg27x6EMRVPfvkokIi0cf9PwcfB18
JyMefShCxGsJO8O0ePShCG35O07eyo1HH4qQeqVhW3JlPPpQhJHCP7W+1fHU
Wp4PRVhzv+FN2b949KEI+RoKPTv749GHIoxTcA+1GYlHH/T8fe+z8xVIQB+K
sFJ7R9G3cQnoQxEK/hrMn6ySgD4U4fb+uNa9CxPQhyLI6MZYHaUS0IciLE0S
EwrZkIA+FGFdfsS2K4cT0Ici1E77ovFzRwL6oMernOe07VIC+lCExXYuf0od
E9CHIhj+dhcocE1AH/TtTelVeHElAX3QPY6ECYb7JqAP+vFd6r3cEJuAPhTh
V7p97NfcBPShCO53t5XNgwT0oQhptVIlz18moA9FeFfxUXXqfwnoQxFaimwC
xZoT0Ici9MU8vWQpnIg+FEFC+kTfxI4E9KEI5r2Snq0yiUwPUUX4uu2BxrWp
iehDEVw7vDT5JyaiDwXIfPhwgT+ViD4UINj3kNJ+o0T0oQCHJwfeFTJNRB8K
INZeV3vOLBF9KMCHigBvOYtE9KEAzfJG05PpbcaHAiQ0Wx0+EZqIPhTgUNn1
6CluiehDAfLuvDof75mIPhQgI8lw/Nu0RPShAGcOlBk0FSaiDwW42r/YueV+
IvpQgLotPp6mtYnoQwFkrOtbM58log8FeDLujFB4cyL6UADbU0KNNkOJ6EMB
Ugxaz6WKJ6EP+vavhMzar5SEPhRAYpGckd3MJPShAMpvV3yQ009CHwog2etv
bDsrCX0owMbNOxv5jyahDwX4Ovry0pYk9KEA2wbddibuTEIfCnBs+6dtIw5J
6EMBEu+MuN33TEIfCiC+U8QAIpLQhwIIcxqeq99KQh8KcPah98uKtCT0oQDj
T03/4/0iCX0owO761Z176G3GhwIUN5NDFi+T0IcCDJ2Ukat6lYQ+FEBhwWnd
cQNJ6INeH4fcC3qEktGHAszt4267MT4ZfSjAlrjp0fkTktGHAvxrsS0bPzkZ
fSjAzCVR/d8WJKMPBbgW2dxpsiYZfdDry1uv7svRZPTx/23GBz3fpQ+bcj2S
0YcC6KwsaHx1ORl9KMD8lsuvNwclow96vu8oFU3NSEYfCsCN6e8+kpeMPuj1
sPNRYfWDZPShALH81L+/75PRhwKMHl1m1CajD3lwFD7xIPFnMvqQh09uP9an
tyWjD3n482fxVBmpFPQhD492OWpE66egD3mYdt5wKmdBCvqQh61TltybsSUF
fcjD4+cf3/02SkEf8qCUP6dwxc4U9CEPVytXBxnYpaAPeVAY5eWdgj7o8eh/
0Ff0S0Ef8jBp393+0xEp6EMedr7Tjo7ISEEf8tDdsXjjsbIUqovnQx487Mbv
i32egj7kQfhdwJzH71PQBz2e+95H3tenoA95KGrquK82lII+5MEzBKL9dFPR
hzwI3kvbzZ2Qij7kQTT3zsVi/VT0IQ/y6wwheUUq+pCH9PDgqoF1qehDHuo2
uNMjSkUf8qB70PqE2eVUainPhzwYrHm8pSQiFX3Iw44paWn9IanoQx7Ek090
2Uenog95cNp3c614Vir6kIelafbN556nog95ELi60H6wIRV9yMNTX8fxzt2p
6EMeoG194I/+VPQhDy/PNAk/1LyJPuQhytzHxUbrJvqQh4Wmo08Qb6IPeTj1
weFm0YGb6IPu5+hllmRxE33Q81d6P3G2/U2mx1x5ODAvter8lZvoQx5UCyTP
l928iT7kwYRI7skNuYk+6Pkda+Bwpfwm+pCHVPrs+WH1TfQhD/ekY1ZWtN1E
H/JAqaz1Pt1zE33IQ1hVdlmmThr6kIcu9Uy9Ynqb8SEP8/fUXD0/Lw190Pf/
sIJEz0ljegzJwa//uoKX705DH3KweantpFVH09CHHHRQsQLCrmnoQw4SD0UT
cfc09CEH9VRp88sbaehDDpR15pT+vZ2GPuSgblNB3b/KNPQhB4ZyeXsHH6Wh
Dzk4bhtYsXskDX3IQbWpztXNaunoQw7OLNp7rko6HX3IgXWZwKugWenoQw7O
L9zn0rwuHX3IwewvYf2XtqajDzlQ7RA7k3wqHX3IgeNBX5kkh3T0IQdWywum
7Q9LRx9yEOR7K+FSSjr6kAOdD6dMJJ+kow85cLoyeWPw83T0IQcuz9cFH/qd
jj7kILrqtZK5aAb6kIO4Ze8m75DOQB9y8Lbu1ch5/Qz0IQchwcJ7pWZkoA85
iIhMz39jkoE+6D79Gfyt1zLQhxx8/Vsu/iIkA33QPYRzmn+EZaAP+vKUqPtj
sjLQhxzY/8iktFsy0IccHDOf9HWhfCb6kIP54Uu2iQtnog854FsNl6W1MtGH
HEh83Pyg1yATfcjBkvMjvxNXZqIPOdATKlMxPJWJPuTgs8gDydlXMtGHHOif
GNPu4ZeJPuSgMGCw+vfTTPQhBxnqYkW1zzLRhxycqIz6UPE7E33IwbZLoQ51
CrfQBz1eGZFmsSm30Ae9/uo2yYcev4U+5GDStdEPUNxCH3Lw+9DXi5fcbqEP
Ofi2LG+g/8Et9CEH1xc3fC1svoU+5EBr6aPBP4O3mPH3y4JPQrSFme5t6uzo
eNtk4bZulZHawdvU0dHxfZcFX76ipHXWt6k9o+Opk4WXr52XV9+8TY0+nF+v
ZMFkavuEvoLbzP09lIVTn3ceXPX7NnN8KpcF786JNkVSd5i+ubKQELVW1nfB
HaZnmiw07Txvtcr0DqU92i9WFobum98+s+UOpTjaK1gWnAKmbvluf4cSH+3j
LQueesor9VLuUCOj/5xkQdp4Y9X9ijvM/NvQjyejJLH18R2qZXSAlrJAFWjO
pv7cYeb3ID3+QmFjG/67zHyaycL6kmMdz+bdpZ6Ozt8GWbiRrbjv6ta7FHf0
BlfIQtaaaWrGa+9ShaMLbIEs5NxqiWpxukvdHn3A02WhyqpD/kfYXWr05t6O
k4WZLgUGx1LvMutPXRZu3RxIabl3l1lvsrIQPPry0JO7zPoSloU7TxfpXxu6
iz1kwG+ZqkU1fxb2kIEVIZFLX0pkYQ8Z+PNNXzpHMwt7yID1kErvt0lZ2EMG
bvo8nuZjmIU9ZMDxzQTD6sVZ2EMGcrM2HLm+Lgt7yMC0duecyWZZ2EMGUmfm
8z06koU9ZCBr+EKasWUW9pCByKc5VQ93Z2EPGahJmH77i2MW9pAB4Rzf6RNc
srCHDBzk+7LyWmgW9pCBdz9NBG7FZWEPGXjslm4rkJmFPWRgafO4RcolWdhD
BsSMp15Qqs3CHjJA/bL5fulpFvaQgXbT1Ru+1mdhDxmY/yxUdFVTFvaQAT3x
6QMaf7Owhwwk2YXkb2zPwh4yEHEh5e7MvizsIQPT05Q+H1DKxh7S4JW69k63
ZDb2kIYCFe5uuQnZ2EMaCk/OMpyklo09pGFXu5lCy+xs7CENvwMnjayblY09
pMG+Kkrn7MZs7CENCe8kIkN3ZmMPaeibKt4VQW8zPaRhm2nVd5X92dhDGk4t
VqgJuZCNPaTh4vZ4FVfPbOwhDZqLpt07cyMbe0hDDLxQnBKUjT2kYd2XN8/G
RGRjD2mQqK3/onk3G3tIw+i7x1nJ2dhDGo7njP8WVJKNPaRBakGbLB83G3tI
g+H9LeHLH2RjD2m49uV9zYyH2dhDGrRPlDTbvMnGHtLw4e7i+kuN2dhDGvg1
LT+M+ZuNPaRhR2rnEsWubOwhDQv9anx2jLA9pKDzSmB7g2gO9pCCPdrrh89J
5WAPKYj+d3jBSpUc7CEFgmNP1C2bmIM9pMC2O0T05+Qc7CEFt/Mc0sbNy8Ee
UqCW2Gc6fWUO9pCCtSXbH9isyMEeUlC1fWlG5oYc7CEFF6/5/ZMxz8EeUrDt
6OSkj/Q204Mej6vUtTHWOdhDCtrtkiUHPHOwhxR+HyMHe0iBW2nuxY/uOdhD
Ck7uVnunHpKDPaQgt2Gf1/XAHOwhBfaHTX3TInOwhxRopqQWCafmYA8paLw3
r7PrQQ72kIJpxTOkhopysIcUZBTXHUi7l4M9pODnpOXjm2tysIcU5Ldl6im9
y8EeUnAoLuWlDn0500MSXukV5Up0sz0kYenJm8undbM9JEEulpCeP2wPSaiq
3vTsm0gu9pAEvZP3J/Xy52IPSdhhNT1vsnQu9pCE/Enzl3E0c7GHJDxp+zlQ
op2LPSRBQCRo2rnpudhDEnyvzImeNT8Xe0jCtuTjnJeGudhDEupF/xtQWZGL
PSRhjqipteDmXOofr4ckvNO0nPvhQC72kIRjQTkDq7blYg9JOLfG9cmdk7nY
QxJIFddx+pFc5vi7gR6fU+CGcPtc7CEJxqc75d465GIPSVA3TkxzdMvFHpIw
5u6t92cDc7GHJPy2VW2ICsmlwnk9JOHM1eJJu8JzsYckFAncXXwVcrGHJPgv
IGV78nKxhwTkNNnkdlXmMs8/2iQg9rrNgVb6cqaHBAx/BLuDD3KxhwRM3NVo
rvOA7SEBW8SbBKY25lJreD0koNh09AsjbA8JcPstotn8i+0hAd/6q+ftGmZ7
SMClO8ESL9pymedjsRJQtHDRVl/BPOwhAXsdPVx6JfKwhwT4xM8MSlPNwx4S
IHFp0/1TinnYQwIuzI8QaJqShz0kYFSLhkEe9pCAy7dDNH5Ny8MeErDhmMhi
2QV52EMC/hr/9jfZloc96Men5LtbZHke9pCAmDkWK3dtzcMe9O1PszTZbpZH
JfJ6SMA12bU5iQfzsIcE1BFpH9VjedhDAiwSKzS5l/OwhwTcjpd5OdY5D3uI
g2a4y1nKPQ97iMNW/tE9Qh72EMf34/Kwhzjcihh9AzMPe4hDscPZSuuUPOwh
DsOlhta1N/Owhzisd9z1Ib04D3uIw2p508Lcu3nYQxzGcyVSt1TlYQ9xOBKv
Wz2hmu0hDs6HX8Q+rWF7iMN3i1WcxjdsD/r2lt4w2PGN7SEOPzZtX/PoG9tD
HAambAt82c72oG9PUULeSiwfe4hDRt3oB77ZHuKg/8zUrEk+H3uI4+cf87GH
OBh2PgtoU8vHHuJQFFh5UGZSPvYQh7V3okz3Tc3HHuJwNPPpZP6Z+diDvv+h
B77yVD72EIcDeWP/27MiH3uIgfGB5w/l9uRjDzG4s2Uk79aOfOwhBiuf+U/x
NsvHHmKQ0zlv3mLTfOwhBnfVX+xQOpqPPcTAZix322zLfOwhBr/cvpxuPZKP
PcTgyWTjinEX8rGHGIypP7xq6Fo+9hAD7UmfZwm452MPMZgeOVnsUng+9hAD
8xx3BwjLxx5iILY0antcZj72EIPic9f7ihPysYcYbJzcN/ZXST72EANL+8j6
5Fy2hxi8dJLdV5qXjz3E4BBlf6ntMdtDDNTSlzdavGN7iAHfFEnl6pdsDzH4
cLrss10T20MMnr3zWPa1ie0hBo/nbibbm9keYhBZMevJjWa2hxiMf6D7qmSQ
7SEKk/6YGRt3sz1EYWzY3yMTRQuwhyjcnFVrZC5fgD1EoWP3nXG5nALsIQoW
mXXbd00owB6i0Cn92WudYgH2EIXZTqG9f+YWYA/6+gVT/3FnFWAPUTg73zZj
1ooC7CEKMWPis78ZF2APUeifrarYbVSAPURhseTMjQ9NC7CHKNiNrXa+vr8A
e4hCe4FtzrIDBdhDFPz5Hr9IOF6APUTh18pna2LOFmAPUfh2TLFU/lwB9hCF
yHdvlW84FGAPUbiTV3sw1LMAe4jCRNl+r03uBdhDFJ5PkNw0O6gAe4iClo16
kkZUAfYQBc0+1WitiALsIYrfDytgPg8gLAqLDpgF3bxVwHweo18EPsyPjtXK
KMAeIhB4eYK/QmkBc776XQRO/JH/j3pYwJyf1onAsn3DfadeFzDno69EINjJ
doltVQHz/tdDEbCM7vD1/VbAnP+Xi8BLPj3/cT8KmM9H5IrAM/3DfemfC5jP
Q6SJgNcMxdVG9WwPERCfrbBmZ18Bc/4eLAJZQqaH3nYXMOfr3iLQOvr2i3gh
c37uTF9uMmZomWAh83qujQiITNY2WcNfyJx/W4qA4skv0velC5nPixwUgfjR
t9s1CpnPh5iJQIyCXJCVbiH2EAGBo1vvtE0vZM6fV4jAW07Zq7HzCpnXLxaI
wPT8hZMnzS1kXq+YLgKRiYWvZ64oZF6fGCcCfOcGu+6aFOLzKxHwc/EwCjMq
ZD6vISsCS7xiJl/YV4g9ROD1no7pzw4XYg9hOPx0ieCcPYXYQxiclRfbLDtd
iD2EIffxVN0TLoXYQxj0c1bMm2tTiD2EwS48Sum6WyH2EIZS8xMVrfQ200MY
YlRUE2MjCrGHMCRN4fepvFaIPYTh3PoZY04GFGIPYTD0i5oaHFqIPYShulLC
/F52IfYQBv8wJ8OPeWwPYfhu7p35pILtIQxH5U4clSpnewjD56n7l+g9Y3sI
wz3x9j8CT9gewvBC+Cu/5gO2hzBMzB4JafvE9hCGSWNzht1r2B7CUGfSY87/
me0hDD8Hnyw83s/2EIbFD51/d/1lewjD7bbRJ+RsD2FI++ucMDTM9hCGR025
HtFiRdhDCEJXH1RdLVuEPYTAaaNDq5JqEfYQgu5G+ydj9IuwhxDMWePf2mNQ
hD2EwPcRt8BvYhE+3xWCDeoL4lOmFmEPIRBIW+ocP78IewjBxkbRFdKLirCH
EFgZU0tS1xVhDyGwa7j8ftrGIuwhBA6mLn8nbi3CHkLgqrwhIfxgEfYQgj35
lit2Hy7CHkJw3dBeZ75ZEfYQgs3R89PvHS3CHkLQuDWl+t+VIuwhBLKHpEym
eBRhDyEoX+8lOMu9CHsIgfDWZ7dSnIuwhxD8vd+dvDe0CHsIwYP6/+KLvIqw
hxD85ib39roVYQ8hCNR3WW8cVYQ9hGCxh7zUzLQi7EHff+a1zcblbA9BWNGi
uXRcAdtDELRNs2u7stgeglCb67Dx5D22hyBkTd9rm/6Q7SEI27ZbjAl9xvYQ
hNBpV3cff8v2EITWYgE4/oHtIQhdCZIte76zPQQh85bCq23/2B6C8N06qHx9
E9tDECY09jh7/2N7CMIV+4dunULF2EMQTHaf4aSJF2MPQbjxR273SbVi7CEI
GndrZD6IFGMPQbDf8JebP74YewiC3bH6yBdKxdhDEAJPHZF+NrUYewjCdsuD
Kh8WFmMPQfDVXf+f3Ppi7CEIJVtD5M/TlzM9BOGjyLp+2VXF2EMQHGv9FV1W
F2MPQRBwfBjC2VuMPQTBz9W889+eYuwhAPUPNTOsdxRjDwGwf7n2wpQLxdhD
AHLLRN4lHijGHgIQXqMRbE9vMz0E4Pp2V4NCh2LsIQCtr29KHj9djD0EQK/4
3sRZ1sXYQwCsazccHkPfPtNDANrVLuVVORZjDwG4vVGssiS0GHsIgO69C5ZN
EcXYQwAaN57e353A9hCAiuqVV9bGFuP5uQCscT3b1XOb7SEAQms62vrK2B4C
0HGwO+dPHttDACYJRj1PJ8XM5wk3CEDOpKe7t71hewjAoaH+y61P2B4CkMp9
NHHbU7aHACjtdljV/oLtIQAC+nu58xrZHgJgt1iq52Mz20MAnz+xPQQgOXS5
nMMg24Mffl5bMfFCB9uDH6La5X0ahEqwBz+YqO/u3a5Ugj344bz3ja8dnBLs
wQ+U1aIzMeNLsAc/qH2u6rPWLMEe/FAxTl3v09gS7MEPpGe+xV3DEuzBD06n
AjntU0uwBz+o/9IMr9MrwR78cHDiMsH4ZSXYgx+yPJdRMUtKsAc/KFtdWDSX
3mZ68ENrWu1x6+Ul2IMfYqMTipo2lmAPfhCwCJ4+ZFyCPfjBZcmBe3bnS7AH
P3jEqBmJnC3BHvzQF+raYmBVgj344YLRyYQj9PWZHvwwcdpimWceJdiDH27o
HBm+eKUEe/CDdsXi5kfOJdiDH06njr4AW4I9+EGw7MBTD/8S7MEHJjuXlr5N
LsEefNBZbpN3IJztwQf1mfG5KllsDz5IafpP+0km24MPbrYfswh7wvbgg+ht
c2qHn7M96NtbOk5eg8v24APPluXRjVVsDz6Ys/rJgdo3bA8++PujeErXK7YH
H/j9uLHLpIHtwQeXLDMWcJrZHnzQfs78MnSwPfjA4vuZy4Gf2R588E5f4LCj
YCn24INNM0c/IMb2oB9/yjHZPIFS7MEH45T2LH+tUIo9+KB/guc/Z51S7MEH
+R493FjNUuzBB8HK997wy5ViDz6Y+WqM8GbdUuzBBwGRmna7x5ViDz5YLfW5
ula/FHvwgRDv95lKmf1t1wjJbT9wvd6wlHl+/mWEHBIY/UWjUmZ/WjVCgvZH
Ol4yx/EUjRARqfnui0zw/pNGiN/YBw9UjUqZ59d+I6Rcz2Druq2lzPmN/Qj5
u2D0BcxSpu+xEXL+1vfgj/Tf83qajBAtn4cDk86UMucrS0fIWsc//xqsS5nz
E70RclPohOXPi6VMH6URUvuie+XDE6VMD74R8upVRuiF4FLmfOPXMHFebvu3
MbGUOb94O0w2LVTenxSF81s5TByfnX/fHI3zeYe+vmt3S1NCKfP54ohhMqer
ZPWBW6XM+Zr7MCnvM4ufdLeUWa9Ww0T44N6nGpmlzPo0HyYJ+xb1WJSWMs8v
1w6Tv/VvDi5+Xsqcb80eJmM3RJXeLCtl1pvOMPmmb0bNe1zKrC+JYRI+/cRM
7U+lzHrqGiIb1Ou/z/rA9hgisX0GtYE/2R5DZMqK1QYnfrA9hsi6Sz3y4m1s
jyGy0Krc3L4F+/sNEbuAre5bWtkeQ2SplGnInhG2xxBZu6C6Yp9IGfYYIkkL
zRbuki1jPC0dIneOvj1krlKGPYZI7fLiR+H0NtNjiFzmFx3mH1OGPYYI8/yu
jPHwa5A03iwdDKcvZ3oMkknDei1VS8uwxyDxvbDltd3sMuwxSIY6FNUG15Yx
6zlikBxvnTlUOL8MewwS5vdmyrDHIDG397shYlyGPQbJHvH6Ced2lDH7h7WD
5KJ2xuTHi8qwxyBZcU5+suqFMuwxSOyttLQHT5Rhj0FyLO7UWXPLMuwxQKQV
foubW5RhjwGipnDdesb1MuwxQIzkeqX3RpZhjwEy0Ko1QcKrjHk9M2mA9L6e
u64xqgx7DBDH1I3Xs8LKsMcA8an5r5BL/z3TY4A0PRIMWB3J9hgg9zdX5yQH
sj3o+/f8OdM5le0xQNzbLJq88tkeA0ShZ2jZvjy2xwBZf0Bt+9Qitkc/WZcY
ZjKtkO3RT6zHSjZufMT26Ce/Hg8mna1me/STvc0p5Vqv2B795KjWuPfjatge
/SR5jN1lh7dsj37ywLbcb7iD7dFP7lV5aZ0aYHv0k0TRpg1Fg2yPfrJsTufX
SIFy7NFPCnO3ub4ZYnv0E/Oe+OxlwuXYo49s/5VbPEa+HHv0EbeC5YHDguXY
o48Mjf78kU459ugjfft8hy6OK8cefaQj+4Bn7Yxy7NFHzKN93C9PLccefaTA
ZPQLveXYo4+sGZN2ZP3ccuzRR/IufnT/vqgce/SRUINrJ0I2l2OPPvIh561K
35Zy7NFHFt24b6Wxthx79JH/Rj+us7Ece/SS2Owajsj+cuzRS+4dc5bMOVqO
PXpJ9+GgQS/6cqZHLznu0WzZ7laOPXrJ/dGvA9mUY49eklBX0GriVI49eklv
bu5KM8dy7NFL3q9+JchxLccevWTePTN31Rvl2KOX9Cs/OLfYj+3RS052rltg
mFyOPXqJ6QVFy5vRbI8ektGa8DMgk+3RQ6bdtgn/lsD26CEX6tcfXXaL7dFD
rHenKofcY3v0kJRkz4Q3j9kePaSl22jhJmB79JCsGY827HzF9ughIbuet67+
j+3RQ0gZ30BzDdujh9y/fIm/+xXbo4dYtvZGdT1ne/QQkxkxDnn1bI8ecq9w
e/66FrZHNyk0T+Tk/GF7dJO/aQ53+NrYHt2kirTL6YpXYI9uoup/KydliO3R
TX4an3WarlGBPbqJx5bWzsnyFdijmzx/96Vvx9wK7NFN2iVu1H3lr8Ae3cSX
GN1zm1aBPbqJQvsYz2q9CuzRTc6H1F/do1+BPbrJ9xtGEzymV2CPLsLdNNAz
ZWUF9uginzJ+bdm4rgJ7dJGMnm2bHNZXYI8usnfR9yWH91dgjy4Sfl498O+K
Cjyed5H3z2b+x6Wvz/ToIidfaNb37KvAHl2kbfbrQyG2Fdiji8wNaAq/6FCB
PbqIt1V9g5NNBfboIptLR79gV4E9uohTtP3fTV4V2KOLLKafbQvQlzM9/pFT
VwZTVjtWYI9/5OTSt6ZRQRXY4x9pfVcx71UM2+MfeT1J0GS5XwX2+Ed+lHwy
i8pne/wj48OS30pmsD3+kfsmaXsFUtke/4i9+d1VA7lsj3/k0YYh1cOlbI9/
RHfSBrVnT9ge/8gd6rV5UTnbgx7frKbTKW/ZHp3k/qvtJaXP2R6dZLq7ye7H
79genWTGJt1Bgx9sj04yuJqcav/E9ugkDrzP97A9OknL6Ncnm9genSRdwszk
WTfbo5M8cbi+9KQAwR6d5OQ8v3sHhtkenURfzXhtqwTBHp1EUVLXZ5U0wR6d
RPeCzal0PYI9OgnzeX+CPTrIaU5HaCaHYI8OwvyeKcEeHYT6mHd4zhKCPToI
83kigj06yCmRvcebVxHs0UEuvtaSPWVMsEcHyTcar7mLvj7To4NMmxXy3mED
wR4d5HuKyXyRrQR7dJBPG0KTL5sS7NFBfo4f/cEagj06SMnFnWHiNgR7tJN6
G+dzJRcJ9mgnj05uKtamL2d6tJNb8llSB5wJ9mgnmf/OeH65QrBHO5nQXLNI
hb6c6dFOfjXUmHACCfZoJ3M+aYn7BRDs0U4065f/3pDA9mgnP9vHNF6PItij
nSyxLNxrcYft0U70HB9MWX+H7dFOTpeHfLyVxfZoJ5YfDSSuPmR7tBFZ3/p/
2jlsjzbSOfp19iy2RxtpWb588u5itkcbKZy1xOT0U7ZHG7FwfDJzVx3bo43Y
Sgh+/vmJ7dFGFnjfmhv8ge3RRpwMnQfaGtkebSQ52PKo9k+2RxvZNPpy4G+2
RxuZK97gv0YYsEcbCd6/pW3fCMHn663EIscpVkQKmNf7K1uJ6q7L26Tpbd7r
9xGtpFDR+YOgGDDvr1u1koOnfWLaFIB5v2NtK9llEHqjQRmY9791WsmXMZZm
s+SBeT+i6y/ZMUPD960qYN+/JEfrrc0+dcCef8mKMKtmfR3Afn9J/MuEyocq
wLy/YvKXrNx38tN8+vpMn78kaXOXzZQpwLz/MfKHbM8f/QIE4Pz/IZrGOzUP
TwLm/Yk7f8jkrSovWqYDzu8fImJswz9jNjDv55j/IU62X8p3LQScvz8k0FvO
on8eMO+3SPwh1z4ErO6aCbhef5OcBsEXasuBeT+k6DcRWzSiOWYp4Hr8TbYJ
BV0cNgLm/aNjv8ni/aNf6AU8v/pNrCeNLjDA9fWbXKznezdhM2CPX2RIpC79
LL0NvB6/iP6ukkl5JmyPX8Rontkz61WA6+MX0VYffUeZ7fGLKFQfkTtxFCgt
Xo9fZMwlnzDFXWyPFsJ8fpjt0UK+6q5QuHUA8PylhTDfT2B7tJDP9U8UYujb
28Lr0UKEbxr6l1mzPVpI1t65U55aAvpoId/fRz0XusT2+EmKAnJWV58B6hav
x0/SGBtTyWfH9vhJgsaY87vbA67vn2T6hrawA1fZHj9J6Z7h5mUOQInxevwk
l5cYWj66xvZoJulW+w95+gDuL5rJDs4uiUAvtkcz+di5pqc8DKgjvB7NxCZB
sG6pN9ujmVi9CP+rEcH2aCYPZV4UZgSwPX6Q+hH5MP0ktscPIjHGctAulu3x
g9RsDrqgF8v2+EG+fwfVpxFsjx/kRVLjyI00tscPclLk5j+BRLbHdzKO9wEa
tsd3cmCz+7UtBcC8n5b0nRxTs3W1uA2UHW+A3wlnfd7X9jy2x3eS+Sn0/UzC
9vhOdr73OmeUx/b4TqZdt0s4y2V7fCMzw8mK70/YHt/I2VnCD7YD2+Mb6Qr+
Hh/yH9vjG2mcR0R+Pmd7fCMhJvDqZw3b4xupFb/3seEx2+MrCV7aS118xvb4
SkY1nKpme3wlanF71e/WsD2+kmN+mb9V6tgeX0lO8vz5/F/YHl+JaE+x/1Aj
26OJdLhuOlz7ne3RRJ5cyg+UamV7NJHeCy+d3/xmezSRUy1Lpgy3sj2ayKqx
43bM7WF7NBEzXe8zh/6wPRpJaNN+5eJ2tkcjESuUo3b3sD0ayfwPpVskhLjY
o5E87fFZZUFvMz0aycyjixeJ83GxRyNxXVl8RXKQ7dFIhvfd3T5Jios9vpB2
pfMpscJc7PGF+K0fMPCht5keX0jCDs9AJy0u9vhCLB9NFzXQ5GKPL2RZyDV5
OxUu9vhCnr+Jv7RejYs9PpOgfrOBz7pc7PGZdF3dbN0xlos9PpOa9C/yT+nb
Z3p8JlZz5k2ZOIGLPT6TlrqkP5v0udjjM/lx+fjJR9O5VA1v/J9IYs2+VR9n
ciln3ng/EQWTDQ18s7mUAW98n4jUhUBTmznseBqIrGFDV9MyLuXDu/8GYiDo
9l8YxaUW8O6vgbQMlGhPXcGlmnm964muUfCtS6u42LeePL7ns8htMZdaxetZ
T4ziBlRvG3GpNt6E15ExZ9Oe79rOpeJ5vepI/bkazZHNbJ86MiO72adhPxd7
1BHv09H7rHey8/+RVBq2/Xiyg0vt5M33R6I7cu74033s/H4kA/eNXVTM2fn8
QGzPzF2z5hA7fx9IffVJo7rDXEqON18fSFuAnuyxM1xcr++Jte7qrdNOc3F9
vidaYo8FJlpxcT2+J42G5y2r6csf8dbfO6L/wrU09yK73t4Rx79CA3et2fX1
jujc2q0v6cL2eEu0JOJuu7qyPd6Sx7vevZZxYnu8JYe7El/ZObI9akn9urhs
70C2Ry35e/fe0sXubI9a8sjwdN8ff7bHG+L89vjz/mC2xxvSaRExEBnF9nhD
jI7WPBgbxvaoIR0Vn6/JJnLx+FJDdKfe+Xya/nsz3gTWkB+jPzcUz6WEeT1q
SLG90J/79O3l8nq8JlLzNI4m3uZSB3k9XpOdGjHhkelcSpbX4zXZ6Gf+R5W+
/XJej2qyvnpu0NkCLmXJ61FN/ovf+0K3hEtp8HpUk/16BxarZdPzy+vxihxP
z2z3Ai51kdfjFVH0MBfSzeNS43k9XpGrbWaFBlwuVc3r8ZLcXPpE3/QZPb+8
Hi+J6T94eOA/LjWd1+Ml6XK59vXlQ3p98Mb/goxrm/bdh76+Em+8L8iRzkmf
fUvp/rzxPSdmBx617HjBpap443lGGj61rFeu5VKTeff/jER8iQzNreZS7rz7
qyJDKjHT8hu4VCOv91OSPhxdn/+JSxny+j4lF/Y/P2XWzKUieT2fkH1HFSIf
13Gpbl6/x4T5PVYuZcrr9ZiE7LVfzf+bS93h9XlETqg1Wczu5FISvB6PSP6e
iTqZrVzqGG/+H5K1bxcHunRwqUrefD8gghJd/+R7uRSHN78PCCfr4JKFfVzK
gTef/5G40cN9P5d6y5u/+yRhnrDvvyEuNZs3X/eJodfW6F38lZQfb73eI3ok
/nP5MJf6xVuflaT/rJJsg3QlZcRbj5XkvcLoD2pVUsm89ccl4w1mtidKVFJ8
vDcYgOzzesM5qFZJmfPWF5DQu1bz9bUrKSve+AlZuCZnbZp6JaXHG28F2ZB6
1ydnXCX1hTe+MsL73x1oVlKRvPGUki3Df7XnTqykTHn3X0Le0Gcfv2ZUUhK8
+ysiAsJ6ZpXjK6lKXu9Ckj+7PXferErKnte3gDR/k8znn11Jzeb1zCfyT4/J
rNOvpH7z+uWSkLRnf53m0Y+H1yuHDAh6D0kY0uPn9ckmC/+pyLYurKSUeD2y
iNFYv8V8SyupcN783iYXDLqL566qpMR4b/BkEAX7tW9DjSspO97jTyOTFNod
lq2upJp56yuFbJi496flhkpqJ2+9JJFtP0zandZWUlW8/vEks9XM3HZTJeXM
fCGHTC64mjphRyV1gPlBGTLd+55h6u5KahnzhRxy6eYGh+A99DbvBfxrRAWC
XQTpy/nGjD7gK+THPI+UicfobdXRCT9COOnqt4cP09sKvG3qWvHIuOn03zvz
TiCuUDa1e/3sLOjLeX2vUYHbC/LIzkoqnrd+A6iZnXb587dWUsB8QYjS8RZw
HLu5kvrMe0IfTTmudxsca1ZJXWYeD3Vtja3cYvr6YszjpW5tUmvoph9fODMf
1I7Rr5fS86XHzBc1b/hn5pZ1lVQRb/1lUGWZ9y5G0/NjxMw39fpO75K5Gyup
d7zzj7uUBdc+cMqySmoO04tKLXEOU6d7XmZ6UhpNOqnvplVS95nelEH++u1O
kyspKWY9UNHdC5vi6e1tzHqhXogqH/s1pZKKZtYTtWKDXa/uhEqqkbc/LaLS
sm73F9LrUY9Zj9TbvOV113Xo9c2sVwqOKU38waHHz6xnSjZyb88Oen3yMeud
OrNq+SIPefrxMB6oZesmbihXpLcZL1Rh3ebLlir0+uTdH1CdKqMnhJWUP+ON
ahyY9vkuff05jEdq68+qxpO0x3eMV+qNXFZ2Kn39y4xnamSBiHi3UCXFYbxT
+zxGLggK016Y/QH1Q1b1yWvBSuoYs7+gSj52VSvR+wMJZn9CRYCYze8Bev/E
7G8oi6z0zjR6f2PK7I+ownSrEk16/9LN6/GQEu0df+wWvT+LZPZnVEPc8r5z
LfT+kdnfUV+OF7ZfbaIfB7M/pOJm5372o6/vwewvqZlLli23/sGlpjD7U0ph
7IuvJp+51HNmf0s9HjQq2E///Xlmf0zxfVKY8OAtl1Jh9tdUmdHgt7/PuVQJ
sz+nHpALI0P09j5mf0/dHFg/04TeFmCOB9TF+E7CT+/fU5njBVUm4vjzD308
mMAcT6heU7uXv+nj10XmeENlepeMOVXJpR4yxyMq8dXoB6C4lDpzvKJemezs
1C+nj3/M8Yza1TOnyobQx0fmeEe9y1D0KKQvl2WOh9R5R5nG4tHjK3O8pK7P
e1i8sYg+/jLHU8rjCQk1u0Mfn5njLTV5p1fuwyz6+M0cj6nYlrmNZ/K5VDpz
vKbmtFje7InlUgO8Hq8pE8tI22j6+LyROd5TD+8vj9lIb8cxzweoB7Ge4++n
/q+o846n6v0DeNl7u9e9F7eotFNpj+dTtIdIe2gppZSRSPam7L1nStl7S8O3
RWlvCk1CKJX6XZ3POb8/z+tyx3nfN8/zfNYV0kOtF8iZ3rwNFrFXiD61niDH
xfW09gnWCxHUeoPss/7jdldw/Z5aj5DtCUs+LBOsX+ZR6xUyYrF9Z7P3FRJA
rWfI8n3u3BrBeuYVtd4himXDDWWukGnUeohcPnEi8I3g2o1aL5FjR3mffQTr
owfUeorIbR3ve8Kd5vGUqBWYqo90o3k8Jbb/+jXSPJ4SKj+E5vGMdEy197l1
kubxjBhJTE3e60jzeEZ25TwbK2pF83hOumeYn+s4RvN4Tmr9l7pNMaN5PCdC
L33YSbtoHi/It7LdfgOHaB4viPvgyZ7/DtM8XhCnc5aNzaY0jxdE5IijaOFG
msdLIjlLP2v8bprHS2KywmlljhHN4yUZnDBz9cJlNI9XZOGCpkApY5rHK9Jn
PXPO/KU0j1fkW+CPivxlNI/XpK+oYOaCJTSP10RB9OmXzgU0j9dkipDEteAl
NI835J6ugqmbPs3jDfnXrnQhzeMNmWraG1sg2H8oUfsR4kqW+ystZvYrhHfJ
wzpkOrOfIY0tX9mFY+n1bQuRKVqQrjbqCimh9kNEJ17nAwiuX1P7JRI53F6J
w+ynSFtf7NXto+n1cyu5U7ezo0npCtlO7ccIO29qma5g/+RO7dfItOubzN6o
Mvs5InU930+HRa/PW4nKwolpswXXf/7xaCVzTWevURbsF8dR+0VSci5Waq0Q
s58k9b9VZ2wRY/abZOuf0amLhK/Q+1Fy6LExPP9bR25R+1XSPRwOGmL2syTM
Qzt0xjdmv0v+HYd+Y/bD5NXbSbdHC64tqf0yuTttXrp4H7OfJi/FjyxN72b2
26TVKq5i4XtmP066v3neOvCqDnm0EZtnH+KT3jL7eaLvI8Xf0cLs98lGr/5Z
bk/rkEcb2fpKr0H4RR3yaCMNPR8+Jwr2/xSPNvIoxe+gSRNz3kASxjlZWD2p
Qx7thKovqEMe7WTDzo8KYbfrkEc7Gde9SKn9CnPeQVZP+DAQeqOOPKLOQ0jr
hpw3QrV1yKOddPzR+zvYUEd0qPMUUh4i+9egjjlvIYuvtteHVjHnMeQSq2HO
rbw6kkKd1xBzwe5ofwHNo4O8KuJkjs4S/B+lznuI5ds2Z59U5jyIFFScrjAV
PL6MOi8isQbVLQ/iaR7vCavrfIZwWh2Jos6bCBXPZs6jSNiSVS9rBM/3kTqv
ItGXTptsiaF5fCADMYWL26PryALqvItEzLEju8KY8zDSrWAReeJcHTlHnZeR
HB3Tk35BNI8PxO3TNf/a0DryhjpvI6teh69TOcOcxxEt56KuR051ZDp1Xkek
ah82xfnTPD6SiDdbxQIc6ogHdd5Hdm3wdNA7zZwHkmgyfIBB8/hI3maySqSt
aR4fyYVbwwcsNI9PJErurDX/OHMeSWRG/NRabltHHKjzSvJtv/s9XQv6vOYT
2fkvvkbz+ESkhjLtWvfRPD6RHDHrWMNDzHkpOdC71+joHprHZ3Jf+NrN1E00
j8+k48AihaJdNI/PZM9wO1Qj5ryWXLbYtv/kBprHZyIcuD7TewXN4wt5H//x
+MZ1NI8vxFn+wsqmxTSPLySuQyPzw0qaxxeyQSjOpnstzeMLaZn7ZvFeQvP4
Qir+lG29vJDm0UmUIwryS+fRPDqJevOFupuzaR6dpH/aKjP/eTSPTnIp8Mq0
2Pk0j06SlTRH9aIuzaOTfJ1pf1FrHM2jk2QfypatmEDz6CK9ef35OuNoHl1k
58/W6eu0aB5dRPvW3XF22jSPLkKN76N5dJE6ezHZIWWaRxf5bhkt+0Se5vGV
mNa5uYyQoHl8JU7V+ZvTZGkeX4n3z0yzYimax1di9aMrWVuY5vGViMTWnPMY
SfP4SrY8+b1R9E8tnu93k51rnY6ICdXR8RIy9YH/rdYuJp5CHm35veb7m1r8
e9lNilyHB8TVYvygm3wzmawd287Ea4jC0TUPNr9g4jlE7M+abONHtfj3tJus
SXjxRu9pLcYnuonmWLMl7KtMvIh8jdtsNr+JiScR9caU/LgaOl7TTWxZRpaz
82sx/tFNXGPCdYqrmHgVWW9wYEj6IhPPIlS/yFr8e9xDdn4O8CyJr8X4Sg9R
nHL15grBNRWv6CE5fKMtU5KYeBpZvE59WlgUE28jpiPusaen1iLPHhJQwtkV
HlSL8ZAe0vX1aNDrE0w8j3Torp8x3o+J95HUo66+V31r8f9TD7mi7SWbZU7z
6CXSB9de4R5i4olkdKeLa/ERJt5IrBboTV6+i+bRS5743e6RMqB59BL7WdMW
bdjFxDNJrkyW7Pr/xzsJT4abZLmM5tFLPs347Hh1Js2jl5TIrjwkOomJp5Iz
W8v3jtVl4q0krCPo8DEuzaOXuN/ef/e/UTSPXlLabFGYr8TEc8ndVwkW61WY
eC+puXPwWqUSzeMbmZs1dQF/sAZ5fCOSPaGrtvxk4slkVvK85bIjaR7fSP35
xrS3f5l4NLkZcZrl2VuDPL4Rcd26mG/va5CH4PWSJ67hvGLi3eS8a9HfkY+Z
eDjJv3kyx+N1DfL4RqKn/Nlh+agGefSRUYdvqzTeZOLtJM8zXVSzkYnHkz0n
rA/4C36f4tFHFF+GHlx0owZ59JH9jU8XFt5k4v2kMDmgdVkFkw9AgiqNW3Iu
1CCPPuI0Zuwimewa5NFHjinEf1SJZfINiM7SZ6sTU5h8BKLbdYn9waUGefSR
SPgqWEHXII8+IlYppqXryOQ7ELmvHovmODP5EMRmtn3FesE1xaOfxCRukg6x
p3n0E35ycvm3w0y+BZme8uqMsw2Tj0Gu5B9qMjvC5GuQ66s2FARspXn0E+u1
lYuyV9A8+kla5XM4sYbJByEXDu/dc8iEyRchpo7SwbKraB79pNnWbsbc1TSP
AfL5Kv/Tu+VMPgrZtNdp3ajZTL4KMZmaGHCPQ/MYILW74ma8HEvzGCDnVn8S
0ft/PgwxCLIZmKDF5MuQUy3fb7HlaR4DpOfBLue1CjQPwfOrjTD8+4fJxyGi
w8vlfiZfh5iNni8SKELzGCArk6X1Po6geQyQV+cMlXYOMPlApNrxRebiz0y+
ENGVnjPR7XU18vhO/CWP/GA9rkYe30lu4Y1l25uYfCTSNVOjO/chk69EpFVk
lj58Wo08vpMlbe9ujnlWjTy+E/J4qcuWimrk8Z04PY/Syq1m8qWI2YVp3W71
TD4VWUp+9H8oqEYe38lO1V7jXzXVyOMHSeW2G0pdZPK1yHvZDjPhJCafiyzV
lObl+lcjjx+kb65MR25wNfL4QU5MUus+d4bJFyNpR7Jemf0/n4w861BwT3Kv
Rh4/SNMdd1JwvBp5/CD+c5demnuayVcjQnZj1lnbMfls5ODs/8ZoH6pGHj9I
Nb/UdPG2auTxg9Te+tx87//5ckTx7fFRN42YfDpScmjBmllbaR6DJJ2j2wlL
aR6DZMdKXqrZXCZfjywriTbYp8Pk85Ge1s74K/NpHoNk1s/JExdNpXkMkpq5
a4NG6tE8Bolf45P7r7hMPiE52fvU65Eck29IukbxOneNp3kMkv/aNHeuUaJ5
/CT14mb3apWZfEaS2t9tlipB8/hJZlu7v3CRpHn8JOwF9wbfjKB5/CTvDif+
N/czk09JHEpSx09qZfItyfcxefPEm6qQx09iN8fw5H93q5DHT6KSP+WCSguT
z0kkGyY7Kj1l8j2JZH7g4iXVVcjjJ/mUMvwPsQp5/CQ1bsq8Rf8x+aRkkd/+
sohyJt+UnF/zN9TkfBXy+EVi23/vNomvQh6/SHTJzd7a80w+K9EsU0nRimby
XUnS+769+wTXFI9fRCk85LD2uSrk8Yu4LJ+557lbFfL4RfT0hhvaMfm2ROVR
SdVdOyYflxj897As1L4KefwivHlXOms9q5DHb2Jh2n7ysDmT70uWjtEPzD7E
5AOTcUKPiO+BKuTxm9xzXtUUs60KefwmazXa+vcYM/nGxOt7nvXV1Uw+Mmld
m3nv4XKax2/yo/2Onddimsdvktat15c1gcl3JgW+VZA+n8mHJo/XShwaOYbm
8ZtoTzqwceMcmsdvAks9hBWmMPnWhOrfx+Rjk6bws8Y/tGgeQ+TTvY8Oc1g0
jyEyo/GN51IRmscQ+XHbve3HbyYfnPT5SLd/HEnzEPz81eCOZwOVmB8zRP4K
/htzvzL55mTplqOv2K1MPjqZ6l01zf4tk69OrFf7P3spuKZ4DBGqnrESefwh
ZbedX31sZPLhycVPD9csfcrky5Oe5QFP79yoRB5/SMkDx6ZOwe9TPP6Q32MX
HTp4hcnHJ0kJh1aIXmTy9cm02zP4FimVyEPw+8nxsok5lcjjD/FsOPapN56p
ByC7HFysb4Uy9QLk9MIp5EQEU09ATo6J+hvsXIk8/pC2gds6k7yZegQy4J41
2cyWqVfA8z2mnoHMGQ4/7KtEHn/JvNt2TbetmXoIIqX04pWwLVMvQS7LipSm
b2PqKUgRpyfn2jqax1/SFXxZ1vQEU49BjvNSfu5bzdRrEP7MDZy//6/nID+X
2zZVLKd5/CWn0oIGXQHvl+gIqEg8N9J5BlMvAt+r7jt9HcvUk4Bl3LeEi6Px
9bVHQES8sqM5n6lHAaVYS+1cNaZeBTJP1nFluEw9C3hMb4jqF8f3t3YEHB8Q
v3XsVwXWf48ADe4e3ZtKTL0MyElO8JutWEnX08D3n+ljZv1h6m0goinKY9kn
ph4H9ngrpOwYZOp1IHV4efScqeeBnKjuCP8nTL0PtJyqH/muqQLr30fA1U0m
hdV3mHohCA6yGuVyjaknAuNPL/+cv8LUG4HBpszdSvVMPRK86R4uCGLqlUDK
3nfWmjKmnglm/l67rziRqXeCO15jHSQvVmD9/wj4OlmX+yG4AnmMhNMiodIT
Ypl6KnB+PfjJ0IeptwKqX2sF8hgJzW+nX3jhzNRrwb1VX3mmjkw9FxQZKvaM
8mHqvcDF+2W+07EK5DESQqwc587ZSfMYCUFzBqfM38bUk4F1jN9TlglTbwbv
R30w37SGqUeDxaNOtizZytSrgXDwGOO27Uw9G8gnSq5TWsPUu8EYMrn9xmKm
Hg52XvdxVjKgeYwEdy3W9C+6TD0dpLO+HtUby9TbQc/sW5t85jD1eOCyV9/N
V5Op1wPjMRcja0Yz9XyQWvRy8QZlpt4P1jtdr7X9W06sqHpA2J8xdyhIiK5P
GwnZ7//mjRhZQc2vFhWCDUccpkkMlFPzaeSFQLRrmlVsXzlVL8QRgnqRMRsK
B5h6Rfh03uNS7zemnhGu9TypXd5ZTsqpekf4pTqcgVBOrlL1kLC25fGrhY+Y
ekkoMu/O/lNTTp5S9ZSgvWDs4+gb5dR8oL1CEFEWaHX9ejk1D8JCCA6H+5XU
pNH1s0KgGHMh/Fw1U88JtwZuFC+/WE6kqXpPuBO7tWVSRTlRpepB4biSR92t
lHLCp+pFIWf8rdVzY8rJRKqeFG6KHur+HlBOzYctFAKqvqCcmv9QLQS6L9bv
0HYvx/p6ITjl+cCd7cTUs4Lbgv7Om+blZBdV7wqSw+GHU+XkEFUPC6N4cz4v
3UfzELx+wl1D1n6mnhb2LrA5Um9UjjyEYTNx3Zy1ieYhDKeffKp6sp3mIQzU
vHOmnhfeWg3Y5M5l6n1hwp95rLEzaB7CsKjp49VrujQPYXixd9e4hxo0D2FY
v9hH31WD5iEMY/81QKN5CEPYwiffW0fRPIShcu+L1DtiTD0ziLkceFMhztQ7
gz/xn28jT/MQBqHY7L2TZGkewtAz7sDZosEy5CEMZfciJEz+liEPYQhfreG3
sKsMeQjDJOt3Vpc7ypCHMBzxnfib87oMeQhD8+mNX64+Yuq9obg0g6/5oAx5
CMOKzdp7OHVlyEMYNL6sk7l5swx5CMP26uGBM0y9OVx8aTDlbnYZ8hCBjhVb
DC4IrikeIiD1yFrmWEYZ8hCB7qrBgm2xTL07mIQtaHgheDyXqoeHa+WtzWeT
y5CHCBRYPLaN9i9DHiLw/VLG2F9ny5CH4HpJpKiySxnyEAGzqRViDXZlyEME
Pi41WhZpVYY8BM//vcih2Z6p9wd7f+kB1e1MPwAI1b929+KBMuQhAg1zn985
s68MeYiAOTE28N5E8xCB1CdJ196vp3n8/3GKhwjczXz69sBkmocIUPPwaB4i
MN/s5inPqUw/BLATl+n8zqd5iMB22an15ZNoHiJgxNNNK9SheYiA0nrp3X2q
TD8G4FfmPU8Ro3mIwgPLvul8BZqHKCgXWY4fPVSKPETB8/um8g2DTD8IuH48
1ypViOYhChdudDuxukuRhygUH1MTvfKuFHmIwrUGq56Rt0uRhyhQ/WxLkYco
UP0/S5GHKEQsE9vdXF2KPEShUk/PxLGB6YcBUSu3Ss1pYvplQKj1koatpaXI
QxTWPcgPtysqRR6ioBavHpMqeJziIQqjOVWDW5JLkYfg59vTHM9eKEUeotDx
criBaCnyEAU/n47uvzFMPxDYMJzuGsr0C4FVo4cHGpciD1G417uwbIFFKfIQ
hcGBnCWmp0uRhyhUz3Tpyd/D9CsBFekzy0p3lyIPMTjqWDl2nuBxiocYPNY2
13m9k+YhBiGVEhvD1zD9UmCeudSPYME1xUMMyAZlLa8tNA8xkNDlbTw4j+Yh
Bj9j2wvuz6N5iMGmH0+F3k+neYhBUO22ry9H0TzEIEZL6pQ9h+YhBndFpwbN
0mb6xYDpMUeraM1SMpLqJwM5btlKk+VoHmJgwHOV9VWgeYhBQo9W2ezBEuQh
Bi8r4jLntzH9bIB9zmJGTEsJ8hB8nsAA+a2vS5CHGGx1tl3m+ZzplwN/ur+9
8XjC9NOBMT8VcpffL0EeYqA6aZtIcWMJ8hAD0UcbiqqqSpCHGBR4rN7ZUMb0
84Eu5bhPY0pKkIc4TD661yrscgnyEIdB+cA/CwtKkIc46H0c0bwyogR5iEPf
lwuj+s+VIA9xMCy6FNwbVoI8xOGRpLnWUfsS5CEO8RoXa74FlCAPcShfMFzg
UYI8BI+PWSueYl2CPMTBWu5D5KHjJchDHC759YWsPlSCPMRhqt2vyzM2liAP
cdj0+IW0lVEJ8hCH9p6i33WbSpCHOMi5/dcQtormIQ5uPJsPi1fTPATPV6vR
2zKX5iEOY4bHz82geYjDRPWOE8aLaB7icLz05joHDs1DHA63796zeTzNQxzG
spaq+XFpHuJwMyvb6bwwzUMcyoLcWkdK0TwEz3/00p9sSZqHBEiGHOod312M
PCRg3aZZ8ecE1xQPCYiXyqxMeVOMPCRguDs2u6MYeUiA+rS5r+2bi5GHBFw9
4sNteVWMPCRg0vlmw7mVxchDAlxUuFMu1xUjDwlYW7a8YtONYuQhAY5vw1UK
y4uRhwQ4Z0nJXisoRh4SsH//7hXqgmuKhwRYtw//AyxGHhLQXX3AVyK9GHlI
gFiM5KSK2GLkIQG1zzpu9HkWIw8JiMqbfWO9fTHykADRgxMPH3EuRh4SkPgn
teK4RTHykAD9pV8/PLcuRh4SkN9kbC5/pBh5SMAmLXJ/kkkx8pCA0v6p81at
L0YeEkD3e6N4SMAPYYf7BauKkYckyNW/7GpfTPOQhHmrvjUUzaZ5SMLf5ZE6
FtNoHpKgs/3CZzKa5iEJxbp5Myeq0jwkger3TfOQhCn1wuWnRWgeknCsZseR
RmmahySEJn1QzRooQh6SsKeWlWX0pwh5SMLc/nGTJvUWIQ9JGBsxoWPUhyLk
IQk8nYl16m+LkIckLL28MvLVqyLkIQk2jTF/Zj8qQh6SkHne0j7gfhHykASD
t5pr+BVFyEMSGryER2+rK0IekvD0kvOOgw1FyEMSvn7x/s8gowh5SMKlmz/i
96QXIQ9J6Jeu23A/tQh5CJ7v6uOGxOgi5PH/n6d4SEJS7LiGHwFFyEMKJJ9d
vVB8ugh5SEFSV1SWvEsR8pCC/t/DDaOLkIcUnHaXE1HaXYQ8pCD1bde+DTuL
kIcUyIonWHzbXoQ8pMA2qGRBsUER8pACzuHhgt8i7FchBTJvZFbKrKV5SIHO
8RfG+2bQPKRgXuZKW68pNA8p2JQyLunqaJqHFJjWb5m4m0fzkILFQ8MD7mke
UnCiWW98rDjNQwqMyq7eth9B85CCsucO92WFaR5SQPWzKkQeUrDCrU9Y9ksh
8hC8n2tTIeRVIdn4j4cU/Bw53GGxEHlIgZz3/MsnbhciDym4+zgvwvteIfIQ
3C/vW9wNtwqRhxSMDuSWXagsRB7S0O9SOM+mqBB5SMO4No/Eu1mFyEMazhkO
J4AUkox/PKTh9Zi98yUiCpGHNGybWP7Q2L8QeUjDr1g4ahBQiDykQfxz+n6b
04XIQxouP3fJaQgsRB7S0NYy5fM2i0LkIQ1GQ69HDh4rRB7SoO8ePd95dyHy
kIZXL94teL+rEHlIw/h1r3d8MSpEHtKwqvDqxVEbCpGHNNRMexA3MK8QeUjD
TNeRjfGkEHkIfr++dc8tXiHykIakS8b8zjE0D2k4NvzvVZPmIQ3TFNZv+ixH
85CGKL+GT79UaR7SILw3c+ssCZqHNAx3NznVX4A8pIGr/1U/vL0AeUjD3mgh
X6vOAuQhA/nSwxMWC5CHDMw5OuLFwaYC5CED4a/n1AzcKUAeMmBWefby8roC
5CED1XekpVddKUAeMlDXaph49UYB8pABrazuQ/aFBchDBibXNZtkJRUgDxmo
FXpb659QgDxkwD670TE7ogB5yMC6/G1t59wLkIcM2DwpndvkVIA8ZPA8pgB5
yMBnr7X6iZYFyEMGNtyFumLBNcVDBsbHLBmdaVKAPGTgR+xDb4dlBchDBp7/
PjB9MxQgDxmYd1GT/05wTfGQgeiLq7q99QqQhwxwnzaJn+AXIA8ZkD7H2tzC
LUAeMvDlvpnjYhWahwwEDJcnytE8ZGCjmJz5RymahyyYbrY2VfuZjzxkYcq/
BFOahyzstN89cXZHPvKQBdcD821Pv85HHrIQ9nhCcuzLfOQhC/VLvw/8aMxH
HrJwJdHsjnJNPvKQhYbnb55pVucjD1noOkNm7a7IRx6ysG3Oaw3OpXzkIQsu
vOqT2zLzkYcsrF8aaJwTkY88ZGF1/sqyWYH5yEMWpnbFfg4KyEceskDlR+Yj
D1nYNPeV7JBlPvKQBe2UKe+Nd+YjD1lQGF5e7s5HHrLQPuOmtvKafOQhC18L
KnSnLMtHHrKgPuMh+wfkIw/B64+vX8hdlI88ZEG2qzpHVTsfeciCwYvHlW1j
8pGHLNgs3GT7XDIfechBbrxa59rfechDDmL2Ff7HE81HHnIgPEJx8ta+POQh
B7VO9c59vXnIQw4+nwyo2/omD3nIgd/n6oSPt/KQhxwoGvJO6zbmIQ858Fw0
x7n3Sh7ykIOM6LtTagrykIcc9Oiv3lp3MQ95yMF4r4crzyfmIQ85+DucXhiU
hzzkoN9Km/fHLw95yMEzwe7m+Ok85CEHR4KsA0xs8pCHHMw2dX06ZVce8pCD
yuYn0We25iEPOTA04J7oWZOHPOSgZQw7u3NOHvKQgzPrH0VbTM5DHoLPu467
7cO8POQhB3e3S638xc9DHnJgk7dy1xleHvKQg536Iqd+iechDzm40bL3+Zzv
uchDHnQnrt++61su8pCHpaqdLay3uchDHlrjFTOqr+QiD3nYc2+p0PKoXOQh
D2P4ojE5VrnIQx5kOuMPutnlIg95qPf78OSxYS7ykAedi2uniy/JRR7y4NDI
Utgun4s85MHnyHCDjBzkIQ+KRj1jAltzkIfg/RZ53tjVmIM85ME2Iqwf7uUg
D3lo2JFgrJKYgzzkYeS1XdX+Z3OQhzxQ/cJykIc8nL/eNMtdPwd5yMOrRf6e
IybmIA95mGVQYRCrkYM85CHkjt4l37Zs5CEPS56FT6q6nY085MHu0TqbhXnZ
yEMeLg2nl4dlIw95mHC0P+C/g9nIQx4qlqRN3Lksm7pfQgrw405neaZYNs4r
VIBpa9cYPXhwGefhKsB3OaWhWUXMvBE4Y2N5c4/jZWq9ylYAfm3pxyZnZl4J
TM/afMLv2GWc564AC5snGtxfd5medwJfG0JfvxS5jPN8FSCgZ8Ot7YOXqPer
qwBUPv8lnMelAJqH2hap1V/CecEKMEPvQ8TvGGYeC1TPmbTimM8l6vu1TAES
Tee9X+vCzHOBqstTBZ/oEs67VwDOcPuHmcw8GDAS0QmZKXwJ5x0rgGxrtJmh
0CWK324FKHhxKCKmmZk3Ax+9R54/9CiLOm8xVwCq3paZVwMN1y9b/76URfG1
ETzfh5Y+vyhm3g3Yml0a984mC+c5K0Bcz9FlRpuzKB7uCsDLi034tTcL53kq
QJ3XpM1X9bJwXrQCNO73WCDGzaLn8UDafY1rjSpZFI8oBXjSq+Jxf4CZ5wNv
50x8GfX0IsUjRQGMI0Ysb73GzAOCu5dXNyzJuYjzrhWgnlXptDnmIsUjTwEU
K+aXmIRfxHl1CnBl7I4y8TMXcZ62Aqwwc5DNW8bMKwI73zH8PcYXKR7XFcC6
FVaydJl5RzDU5jHorXER590rQO6DlWvaO5l5SaC9+ODmjHcXcN6xAhxO5Tya
2XiB4vFaAcxOhFfNb2DmMcHN+6eUjpZeoHh8EFwPbW2Oi2PmOYHDYYeH6z0u
UDy+KYD0/Rsl+c7MPCgIPPF3tu7uCzjPWQGUFOaW5iy6gH4oQvK/fvMX0A9F
WF9werLWtAvohyJ8/uGQoDn2Aj2vClql7nL3DmSiH4LHh9vvSV2g513BGLVq
SduXmeiHIggdE1N+fpeZlwUzyBw9s8xM9EMR1GVObm2NzEQ/FGHJEpv3D2wz
0Q9FmH7r6UmVs5nohyKIrlCeF3iYmecF4/Q/Hny+LRP9UIRubl9GKWHmgcHI
OwpatpMy0Q9F4G1a2KYuuP7398xEEZ5tCvU+oJSJfihC7z31P+TbefRDEbgy
te2/vjHzyuDY+ffuSa/O47xxRfB+0zvkUMvMO4ONx9zWG2edRz8Uod5tlk1n
HjMvDfrWHE61DTyPfijCp6Olyi/CzqMfipD2crjB6Hn0QxHaVw0XnJ5HPxSh
UPFdsPkuZp4bpBndHuW76Dz6Ifi8w+NoFjLz4GDQ9Efz2Cnn0Q9FcHow3FDg
PPX39Lwi5HG8bg6Kn0c/FMFAmmtQ3JyBfijC6ZOBI599zkA/FOF3iNaMy28z
0A9FuLExSK8sm5l3Bx6j9zZq3cpAPxRh5glYsyWPmZcHimNWP16YmoF+KAI7
qm9JS2gGxeOh4PE7kxOO+GagH4Lvx8YrvdMPZ6AfiiByc4HPDBNmnh88m/1Y
/tf6DJw3rghG15xIMJuZBwj+EttfPtfIQD8E968xQXS5cAY9TxBOHA5+tUdw
TfmhCCMGeHOW/05HP5RAy/KbRXBXOvqhBHfEL7qOak9HP5TAc9TAD5s6Zt4h
xLgMJ8ymox9KcOBBxnOhBGZeIuxqKHv79kI6+qEEDXYSU2adTad4jFOC3Xq1
/VV26eiHElzasUin+ng6+qEEyeJTnjdvY+Y5wq2ae/+d3ZmOfiiB1biR17XX
MvMgYe/Bjyb6k9PRDyXoFDoeqqvBzJMENfswz4+j0tEPJdg4FG77WiEd/VAC
rsF2jv7XNPRDCZpOL62zaE1DP5SAzbFf9b2RmXcJJiZDq99fTUM/lGDRcoeO
9jxmXiaU/N0ZpJGbhn4ogezHNbfmpjDzNuF+12fet4g09EMJflRNnrPvVBr6
oQT7k3YIVmBp6IcS9K5yv13jnYZ+KIGctg3vqjEzDxSeS/Azjm1JQz+UoCA0
WXL3YmaeKGiebFIdIbim/BDc/w3zv3A00tAPJRhUjpC1mJiGfijB2+xvx6OG
UtEPJTjdIvH9uHAaPe8UHNYfLkzuSEU/BHxzD39NeMvMS4W7B8K2LG1ORT+U
QO/tLr+4HGbeKhwgARkra1LRDyV4lWykmpOain4ogc1w+CQgFf1QghOWQvWL
vFLRD8HrW/c2bHNi5sGCy6/5Jxp9U9EPJbD+sWp7pAkzTxZG/DvwSUU/lODr
wS0W1kuZebQwQ64taOuSVPRDCZI22x3UGZ+KfijDcLRji04q+qEMbj+9ZEW1
UtEPZVC+1K/HEmbm5YJ3jOK8pwMp6IcyqA+Pj//JzNsFhcXh5jffpaAfyhA9
drjAJgX9UIYRdb/6PtanoB/KAMe9pB9Wp6AfylCudPvU/BRmHjC4HJ+67URs
Cjnzzw9leHLX0fhlJjNPGHQKRr32PJuCfihD7hLT079sUqj172plMG7SibKw
S0E/lGGoEezGm6QQ1j8/lEGlYVzi1rUp6IcyTCmVf+i5MoX8K0/erQyWF9Te
H1/KzEsG4nXsUe2sFFxfKcPg4Zdxb3SZectw4kHS0ErFFPRDGeostQz0FVJI
xT8/lGH1pjEnZv1ORj+U4bbJKZ5/TzK59s8PZRAP2Xzj3q9k9EMZusTub7/f
kUwa//mhDNljzN2jmph50jD/9dRlwvXJ6IcyNLPfq/jlJFPr73hlmGQ0EGld
k4x+KEON06HrbinJxPyfH8oY701GP5TBz7rQ75VvMrH+54cy2Fb2Fm05zczL
hgt64tmT7ZIpHhXKkLRu6+QgF2beNowulEtV2JmMfiiDtcxwg85kisctZfgX
3pifjH4o43olmeLxUBn2PYmrfjoqGf0QfH8ybZZNGJ1M8XitDB45M21TlZl5
4nCRpXi9TTYZ11fKsPjGOP2kZ8w8cgj++VmV9TIJ/RB8X9j792g0JFE8fgi+
fzUTjOJeJaEfyvDO2c7uQ1YSxUNIBUyG20PFMvPS4UvOioV6PkkUDxkVCB1u
p7edmbcO94fbU81NQj9UwE6xuzhfO4nioa4Cp4Q2OI5YkoR+qIDKw+4pl3lJ
FI9xKlCk89L78s1E9EMFbkQ+rH0unkTx0FWBy8UB10y7mHny4N58aadwSSL6
oQKvf5ktsT7DzKOHlIVvl7v6JaIfKtA367ZZmk0i+qEC+m5TzJpMEtEPFShM
0+FdH5+IfqjAjMDZM5PUEtEPFbgkGvfmETsR/VCBv1UiQj+EEtEPFXA82HVD
RzIR/VAB82obj98NCeiHClz4nvgiIjMB/VCB6/umHT8cnIB+qIB0w9vO76cT
0A8VOGHf4f/dNwH9UAGLltSu3asS0A8VWPLeRTh9RQL6oQJtd8y2dexPQD9U
gGufnrdENQH9UAHtrXkfpo9NQD9UwHPfvZz3CgnohwpY7w37vFM8Af0QXH97
crK8OR79EDxf4PuZya/j0Q8V2NAtvHxdVjz6oQK5v5yKt12KRz8Ev69Qs+S6
ezz6Ibh/JrGv5f3i0Q8VqMqOGf1zezz6oQISXt+lJ8+ORz9UQM42zfnu+Hj0
QwXEzvUNTZsRj36ogObweDmlePRDBXoufs8V74pDP1Rg5urWABCLRz9UwNBv
1nmr8jj0QwXCx19/urEqDv1QAXU7T/ub6XHohwoI/RsAEYd+qEDCcDtz5zj0
QxUaWK8eibnHoR+qcO344J8q0zj0QxWWxvsoR6+PQz9UYYnOhE0rZsahH6qw
625EvKVeHPqhCnMMufI7+HHohyr83Xt+JedOLPqhCicOVcwQ7o5FP1ThmPMW
07LGWPRDFc4965TzrI1FP1SBq7lZOSkyFv1QBd8SiekL42LRD1U4VWVZsts+
Fv1QhTGbbo2O3haLfqjC9nda2e+3x6IfqhCZv/ytv24s+qEKlnnjRO/MiEU/
VGHwyAqrwPmx6IcqdL7bss9EIhb9UIXGde1/9P7GoB+qMHD/4qSk9hjq/MhS
FR6Eb+yZVRGDfqgCp9TH5mpGDPoheH/r2NU5gscpP1QhOiUyICEiBv1QBQ3b
nLsWITHohyq0Vt7l6XjFoB+qcENdRCP7SAz6oQoFxRKP3cfHoB+q8LRH5FDE
4hj0QxUKv/q3uEyKQT8EryeeFL9FcE35IXh/Z/rX+n+KRj9UwaFivXOHeAz6
oQrvx13Xan0cjX6owt7963jXqqPRD1UQ2fC4vLAuGv1QBZNHFVdfpkejH4L7
PXwckBKNfqjC4/lW83a7RaMfquDyUht6baLRD8Hn542r/XQsGv1QhZ9xG3xd
9aPRD1WwSDlgfeRQNPqhChE1Ctav/0ahH6ogY2XUbM6Opnh0qcLNyPbPM35H
oR+qsK9A6Ny7+1Hohyo4s7qfSD6MQj9UYf6pPRk6gscpP1jgUDdprnVYFPrB
guqtalqZuVHoBwteFebct06OQj9YsKDxP0ddzyj0gwVKYePCbT2i0A8WRE/c
p/X1YBT6wYIvrbcNFI2j0A8WdAzWczWWR6EfLCgonDFprGoU+sECk2Mvxa//
ikQ/WNC+dfy7Cf2R6AcLMsYmP1j0OxL9YMG64eO2L5HoBwtmXPZ5uK05Ev1g
weZrBq/v5kSiHyxoPjY1bagoEv1ggfCu5FXiwZHoBwtujK8JvuYWiX6wwPZX
nNgvs0j0gwWPry68l2sciX6wwMP3YVHA4Uj0gwWqjlefJqyKRD9YcLllp/lG
biT6wYKVEWzDbwaR6Ifg9Z586Jg8FIF+sODjrr0HDeQi0Q8WvM9xTRj4GoF+
CN6vsuUH9d4I9IMFfY1bXOY/jEA/WLAjMCU7PDcC/WDBVddbCYszI9APFnQu
VnyUERyBfrBg343jZm0+EegHC1ItN88cHR+BfrDATqLZkeMYgX6wYNde6YC4
AxHoBwsiHS7l6M+KQD9YoCulI7dsXAT6wYLwW7fa+1kR6AcLeK/FHS1/h6Mf
LDjYvYTT9zUc/WDBT1llWePucPRDcD/nOq9zFDxO+cGCbelTa2Qfh6MfLFBQ
X1jWkh+OfrCAqv8ORz9Y4Hmi0rvpbDj6wQLrcTudIxPC0Q8W/H2jtUQoOBz9
EHzfVvz2n7UzHP1gQ+/L6ZNu7QhHP9iQ431tUeTicPSDDelHZ/+6MCkc/WAD
dyo7sm1sOPrBhqGgTLgyKhz9YEPF9EV7/cTD0Q82BLpHHngwIhz9YAP4DPYK
fQlDP9gwTahmtl1bGPrBhjU9a6+uuR2GfrChtmLihoArYegHGw5Hmu5VLw2j
ztuBDZM6NT/5ngtDP9ggoek59mpkGPrBhpKPNcZrw8PQDzZsMz/rGL0vDP1g
AzWPIQz9YMOhyItds1XC0A82fF3tVpm6Ogz9YEPwcDuzwVD0gw2R5SYj3o8K
Qz/Y8K88lBuGfrBBSu5h46NfoVQ8wp4NvJfT7yl8DEU/2OCYMVlf/XMo+sGG
ibMDqozuhaIfbIgJ2zsurioU/WBDsXt3wYm0UPRD8Hz/5reFoh9sGMddpVMa
Gop+sOHvq+EGwKHoBxuEh8vVzUPRDzZ8nOpXqHUkFP1gg/moBSpZEIp+CO5v
2mxW+dpQ9IMNdqfDR3zWCUU/BPdnPq+3SSaU4lHHBrGTrqyRIqHoBxtm7zK0
3fUjBP1gw/r7s9MCekPQDzYMjj9Wyf0Ugn6wYYIB78WNnyHoBxtszPoLh+6F
oB9smD+awy68FYJ+sMG1sev519gQ9IMNeu4zZhxLD0E/BJ8nbULPce8Q9IMN
tqKuTUWHQygeP9jgPC5/u+H+EPSDDdaGv6vLD4SgH2pwNE/1mc3iEPRDDZrH
Larn64WgH2rwh72/8vG8EPRDDdKEQ/OO64SgH2rQXl4jLy4Zgn6oATyasZ8n
FIJ+qMHH3o4T2QPB6IcaHLg03PAmGP1Qg0wF52gbwTXlhxoUnL5vXlUTjH6o
QYeCTod8VTD6oQZH8kwPBsYFox9q8P7R6hlVacHohxr0kkQhUY9g9EMN7J88
C3Y5GIx+qIFGldkii2PB6IcabHxkKnVkYzD6oQbhS4+M2WgYjH6owcFXhJWq
H4x+qIFR/iiP25xg9EPwfOuzGhrmBqMfgvtV8/zyJlYw+qEGC71Gdvd9DUI/
1EBv5wPrzT+D0A81WO+9uNBlMAj9UIM5gVsDDEcGox9qYH7ji514fRD6Ibhf
d+fKGnkFoR9q8CJD1ifDLQj9UAPjPIVDQXuD0A81OFuusMHbMAj9UIOaSTrL
FygHoR+C+2OsKrlTNgj9UIMRttHTptUFoh9qcPy+ZYz95UD0Qw0uxKyadj0v
EP1Qg1gRlSDd/ED0Qw0Or7w9J8QwEP1QA25Qdv2VeYHohxpol70ge6YFoh9q
YHd82T53biD6oQYS/wISgeiHGhR9WbXHRi4Q/VCDWeEuzf0fz6EfamCoseHF
pOhz6IcaBIVuea8WfA79UAPLOVfmrEs6h36owdL7C12XOZ9DP9RgpoFIc9Hp
c+iH4PNfjZp6ePo59IMDJYMuj0K0z6EfHNBcaLkx6v1Z9IMDK+pmuI5sPIt+
cCCy3nq+y82z6AcHchYNJzydRT84sMmhR8/wwFn0gwM7stTTezadRT84kLdG
X7/41Fn0gwNThG1iyJqz6AcHqivfFJiMP4t+cGDuX6m+tv4A9IMDL5yeqk+/
FoB+cOCr/rzJ5sUB6AcHeksXLdlXGYB+cCC3zTbtmXcA+sGBMr90HTvnAPSD
A1uahguKAtAPwfuZ+tGjbmwA+sEBhatbu78sDEA/OKAVUtKjMzEA/eDAmfpj
/8V+8Uc/OFB5s3x3W64/+sGBOzzWttFx/ugHB5Z7Pr91vtQf/eCA1aprqyt9
/NEPDgyOHju5xcQf/eDAyuHyg6P+6AcHbl9NOPhymj/6wYG/cdYtupP90Q8O
ePT68kaO80c/OLDfetsC6PBDPziwZ8Upi77rfugHB/THSmo01fuhHxwY0JXv
uxTuh35wYDVv61ONeD/0gwPpwp2H39r7oR8c8H/mNqHcwQ/94ECR1pHUphV+
6AcHjGfpXhgr44d+cMDk58a++9980Q8O7NR2tzrx0Rf94EBPsNq3CSW+6AcH
9plktyi98EU/ODDUaykw1hf94MDSg/X+OQd90Q8OjC/bauRx2Bf94ECbeeDl
3zN80Q8OZHzzTpZf4It+cMC65ZH1oXG+6AcHnAclZf5o+6IfXKDmX/ugH1zo
/HPIQyjDB/3gwqv+KY02ST7oBxfWC7WPkM7yQT+48Cemo77zpA/6wYWM2qh6
j4M+6AcXnFjzzcZM90E/uLCfn9Oxer0P+sGFb0+4I/ZM8kE/uFB37XBzKcsH
/eCCuVx6h1iiN/oheL6eZL1pb73RD8HrDe7fHnfDG/3gwrzPPx5uDvFGP7iw
TGSKZWegN/rBha6MN7Zubt7oBxc0bvp7Txc8TvkheH96reuOmXqjH1wQ+uMp
p7rYG/3gQqvezI8Zat7oBxemiYS3PvjuhX5w4UEx3Dn+1gv94MJGdaPPKx56
oR9csP7VHqZ61Qv94AI1r88L/eBCsd1ssu2sF/rBhcKGTXbSll7oBxc+thjq
S5l4oR9ceB4/77nObC/0gwvrUr5xKw280A8u7DQ4vjZL0Qv94MKKrHB93UJP
9IMLnyI13vJLPNEPLvRKWKYfDfFEP7igqtyu7p3siX5wwcX6+LMzpZ7oBxfs
ev47HLPZE/3gwpfZF4Yer/dEP7gg3Ck3QWylJ/oh4HW+TPT8VE/0gwv+I9bW
OE/xRD+40L16zlTfTg/0gwsvJR6xN/70QD8E72+rU+3bCg/0gwu3VV+3a9V4
oB9ckLsmu7EkzQP94ILbayn2BUcP9IMLEwvj3wT4e6AfXKz38EA/uFAwPM5n
kQf6wYNXgt0wa6kH+sGDjsXzpBREPdAPHixJa0ptfueOfvBA+ffY6FHP3NEP
Hpx5k7OO0+WOfvDAduX17U+uuqMfPHAdHjfs745+8MDhlvzIyVHu6Mf/ryk/
eHBOxpq9V/DzlB88ODrcLmqqO/rBg3A1kc1yU9zRDx7YiAV/7h7tjn7wYPLP
xC9X/rqhHzzwudP9U0fZHf3gQZHfK9+5793QDx5Q/Y/d0A8eUPOG3NAPHhxp
W2/APeGGfvCAfbFj/IC3G/oheH3Y6SHh7oZ+8ODC8ZgHZtPd0A8e3BqSW+a2
2A394IEhZ9WdIb4b+iH4fJ7PTO9LuKEfPMyncEU/eDBxT49/ZK8r+sGDmtol
jv09rlS+UQgPfhn7/TbIdUU/eFC1zeP7pnJX9IMHfsrfxHf7uqIfPNioP1wg
44rxQR6sHzU79fp+V/SDBwu+cDQ+L3JFP3iwWjpq01MZV/SDB588eG/uSrqi
HzyQE3wbw0a4oh88cFow1fDsfRf0gweJVpMa99m4oB880LvpfKfazgX94MEp
g6ZTI8EF/eDBKPsbEr1DzugHD4S0HX6cee2MfvBAZf7g4oP5zlT+2TseRLRO
zf9w1hn9EDx+Z9HN+jPO6AcPhkKepod4OaMfgvuzO1ar7qMT+sEDVXdp86ev
ndAPHrTlupx7XuiEfqiD3CHtM+ElTuiHOvjunWxvl+iEfqiDH/sn6+wIJ4qH
ojro6fcV29efQT/U4fBcM8saRSf0Qx3CWgpyWwPPoB/qcG043X7DGYwPqsOq
1afVtiecQT/U4ZfWcMLmGfRDHZbsUJv5QPwM+qEOr02jMxv/OKIf6tB0IN0j
9oYj+qEO2c4l/PnrHdEPdVg+8ktni5Uj+qEOPPbhRU+MHdEPdYi7EZeya6Ij
+qEONx5mHhzVchr9UAelfp3IESmn0Q91SL+l2yV2/zTFY786WAy3Z9l7Gv1Q
h+kztcRfLD6NfqjDOJ+YhkvVDuiHOgiV/RHquOGAfqjD5Xc/Upp9HdAPdTD9
+sc+d7sD+qEOm9jdM64ud0A/1OHWhG6RfC0H9EMdVlsc+hZ23R79UIf87z7N
HjoO6Ifg89yeaqPaYY9+qIPVRImHRtfs0Q91yKk23JTiZo9+qEPIz+VNvlPs
0Q914Ph7WfxVsUc/BN8Hh2TTjDun0A91uPm78/eXkFPohzpsyVTxykw5hX6o
w+MQ7QQ3weOUH+ogbb/4gu6OU+iHgEdUZYvGxFPohzq0rX5r1KRzCv1Qhzlq
Qd8NX9qhH+rwTiL77QcvO/RDHfIuPzseGmCHfqiD2UmxFPYqO/RDHRx6DSyS
TezQD3VQF96iuarrJPoh4GGha36m4iT6oQ497X2XvhacRD/UYWDy/sTuYyfR
Dw2oyc5aZ2x4Ev3QACe/env2vJPohwYYZS6sUGSdRD80YM+N8t4/bbbohwbE
TuWnC7nboh8a0Fe6/lhFri36oQG3TBVWyO60RT80IOVYcPpfsEU/NOBctbWa
DscW/dCAIJUXXdPu2KAfGmDO3b1ds9gG/RA8/6ThDoM26IcGZNcFP8pOtEE/
NEB74qBT+hQb9EMDDi5v2/NihQ36oQHXPietXalgg35owLG2igntxdbohwZw
9MP9R4dbox8aYOJiM8s80Rr90IB/5R0rrNEPDXjr+9dr2i5rjA9qwKXGI26L
xllT/UZsNOBCmm9+j6g15pdogOG6uVl+fVZU/w4nDdCXt2gZyrSi+ie4a4CP
e03MopNWVP8BHw2QnNgnXbfBiuqncFYD7vQrbnRaaoXrKw2oFOKNXidmRfVX
iBLcX+mgVBttK8wv0YA/ThZ3gptOUP06UjSgaHn0kOq5E5ifKLjfBpqnRpw+
QfUjuaQBWaFKd97Kn6D6SeRpwM03+z5tnHkC/dCAcd+erTmge4LqL1GhAe6t
I6ViFxzH810NWCjRfadi1nGq38R1Dehc37zlM/845pdowMyOnLFtHpZU/5Em
wfs51xZ10NQS8xM14EHmpj6fg5ZUP4pnGuCldCXM6v0xqp/Daw34JGowxbrv
GK6vNCBwuJwg8BjV3+GDBux6LBfsMPUYxgc1oFX8bKzJs6MUj28awN/z/dAG
56OYX6IBhUZn30qvOkrxGNKAD+ONYMw5C4qHkCZssCA1E4wsKB7imiCuXx+/
LNyC4iGjCRv7vTe7j7LA9ZUmvJfKaB9wO0LxYGuCxUKt7vuTj2B+iSYYzYZr
e68dpniM1oRW5eVyR7sPY36iJmS9TOogf80pHpM0QcVr7Ye2X+YUD11NUOYH
Hlh21Rz90ASqH5I5xWO+JmjvC8//PN4c4x+aUKk/bWXSr0MUj2WawG3tXCLx
3yHMv9KE2hLtJbtWHaJ4GGpC6NJtP35uP4T5u5pwvPLezsyQgxSPbZrw7b9r
xjczDlI8dmvCyXCPZyJqB3F9pQkBjR+GZskfpHiYa0KRcfbE5H4z9EMTWIkL
73PHm6EfmjD3XdCQj6EZ+qEJu+KeaBVeO4B+aIL5+esTv/YdQD80QfbvRzGp
qv3ohya0HBw+cD6Afgg+Xzg/M7FyP/qhCZ82Pt08tGM/+iH4fP3+u0LW70c/
NGFMyw31iqB96IeAZ4Xhx8qSfeiHJsjd+iSzdNo+9EMTPFPkJr3s3Yt+aMIO
jeEA9j70QxMmjTxb76e/F/3QhOfqZ50sZfeiH5oQFdo+JrxmD/qhCZsthwy3
XdiDfmiCnRVPtmXKHvRDEzLOKlecjzNFPwSvv6Lu3DxbU/RDcL/NvWZKjt+N
fmjCvTM2YxYu341+aELeb30DR7Hd6IcmjBS9m2D4YBf6oQkFZ80jTffuRD80
ocZV+O8IhZ3ohyY85DR+XlyyA/3QhJ/WwwUJO9APPmwxdzQEy+3oBx/+nlWf
GXt+G/rBh9ZIvc/TZ29DP/hw0+EvX2ftVvSDD0qpZ5ZIS25FP/jg8vDEC4lH
W9APPow9fmuc1OIt6AcfWN+vvYlbsxn94ENQrJnoSdfN6AcfHMTtm+vNNqEf
fFi42XNgWYIJ+sHH/08m6Acfnnj7W/0ZZ4J+8OFlLCc19/pG9IMP15dKaBtd
NUY/+CBv4WUwy9UY/eDDTrOdOm3zjNAPPgT3ye3032CEfvChu3jzkcuFG9AP
PsxP+/5k4dYN6Ifg/e7ZEVvyfD36wYfD2jPE40esRz/4MC4mIOdK/jr0gw/5
q2fqONSuQT/4MDL8ZNdk3dXoBx+yZo3vr9NajX7wocrrQKlXwkr0gw+7gjRy
47JXoB98UHw3K/fT5eXoBx+ihky5kx4vQz/4YGES+WTEDgP0gw+FJysWGQfq
ox98yPk0kNZbt4Tq33OJD48khtZWWy5BP/iwQ1unbCgK0A8+TBpjuHK0C0E/
+LBHvJFj9HwB+sGHNVW98oqd89APwf3Pdlf78HwO+iG4X55+/b/5s9EPPiRP
2jGLkzQT/eBDgWPU91ecGegHH7aqN/4+IqeLfvDh8uz0gYZRk9EPPvhVPmoM
sByPfvBh+Y0iV66ENvohuJ8TLN0uSmugH3zQs7Ov2XROBf3gw8CRFwFX+yTQ
Dz5oyNxTNPnwfvH/AEF4rWk=
          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], 
         LineBox[CompressedData["
1:eJxE3Xc8Vu//wHF7rxu3cVttfdrR0HKUhnYqaSqJRMooSUsySsOohCQjGdl7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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.9882154285714286, 0.5505617142857142, 0.08483494285714285]], 
         LineBox[CompressedData["
1:eJxcnXVY1E3XgOluFtilLB4bCzsYCxHFwkQMLDBQMRDFxlYUEcRCRVFECenG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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8974812857142858, 0.3693308571428572, 0.14526651428571424`]], 
         LineBox[CompressedData["
1:eJxcnXm8TdUXwN88D3e+76EkJaVE6CfFXpEhEaFQEok0SWlQSYhEMpUxRIZI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          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.6695744285714289, 0.22438285714285722`, 0.3381279999999999]], 
         LineBox[CompressedData["
1:eJxdnXm4TtX3wO88D+/8UkpSEikVJWGvBkO+yliGpCJSypCUpIylQUkqY4ZI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          "]]}, Annotation[#, "Charting`Private`Tag#5"]& ], 
       TagBox[{
         Hue[0.8503398874989481, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.31953685714285723`, 0.11640000000000005`, 0.4341454285714288]], 
         LineBox[CompressedData["
1:eJxdnXmczlX7x2ffl3tHoZREWpSUVM5pUZKSpVBSUtKG8iitlKSkpEhKRSRK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          "]]}, Annotation[#, "Charting`Private`Tag#6"]& ], 
       TagBox[{
         Hue[0.08640786499873876, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxdnXmYjtUbx2ffl3cdJZJfSKmoiFRzTklKikSICCmlRFpUKkvSokKLihYR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          "]]}, 
        Annotation[#, "Charting`Private`Tag#7"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(7\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-7.9975000000000005`, 7.997499999999999}, {
       0, 0.14516045}}, PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"T2.6\"", "\"T3.11\"", "\"T5.13\"", "\"T9.22\"", "\"T17.35\"", 
       "\"T33.58\"", "\"T65.81\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.8990594285714286, 0.5637948571428573]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    1., 0.7397017142857143, 0.23300614285714288`]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #6}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #7}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.8990594285714286, 0.5637948571428573]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[1., 0.7397017142857143, 0.23300614285714288`]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.9882154285714286, 0.5505617142857142, 
                    0.08483494285714285]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8974812857142858, 0.3693308571428572, 
                    0.14526651428571424`]|>, "RGBColorSwatchTemplate"]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.6695744285714289, 0.22438285714285722`, 
                    0.3381279999999999]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.31953685714285723`, 0.11640000000000005`, 
                    0.4341454285714288]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm], ",", 
               TagBox[#6, HoldForm], ",", 
               TagBox[#7, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True", 
                 ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.9101569506659565`*^9, 3.9101571595324707`*^9, 
  3.9101610790210724`*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"8d675a63-e53e-400b-8224-c92b1d42a02c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Alternative sequence 2", "Subsubsection",
 CellChangeTimes->{{3.9101565749255075`*^9, 3.910156579265273*^9}, 
   3.910156965807495*^9},ExpressionUUID->"85eb5c05-a459-4dd8-90d1-\
03ad6cc738d7"],

Cell["The second alternative sequence is:", "Text",
 CellChangeTimes->{{3.910156660637101*^9, 3.9101566672747507`*^9}, {
  3.9101570488956923`*^9, 
  3.9101570493925924`*^9}},ExpressionUUID->"8c377bcb-d060-434e-a0d3-\
1e2b20b615ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<T10.22\>\"", ",", "\"\<T37.37\>\"", ",", "\"\<T73.71\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
  3.910156608462936*^9, 3.9101566170742188`*^9}, {3.9101569766320734`*^9, 
  3.9101570153138638`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"fd0aec85-f518-47e8-81b5-0b475e1f24da"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{8,8}-tess_T2.6_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
  3.9091142248348513`*^9, 3.909114238346472*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"164b9b72-1a98-43c4-8a55-72bda0b9730c"],

Cell["We construct and export the Abelian Bloch Hamiltonians", "Text",
 CellChangeTimes->{{3.9101567017353535`*^9, 
  3.9101567119301167`*^9}},ExpressionUUID->"c687b6ce-dee9-4d50-95e0-\
c348caec9abf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"AbelianBlochHamiltonian", "[", 
          RowBox[{
           RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
           RowBox[{"0", "&"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "&"}], ",", 
           RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "&"}], "/@", "supercells"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"d936ec5c-9029-40f0-8659-c0f87f454fb3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<H_{8,8}-tess_T2.6_sc-``.dat\>\"", ",", "#"}], 
           "]"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@",
    "supercells"}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
  3.910154322749093*^9, 3.9101543310279417`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"d68def57-80b7-4cf6-9cf2-a13fd3ed5406"],

Cell["compile the expressions", "Text",
 CellChangeTimes->{{3.9101567165821447`*^9, 
  3.9101567199242735`*^9}},ExpressionUUID->"5c5d7114-d701-4e7f-a8be-\
17c53bdedcbd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hsccfs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{
         RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
         RowBox[{"0", "&"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "&"}], ",", 
         RowBox[{"PCModel", "->", "pcmodel"}], ",", 
         RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091146138495903`*^9, 3.909114652753991*^9}, 
   3.909119478873217*^9, {3.910154420411165*^9, 3.910154425008809*^9}, {
   3.910163122567151*^9, 
   3.9101631235102377`*^9}},ExpressionUUID->"db074c64-429b-4f8f-bfbd-\
9637d623c1b8"],

Cell[TextData[{
 "and compute the DOS with an energy resolution of 0.005  and a sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "4"], TraditionalForm]],ExpressionUUID->
  "4f92b982-9a6c-478f-b160-787aef6f54a4"],
 ":"
}], "Text",
 CellChangeTimes->{{3.9091148872154474`*^9, 3.909114904344953*^9}, {
  3.9101567234788375`*^9, 
  3.910156729219191*^9}},ExpressionUUID->"7d08cf4d-b02f-41df-b3b2-\
5f8cec46cf47"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dosscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ComputeDOS", "[", 
        RowBox[{
         RowBox[{"Hsccfs", "[", "#", "]"}], ",", 
         RowBox[{"10", "^", "4"}], ",", "32", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], "-", "0.005"}], ",", "8"}], "}"}], ",", 
         "0.005"}], "]"}]}], "&"}], "/@", "supercells"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9091148504724855`*^9, 3.909114863025732*^9}, {
  3.9101548693475285`*^9, 3.910154869724236*^9}, {3.9101549493832054`*^9, 
  3.9101549496375976`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"05079843-3a04-4fc6-a548-681b0294baa7"],

Cell["We plot the density of states for the given sequence", "Text",
 CellChangeTimes->{{3.9091258353931103`*^9, 3.9091258729641294`*^9}, {
  3.909126315654191*^9, 3.9091263169689493`*^9}, {3.910156746327403*^9, 
  3.9101567572332544`*^9}},ExpressionUUID->"683ede2c-0421-41cf-b250-\
b8addca7c6f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Association", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<T2.6\>\"", "->", "dospc"}], "}"}], "]"}], ",", "dosscs"}],
     "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(4\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091194227381277`*^9, 3.9091194385257072`*^9}, {
   3.909125701919447*^9, 3.909125705158804*^9}, {3.9091264450645742`*^9, 
   3.9091264526411266`*^9}, {3.910154999941857*^9, 3.9101550239169064`*^9}, {
   3.9101562589192905`*^9, 3.910156259119133*^9}, {3.9101570343676405`*^9, 
   3.9101570352338457`*^9}, 3.910157127253744*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"922a33d0-a655-4267-afc5-8a8ce2e391e6"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxdnXfcHVWduN/ey733vW9/3wTUZbHsimv9sbpzFCurK/auKOqyVgRxWWwB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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxdnQuQXFd9p2d63jM9M909M5JNhGMlKZV3lWW1S7Tr0ob0XW8UWC8VOYmK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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxdnQuYVWd572f23Gf2zOzbhGgxhl540qb10Fo8OahdqzlGLfUxqfLY0FhO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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxdnQm0XmV5ts/5zjx/0zFgI5Kq/Ni0/qkayx+1e1dFMVqhyrIiNkWxNIpG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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(4\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-8.002500000000001, 7.997499999999999}, {
       0, 0.1847400284900285}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.6\"", "\"T10.22\"", "\"T37.37\"", "\"T73.71\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091194429099684`*^9, {3.909125698510269*^9, 3.9091257066406164`*^9}, 
   3.909126457110761*^9, 3.9101549712826576`*^9, {3.910155008395378*^9, 
   3.910155025671894*^9}, 3.9101562605065956`*^9, 3.910156947789962*^9, {
   3.910157155058463*^9, 3.91015716048361*^9}},
 CellLabel->"Out[33]=",ExpressionUUID->"a9c6624d-2a45-400f-b36d-2783cc35c172"]
}, Open  ]],

Cell[TextData[{
 "and finally consider the full data for this sequences, which is stored as ",
 StyleBox["data/dos/dos_{8,8}-tess_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091257257973347`*^9, 3.9091257829464827`*^9}, {
  3.9091258161267524`*^9, 3.909125817972119*^9}, {3.9091263241669226`*^9, 
  3.9091263478044133`*^9}, {3.9101544811965094`*^9, 3.9101544880133915`*^9}, {
  3.9101556042258387`*^9, 3.910155604445711*^9}, {3.9101567591084995`*^9, 
  3.9101567776566224`*^9}},ExpressionUUID->"c399c57a-4114-4e62-862f-\
4eebf1e0623b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{8,8}-tess_``.dat\>\"", ",", "#"}], "]"}]}], 
            "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.6\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(7\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9101570404020367`*^9, 3.910157041144208*^9}, 
   3.910157132135954*^9},
 CellLabel->"In[34]:=",ExpressionUUID->"4d17b6dc-e479-45f4-84e6-62890e91ed68"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxE3XVYFF0bwGG6u3vFxECxm7FFscDAwC4UA0UEQQQkRZDuTgmDbjjPoq+J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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxcnHVYFF8XgOnuxhZbFBHrZ+BFQEVQURQTLAQDO7ELxU4wsTEJyWWJ5R6w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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxcnWV0FM3SgOO6SVaDu7u7dOPu7u7uDsHtxV0u7k50Y3QT3N01QNAAIUYS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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxcnXVYVdkWwOkL3AvcBIOxu7vHvcd49tjd3RjY3TjGmKNid4GKdKh7293d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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(7\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-7.9975000000000005`, 7.997499999999999}, {
       0, 0.14416444444444446`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.6\"", "\"T10.22\"", "\"T37.37\"", "\"T73.71\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9101569506659565`*^9, {3.9101571561975183`*^9, 3.910157161799483*^9}},
 CellLabel->"Out[34]=",ExpressionUUID->"0c343022-39e4-42fe-8244-6b14013f8b84"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elementary nearest-neighbor model on the {8,3} lattice", "Section",
 CellChangeTimes->{{3.9091097560137053`*^9, 3.9091097636740923`*^9}, {
  3.909109820746976*^9, 3.909109821007987*^9}, {3.9101530821292405`*^9, 
  3.9101530911518974`*^9}, {3.910161201243699*^9, 
  3.9101612014819603`*^9}},ExpressionUUID->"a418547a-0b1f-458c-8af5-\
495ebe9a3d66"],

Cell[CellGroupData[{

Cell["Import cells", "Subsection",
 CellChangeTimes->{{3.909109766864945*^9, 3.909109771535059*^9}, {
  3.909109823230064*^9, 
  3.9091098236720653`*^9}},ExpressionUUID->"5ab80389-8a61-4228-87da-\
25573989ad0f"],

Cell["\<\
We first import the cell, model, and supercell model graphs as produced by \
the HyperCells package (see \
https://github.com/patrick-lenggenhager/HyperCells for the package \
repository):\
\>", "Text",
 CellChangeTimes->{{3.90910977524686*^9, 3.9091097920317583`*^9}, {
  3.9091099483552275`*^9, 
  3.909109968542066*^9}},ExpressionUUID->"e31838ec-b122-4e26-b20d-\
d0e7b3f04e1e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcell", "=", 
   RowBox[{"ImportCellGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<(2,3,8)_T2.1_3.hcc\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9090560618564167`*^9, 3.9090560733680687`*^9}, {
  3.9090561514000225`*^9, 3.9090561514836597`*^9}, {3.9091128212745233`*^9, 
  3.909112832496519*^9}, {3.910161215877681*^9, 3.910161217541376*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"aeed050f-e253-4109-a2b2-61acd4c5f6c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcmodel", "=", 
   RowBox[{"ImportModelGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<{8,3}-tess_T2.1_3.hcm\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.909055936914714*^9, 3.909055963188888*^9}, {
  3.9090560238348665`*^9, 3.909056040271286*^9}, {3.909112837065897*^9, 
  3.909112838796729*^9}, {3.9091137679617558`*^9, 3.909113768077687*^9}, {
  3.9101612202907867`*^9, 3.9101612228731327`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"2d8fdcce-2a72-403c-8a63-d9f8107654d0"],

Cell["\<\
We consider the following sequence of supercells, defined in terms of \
quotients given in \
https://www.math.auckland.ac.nz/~conder/TriangleGroupQuotients101.txt by M. \
Conder:\
\>", "Text",
 CellChangeTimes->{{3.9091138575774813`*^9, 
  3.909113909312521*^9}},ExpressionUUID->"1e62225f-f3ae-411f-8798-\
f1e688bb4be5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<T5.1\>\"", ",", "\"\<T17.2\>\"", ",", "\"\<T33.1\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
  3.910161235495674*^9, 3.9101612492366943`*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"028c58da-dcb5-485e-a800-fe3d0c8c4068"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{8,3}-tess_T2.1_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
  3.9091142248348513`*^9, 3.909114238346472*^9}, {3.910161254190941*^9, 
  3.9101612556785207`*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"20078e31-eb53-4fa0-9ee3-a3f7d9b41076"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the primitive cell T2.1", "Subsection",
 CellChangeTimes->{{3.9091098104889455`*^9, 3.90910982999617*^9}, 
   3.9101612604916887`*^9},ExpressionUUID->"fc1ad04f-0452-43a1-8d35-\
89b14203b5af"],

Cell["\<\
We define the model on the primitive cell given by the quotient group T2.1. \
The primitive cell (Wigner-Seitz unit cell) forms an octagon with a single \
site at its center and nearest neighbors in adjacent copies of the cell:\
\>", "Text",
 CellChangeTimes->{{3.909109834065158*^9, 3.909109920885654*^9}, {
   3.909109996816284*^9, 3.9091100631664762`*^9}, {3.9091138866924057`*^9, 
   3.909113887462228*^9}, 
   3.910161267524358*^9},ExpressionUUID->"98e3dbae-71e3-4850-88b6-\
fa213937fe05"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VisualizeModelGraph", "[", 
  RowBox[{"pcmodel", ",", "\[IndentingNewLine]", 
   RowBox[{"Elements", "\[Rule]", 
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ShowCellGraphFlattened", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ShowCellBoundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ShowEdgeIdentification", "\[Rule]", "True"}], "}"}]}]}], 
     "\[IndentingNewLine]", "|>"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"CellGraph", "\[Rule]", "pcell"}], ",", "\[IndentingNewLine]", 
   RowBox[{"NumberOfGenerations", "\[Rule]", "4"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9090560452383413`*^9, 3.9090560491912336`*^9}, {
  3.909056084328685*^9, 3.9090561117988863`*^9}, {3.9101612828124905`*^9, 
  3.9101612870015707`*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"03e42d22-45fc-4d64-94ef-c177fcf821fe"],

Cell[BoxData[
 GraphicsBox[{{InsetBox[
     FormBox[
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJzs3cty68q25vcTthtu+hX8Fu666W45/ABV4eMKd8oRpxzh8Fv5dbglTUqc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         "], {{0, 300.}, {300., 0}}, {0, 255},
         ColorFunction->RGBColor,
         ImageResolution->288.],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
         Automatic],
        Selectable->False],
       DefaultBaseStyle->"ImageGraphics",
       ImageSize->300,
       ImageSizeRaw->{300., 300.},
       PlotRange->{{0, 300.}, {0, 300.}}],
      TraditionalForm], Scaled[{0.5, 0.5}], Scaled[{0.5, 0.5}], Scaled[1]], 
    CircleBox[{0, 0}]}, {
    {RGBColor[
      NCache[
       Rational[2, 3], 0.6666666666666666], 0, 0], AbsoluteThickness[2], 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAUJYdAADp5j8U1uileNSzP8yvYTjJ
yOY/jPfzdde3tD/Qbq7T5qjmP3zvnqAqnrU/JoF551mJ5j9cbJxRaoe2PyLP
UIYjauY/tGYtm45ztz9mJtG/REvmPyggZnaPYrg/Vv6coL4s5j9Y/XPDZFS5
P2VWUzKSDuY/3DjkSQZJuj+lroZ7wPDlPyRs67hrQLs/1hq0f0rT5T907K2n
jDq8P1VwOj8xtuU/NPmIlWA3vT8lj1G3dZnlPxS5XOreNr4/bMYB4hh95T/c
A9f2/ji/P6JUG7YbYeU/2Hpf+tsewD/PAy4nf0XlP/akoIOAosA/BuKAJUQq
5T9avZ6daCfBP4AWCp5rD+U/MNHJw4+twT+O02Z69vTkPzaOuWbxNMI/qmXT
oOXa5D+i8VTsiL3CP/NfI/Q5weQ/CFT6r1FHwz9Q5rlT9KfkP9DQpwJH0sM/
gRWCmxWP5D8mCCQrZF7EP2SJ56OeduQ/rDknZqTrxD+jAc9BkF7kP8K2hOYC
esU/GSWPRutG5D/SqlTVegnGPyJk6X+wL+Q/dDgeUgeaxj8i+gK44BjkP57p
AXOjK8c/Zw5etXwC5D/MceRESr7HP8L00jqF7OM/asCZy/ZRyD/0jYkH+9bj
PyxiEAKk5sg/O8jy1t7B4z/IL33aTHzJPzZAwmAxreM/rEiHPuwSyj9MAuhY
85jjPxZYdA99qso/2myKbyWF4z8aI1Um+kLLP1AzAFHIceM/Hl4yVF7cyz+F
gsql3F7jPybIOWKkdsw/WkaPEmNM4z+aiusRxxHNP/WQEzhcOuM/t9tHHcGt
zT+7IzazyCjjP2ni/DaNSs4/MxrqHKkX4z+12ZQKJujOPxO3MQr+BuM/ZXKk
PIaGzz+rCEtp
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVUH0s1HEcFpdTXacXlC2TaadLauUcOVZi87JW465GSfIWapKJY1IjdjqX
htGxRcNWUm3YrTQ9zGb0ojv3hvP2+1JyXOY9Y/Trj2efPXs+z+f57HGKuRsW
b25mZsal8X/WRtfpqEUK8l2iheXJYXQn9AS7z1PQLwpfepQMQ1RrPG8xR6Gg
e2kh4cww7O7t14aaKPhuM6qKJwxILttkO85SeNARwm2UGWD+3H49eYZC4lXx
ZKenARxpfo0HzVmrjDkdNYQ0sDZzab7AqeLNSofA+sy3CaT9c+KxWgZ/CBGR
PIOMvr9hfdPReXwQx1anA4V0PsM7ozrkySAS1aaQSvq/bKujZrm8QfDqJcqI
JQpVMwe8OkYHIOYrOqpWKbiGJrjZFA3gpx9nK2KdQlOgvDfHfQDhN3xvV25R
UHDylzdG9Cg/YjcexiCQ+HLllRI9ouLzeMU7CMSSxupL7nr0yVkCf2uCCymc
CZdRHUxJa52ZtgSnC+tEzkU6pEcFl3EPEVy5taIO4OmgULSlhzsT9OS98i8Z
06Ik9qsLw5Wg3Wrs8XapFpEun5KOuxNoBv0yG/laGIZki0oBQVwB+fuIaDCg
2509H0Dw7LLzL+lTDVrz+t7KLhIwk1/Y93lrIGGeFDSEE/gR1p2QKTWGXa5/
8YwlOHzwRKtFuRpGQfhWQAqBYuZd98Y5NQRhS1nfsmjdaW+G159+PEwf0X4v
IHBTlZZ+rO5H057qxqBSgn6TrTEvuB/swjKpTw2BjYEZVLmqQpTO2up1E4HQ
Ifj+WoMKFdln38ja6H0HW68mkQpp13w2pnvoPiyNwmYLFUpN7Nx2PYGyJbWI
3aLERGrze+YUQW9XXEVXjBLRQntWzwpByoccD80+JX4rTu3ctJwAO63ep7Dw
B/4BC3Z8jg==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVjn0s1HEAxi8uVEJFZcvMNC8rNXOOvOwpbuOsFY5G6c1bUlOaiJnZ6W7O
ORqWUF6GTZKKpqh0pplKunNv3Hn7fVnmkLxeIrr+ePbs88fzYhd9KzTOgEaj
Oev13yd3hS2uTA6j70qtklqiYLfMqXEvHMZifC/bbYFCf8/yYvyJYWRXa/0M
5ynwtmml+RMa+CXvU4TMUfgkDnJuFGnwsHjTzHaWQvP5e5NdHhq4PLJeT5yh
EKKjzyspNYKFOVXuemY6ljNmhWo8/mi6maVn1/SxajpTDWYn0zJAn/e1uGpr
Pz4EbhRDI9L3s7xSK4LyhsDRTQdw9PvtJk60LMYQHsjmgkr1/wZnDniKRwcR
VZcriVymkBAS72IpGEQNs01crqMwFVD2OdNtEGZ+DluR6xQWHHJWNkZUyL7s
e6N0i0KXr3NZaa4K7w/vHw+lE7zKbaw466YCP47LyN9BkJPkMOE4qsRqmam3
vzlBAr82zF6ghFXiWleaFUHetVUZi6HEk0vsYudDBH+5Df6FYwqMtnWkRNgT
/DIZu79dqEBbzFdH+hECI/WptEamAjzHd9ePuhGU8MjvbCKHgUa0JPEmEIfb
/xAWyEFT7c5YYBG4J1Za93vJMcztfy46Q5BETG8GTcnw0vi4d30EwemDx14b
lshAd7r4xSOGgMw092yclMHSJ2KLlUTAttuT6vlzALGhy+l96QTh0qKi9ooB
NKSMKL7xCP7MWWm57AHILSoaA4sIvDTGgaU6KTz5xUKfKoIMG/bdtXopBEpz
k6dNBDobK8+mMCnEGXgm6iA4Z6TltBhKUXnBZ2O6l2Cp9bbArFWCzjmzrA8q
Am137MPuaAnMk1teGE8RFLzNdJfvlSCfY23au0oQfKfOh8//Dss3rjs3jSbw
D5lJVec=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAmNXopXjUs78mlh0AAOnmvwz383XX
t7S/oq9hOMnI5r/87p6gKp61v6ZurtPmqOa/4GucUWqHtr/+gHnnWYnmvzhm
LZuOc7e/+M5QhiNq5r+kH2Z2j2K4vzwm0b9ES+a/1Pxzw2RUub8t/pygvizm
v1g45EkGSbq/PVZTMpIO5r+ca+u4a0C7v3yuhnvA8OW/7Outp4w6vL+uGrR/
StPlv6z4iJVgN72/LnA6PzG25b+MuFzq3ja+v/6OUbd1meW/VAPX9v44v79F
xgHiGH3lv456X/rbHsC/fFQbthth5b+upKCDgKLAv6kDLid/ReW/EL2enWgn
wb/g4YAlRCrlv+LQycOPrcG/WhYKnmsP5b/ojblm8TTCv2jTZnr29OS/VPFU
7Ii9wr+EZdOg5drkv7hT+q9RR8O/zV8j9DnB5L9+0KcCR9LDvyrmuVP0p+S/
1gckK2RexL9cFYKbFY/kv1o5J2ak68S/P4nno5525L9stoTmAnrFv34Bz0GQ
XuS/fqpU1XoJxr/0JI9G60bkvx44HlIHmsa//mPpf7Av5L9H6QFzoyvHv/z5
ArjgGOS/cnHkREq+x79CDl61fALkvw/Amcv2Uci/nfTSOoXs47/OYRACpObI
v86NiQf71uO/Zy992kx8yb8WyPLW3sHjv0xIhz7sEsq/EkDCYDGt47+zV3QP
farKvygC6FjzmOO/tiJVJvpCy7+0bIpvJYXjv7ddMlRe3Mu/KjMAUchx47+9
xzlipHbMv2CCyqXcXuO/MIrrEccRzb80Ro8SY0zjv03bRx3Brc2/z5ATOFw6
47/64fw2jUrOv5QjNrPIKOO/RdmUCibozr8NGuocqRfjv/VxpDyGhs+/7LYx
Cv4G47/yeHmJ
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAJNbopXjUs79Elh0AAOnmP5z383XX
t7S/wK9hOMnI5j+M756gKp61v8RurtPmqOY/cGycUWqHtr8cgXnnWYnmP8xm
LZuOc7e/Fs9QhiNq5j88IGZ2j2K4v1om0b9ES+Y/cP1zw2RUub9K/pygvizm
P/A45EkGSbq/W1ZTMpIO5j88bOu4a0C7v5quhnvA8OU/kOytp4w6vL/MGrR/
StPlP1D5iJVgN72/S3A6PzG25T80uVzq3ja+vxyPUbd1meU//APX9v44v79i
xgHiGH3lP+Z6X/rbHsC/mVQbthth5T8IpaCDgKLAv8UDLid/ReU/ar2enWgn
wb/94YAlRCrlPz7RycOPrcG/dxYKnmsP5T9Gjrlm8TTCv4XTZnr29OQ/tPFU
7Ii9wr+hZdOg5drkPxpU+q9RR8O/6l8j9DnB5D/i0KcCR9LDv0fmuVP0p+Q/
PAgkK2RexL95FYKbFY/kP8I5J2ak68S/XInno5525D/WtoTmAnrFv5wBz0GQ
XuQ/6KpU1XoJxr8RJY9G60bkP4s4HlIHmsa/GmTpf7Av5D+16QFzoyvHvxr6
ArjgGOQ/4nHkREq+x79gDl61fALkP4HAmcv2Uci/vPTSOoXs4z9DYhACpObI
v+yNiQf71uM/4C992kx8yb80yPLW3sHjP8RIhz7sEsq/MEDCYDGt4z8uWHQP
farKv0YC6FjzmOM/MiNVJvpCy7/UbIpvJYXjPzZeMlRe3Mu/SjMAUchx4z9A
yDlipHbMv3+CyqXcXuM/sorrEccRzb9URo8SY0zjP9LbRx3Brc2/75ATOFw6
4z+D4vw2jUrOv7YjNrPIKOM/0NmUCibozr8uGuocqRfjP4BypDyGhs+/Drcx
Cv4G4z9s02Ib
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA6gtU8vXk3D/KYKPW4fPhvyf0U6E1
j9w/8GbISTPx4b/UxvTyZjncP36g6kID7+G/iwHq0Yzj2z9AcRPVUe3hv8rA
Simqjds/k5P+Dh/s4b+0WnjkwTfbPyqYGftq6+G/V/cE79bh2j9Oi4OfNevh
vzwnmjTsi9o/mr8M/n7r4b84ed+gBDbaPzS+NhRH7OG/RBBhHyPg2T+AXDTb
je3hv0s6dptKitk/UPfpR1Pv4b/ACCgAfjTZP47T7UqX8eG/3usXOMDe2D9a
pIjQWfThv25RZi0Uidg/nDa2wJr34b/uR5nJfDPYPwpCJv9Z++G/+CaD9fzd
1z98Xz1rl//hv8g9KZmXiNc/uSQW4FIE4r+3iKqbTzPXP4JlgjSMCeK/im4m
4yfe1j/zmQw7Qw/iv3CGo1QjidY/Emr5wXcV4r+SZ/bTRDTWP5heSZMpHOK/
A4OoQ4/f1T/atrp0WCPiv/cI34QFi9U/smPLJwQr4r8M2kF3qjbVP4Anu2ks
M+K/nIXi+IDi1D/+2o3z0Dviv8dVI+aLjtQ//NYNevFE4r88ap4ZzjrUP9iC
zq2NTuK/duIMbErn0z+rBy87pVjiv1QYLrQDlNM//iddyjdj4r/p667G/EDT
Pw48WP9EbuK/UCERdjju0j9eUvR5zHniv13RkpK5m9I/onTd1c2F4r8B7hXq
gknSP84Qm6pIkuK/QNsHSJf30T8yhpOLPJ/iv4AdSXX5pdE/g9YPCKms4r/+
HRU4rFTRP7p6P6uNuuK/XAbqU7ID0T+YWzz86cjiv/qzcIkOs9A/uO0Ofr3X
4r/yw2SWw2LQPwhxsq8H5+K/lrh8NdQS0D+GUxkMyPbiv11ypDyGhs8/Drcx
Cv4G47/+j2va
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAtGCj1uHz4b/HC1Ty9eTcP9xmyEkz
8eG/BPRToTWP3D9qoOpCA+/hv7HG9PJmOdw/LnET1VHt4b9pAerRjOPbP4KT
/g4f7OG/p8BKKaqN2z8bmBn7auvhv5JaeOTBN9s/QIuDnzXr4b809wTv1uHa
P42/DP5+6+G/GieaNOyL2j8ovjYUR+zhvxZ536AENto/dlw0243t4b8iEGEf
I+DZP0j36UdT7+G/KTp2m0qK2T+G0+1Kl/Hhv54IKAB+NNk/VKSI0Fn04b+9
6xc4wN7YP5k2tsCa9+G/TVFmLRSJ2D8GQib/Wfvhv85Hmcl8M9g/el89a5f/
4b/YJoP1/N3XP7gkFuBSBOK/qT0pmZeI1z+EZYI0jAniv5mIqptPM9c/9pkM
O0MP4r9rbibjJ97WPxVq+cF3FeK/UoajVCOJ1j+eXkmTKRziv3Rn9tNENNY/
4La6dFgj4r/mgqhDj9/VP7pjyycEK+K/2gjfhAWL1T+KJ7tpLDPiv/HZQXeq
NtU/CtuN89A74r+CheL4gOLUPwjXDXrxROK/rVUj5ouO1D/mgs6tjU7ivyNq
nhnOOtQ/ugcvO6VY4r9e4gxsSufTPxAoXco3Y+K/PBgutAOU0z8gPFj/RG7i
v9Lrrsb8QNM/clL0ecx54r87IRF2OO7SP7h03dXNheK/SdGSkrmb0j/mEJuq
SJLiv+7tFeqCSdI/SoaTizyf4r8u2wdIl/fRP5zWDwiprOK/bx1Jdfml0T/U
ej+rjbriv+4dFTisVNE/s1s8/OnI4r9OBupTsgPRP9XtDn691+K/7LNwiQ6z
0D8ncbKvB+fiv+bDZJbDYtA/plMZDMj24r+LuHw11BLQPy63MQr+BuO/SnKk
PIaGzz+RZWhn
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAATpYdAADp5j8I1uileNSzv8qvYTjJ
yOY/gPfzdde3tL/Obq7T5qjmP2zvnqAqnrW/JIF551mJ5j9QbJxRaoe2vx/P
UIYjauY/qGYtm45zt79jJtG/REvmPxggZnaPYri/Uv6coL4s5j9I/XPDZFS5
v2JWUzKSDuY/zDjkSQZJur+iroZ7wPDlPxRs67hrQLu/0xq0f0rT5T9k7K2n
jDq8v1JwOj8xtuU/IPmIlWA3vb8ij1G3dZnlPwS5XOreNr6/acYB4hh95T/Q
A9f2/ji/v59UG7YbYeU/znpf+tsewL/MAy4nf0XlP+ykoIOAosC/AuKAJUQq
5T9SvZ6daCfBv30WCp5rD+U/JtHJw4+twb+K02Z69vTkPyqOuWbxNMK/pmXT
oOXa5D+a8VTsiL3Cv+9fI/Q5weQ//lP6r1FHw79M5rlT9KfkP8bQpwJH0sO/
fRWCmxWP5D8eCCQrZF7Ev2CJ56OeduQ/pDknZqTrxL+fAc9BkF7kP7a2hOYC
esW/FCWPRutG5D/JqlTVegnGvx5k6X+wL+Q/aDgeUgeaxr8d+gK44BjkP5Xp
AXOjK8e/Yw5etXwC5D/CceRESr7Hv7300jqF7OM/YMCZy/ZRyL/ujYkH+9bj
PyFiEAKk5si/Nsjy1t7B4z+9L33aTHzJvzFAwmAxreM/oUiHPuwSyr9HAuhY
85jjPwxYdA99qsq/1WyKbyWF4z8OI1Um+kLLv0szAFHIceM/EV4yVF7cy7+A
gsql3F7jPxrIOWKkdsy/VEaPEmNM4z+MiusRxxHNv++QEzhcOuM/q9tHHcGt
zb+0IzazyCjjP13i/DaNSs6/LRrqHKkX4z+p2ZQKJujOvw23MQr+BuM/W3Kk
PIaGz79vKV5Z
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVxXss1AEAB/BzNskfRKPLq9p5FGHUdKxFJiJ/OK6mzc77Vpg3KzGmPIuz
xpZHt1vOxHbYvE7h6xA/500ozOT38LpacrtJZtUfn30uRSeHxLFZLNaVf/7/
vdqKxdphkLK43fjkcwcS26J44wQDjfYgc7mnE2lJrQvMewbqHxKpg6QLqvyn
Ww9LGXxJqOfHF3eDmA4u4sYz4Imc6irSe2BoNwffewzaL4iyxNEKsE7qpQNX
GVDH6cOxgl6YPAh1e23IIINHBegFfICgtejZ4E8aIwl7igTvjyg278wLXKBh
qZY3vfLsg36Kp5drN42Nw5LqyBv9WKng92TW0JhVhO+uuw+AO6qzycmlUaW7
rD3hAeECi26LKBqK7IijVetBvNR1ts+7Q2NFJn2e/24QI9/ybX0daPj0S94+
slfC28xAkmBEgzM3PiyWKxG8IMrWaihYV/SK9q8PISluQUqvUKjcF6hL+ofQ
G8HVeCgpaEOP2vj+w+AwvaGaJgpDs01s//lhBJkW1JmKKVjq2zjGCkfgVrrV
IMmiIPOwF8n2RpCuM3O7UkhB0f2CYWd/wq6N2G/Pj8Jki2Ax+/QotDE7ee0u
FJJ51iGnakdx+Jut2OBQqN3RSW9wHIOXobArh01BlUr5Bg6MoV4z71moJhE/
WDOh5ROYLS899WeJhFP0GbaMIXCe+LW0riRBuOSuBOWMw8x7KNJVTkJ+t/iW
2kQFZ/Z22MEbEpywDKPcFhUGEsuSbQtJWHHv2x35TMD9GotPpJK4KHQTCNcm
kFSgalwTkrAnPKJlWZPw9RObxASRqCvbMx4znsJm5VleuCeJvlV/K6V8Cs1c
9w7iMonEzWP38sBp2JjvWjafI6H4WmVgtz0NvR5XgxM9Eo/TZDeLimbwFwDX
dvM=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVjn0s1HEAxq8ISYeismVmmkuvqzsveekRFmeLeWk7VIpoyZQSMZN5udE5
NiyOFg1boWw0iVWMmd64c+7O3Xn7fRnzlnAcc3P9+uPZs88fz4t9zMPQuL0M
BsOJ1n8fuF0np9YpzBwIX9uYGcNK/ACXvUrBXhP2xrlkDJm1Cz4GKxQG+zVr
8ZfGcDn5sCxkmQJ/z4KkaFqN0rJdpt0Shb7uQKdGoRqnKm12EhYptEQ+m+lx
VeOaILfGmeZQreGKnFKh8pvZbhbNrqwqzpJABfZXFyt/Os9On6w1dFHh+Q2O
Wkj3w+KOncOUEsHaef8wev+qe2p14AslhNLlwAr6X5fJSUYWRwlefYE4QkNB
tXjUrXtiFK9c2rurtBQSQuLPWhWOwtTHUR+xQ2HeX/Q9kz2KzGivBxV6ChrH
3A3duAIdJ45MhRoS9Hk5iSoKFMiJy+EU7SdoK2isDmYrsCYy8/A1J+AnOU6z
JuSwTNjuSbMmSOTXhTsUylF5i1vmdJyg+N6m1I8jh7K9M4XnQMDIfetbMilD
a+xPluFpgnWTybx9AhmyWV33z7AJTFVX0hpdZNhVCdfFHgSifLKVTUagkx/M
WPWj/1x3mBUUj2A0Z/C9MIjAPeG1zaD7CJqMz3s08AieELPEwDkp9KybP1xj
CUKOnftoUC4F05On90simF380K/zliI6VJP+K50gyN4y1e3PMOpSxmW/8wki
JaWln6uHMWRR3RhQSqBftl7I4Q7jIr9M4FlD4K02DqjQSpAnNzd510yQZct9
ut0gQWcGmoSdBDpba7fmcAkqozx18wMEUUYLYa0GEnQsM7O+KAi22h4VMtvE
ME1ubTGeI/jbe/dlb4wY/DAbs4FNgvKOTOeRQ2IwP10w3TWaRtTjek8+fwj/
AOc6V7g=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVjn0s1HEAxm+Rl7qQXGiZGjuuVGvO67GSW9y1lbg2elF5nWqS5C1T8zZv
l+ZaN26Lhk0X2jBJs4c005vu3AvucH5fljlv854YnT+ePXv+eD7PczzqYWjs
HhqNxjJo15n7BUurkyMIuVOjppYpxC+HvfUoG8HTuD6e+yIF296VpTifEdCr
9ReMFigM0PTy0gkt5EmHVFfnKDC6+CypUAuWaNvCcZaC0fX0yW4vLb6K7Tfv
zVCQrhkvqCkNZopzqzwMWcSsZM+WaOAL+nb2bk7XVRt7ajDU6WkTZOjXWN51
dBofhutNtlZo4Df5pEr4xcP4tzYdFGbYdzVzpWWzh+GnmOOLDf8uzdh6d40N
gV5bKItYoaALiTtlUzSEUM+2rsp1CtFBFd+y3IfwJYC5E7FJIZmZu7o1Ogjv
2/73xTsUgvxZFeLCQaQ7Hx4PNSbgFEolV9wHwY3NYZeaE1gnMidcxtRor6Bz
Ai0JtvJrBE5FamgSNrrTGATO8WsKLluNmEieiHWUQJJTH1imU6G+rSMl3IlA
ZKbL21uiQl70DxfjkwRNwwFpUk8VBC6fE9zcCQLzyd/nRAmVRrgs4xA8vub0
p+SFEkr1gcxFLsF8whv7fl8lWnP6G4WXCdwI/QF/SoEi0zOcunACK7vTrUav
FBh3ufXdK5pAOtPUu3VegSVO+A43kcDu+MFU7/kBcENXMn5mEJyQl5d/kgyg
NGVU9SufQDHH0OfwBtBhJZEGlxMc0ZoGi9flOFYgKvGrIoh04D3ZqJMjWW1p
9q6BgDgwvBsEcjRknnsv7CC4aKIPazaSo/SG39Z0H4G+JanIokWGxjmL7M5B
gqmemNc9UTLQHjV/MJ0ieNme5aG0luFZmD29b83AT671Kyj4DfOPZ/dtm0zg
P/rCe18=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAABNfopXjUsz/Hlh0AAOnmP2j483XX
t7Q/PrBhOMnI5j9E8J6gKp61PzpvrtPmqOY/FG2cUWqHtj+MgXnnWYnmP1hn
LZuOc7c/gc9QhiNq5j+0IGZ2j2K4P74m0b9ES+Y/1P1zw2RUuT+o/pygvizm
P0Q55EkGSbo/slZTMpIO5j+AbOu4a0C7P+yuhnvA8OU/xOytp4w6vD8XG7R/
StPlP2z5iJVgN70/kHA6PzG25T9EuVzq3ja+P1qPUbd1meU//APX9v44vz+a
xgHiGH3lP956X/rbHsA/ylQbthth5T/4pKCDgKLAP/ADLid/ReU/WL2enWgn
wT8h4oAlRCrlPyTRycOPrcE/lhYKnmsP5T8kjrlm8TTCP53TZnr29OQ/jvFU
7Ii9wj+yZdOg5drkP+pT+q9RR8M/9F8j9DnB5D+w0KcCR9LDP0zmuVP0p+Q/
AAgkK2RexD93FYKbFY/kP4Y5J2ak68Q/VInno5525D+UtoTmAnrFP4wBz0GQ
XuQ/oKpU1XoJxj/7JI9G60bkPz44HlIHmsY//mPpf7Av5D9m6QFzoyvHP/f5
ArjgGOQ/knHkREq+xz82Dl61fALkPy/Amcv2Ucg/ivTSOoXs4z/uYRACpObI
P7aNiQf71uM/hy992kx8yT/2x/LW3sHjP2xIhz7sEso/6z/CYDGt4z/UV3QP
farKP/wB6FjzmOM/1SJVJvpCyz+CbIpvJYXjP9ddMlRe3Ms/8jIAUchx4z/g
xzlipHbMPyGCyqXcXuM/U4rrEccRzT/vRY8SY0zjP3PbRx3Brc0/hJATOFw6
4z8l4vw2jUrOP0IjNrPIKOM/ctmUCibozj+0GeocqRfjPyRypDyGhs8/jrYx
Cv4G4z+eT1MC
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAdNXopXjUsz+2lR0AAOnmv/T283XX
t7Q/NK9hOMnI5r/s7p6gKp61PzxurtPmqOa/0GucUWqHtj+VgHnnWYnmvzhm
LZuOc7c/k85QhiNq5r+oH2Z2j2K4P9ol0b9ES+a/4Pxzw2RUuT/O/Zygvizm
v2g45EkGSbo/4FVTMpIO5r+4a+u4a0C7PyKuhnvA8OW/DOytp4w6vD9WGrR/
StPlv8z4iJVgN70/2G86PzG25b+8uFzq3ja+P6uOUbd1meW/fAPX9v44vz/0
xQHiGH3lv6h6X/rbHsA/LlQbthth5b/KpKCDgKLAP14DLid/ReW/Lr2enWgn
wT+Y4YAlRCrlvwLRycOPrcE/FRYKnmsP5b8Kjrlm8TTCPybTZnr29OS/ePFU
7Ii9wj9EZdOg5drkv9xT+q9RR8M/kF8j9DnB5L+k0KcCR9LDP+/luVP0p+S/
+gckK2RexD8kFYKbFY/kv4I5J2ak68Q/Conno5525L+UtoTmAnrFP0sBz0GQ
XuS/pKpU1XoJxj/DJI9G60bkv0Y4HlIHmsY/z2Ppf7Av5L9u6QFzoyvHP9H5
ArjgGOS/m3HkREq+xz8ZDl61fALkvzjAmcv2Ucg/dvTSOoXs47/2YRACpObI
P6qNiQf71uO/jy992kx8yT/0x/LW3sHjv3JIhz7sEso/8j/CYDGt47/aV3QP
farKPwoC6FjzmOO/2yJVJvpCyz+abIpvJYXjv9tdMlRe3Ms/EjMAUchx47/i
xzlipHbMP0qCyqXcXuO/UorrEccRzT8gRo8SY0zjv27bRx3Brc0/vpATOFw6
478c4vw2jUrOP4UjNrPIKOO/ZNmUCibozj8AGuocqRfjvxJypDyGhs8/4rYx
Cv4G479afmTV
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAASgxU8vXk3L8oYaPW4fPhP4P0U6E1
j9y/SmfISTPx4T8sx/TyZjncv9Cg6kID7+E/3wHq0Yzj27+OcRPVUe3hPxnB
Simqjdu/3JP+Dh/s4T//WnjkwTfbv26YGftq6+E/nPcE79bh2r+Mi4OfNevh
P30nmjTsi9q/0r8M/n7r4T9zed+gBDbav2a+NhRH7OE/ehBhHyPg2b+tXDTb
je3hP3w6dptKitm/ePfpR1Pv4T/sCCgAfjTZv7HT7UqX8eE/BewXOMDe2L94
pIjQWfThP49RZi0Uidi/tja2wJr34T8JSJnJfDPYvx5CJv9Z++E/DSeD9fzd
17+KXz1rl//hP9g9KZmXiNe/wiQW4FIE4j/BiKqbTzPXv4dlgjSMCeI/jG4m
4yfe1r/ymQw7Qw/iP2yGo1Qjida/DGr5wXcV4j+IZ/bTRDTWv45eSZMpHOI/
84KoQ4/f1b/Ktrp0WCPiP+AI34QFi9W/nmPLJwQr4j/v2UF3qjbVv2gnu2ks
M+I/d4Xi+IDi1L/g2o3z0DviP5xVI+aLjtS/2dYNevFE4j8Kap4ZzjrUv7CC
zq2NTuI/POIMbErn079+By87pVjiPxIYLrQDlNO/zyddyjdj4j+g667G/EDT
v9o7WP9EbuI/ACERdjju0r8mUvR5zHniPwXRkpK5m9K/ZXTd1c2F4j+i7RXq
gknSv4wQm6pIkuI/2toHSJf30b/shZOLPJ/iPxIdSXX5pdG/N9YPCKms4j+H
HRU4rFTRv2p6P6uNuuI/3gXqU7ID0b9EWzz86cjiP3OzcIkOs9C/YO0Ofr3X
4j9iw2SWw2LQv6xwsq8H5+I//rd8NdQS0L8lUxkMyPbiPxxxpDyGhs+/qbYx
Cv4G4z8XQmoo
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAQGCj1uHz4T8OC1Ty9eTcv2lmyEkz
8eE/TvNToTWP3L/5n+pCA+/hP/7F9PJmOdy/vnAT1VHt4T+5AOrRjOPbvxWT
/g4f7OE/+r9KKaqN27+vlxn7auvhP+hZeOTBN9u/1oqDnzXr4T+O9gTv1uHa
vyS/DP5+6+E/diaaNOyL2r/CvTYUR+zhP3V436AENtq/EFw0243t4T+FD2Ef
I+DZv+L26UdT7+E/jzl2m0qK2b8j0+1Kl/HhPwgIKAB+NNm/8qOI0Fn04T8q
6xc4wN7Yvzg2tsCa9+E/vlBmLRSJ2L+oQSb/WfvhP0FHmcl8M9i/HF89a5f/
4T9PJoP1/N3Xv1okFuBSBOI/JD0pmZeI178mZYI0jAniPxeIqptPM9e/mZkM
O0MP4j/tbSbjJ97Wv7pp+cF3FeI/1oWjVCOJ1r9CXkmTKRziP/1m9tNENNa/
hra6dFgj4j9ygqhDj9/Vv2JjyycEK+I/agjfhAWL1b8yJ7tpLDPiP4TZQXeq
NtW/sdqN89A74j8YheL4gOLUv7DWDXrxROI/R1Uj5ouO1L+Ogs6tjU7iP8Bp
nhnOOtS/YwcvO6VY4j/+4QxsSufTv7gnXco3Y+I/4BcutAOU07/KO1j/RG7i
P3rrrsb8QNO/G1L0ecx54j/mIBF2OO7Sv2F03dXNheI/99CSkrmb0r+OEJuq
SJLiP5/tFeqCSdK/84WTizyf4j/k2gdIl/fRv0bWDwiprOI/Jx1Jdfml0b9+
ej+rjbriP6gdFTisVNG/XFs8/OnI4j8MBupTsgPRv37tDn691+I/rrNwiQ6z
0L/QcLKvB+fiP6rDZJbDYtC/TlMZDMj24j9SuHw11BLQv9e2MQr+BuM/4HGk
PIaGz78AHmq/
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAASpYdAADp5r+Q1uileNSzP8SvYTjJ
yOa/APjzdde3tD/Gbq7T5qjmv+TvnqAqnrU/HIF551mJ5r/AbJxRaoe2PxXP
UIYjaua/FGctm45ztz9WJtG/REvmv3QgZnaPYrg/Rf6coL4s5r+g/XPDZFS5
P1RWUzKSDua/IDnkSQZJuj+RroZ7wPDlv2Bs67hrQLs/wBq0f0rT5b+o7K2n
jDq8Pz5wOj8xtuW/XPmIlWA3vT8Mj1G3dZnlvzy5XOreNr4/UMYB4hh95b/4
A9f2/ji/P4VUG7YbYeW/4Hpf+tsewD+wAy4nf0Xlv/ykoIOAosA/5OGAJUQq
5b9gvZ6daCfBP10WCp5rD+W/MNHJw4+twT9o02Z69vTkvzCOuWbxNMI/gmXT
oOXa5L+c8VTsiL3CP8pfI/Q5weS//FP6r1FHwz8k5rlT9Kfkv8LQpwJH0sM/
VBWCmxWP5L8WCCQrZF7EPzWJ56OeduS/mjknZqTrxD9yAc9BkF7kv6y2hOYC
esU/5CSPRutG5L+5qlTVegnGP+xj6X+wL+S/WjgeUgeaxj/q+QK44Bjkv4Hp
AXOjK8c/LQ5etXwC5L+sceRESr7HP4b00jqF7OO/RsCZy/ZRyD+1jYkH+9bj
vwRiEAKk5sg/+sfy1t7B47+gL33aTHzJP/M/wmAxreO/gkiHPuwSyj8GAuhY
85jjv+lXdA99qso/kmyKbyWF47/qIlUm+kLLPwYzAFHIceO/6l0yVF7cyz84
gsql3F7jv/LHOWKkdsw/CkaPEmNM479jiusRxxHNP6OQEzhcOuO/gdtHHcGt
zT9mIzazyCjjvy/i/DaNSs4/3BnqHKkX47962ZQKJujOP7q2MQr+BuO/K3Kk
PIaGzz/HjWNG
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwtknks1nEcxzF5xLOiBxMLj1pzjGXkSr1RKemJ2uMPosPVQhNWEumgFKYc
maYpc0RNrpCjdWwo2+OmmOd5ft+PI3lolHOWpa0/Xnv9+9p7b2FQ1KlQFSUl
JfMN/vnzueIh9pthXFP8a3F8FCTIW9ZaYujUCNbwFEqRPujWkLTCsMnWKTM7
UIqUFCt1yzWGRIE0vveJFCKzPqa7ztA9feeL6pAUEtMCeygTSnlZ8ZbbZMgP
m1wpUyWYmJXcO3RChuYaVQOROiHqW87siTQZ1CROaTZ8gn/P1Vee7TIsdLc6
irUIH7xfvLNVkUP54ltBvQ5hIb5DyD8gR76Fl7p4O4FVtQ32xstxbTRVxcaI
MD3FfU2ul6Os98qs105CqEblbuG8HDJ37boSM8JIYfo5sR6HhEovl33WhHDT
vf18Ow4z9vzorXaEyjDziKaTHPJ19jgKnQmTXHS5XxQHj5W0uMuuhOLjIs3Z
DA4rt74L/ngQivpsdGJfcnCt5s23iwgS6+6Dig4OW0JK5yVigvuglqHvBIfJ
gZhl7QCCl56JYbUKQ5a+4Vh2MCHALaxtzZjBucI91yeCMN+eWeCwn2FpLvXH
sViCr98D42B/hobh5A+3Ewiu/Iz+G3EMxec7FxeSCUdidZ1TcxlGbRUhJRkE
7fc/B5NqGJ4cjpl6+JjgPWxlEdLF8Dpuyq+xkBB006HZXsEQ7jKQZVBOeHP6
4+YlHqHHrflCUw2hdsfA06JdBAsTo9qclo2+R5JlRzfCDD/Zo6KNEFkV9Kwl
kDCXFbm62k1QainSN79OWD16tvDuCKHNc2HqVh4hpYDxjk8QnvoJ8z7VEsbv
JfJEcxt/OONdNtu1sVtI66X7a4Q6H7XnygqCTqONxrraGAz++y8lXlBc
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwdjAtIUwEYhS9qRCkiWqKVslC0lag5fDBfcz4IFV9QmjOnkuhqpeYSnaJD
zAcJleFbdE6d5kKny+UjO1YgaRNFZk2yhhi7d8OZJkFlWLd+OPx8fIdzNqcg
JdeCIAgmnX9f2exCEEYDhGvUQKlWBc12XYr+jwFRc7FfWAEqZESM1JOOJLwE
gkJh+zhcG8LCnbxJrHSl7rgfjkFkH2RfFE2CKlce8K+PoYNl7trLIDHJavRh
aJRY/W0lbheRGFoVncr3V+K2uSIyv5EEcUfdKOKMQqkYbrrWT+JhvNMtP+cR
1COUKHtB4tJ87LLt96dwTIpwn9aS4Ng59thqFdjfcmlhmEnMvZ6aDlAPg+3e
ua04QsFO/+Hb/c4n4Mo2Z3muFHxtso471AzBVlrR4xNIodC2XL1SMIgrH3ke
nkm0F5d0L2TKweGtGSIEFM71KXkWyQPo4QyKqqopTM7XlFXF9EPT9jNH30lz
ceDd6PA+WLKyorIn6L731mxasAxhpRvDVsv0flLus1l2L+qj9Z4LFIVdZpyi
NFSKN29j40csjFCqK5dO13VjiS8aUp0xwndzJ8iyows2Yg+NLsAIQhRJjqo6
kFghi3FJNoIxLz92XtuGA7lMLrlJ+yazquygBTWHPLFFLe0Zog05sxmuAZJE
mdQIyd4BbyrzMRRd4Sr+jBG7VIN5suMRVq3j/Njv6b6pISN95gFC1tfSLu4Z
IS0ZZgcnNuLHQut4lI0Jkrq6QLe9enw6urxY7GkCJ2FCx+i9h5POXK+XXBOk
ldZ5XH41Wtcjst0yTZi7sbxxIbUS/SWKfVkZze82xSk2pfAXmoQhzfRe9/NF
h89FuFrz6/JXpQnE7ivDifY8CHWCwBkNzQm1Ei4/FUxtensPRfP/04X8BYVM
acg=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwdzX0s1AEYB/CbWPOSiWZK2hVj0lLe56Wv9xkt3NaYkzvGMBrmR3dc3JCX
dVsrkbc4F4cjjovyVtp6cXbtbN7Lcpb8fnd1pJc/itSvnu27Z5999+w5mZLD
SjNgMBjOdP7tvQWqkzevQES9HYOh3YRmKnLD3UuBRH0Va+3PJlSZmbnZjUP4
GNRfTVqTIO7HbTnsD0JccwE2Z0ncFch3OamD0Fv6WOaFkcj2ELkyVXKYeOhb
dhJJpM4RxzI85fD/bVjUSJAQ5o+IiMABqPWCkAwRCZtLNlfdjvbDuE9250oH
Cc3rSLX5jz68fRbA4E/QPmzdZj7fC25MkMPYPAnui9ExrxEZPDbs6pl6ElOa
pa83m3tAODR/7jWiQB3imlhVdIOQrE+yT1BgWhSPzOZ0wUcsaHP1pvviwlZl
khT8d2xHpxgKmg452yC2Ewnshc2gTAoZ0xX80vAODAZ2EaVltAu8C8LwAIsN
P1PWminMun6YjPeTwMidG5o8TMGClfZo0rcdPrxVmaGagtglqpcXIEZR2JqT
kqLwZbTkjW1VKx5OR17sN9BCuLHlc6CpBQMcoltxXItz10LIAUUTSL6jatlL
i0Cl1Pj0fANOCSThdrFaMOr0Cv5uPV5JJVJhlhZMe2JV6lyHiH12kUGlFtzv
u+zRpFqseAqjJWItpj7V6J803UZSCxSccfrfdk1iwvgtXDeNcvNdpPtima9f
tAia5YX48zt0L6rytt+pRq3y3lComQ4a1vAys/0Gcg+qZ/KddGCUm6YHc8rQ
bhN85mkw7Xz1qktcCWxXgpLtk3QQzq0Xscx4YBb2fpPwaXc+nrF6n4eeLF22
fx3tveebRxrT8bL81+VtOX2fWikM5sRhdinTe1xF+/90T1TOJTS2UTr8BQYu
RxE=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwtzX8s1HEcx3HMnLgt4kwUTk1+pKUkST9OZYmT2rV2pSiSDcmPEkp+hMLk
V7amKUsizI9WccqrX1it/CZad/f9vPXjYtcoP7Msbf3x3OPPp/Bk5MFTWhoa
GnaL/bNTX/Jz6vMnNAXeHWS/GBr0gvS8hHL0GRXPGEwzqDZsyS04JkfCgOhx
0iyDv5E8vuemHLFXHHUd5hlqRlPfaA/K4W7bywQLDEm8/HiHZQrIrEtcdmgS
pteUZ+z2VSA95OtshTZBNFSo9s1SoKJB20ysS7DtPl/t1a7AxLstWU58Qvb+
+882aimh6HrqKjEgtMR3CPnblRgNbTJ6ZEyoqGsb6IlXItneW1eynFCt4j6k
PVIi8FOmlpMFYZVerY1wQomcnnNq71WEptLsQIkJh9cehg/LbQme1pv6+M4c
Amu93beuI2SG2IU1H+DQ7cKPWupMABdVKY3kkGi83lXoRkjwEeurczjYzmbF
nd1JiOt1Mo55wGEo+ZvRH09C2bquXWMdHKzqeRPtYoLxgIH5oS8c1EH3Jt5L
CCtMrMzrtRhe9UfPGPoTHEQhbfOWDGdMzUcKghZ/7bklm7cxCKo8ivzCCNbS
a5ZBRxi6xzO/74sh6PNz+i7FMeQNpz1PSSQYxAjcMosYEk+8nZpMIwy3/hhI
amBo3DgWXJ5DEAw72gd3MkTsiVZdv0GwubxZ5jLGkBKnkj4pJVw4+mLJNI/g
7t6fb1ZJiF3Zf6tsNeGOSHa6uYFgkfd+xlVE+G1p0VjYQlhbd/J2yzGCjJ/m
WdVGaJWVmdolEJ7lh8/NdRFSvSZVycWEV3sDStM/Eg5LhcUvGwniEsbz+UII
OL6/Qt1JqMm4yBOPE8L9dO5ojhFCg59GXJ0n9Dx20lvQGcHQf/8Crth1vg==

       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwdj3ks1nEcgHknr3i3yLFk0Usrx7TeHLnq0ytZcmZvW4oSko0mhFHpeHNm
ovROacpCjplrKORDGx3LfRTr9f6+H5EyjdxTlvrj2bPnz0cYFOl7gaekpGS2
wT8na0h+LX79gsWBz4fZPIMI9WB1N6Ec27Rly5pLDEr322fdD5Bj2JC4IWmF
gVBbntD3SI5BdyzVLNYYxP64/V5lWI4Wpv1Md52BBz8nwWLrGFYY59uCMsG7
PUUpLl5jGBc6uVKiQqD/+cGMV8YY5tWobPdUI9jUG1fh1jmGXz/aZ4gEBBHe
L15b8RQ42NNiJ9EkKEx4KxQcUiAX9lK7Xocgu6pjqC9BgfHm7moSfYLHU9wn
ab0CT31J5YkMCfTUK3cL5xSY0hc7425CUFdwN1Cix2Grs1ZdkSmBi7HNgMCa
Q/9KdyfHvQSpoWbhr05w2G0riNpiTdDORZX6RXKYqLPPTuhAkOThqTGTyaHp
Skb85cMb3S/SiSnncPTmN+0/rgTle3uOTL/l0KSaP9fpSWA0pGlwcoLDueDi
uS4JgZneToNqHsN3g9HLWv4EjuLQjjUjhle2GYzfDybo7czKP3CQoWGZc65P
OIGNX7pR8GmGo7Op34/HEAgFmQPX4xk+HpG23bpKYBqj65CayzDt/IfFBSnB
fOvPoaQahm1W0yFFmQSiEUvzkG6GSUejp+493Pi9caDJdpphbvyUX2MBQd6Z
9s1LfEIfp8Gc7aUEsh2DTwp3ETaImy6+qiEQZ3ct24kJNXca1j5oJvCtCnra
HEA4IJC6lnUQTDYVbjNLJPyUE7G62kNQ4bYwdVNGyB07V5A8SiD1E8re1BKG
5zO+xwRB5lnvkpluwo8p1/ieswT5PqrPlKcJ00NaLqWtEfAaRerrquP4u+G/
4S9nJWAR
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAPNbopXjUsz9Blh0AAOnmvxzBSuQz
NrM/Vu2HUt//5r8IamlwbJmyP99BrojnFue/rJ1X7iT+sT+aiT4/GC7nv8x8
sPtfZLE/6BI4EnFF57+kNIwvIMywPwY07ZzxXOe/mNN0Gmg1sD83/QR6mXTn
v/Bztox0QK8/y+18Q2iM57+IThhtMhmuPwasqpJdpOe/UMhKzw71rD/Xvz0A
ebznv0gSFp8O1Ks/XlBBJLrU57/QxLm6NraqPzPkHZYg7ee/KOHX8oubqT9y
JJvsqwXov0gOYAoThKg/c6LhvVse6L+QEHu20G+nPzegfJ8vN+i/UHx2nsle
pj9421smJ1DovzilsFsCUaU/WlvV5kFp6L/QyIR5f0akP7JAp3R/gui/0HU3
dUU/oz/XmPli35vovzgw471YO6I/BjNgRGG16L+AUmW0vTqhPzp43KoEz+i/
CCxLq3g9oD99Rd8nyejov9C6fs0bh54/sMhKTK4C6b9Q5e44A5qcP7JfdKiz
HOm/EHhD56+zmj/qeSbM2DbpvyDKpgkq1Jg/JnyiRh1R6b/gle2zefuWP8um
oqaAa+m/8CN03KYplT9M/lt6AobpvzD1+1u5XpM/3jWAT6Kg6b+Q7IntuJqR
P2ScP7Nfu+m/IPGJXFq7jz+DC0syOtbpv4B9qjo7T4w/59jVWDHx6b8Ajoc3
I/GIP5rJl7JEDOq/gFS12CChhT94B8/Kcyfqv8CEC2dCX4I/qRhCLL5C6r+A
ds/cK1d+PyPZQWEjXuq/wNbhelIMeD8pdqvzonnqvwCpt8oT3nE/smvqbDyV
6r+AA8LmFJlnP8+D+lXvsOq/AHSGgEJfVz/a12k3u8zqvwAAAAAAAMQ8kNNa
mZ/o6r8Xple5
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAwJUdAADp5r8w1uileNSzP9Tsh1Lf
/+a/GMFK5DM2sz9cQa6I5xbnvwhqaXBsmbI/GIk+Pxgu57+0nVfuJP6xP2US
OBJxRee/2Hyw+19ksT+CM+2c8Vznv7A0jC8gzLA/svwEepl057+o03QaaDWw
P0btfENojOe/CHS2jHRArz+Aq6qSXaTnv7BOGG0yGa4/Ub89AHm85794yErP
DvWsP9ZPQSS61Oe/eBIWnw7Uqz+s4x2WIO3nvwjFubo2tqo/6iOb7KsF6L9Y
4dfyi5upP+qh4b1bHui/gA5gChOEqD+tn3yfLzfov8AQe7bQb6c/7tpbJidQ
6L+QfHaeyV6mP89a1eZBaei/gKWwWwJRpT8mQKd0f4LovxDJhHl/RqQ/Spj5
Yt+b6L8Qdjd1RT+jP3kyYERhtei/gDDjvVg7oj+rd9yqBM/ov8BSZbS9OqE/
7kTfJ8no6L9ILEureD2gPyDISkyuAum/ULt+zRuHnj8iX3Sosxzpv9Dl7jgD
mpw/WXkmzNg26b+QeEPnr7OaP5R7okYdUem/oMqmCSrUmD84pqKmgGvpv2CW
7bN5+5Y/uP1begKG6b9wJHTcpimVP0o1gE+ioOm/sPX7W7lekz/Omz+zX7vp
v/Dsie24mpE/7ApLMjrW6b8A8olcWruPP0/Y1Vgx8em/IH6qOjtPjD8CyZey
RAzqv6COhzcj8Yg/3gbPynMn6r8gVbXYIKGFPw4YQiy+Quq/IIULZ0Jfgj+I
2EFhI17qv4B3z9wrV34/jHWr86J56r+A1+F6Ugx4PxVr6mw8leq/wKm3yhPe
cT8xg/pV77Dqv4AEwuYUmWc/OtdpN7vM6r8Ac4aAQl9XP/DSWpmf6Oq/AAAA
AAAAxDyKDVec
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwlkWss1XEYgHVmjjiWcpmYy1EztCyRW+oNZe6Xdmo7ShekmpqwMhUphSS5
pQuJkVKaS3OvvaphtSGXU5Rzzv/3oo4OjXLNsrQ+PHs+Ph8eYVj03mM8FRUV
qxX+ue9I2Uf2i8G4pujn7OgwTugUzGvPMejWCNfwFkoxX+LWkLTAgG/nnJUb
KsWbVzerb1pikKgjTei9J8X9ln1Mb5lBz/cr71Q/SlFiXugAqwjK+DkJm9bJ
sCTy60KFKoGxZXnq7gAZttWqGvqrE0QN5k0GZMhQq8s5w1ZAIPpw7pl3hwyX
el46ibQJmgIfv7LjyVH9ZJNOvS6BMqFTKNgpx2JrX3XReoLB6nZJb4IcE4fT
eLYmBHIF9ymlXo5VvWcnfTcQiDWeWwin5Ujua1+UWxL0F984ItLnMPm5r+t2
G4Iw8239AnsOpxwEMWvsCcojraKagzks0t3iJHQhkHIxT8TRHPosZMSf2UVw
389fczKTw9/J33T+eBLc6bPVjXvKoUcNf7rDn+CtTY+HspND7YhH010iAgeJ
ttG+MQ4VA7Hzaw8SgL6ZUQ2PYa6B0UhuOEGQW2T7kilD10r3/KAogtGOrELH
HQznptLGfeIIvMTXTcNDGDYMpbRdvkCwVZDZnxjPsOzo+9mZFAKnOD2XtHyG
X+yUEeWZBDz8IUmqZXh3T6zi1u2V3tBm64huhlXxCnFjMUHwJccWByXDE64D
OYZPVv4ceL16jk/Y7dZyvLmWoNR4oKh0I6GFmUldXiuBT3bXvJMboUKQ4lnZ
ThBSHfawNZRwIufU4mIPwURLqYHVecIZr8PF1z4T1HrPKJILCJMKGd9vjCBd
LCx4U0coS73I958iyD4UWDHZTVgY8fJ0+hLBgyC1klVKQq1GW41ltRFQ/W/8
C8+uZHU=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwtkX1MzHEcx+vWejycHkRZuUKq1UpXevAQWuQUcjY10bqe5mEoevDQIkRa
15MstdIkFaKa6IF32qoxuaUnT9f9vh96crJKXNbE2fzx3uuP9+uf997CiKPB
UTwtLS17Tf4xIfxWP/vOYGMkmfrx+SNkJgVqwU+GOQOpYYBQAVHfxoaUGQbn
1V5ZuWEKOFxw0necZSg2ViR3FyowYfeGmc0xDI2df6HTr8BhmyKPDdqEWt2c
ZEfjQYiih2cqdAg2duWX/IIGEVyrYxGoT4gdyBsPyhhE8SuvDFc+IUCecDeg
YxCX5C2eEgHhdtCdp248JbJjn5g8MiXIkzqF/PVK2DqI9SVLCPU17X3dyUr8
+ZDOc7Ui1I1wA2mPlHDoPjkutiWsMLi/UjipxP5NC+vLVxHcS66GSxZxUN8T
r/VxJrQK3Xv4Ig6RHvzjC0SEuSj7Q427OPBNXTyF3gQRd7wy5CiHBnVG4jFf
wldxoNF4psZPHTH57U8Y7nY1ja/mUPlAb7IjkDDPWb5Z1ckhTnp7sktCONsr
sNwzxMGvN069cB/hvNkyy4c8BpW55adcKUHmG90+a82QXbkpf+chwrKOrKI1
6xi2TKSPbYsnpO69Yi0NZeC9S2s9d5oQY5TZczaR4Uv4yx/TaYSDcWbe6fkM
Vm6qyPJMgsuzb30ptQz9fnGjsmua/q2TQ+RrhuGE0ZDHJYSklDVNHiqGEp/e
HItKQmfoc4Ofeprdvk0xjbWEtqW9xWXLCbutrerymjX/yLrUnhsJAn6af1U7
4URNRGlzGGF+zuFfv+QEnaayxfanCMZbD5RcfE/o2Do9mlpAuH6D6W0fIhTu
FRa01RGmLp7RC5wglIbtqBh/TaiWthy5PEuo2qF7U1tFMG9wNZzT/YR5//kX
gyxykQ==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwdjAss1AEAxv+T1oqsYSalaYxJi7zODn3eLSqP1piTwxKGMEd3unHzVree
I4c4F+c6xnGRR6LNypnG5jwaC8vu//9fnShtytDVt3379u337TudlBWVbEAQ
hKPe/zKixpogaA3M56hWrlqJW7qKqOV9DbZGQ9fcPJVY9++sJC1IrKWlZWeI
eiCvugDLcyQqn0ev2+11Y9vUyzQnmEQLX7HDvtkNC3ddw2YcCYG70NlmUoGL
u4YFIg4JzgzHKtVDgUUdPzBVSEKW2yfk+HXBokP+5EYLCa+rlpmuxztBjfgS
vDcktj+ETpn86sDtCH+7QTUJwtSiyUTdjqA16xobHQnu2MCgZ58cpXb139oP
Uphemf9xv/4lyiSrw6xTFLaPJhwxK5Xhkpjf5Myg4HXsbt90VhvuLbLsHSIo
EPz8RlW8FJmsWY1/GoWNFgXLILIVY35tnKJiCoLxUl5RSAu0tb+TluspcPMY
ecF4ASu3hKDEXv3e+ctwjLcEV7hLcsMpCi5Rya+Gmc14FLzsoKIo9DuFtXN9
xRgbD73caUDDZbDw44mKRrxnc2TKkzQUa+teB+oasMezn1zwpJF9J5DsUtaB
yZeEWEfSEKikh8+oa7EilUgF6TT8qnVK3k4NEvdYBQblNBJsOUtSx2pseQjC
JWIa4q0d1kD8U/AaoGQP0dj4WqXrr3uMWqMwV+YcDZuNqrjYoYfYXZiNOb+p
/+PLmd7hQihUz3qCjLVYEVYwbDcr8eDQ1ESugxYJ13oXbJrLMGIZcPZtgBbi
EqOUAHYxmJ/8E23jtRjlTC05RRcC+e0/JTwtBOrVgihjLibStRk+1VoQba8n
zD7nQFPy5/p3hZ7vv9OYi1KwOZ/GGJrU8/RyQQA7GrKZWFETpe//JfP5Cx4n
Sc0=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVzH0s1AEYB/DbpVoxM6RLaVfs0JvFOCN598dpc6xGTg5LiCbrxCEu5KVu
60XknLlzceTEcZH3b/WHxdhZO2FZkna/310dyVpELz/P9t2zz77PniNJmVHJ
dBqN5kple1vMkM25Og321TjQaAY9vr/mfPHw0sDFVB618E+P+atp1zMk3Xge
2FFB2BGoaIhedvrbhSuVZ/0Zpwi031Jv8i93odva2zorlOo9xW7MCTUmPUz1
q3EECnQC+1RPNba2zPIkAgJ92b1iQUAnxKaC4FQxAS6Xcc39QAdGVW2PLjUR
sBrnaC1/tqMKfjThEAGmrZ3MUqfCfm6g04COQO1o/4BXbxuMSw41TBOB9c8z
P+5Jn4HlJP2m2knCxSphr01pK1iKxWHeYRIJ1vm9U5kt0MsKZG5sqi+82TAW
r4TTBx7LmUuC2aLm0SObYcab1gemkWgdLxUWhTXhYkCLoKiYhDyHnR3q/xQF
tRtJC1ISVu5LwzG+CrS6J4Qk9pDgnk9+MezTiLmc+TYzLYmpk+GqXD857EMX
nMdIqh8pnDxY3gDOW865DroBU+Sy9466enD4glbNIQMe5AcTnZo6FAlZE7Ne
lCeVe47patGXrwhziDQgQGLSCDdrEKtUKEXpBiQ4C+aVrtWY+8PLo5dR9+ub
vP74KqR6iiIUcgM+rVSa+uoe4qvUX8MfNED+qzIudvA+dpuHu/u8p1zS5uMb
IUbq7HTM6VXq/+NytuNqBRhjT7pDLIyQx/bMMhvvYG2XdvyGM+W75ilB/GIc
ZQSdGAky4tVt7fzx6ELUzQYmOsZTXlzMi7LIRX22ak0hNEKkeTlu8zELjunG
jDPVlBlv9LaSFPiV/L6wojaCJi0TBfGjETqTxh6coLw9InJo412sREYa8R8D
0W5M
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwtkH0s1HEcxzE5D9eiw8SmrlqFHlxJpLy5SkOX1GkxIk+1aCklelBcpXST
p6zGxJJUa1GTOHqwYVkec6S5u9/3owcPUyk6sqxr64/3Xntvr79ewsiju2MM
9PT0HHT7Rz8z6Y/JjwPYH3Gnl/1k8DKNMvUVqpAqKNCa/2LIXOuelRumwkql
97PUKQYLgSql65buX1xl7DTDcGIk/Y1hrwq/l3czq1mGfbycFKf5alxYXOgK
fcLg8rLLW3eqERj7earckOD9Pm9sZ6YayVWGthJjgkdn0kPfZjVa37pniviE
yoB7DesMNHjRUe8mNSf8SGkR8j016D70XFBtSfj2uEnZlaJBgqO/sXQBwWiY
65NVa7B3IMNAZE/INn20TDiuwbWuk2P+Swja4msRUmsOb8QWT8tWELIWr3/H
d+Fw5JH/Jo/VhL5Yh7jaQA6fXfnH5rkQbNixiuCjHG5aOrsJNxIGdkjMxuQc
JFOZpxK8CKxbZJn4gMOctC+CPz4EyzUdW0ZbOARV8sabJYTrSnO7oE8cHKPv
jrdJCbetF9lVGjCYKI9rLUIJNd6xTTMLGRQ2doO5UYQ9LVmFGzYzxN8X5++K
IzQEX10YFcLgPJ4x7JdIeMyXvzt3ikHbL3uVdoZQn2i1MSOfYeRA6+SEjCB/
+VWZWsXg5DIaXSYndPavcoxuZ/i27fjQ9RuE4fMb6lxHGfjJQ8E1xQRx6GuT
Xzydt6knx7aC4GPfU1S6lOAprjtYW6Xrld2mdfMmlCyyf5KnIPArI28rwgiH
58p87jcRyhWlNg6nCUm58dPTHYQEv4mhCwWEy77hxZc+ECQhwoLGJwTbIsbb
8YkQGh5QPtZOSM84y5N81/mBRiX6o4TtMfVHrszo+taITGeNBtH4n38B5CVL
ow==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwlkH0s1HEcgDFzXm5LoUTh1ORlmYt0RJ+oLHmtTutEhNSmlghdSYUoGfOS
1ZiypOtFoSlv9cHmLCvy/rLu7vf9SCnTUl6nLK0/nj17/n0EEWcOHNdQU1Oz
WeafJXrinzOfPkJz+P0B9ouhq26krrdAAcMGRXP6swxjt7jk5Icq4HK/x8uU
eYa0SiHtvqOAxPTN2naLDIXfUt9qDijA3bqHGS0xVOflSe1WKaHRstgZ1AnP
byrP2O2vhPToz/MVmoStgwWT/llKKK/WNPHTJpR1JT7xlivh+zuXLCGfUCfg
4WtHDRWMdDWJxPqEImm7gL9DBZ9O1hnUGhJaPm/r75aq4Lytj7Z4LaHVODeY
VquCQx8zNYRmhCU6lVaCKRWkdidM+mwgPFd6M1y8moM6z5Uvyq0J1S239vKd
ODhY6eO23Z7QM9ompn4/B63O/LMrnAil3FmZ5AwHpwwdRAJXQidfP73JbA7W
zGclxe4kdOgRGsY/5kB+5YvBHy/CYPuuXRPtHPCreFNyP8J3ffqmQWMcDEY+
mHovJuw1sjCt0mDwtC9ubmUIIe2Mbls0ZxBkbDqaH0mYIM8p3ubO4LfMszAw
hnDo8A3zyGAGtT8yv+6LJ2zRy+69lMQgbjit+epFQnmckWtmIYOQYx0z02mE
OW++96dUM8h3nIgqzybsGNpsG9XJwHdP3HjuLcKRlG0NzhMMwpLGJa9KCe2O
tOjM8giM3fryTGSE1uv7Sso2EiR7NJyoryb8kPt+TuRB0GNuVlPQSKh8FnG3
MZQgn5/m9aiNMLahzNjmwnLnnVpY6Fr+4z09fqWI4PbesNJrI4TaEkFRaw2B
RTHj+Y4R6h8NqJjsJEjJSOb5/SBcF6h1T32CQBTVdPr6ImHqS6HuktYoyP4b
/wKiV14o
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAARNXopXjUs7/GlR0AAOnmPxTASuQz
NrO/5uyHUt//5j/4aGlwbJmyv3hBrojnFuc/lJxX7iT+sb8+iT4/GC7nP6R7
sPtfZLG/lhI4EnFF5z9wM4wvIMywv74z7ZzxXOc/WNJ0Gmg1sL/5/AR6mXTn
P1hxtox0QK+/l+18Q2iM5z/gSxhtMhmuv9yrqpJdpOc/iMVKzw71rL+4vz0A
ebznP4APFp8O1Ku/SFBBJLrU5z/wwbm6NraqvyjkHZYg7ec/MN7X8oubqb9y
JJvsqwXoP1ALYAoThKi/faLhvVse6D+IDXu20G+nv0ugfJ8vN+g/SHl2nsle
pr+W21smJ1DoPyiisFsCUaW/g1vV5kFp6D/AxYR5f0akv+VAp3R/gug/uHI3
dUU/o78Umfli35voPxgt471YO6K/TjNgRGG16D9gT2W0vTqhv4x43KoEz+g/
6ChLq3g9oL/ZRd8nyejoP6C0fs0bh56/F8lKTK4C6T8w3+44A5qcvyRgdKiz
HOk/4HFD56+zmr9meibM2DbpPwDEpgkq1Ji/rHyiRh1R6T/Aj+2zefuWv1yn
oqaAa+k/AB503KYplb/o/lt6AobpP3Dv+1u5XpO/hDaAT6Kg6T+w5ontuJqR
vxSdP7Nfu+k/4OWJXFq7j789DEsyOtbpP4Byqjo7T4y/q9nVWDHx6T9Ag4c3
I/GIv2jKl7JEDOo/AEq12CChhb9RCM/KcyfqP6B6C2dCX4K/jRlCLL5C6j9A
Y8/cK1d+vxLaQWEjXuo/wMPhelIMeL8hd6vzonnqPwCXt8oT3nG/tmzqbDyV
6j8A4sHmFJlnv9yE+lXvsOo/ADOGgEJfV7/x2Gk3u8zqPwAAAAAAAOk8stRa
mZ/o6j+0nle4
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAACJYdAADp5j8w1+ileNSzvxvth1Lf
/+Y/FMJK5DM2s7+gQa6I5xbnPwBraXBsmbK/Wok+Pxgu5z+snlfuJP6xv6YS
OBJxRec/zH2w+19ksb/AM+2c8VznP6w1jC8gzLC/7/wEepl05z+g1HQaaDWw
v4DtfENojOc/AHa2jHRAr7+5q6qSXaTnP5BQGG0yGa6/hr89AHm85z9YykrP
DvWsvwpQQSS61Oc/YBQWnw7Uq7/e4x2WIO3nP9jGubo2tqq/GiSb7KsF6D84
49fyi5upvxii4b1bHug/WBBgChOEqL/an3yfLzfoP5gSe7bQb6e/GdtbJidQ
6D9gfnaeyV6mv/ha1eZBaeg/UKewWwJRpb9NQKd0f4LoP+DKhHl/RqS/cJj5
Yt+b6D/gdzd1RT+jv5wyYERhteg/QDLjvVg7or/Md9yqBM/oP4BUZbS9OqG/
DUXfJ8no6D/4LUureD2gvz7ISkyuAuk/wL5+zRuHnr8+X3SosxzpP0Dp7jgD
mpy/cnkmzNg26T/we0Pnr7Oav6x7okYdUek/4M2mCSrUmL9OpqKmgGvpP6CZ
7bN5+5a/zf1begKG6T+wJ3TcpimVv101gE+ioOk/4Pj7W7lek7/fmz+zX7vp
PyDwie24mpG//ApLMjrW6T8g+IlcWruPv1zY1Vgx8ek/QISqOjtPjL8NyZey
RAzqP8CUhzcj8Yi/6AbPynMn6j8AW7XYIKGFvxYYQiy+Quo/IIsLZ0Jfgr+O
2EFhI17qPwCDz9wrV36/kXWr86J56j/A4uF6Ugx4vxhr6mw8leo/wLS3yhPe
cb8yg/pV77DqPwAawuYUmWe/OtdpN7vM6j8AnoaAQl9Xv+7SWpmf6Oo/AAAA
AACA6bzCFliX
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAYmCj1uHz4b9KC1Ty9eTcP4ITlvcQ
9uG/PwpjCkkh3T8w1UG2fvjhv4kyOY6SXd0/LoQtCCv74b8PE9150ZndP/wn
0uEV/uG/ceqCyQTW3T+CIps2PwHiv1UHkXkrEt4/Umbm+KYE4r/fJ6SGRE7e
P3qxBBpNCOK/PdiT7U6K3j/MzDmKMQzivzbQdqtJxt4/wM+8OFQQ4r+rT6e9
MwLfP9RouBO1FOK/7XnHIQw+3z9wKksIVBniv+ivxdXRed8/VtyHAjEe4r//
6ODXg7XfP4rRde1LI+K/iAqtJiHx3z/IQhGzpCjiv/Oei2BUFuA/bK1LPDsu
4r+JIjXTDDTgP+Q2DHEPNOK/02Ypa7lR4D+WFDA4ITrivxPhcahZb+A/SviK
d3BA4r/XTE0L7YzgPwKB5xP9RuK/3NIxFHOq4D9SsAfxxk3ivw4vz0Prx+A/
JmSl8c1U4r+J1RAbVeXgPwTVcvcRXOK/mRYgG7AC4T+3GBvjkmPiv7BBZsX7
H+E/ZqlClFBr4r9Mx46bNz3hPyrxh+lKc+K/tlmJH2Na4T/x2YPAgXviv6gM
jNN9d+E/5GHK9fSD4r+1cxU6h5ThPyQ062SkjOK/hb/u1X6x4T/oRXLoj5Xi
v8nZLSpkzuE/BXjoWbee4r/ifze6NuvhP8g81JEaqOK/OlzBCfYH4j82Qrpn
ubHivz4e1JyhJOI/mCAespO74r/ukM33OEHiP2ENg0apxeK/BLBin7td4j9s
kmz5+c/iv527oRgpeuI/fElfnoXa4r9oSvTogJbiPw+c4QdM5eK/RFohlsKy
4j94h3wHTfDiv1NfT6btzuI/PGW8bYj74r9mUQagAeviP7e3MQr+BuO/0rcx
Cv4G4z/bI1+e
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}}, {}}, {
    {Arrowheads[{{Small, 0.5}}], 
     {RGBColor[0, 0, 1], ArrowBox[LineBox[CompressedData["
1:eJwtiglIkwEAhX9NSRaK5ipx4ZXlmUWKRy3eNDNNk8zssAkmk8ZQMoMUmzUP
aGjk8sC8HQyx1KTUYd73lpu6+7CMZUpWhlpmRtla4IPHx8d7rik3L6SaEwTh
Zep/dueQ7tX/0IPYTjBZFBEsNDlZGx379C7Yc1xJcZYetLw4Sr6wGKtBYX1V
IXq4sJq+dyrKwfSZnUj5o4NB5C2skdVgKde78uOgDrwWn9kMFh9U+ZbGs1AH
wr6r7tWKAMET1n4eUTpweDmnnLKbQRwyC/tgY/qLiwzlO1ohs2UJk9RaJC8m
5NmXtmP92JhvZa0W3NEFsvjxC1wxZobzGFo0pgpZBL0D5NXB6qjDWkQGDvS2
eXRhWaqbHN3QIJtdsDW5LgTv51S6cUgDVUmha/xoN8gDPMetYg0EpNN7Qst6
QHSspfZf1iBgJ32khNGH1l0N8zR3DWyZ+TbHgwbAtDjgyl1To7FCll5nOYS+
s/PtZYNqOC2sFESsDqEx3ZHCeKQGKUYvrHgzDF28YflXkhqRgvVbXNEIqN1O
bQl+arBb3znt7xwFtbX8fZZRhWfnMw7G8sdAd1FZX5er8Hxt/AulZBzSTFqH
nUCF6pcRmvzcCdAsrOOKslT4NtlyhpMmgkxxgiGJVqFobiffji4GQam9oXYx
7fHToQExr2FhFCubN5ToGZh9sEidhHuAp3PElBKKkOwZNz8J0oRL/W0CJZ6o
mbc/OUtBzzdzM7CVIFl8lQbunoJnwtHeuQQlwkkSfyvLaegyNzeajijhdufS
38TNaWxm8mlUkhKrlVl5vsszYNgHmtUvKmDDuWp1MkOGi3YFDdJhBZI5Dvcb
P8vw1movR1yvQGFVyjmkyvEwkWpZylbAn/jt6GCQo3yfeYnXNQX42/wH/eFC
Sw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMBcCjylb0j9QFwKPKVvSvyhaPAWS
fNI/5f/6Ghjg0b98CBaAyJ7SPzmZYk0/ZdG//BCDn8zB0j8XgBh/oOrQvwwT
NgGe5dI/yH9ZCD1w0L+kcqFAPArTP2qXd4Es7M+/hHL49qYv0z+gdVb+WvjO
v9hUMLvdVdM/xgnLMwgFzr8QggEi4HzTP5AD7cw2Es2/ILbova2k0z8m1Whz
6R/Mv9wzKB9GzdM/Yjl4zyIuy7/A/sjTqPbTP1C+2oflPMq/wBqcZ9Ug1D+Q
U85BNEzJv5DSO2TLS9Q/Kt0HoRFcyL8EBA1RinfUP57Kq0eAbMe/lHJAsxGk
1D9KskbWgn3GvyQg1A1h0dQ/XvHF6xuPxb8MrJThd//UP2JQcCVOocS/CLge
rVUu1T86rN4eHLTDv6RT4Oz5XdU/DKT0cYjHwr9wbRobZI7VP9RL2baV28G/
jErir5O/1T/q4++DRvDAv0AEIyGI8dU/dpXQbZ0FwL+IC5/iQCTWP8Bngg46
N76/3LLxZb1X1j/0BlzCj2S8v/S9kBr9i9Y/bApFFUGTur90981t/8DWP6yP
hCFTw7i/zMzYysP21j9YfIP9yvS2v/jvv5pJLdc/MDa+u60ntb88/3JEkGTX
P5BltmoAXLO/3DLELJec1z+Iw+QUyJGxv7wQarZd1dc/cOVVgROSr7/oJQFC
4w7YP8DIiuCUA6y/KMYNLidJ2D/QkHpDHniovyjR/dYohNg/UBO1nbnvpL/Y
fSqX57/YPwCsK9pwaqG/XCvaxmL82D8AySq2m9Cbv+Q3QryZOdk/YGum87TS
lL9w3YjLi3fZPwCEURuCtou/LBTHRji22T+AGtdLTql7v7R6Cn6e9dk/AAAA
AAAA3rwf+Vn6
        "]]], 
      ArrowBox[LineBox[{{0.4056164008015161, 0.}, {0.6605975298376587, 
        5.664226070673724*^-16}}]], ArrowBox[LineBox[CompressedData["
1:eJwtxQss1AEAx/Hzmts1lkdlmFeZZ2plHnXth3RNZMmUxCY7YzfWRYsJHdoy
WidOyLuZac5U+E85HIe7OJz7/++laZcoScOStEiP9d2++zgnXb+YbEij0Tz+
/NfqA4Z8j6tK1P3Xi/bT1kY/A0Ec06Q8V4m8mqTzSJ6Bnr6fJ2tQIpZnc6dp
WYF4i6JG+ZASprwr9FNcBdKs/AwaFpWYr8oq8F6ZBi2zOYjJIGF569KvuK0p
6DO2NluPkPBlTBynm0zBO+Zo31wMiW2jL3I/y0mwCw1c9LkkSlSpmZ8c5eAS
S/0dLSTGArOnXXwm4O3r7siaJCEcmL23yBwHfVdGtm2S+BA9Fewb8RrGdnUp
KicK+XOmzRbxMlDKk+yJcArL4+1neWlShBqbRZVkUbj/gqUuzBuDIiOoy6KF
wpP10c92/FEkOlFm12YoNFzgukY2jyBUKHiXtUvhpvCtg323BMxeh44YHxWY
LRs3iqXD0EbrV34kqGAYoSMq3wyhKd3Wjv1ABcuF1SLWmhiic/OdFYMqPKpU
pNebiJFmfNC5eF2F7ZRC8xP+A3i2p3E+6JAa9qbxw3y2CMZd68n9l9UQMM7s
C654BZuBMtudUjVG+HedoyW9EHyfTN8Vq5GaW7QzvkFgRa4dl2yqEeA30Nfh
1gObtcHHYYc1qE4mOLT4LsTuZoSWsTXIlixYyx4+x8axEe+qOg2CFmMKrMo7
odjLIRJUGnBlJXqBkRDbrgYh7821SCzLOe2Q3YaAMTMftzAt1ix76l+utoA5
s6N2v6sFt91rlstpxlKeZ9XHQS3EUk+iVlELttfsWNK2FjRO69dupQAr/iGi
mkAdxLwou0KiFNlzxROlWTrwrDThkU9vw9daygogdKD9q0nUncPIb/imw29i
r0W3
        "]]], 
      ArrowBox[LineBox[{{0.2868141075672326, 0.28681410756723275`}, {
        0.4671129929832897, 0.4671129929832898}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAyLw8egp+nvXZvwAQ10tO
qXs/vBPHRji22b8Af1EbgraLPwTdiMuLd9m/AGmm87TSlD94N0K8mTnZv6DG
Krab0Js/9CraxmL82L/QqivacGqhP3h9Kpfnv9i/MBK1nbnvpD/M0P3WKITY
v6CPekMeeKg/zMUNLidJ2L+gx4rglAOsP5QlAULjDti/UORVgROSrz9oEGq2
XdXXv/jC5BTIkbE/jDLELJec178QZbZqAFyzP/T+ckSQZNe/qDW+u60ntT+0
77+aSS3Xv9B7g/3K9LY/iMzYysP21r8gj4QhU8O4PzD3zW3/wNa/5AlFFUGT
uj+4vZAa/YvWv2gGXMKPZLw/qLLxZb1X1r88Z4IOOje+P1QLn+JAJNa/MpXQ
bZ0FwD8QBCMhiPHVv6jj74NG8MA/ZErir5O/1b+QS9m2ldvBP0htGhtkjtW/
yqP0cYjHwj+AU+Ds+V3Vv/qr3h4ctMM/6LcerVUu1b8gUHAlTqHEP+yrlOF3
/9S/HvHF6xuPxT8IINQNYdHUvwayRtaCfcY/fHJAsxGk1L9ayqtHgGzHP/AD
DVGKd9S/6NwHoRFcyD+E0jtky0vUv0xTzkE0TMk/tBqcZ9Ug1L8MvtqH5TzK
P7j+yNOo9tO/IDl4zyIuyz/gMygfRs3Tv+LUaHPpH8w/JLbova2k079MA+3M
NhLNPxSCASLgfNO/gAnLMwgFzj/gVDC73VXTv1Z1Vv5a+M4/lHL49qYv078k
l3eBLOzPP7hyoUA8CtO/pH9ZCD1w0D8gEzYBnuXSv/J/GH+g6tA/EBGDn8zB
0r8UmWJNP2XRP5gIFoDIntK/wP/6Ghjg0T9IWjwFknzSvykXAo8pW9I/UBcC
jylb0r/epln8
        "]]], 
      ArrowBox[LineBox[{{0.28681410756722675`, -0.2868141075672285}, {
        0.46711299298329145`, -0.467112992983291}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAoDy0egp+nvXZP4AT10tO
qXu/NBTHRji22T8AgVEbgraLv3jdiMuLd9k/IGqm87TSlL/sN0K8mTnZP+DH
Krab0Ju/ZCvaxmL82D+AqyvacGqhv+R9Kpfnv9g/8BK1nbnvpL840f3WKITY
P4CQekMeeKi/NMYNLidJ2D+QyIrglAOsv/wlAULjDtg/UOVVgROSr7/MEGq2
XdXXP4jD5BTIkbG/9DLELJec1z+gZbZqAFyzv1T/ckSQZNc/SDa+u60ntb8Q
8L+aSS3XP3h8g/3K9La/6MzYysP21j/Qj4QhU8O4v4z3zW3/wNY/oApFFUGT
ur8UvpAa/YvWPzQHXMKPZLy/ALPxZb1X1j8MaIIOOje+v6wLn+JAJNY/opXQ
bZ0FwL9oBCMhiPHVPx7k74NG8MC/uErir5O/1T8MTNm2ldvBv5xtGhtkjtU/
SKT0cYjHwr/UU+Ds+V3VP36s3h4ctMO/OLgerVUu1T+sUHAlTqHEvzyslOF3
/9Q/sPHF6xuPxb9cINQNYdHUP5yyRtaCfca/zHJAsxGk1D/2yqtHgGzHvzwE
DVGKd9Q/jN0HoRFcyL/Q0jtky0vUP/RTzkE0TMm//BqcZ9Ug1D+8vtqH5TzK
vwD/yNOo9tM/1Dl4zyIuy78gNCgfRs3TP5zVaHPpH8y/bLbova2k0z8MBO3M
NhLNv1yCASLgfNM/RgrLMwgFzr8kVTC73VXTPyR2Vv5a+M6/1HL49qYv0z/0
l3eBLOzPv/hyoUA8CtM/EYBZCD1w0L9gEzYBnuXSP2GAGH+g6tC/VBGDn8zB
0j+HmWJNP2XRv9gIFoDIntI/NgD7Ghjg0b+MWjwFknzSP6MXAo8pW9K/kBcC
jylb0j+PaVnt
        "]]], 
      ArrowBox[LineBox[{{6.99702747969524*^-17, 
        0.405616400801516}, {-4.834719367710373*^-16, 0.660597529837657}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwtigss1AEAxk8Y0xid6kbzinkktTSPuhYqTWQkJbGV3ZWJurR2N3mf1Q3L
5THhPG4zu4ZZHv+U4zvv6xzOvSl2iaXSsC5peXS1vu3bb799n3PSvUv0XSQS
ydPQv8zev6vE87octP8kk37bUXRTiIunmpZmynGrKuniafoUBOb7csV1coTk
UnIavsjgZMOul/bLoc+5Zn6KIYM32c+oblGOvkpmnvfyJETp/CCqhQKrD69s
x29MgJe+sd50RAGKxZivuekEli8f7ZmNVWDO+JvUb884XPONXHSZCtxVJT/4
7CiFN7HU29qoQEsga9LFZwxLvh6OoeMKPO+bebJIlUC0LVYI1hVQx0wEH494
C6Ed77bKSYnUWTO+TYIYxfKTtLFwJd5Lms/npo5i09gyupCpxOP2UHV+1ggK
0oM6bBqVqF4b/mpfMgxbJ6XlzSkleFEMt0j+EPTN5R+YO0owWuYcDnQOYvWV
Q2usjwrURv19zugAODG65V+JKphETBMV7/oRlWZnT3uqAmVhhR26KkLyhfm2
MqjQUCFLqzUVgWJy0JmzpoJ1cr7VCf8+xO2unw9yVSPALGGghCaEoH2N3ntV
jU6Lc3uDy96gu5drt1Wkhq6kwDlmsBsBP8fTdkRqcDPZWxI9gWKpVjK4rkac
X19Pq3sXOldQHXZYAxGdSCEldEC/nX6WS9NAMLhgK372EtxjQ96VPA0aFmPz
yKVtSLZOIRJVGujEhbpy4xaUuxmFfLTSQsfNOOPAEkA6bOnjHqbFDXJX7euV
RkhlW2qPAi1ILYdmGCl8sLK8Kj/B8Bd7ETWyGmx4zYwkbRr2O03fO+XlYPmH
CKsCpxHEjrbPJ4pgMssZK2JOg0TRhEe+eAQheTQ0gDD4v8iF1AyL7Lof0/gD
nw9wxg==
        "]]], 
      ArrowBox[LineBox[{{-6.92670381065753*^-16, -0.4056164008015093}, {
        1.0222443204062975`*^-15, -0.660597529837658}}]], 
      ArrowBox[LineBox[{{-0.28681410756723114`, -0.2868141075672295}, \
{-0.4671129929832925, -0.46711299298329434`}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAlBcCjylb0r+WFwKPKVvSP4xaPAWS
fNK/KgD7Ghjg0T/YCBaAyJ7Sv3uZYk0/ZdE/VBGDn8zB0r9WgBh/oOrQP2AT
NgGe5dK/BoBZCD1w0D/0cqFAPArTv+CXd4Es7M8/1HL49qYv078Qdlb+WvjO
PyBVMLvdVdO/MgrLMwgFzj9YggEi4HzTv/gD7cw2Es0/YLbova2k07+I1Whz
6R/MPyA0KB9GzdO/wjl4zyIuyz/8/sjTqPbTv6y+2oflPMo/+BqcZ9Ug1L/k
U85BNEzJP8TSO2TLS9S/fN0HoRFcyD84BA1RinfUv+jKq0eAbMc/wHJAsxGk
1L+OskbWgn3GP1Ag1A1h0dS/nvHF6xuPxT80rJThd//Uv5xQcCVOocQ/MLge
rVUu1b9urN4eHLTDP8hT4Oz5XdW/PKT0cYjHwj+MbRobZI7Vv/xL2baV28E/
rErir5O/1b8Q5O+DRvDAP1wEIyGI8dW/lpXQbZ0FwD+cC5/iQCTWv/Rngg46
N74/9LLxZb1X1r8cB1zCj2S8PwC+kBr9i9a/iApFFUGTuj+A981t/8DWv7yP
hCFTw7g/2MzYysP21r9gfIP9yvS2PwDwv5pJLde/MDa+u60ntT9E/3JEkGTX
v4hltmoAXLM/4DLELJec179ww+QUyJGxP7gQarZd1de/MOVVgROSrz/kJQFC
4w7Yv2DIiuCUA6w/IMYNLidJ2L9gkHpDHnioPyDR/dYohNi/0BK1nbnvpD/Q
fSqX57/Yv3CrK9pwaqE/TCvaxmL82L+gxyq2m9CbP9Q3QryZOdm/4Gmm87TS
lD9g3YjLi3fZv8CAURuCtos/HBTHRji22b8AE9dLTql7P5x6Cn6e9dm/AAAA
AAAAsLyuDlwJ
        "]]], 
      ArrowBox[LineBox[{{-0.28681410756723236`, 
        0.2868141075672325}, {-0.46711299298329184`, 0.46711299298329}}]], 
      ArrowBox[LineBox[{{-0.4056164008015143, 
        7.166803835241803*^-16}, {-0.6605975298376634, \
-1.6921517786986418`*^-15}}]], ArrowBox[LineBox[CompressedData["
1:eJwtknssFAAAh8+rLqV1qAzjKPPsspJXVx3pIjKSHuKP7Dwy1qUaEzmPLWPr
xJnJ89rNNKQ8bsrjd553cTj3RKOLs67SsCSt0NX6bd++ff//7GJvX4rTJxAI
zjr+mpNh/LDm+zQI/yaimpsL6d58XZNUwaHPH+DabMFoUdo0WNnhVrn8Iki8
/LsrfKZBu1X/rV3KQaDrzHDs7ykQhC78SkklRFku5R+h60bXGWYSF9aTm0qn
/CmwTDuqXy/zYDFsQnEMmsIKO+OsTXoD1A56/gt7dS0sVHMMmtC+L4kfo1BB
oInMMStpgfzYoFt5lQruAxpz0ZNX8N5ODShmqBAYx08iRLdhbRlPg46ooD3R
29Xs2AGxeGpkYF0Ji8y8zZE1Pu79GEvZFijBZOfbRQx0YqOn2HKzSAmq8bn9
fqVvoGldjeu5qsTgjuh+NqMbxbtr52mHlahLyN3r69WLEMNDdgWrCsSXSVKq
jQSoujDfUgoF5haW8+grAuSnWFoxHisgDp7ml73rQ2eEeulnjAJE3tqdAmE/
yJ02zZEUBXyb5mys2wdAbuJ8SNuWgxHGdAjlDoJGlpvcnJQjfnXoixV7CC9T
aW0knhyXW+nK3KxhOBmahBemyfFipPE8K1mITulJxmiwHKdnd3JJ0SJoLKsS
FGQ5nkWM+3mEvIV2SyRrWJchsXfm0SJ1BHs8nGzpYzJk+qRP2FNGEcbX9jTz
ZKApEu9+shWDlqtnr86UodXgq9jTdAzESPeu2UgZtLtGjxONxtGdurFef1SG
wftXtqI2xqFO5dKoxjJwytNy3JYmEGDmqVezKMX77OvEU0wJvEl5teI+KSgs
i+y6zxJ0Ew+wRDVShFfEXjwTNwlmFNWoJFOq+9svSwv1JNIP6rOdb0iR/N9/
AM4WbSI=
        "]]]}, 
     {RGBColor[1, 0, 0], ArrowBox[LineBox[CompressedData["
1:eJwdxX0s1HEAx/HzGJtxhj+4RERqaR7CXPgYaxaLQ90pj3lorHOplWI3TJSn
9MehsPM0YZ7ylHTiMHFRUWE385Dy/f1OmiFkztLDe3vtfTT6RlCcKoPBOPHX
vwsNAgRiSwLG/4bd7GAY9sSJwDM8VEPtkwB2V7UWZ3wIoqznPe/3pSGT01wa
eoVg3SyWV/77ASY9jthaJRJwUqqnKVEhCipYro4ZBA0rQVUeeiIcY6qFZYsI
4rnX9lgTJfDgzjiw6glClrW97+WWgeK4Xd6SEMjVk6I8PSrQe5CZwJwgyPJr
a2zbqcJ2XvW+4BuB0Pi9eex4DbjB7Ea9XQLDJGN7e3EtFrXEWps6FAxZ+zm6
/DrwZLJmIwsKF2/Ry5suDciD4GSqC4V3kznMaUYjnOQbBmYXKGT1/aKaRppQ
t5K4pxZDIezNcpAgtwUr612JNikUhBoyf4Pzz5EzEbyf/5iCScfDTVlmG+TM
IsfTdRQi3KyfJkW2o8MprVK3j0K3XrutkN2BZ5pzY6emKHyYl3Nog06k/2Aj
Z5XCjH5tfctqJ+wC1rLM1Wh4Hc7+MjbYha09fcttExoOoqQOdskLDOYXVGo4
0og+/nNuN74bUwv66YF+NGb5PjYq7Je4k2d1Th5DI/Xu9bgA7R6MhJreLhXS
8Pd1FizO9KBq1vJRUTGNfuNEq5aaV+B/ZjPfttJYiJQnd/ElWKfchc4yGkND
IbyNM73YMyP+c0s01saVw5HKXpDCUXWJkobmTeaoUvoa5Hu48YSRAmv8s4LB
zD7ouGocYtkpYJGQP9Xs3Q/1FBUfsa8CX3cKTCWqUkTwMgIvxSmQxotIJlIp
hKRc7JWhwEHuUl6x+wCU3PDq2HIF0ttZFd5lAygZln6UdCuQ0qpiotwewB/+
CETG
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlj30s1HEcxw2ZeZozFhLztHXnIUTrIh8shU6WHZbZrfM0DxmZNBH5A5Np
3E5DGvNQLNOtWSrNh1axHSlPKd8vv9/d4ZxZhGweO+uP99577b299347JmZH
p+jq6OhwtTp2fr3NosciRev/DrYPenhevHl071f90JukcNFij8Rnz2PWhxCP
/CEKSY+aGrp753Gz2hnKZBT2zNMOnHfn0dFCmOzdQmFo8U47wgL+ERWt36+h
kFNkySsuW8BIjr1vYikF45adMyL5AtbJJEXLuRSWR6tOvzJkMNLJyNI4hcKg
x1LRgBuDRp6VwWNxFCpj1cXkOoOlHHWY5zUKvT3t2Ya5DOq5fs/wBArm/kuN
wXUMmtagauwcBRu+r6DiLYNis8N1Ey6F9v7pr7NzDIZ/7viyak9hJmw6y++I
wVjus4YMKwqCAv28JicW07aeNFaaUMisP3IzvcKinztnJ0yfwqdQb6Y8nUUf
vvBn5z6B2ydnfhlWs6gxzU3r2iYQcUknVSJj8ZsodCTiN4EA16dypykWJZoc
m+oVAocO2THvdlicnRAV5KgIjBi4RsacUqD0RJDu9gIBCRu+vx2owIk3xnJb
QoBUR3c3JirQYLV4mZ0lsJfS/DykXIGbHLu0iBkCo+oS37UuBZq+5sULpwj0
i883N4wpMN+lb/hogoBF7d7ZqxtaFkv6BFrOF+p6bVsqsYXe8PDX8sOoQnXr
BSWm3oviyrWcKa1vjUpQYvTdrs79SQIvBbUvdkuUOC4N6RifJlAo7ghqa1Ni
Hvej1WXtHh8Xx76wYSWuCqRrN+cIJPy9JdRolJjsoLHjaP+UbkyJK8xUKLV+
X5OuJFD1WJ/r4KPCgPRBnyT1cb9kUxajwsCskpWDNQIDcWAcUKDNPYPq+VsE
/gHesGU5
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwdznss1AEAB/DzjGac5A+OiGlqNBLq8syaFXkuj5Arj524i9XsaiZT6jxS
yyvsvGannUfe6Ty+ZxmXtIuwW7vI8nuU1o6IOauuvtt3333++x6+diMqTZfB
YBzV9t+KLcL5IkcCjP9ZHonzP5hY46k1N8FAb46PmKtGy4vBWrt8Crg3mg9x
REdtwmUCMofU2PrfD6D2O+TqxCMQkNe8QFaUQ9LAOu1RQMBtLarJz6wCgUy9
xKIKAurY9F2WohrxMYsnWG1aE8ZBguI6MCJ94jelBAoMszkBfg2Y+1OYwVQQ
4IZ2S7p/NWF/afMe/wsBjvU7+9S3LciIZkvMdrR/cqzc3UWtUBuJjDZMSDBs
9oSmWWKky+Udlg4kIm5Sqxvez1Hjzz92x5uEfFbIXGBIEKhct7C7SEI4tk22
T7aj+ytvVy+FBGdyNYpf3Il1dT/P+TaJJ4byMIvzL1CuiN4rfUyio/fhhryw
GypmpcdxMQna58iz7OQeDHjmN5qOkghl9rjmsXshNlRNu8yT4C4pIyiLPuR/
Z/sL10gIDrS2da71wSX8x317PQq0TdHn6fF+qHfNHbesKagqsnvZ1QMYLi1r
NPCgYOL8U7XDHcTMkvndyBAKQl6wsw77JTJLnM4pUyi4CDLTwo2HIE2wvVWb
R0E/xIu/vDiEpx8dH1VWURBY85w6W14h8QOb+aaLQitHmdufJcUy6ZvnJadQ
9joudv3kMGg7Iky1QmFkRjORrBnG+/IpfamGgjKHOaXBCBTfkqwUljRkvDP8
8cJRbJ0y2Mdyo6F/vXS+I2gMawKdYNEFGhPbZbZSXSAotiDyUhoNbtyVXAIA
h6gXnS2gkVuyUlLlK8NSTFJzaj2NnR5WQ1CdDLkTmJUO0tjs0rHWbMnwF5cN
bZU=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAxiXDItuJzEsKu9aR12gkPVgJeSmRsqKuGJpO1oy6zmphal4X
HWnMS7EMWw2VpdpKm04rL5Hv1/1ezntEuiwv6dr649lnn3+ePY+NWBIRr62l
pSXS5B8FcvMxxzEKk/90eqH6srGPQud6s72L/SgyOv0d019TeBivkBjJKPQK
7JDdSiG5XVne9HQUfsaRF1yrKbYKEtfslkdhGSedv1pEMTd2ua4LStwUWLuL
b1A0SU3sZdlK9LWWSCfSKKKrl3bF9ight91kYhBPYaq4s61Fn0GsU56fIpri
l+O49KUDA04wGeh0hKL7xKSMhDFIEX5KdgLF7+Y6iX4ag1tFXSrFHooz3uMV
fqUMeKM/84Yiikte7iG5HQyG39a/m7Gm2NA50Ds0wmBB9KA82ZRiX9BAisc6
AyN1WUWeIUVHps6VSlsWU7sFS4E6FEr5usPmABaLXpHDDasECHBlcpJYtBml
JTaqCebMBr/q57N4HHfoffB3gn4frYSSVhaZM6nm+VMECuH9Htt+Fh/6YjNT
VQRlOyRRz5ZY3NP11VYrCRL1hKFRlhzYdoMeC0LgyQWtqg9wsPsmm2CHCPIK
IpoqxByst1glBg8StCRUPfTP4XD4iX1MZD9B7lSW+2wjh05he/f6ZwKZeG9V
uYKDQlzSHqLxkeIV58MLHHSVxxy9NR4Qpe2iNuExnBEu6tF49NFrkzWePAbT
GxtW+wgCS+U14ad5iMv86z8OEBSGFj9azuJh5vDG9KBmT4K43re2lkdl2N3Z
UyMEdkKb9sBuHjttpq0Emj/Hl85GTk/ziLd4XpTEa/b86D+Xa6SC9cVXbucn
NX2FOqLtbio4S7Km1mYJ2kJLFlujVPBx8ZV7/SToPQmD/Zkq/AUxhVGL
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMpgZ5S3l3T8pmBnlLeXdvyN9riow
Kt4/R7vk1wPT3b9TEvvcWm/eP5S8Qi12wd2/jYqcmay03j8ljiM/hbDdvzQR
aP0j+t4/XxJUZDGg3b8M5nGkvz/fPzxffPB6kN2/ynwUKn6F3z+kER40YoHd
v3Wg9yhey98/9rCSfOdy3b8kzYsdrwjgP7wiChQLZd2/BC7mfL4r4D+FLolB
zVfdv9VW6H7cTuA/CxLoSC5L3b8Ir6RvCHLgP5gl0WouP92/bDvmmkGV4D+w
kL/kzTPdv305NEyHuOA/EA/+8Awp3b8QvNXO2NvgPwfGpcbrHt2/SUnVbTX/
4D8gKp2ZahXdv8Z5BHScIuE/QPWWmokM3b/tmP8rDUbhPxstEfdIBN2/TUYx
4IZp4T8mOlTZqPzcv/wX1toIjeE/6w5yaKn13L/iPQBmkrDhP+FfRchK79y/
2yWbyyLU4T+y63AZjencv6Mgb1W59+E/BtReeXDk3L91ByVNVRviP9EGQAL1
39y/ReJJ/PU+4j8duAvLGtzcv5aOUqyaYuI/Yux+5+HY3L+8Zp+mQobiP10T
HGhK1ty/lOl/NO2p4j+IsypaVNTcv4piNp+ZzeI//yW3x//S3L/okfsvR/Hi
PxBjkrdM0ty/UlUCMPUU4z9K31EtO9Lcv2NQe+iiOOM/IHlPKcvS3L9UlZii
T1zjPx53qaj809y/mk2Rp/p/4z+slkKlz9Xcv3FipUCjo+M/YCvCFUTY3L8u
JSG3SMfjP+lOlO1Z29y/XfdgVOrq4z9zIeocEd/cv4ny1GGHDuQ/tBq6kGnj
3L+ZjwQpHzLkP25rwDJj6Ny/v02S87BV5D+Ab3/p/e3cv9hYPws8eeQ/jzBA
mDn03L86dGNo
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAwbxsE09unSPlP4BcWwUD
0m6/ID8UXJc15T+AJt1Ag71+vyBhCN/WR+U/ICBkV5v+hr9yUKyZW1rlP4B5
odXmk46/wD4eLSVt5T/Q6VKgPg+Tv3ueGzkzgOU/oFZm+hvPlr8UEANchZPl
P6DkCUN4iZq/LVbWMhun5T8gBXBgQD6ev9ZQPFn0uuU/uEuwqrD2oL+q/4Jp
EM/lP7gZzSBky6K/5Yqh/G7j5T9IcBkxMZ2kv0ZTOqoP+OU/WBv8iA5spr/O
CJ0I8gzmP5hy5+TyN6i/SMjIrBUi5j8g0YgQ1QCqv3k/bip6N+Y/yL335qvG
q78l2PETH03mP7DF5FJuia2/l+lt+gNj5j/QBchOE0mvv9rwtG0oeeY/TLKH
8siCsL95z1P8i4/mP4w8JphwX7G/yBCUMy6m5j/sD7EtfDqyv6I1fp8OveY/
CN7YUOcTs7+WBtzKLNTmPxASpKet67O/b+w6P4jr5j+AHIXgysG0vyBP7oQg
A+c/dJNwsjqWtb/l+hEj9RrnP6Qn89z4aLa/souMnwUz5z8gbUcoATq3v8Te
EX9RS+c/xHdrZU8JuL9miiVF2GPnP5hKNm7f1ri/t1sddJl85z8MGm0lraK5
v5HaI42Ulec/MGDYdrRsur9d0zoQya7nPxjDWFfxNLu/4eY9fDbI5z9EzPvE
X/u7v+wf5U7c4ec/YHEQx/u/vL/XjscEuvvnP0htO27Bgr2/1+pdGc8V6D+E
aYvUrEO+v/44BQcbMOg/QPeMHboCv7/2eAFHnUroP+RXXnblv7+/UFeAUVVl
6D80iuGKlT3Av27lm51CgOg/tLEbnkOawL/uVl2hZJvoP66uARr79cC/iMS/
0bq26D8K2FZe
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAxiVvQ5qLGUledisnQnqRysvymrfsrmINXRhandQsEivDZN5u
MaQxL8VmsdV2xDzVFtpNTV7L93t+9/ud9yzKzea1a+uPZ5999vzzPHZiSVSi
tpaWlqMm/+hfbTnjPEOR9J/xPaqJvSMUwkevBa4CBdp6/ZwzPlA84W2SGIkC
p0sdvPM7Kbqe1tW0v1XgDk+Y4NZAEWuavO2woUBgXPZKVjmF++zdZnhPo93U
xkP8mGI520yQkz+NzU5p9lw6RVXD+tFY+TT67A3NjBIpPIaKD3UYMMhzKfId
ukrBc5nN7nNioMubD3K5RMFemc8h4QxK+cOpLt4UZh3NEoN0Bk3lUA2doMjw
mq31rWSwZ//OirEjRYGnR2hhF4O1Ty39SzYUFr1jXyanGBgKXtSkmlNEBo/d
PrnLgK+uqi0yppBn6tyvs1di55jpepAOxWr1rtO+ACX0zgq/t24RRAa4MQUp
SgyapCe3qQl2LMZ/GJQo0R3nPxjyi4A7r5Uk7VSiYCnNsmSBYIr/XG4/qsTE
SGxmmoqg0VYi6l5Xol7PR1s9TXBPnx8mOshiTmYktyIEfmzwlvoCiyM/c+aU
kwTS0qj2WjELuwPWySHjBLKk+pd+BSyC3ghihKMEpQu5HsttLHr4soHdbwR5
4lP1NUMsPoulslCNMxWbxwNXWewqLjt7aTxYpO2qNuMw/CDCUa7x6MiH841n
OMgz2lq3RjR9ZXVjxHUOoiq/lq9jBGVhFa82cjnoO300v6jZkyBu8Wlq4lAc
/mw5eorAlm8nCxrgwLNbtDbV/IlYjxcuLnKIsHpXnsIRZP0evVFoooLurffu
N+cJisp0HA+7q2AuyV3YXiboCJP+6RSpYOvqU+25RtB/zdvoXKYKfwGBYnpl

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAACA0jx1E09unSPlv8BhWwUD
0m4/KT8UXJc15b8gKd1Ag71+PyhhCN/WR+W/UCFkV5v+hj96UKyZW1rlv7B6
odXmk44/xj4eLSVt5b9o6lKgPg+TP4KeGzkzgOW/SFdm+hvPlj8aEANchZPl
vyjlCUN4iZo/M1bWMhun5b+4BXBgQD6eP9pQPFn0uuW/BEywqrD2oD+v/4Jp
EM/lvwQazSBky6I/6Yqh/G7j5b+ccBkxMZ2kP0hTOqoP+OW/nBv8iA5spj/S
CJ0I8gzmv+Ry5+TyN6g/SsjIrBUi5r9k0YgQ1QCqP3w/bip6N+a/FL735qvG
qz8n2PETH03mv/zF5FJuia0/mOlt+gNj5r8cBshOE0mvP9rwtG0oeea/crKH
8siCsD95z1P8i4/mv7I8JphwX7E/yBCUMy6m5r8WELEtfDqyP6I1fp8Ovea/
Lt7YUOcTsz+UBtzKLNTmvz4SpKet67M/buw6P4jr5r+qHIXgysG0Px5P7oQg
A+e/npNwsjqWtT/j+hEj9Rrnv8on89z4aLY/r4uMnwUz579GbUcoATq3P8Le
EX9RS+e/6ndrZU8JuD9iiiVF2GPnv8JKNm7f1rg/s1sddJl8578yGm0lraK5
P4zaI42Ulee/WmDYdrRsuj9Y0zoQya7nv0LDWFfxNLs/3OY9fDbI579uzPvE
X/u7P+Yf5U7c4ee/hnEQx/u/vD/QjscEuvvnv25tO27Bgr0/0OpdGc8V6L+u
aYvUrEO+P/c4BQcbMOi/aveMHboCvz/ueAFHnUrovxZYXnblv78/SFeAUVVl
6L9LiuGKlT3AP2blm51CgOi/ybEbnkOawD/kVl2hZJvov8euARr79cA/fsS/
0bq26L9j8Fan
        "]]]}}, {
     {Hue[0.6, 0.7, 0.5], Opacity[0], Arrowheads[Medium], 
      ArrowBox[CompressedData["
1:eJxTTMoPSmVmYGCQAGImKN5exVU37+tNewYomCHO1K8Zfcl+NpRGl68R9s+b
q/zUvnOx/cTgjCM2GOo/Wck/1ZpisxWqD11eaIbkU92nd+1FoLQ+VNwfQu9H
tw9d3giqTwtC70d3jytUPA1Ko7tnCtSc6Tjc++Hb1qu22Qf35EDNRXdvmYGl
iGvWJZtSiPz+wm7hTQe/nNhjA9G/H9296PLo+tH9swwqHlvwz3RN9b096P5B
dx+6fyyh6iSg5qLLT4O6o+0+2zbTSydt0NWjhye6fYTcix5edVD7E3GEB7o8
un/Rwwvdvej+QXcPujy6fQCcG2Y5
       "]]}, 
     {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0]}], FaceForm[
      Opacity[0]], {DiskBox[{0.4056164008015161, 0.}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], 
        Offset[{2, 2}, {0.4056164008015161, 0.}], ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.2868141075672326, 0.28681410756723275`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "2"}], "}"}], 
        Offset[{2, 2}, {0.2868141075672326, 0.28681410756723275}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.28681410756722675`, -0.2868141075672285}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "3"}], "}"}], 
        Offset[{2, 2}, {0.28681410756722675, -0.2868141075672285}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.6605975298376587, 5.664226070673724*^-16}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], 
        Offset[{2, 2}, {0.6605975298376587, 5.664226070673724*^-16}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{6.99702747969524*^-17, 0.405616400801516}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "5"}], "}"}], 
        Offset[{2, 2}, {6.99702747969524*^-17, 0.405616400801516}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.4671129929832897, 0.4671129929832898}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "6"}], "}"}], 
        Offset[{2, 2}, {0.4671129929832897, 0.4671129929832898}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-6.92670381065753*^-16, -0.4056164008015093}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "7"}], "}"}], 
        Offset[{2, 2}, {-6.92670381065753*^-16, -0.4056164008015093}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.46711299298329145`, -0.467112992983291}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "8"}], "}"}], 
        Offset[{2, 2}, {0.46711299298329145, -0.467112992983291}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.4671129929832925, -0.46711299298329434`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "9"}], "}"}], 
        Offset[{2, 2}, {-0.4671129929832925, -0.46711299298329434}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.28681410756723236`, 0.2868141075672325}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "10"}], "}"}], 
        Offset[{2, 2}, {-0.28681410756723236, 0.2868141075672325}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.46711299298329184`, 0.46711299298329}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "11"}], "}"}], 
        Offset[{2, 2}, {-0.46711299298329184, 0.46711299298329}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-4.834719367710373*^-16, 0.660597529837657}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "12"}], "}"}], 
        Offset[{2, 2}, {-4.834719367710373*^-16, 0.660597529837657}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.6605975298376634, -1.6921517786986418`*^-15}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "13"}], "}"}], 
        Offset[{2, 2}, {-0.6605975298376634, -1.6921517786986418*^-15}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.28681410756723114`, -0.2868141075672295}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "14"}], "}"}], 
        Offset[{2, 2}, {-0.28681410756723114, -0.2868141075672295}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{1.0222443204062975`*^-15, -0.660597529837658}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "15"}], "}"}], 
        Offset[{2, 2}, {1.0222443204062975*^-15, -0.660597529837658}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.4056164008015143, 7.166803835241803*^-16}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "16"}], "}"}], 
        Offset[{2, 2}, {-0.4056164008015143, 7.166803835241803*^-16}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}}}, 
    {GrayLevel[0], AbsolutePointSize[5], PointBox[{0.4056164008015161, 0.}], 
     PointBox[{0.2868141075672326, 0.28681410756723275`}], 
     PointBox[{0.28681410756722675`, -0.2868141075672285}], 
     PointBox[{0.6605975298376587, 5.664226070673724*^-16}], 
     PointBox[{6.99702747969524*^-17, 0.405616400801516}], 
     PointBox[{0.4671129929832897, 0.4671129929832898}], 
     PointBox[{-6.92670381065753*^-16, -0.4056164008015093}], 
     PointBox[{0.46711299298329145`, -0.467112992983291}], 
     PointBox[{-0.4671129929832925, -0.46711299298329434`}], 
     PointBox[{-0.28681410756723236`, 0.2868141075672325}], 
     PointBox[{-0.46711299298329184`, 0.46711299298329}], 
     PointBox[{-4.834719367710373*^-16, 0.660597529837657}], 
     PointBox[{-0.6605975298376634, -1.6921517786986418`*^-15}], 
     PointBox[{-0.28681410756723114`, -0.2868141075672295}], 
     PointBox[{1.0222443204062975`*^-15, -0.660597529837658}], 
     PointBox[{-0.4056164008015143, 7.166803835241803*^-16}]}}},
  ImageSize->300,
  PlotRange->{{-1.1, 1.1}, {-1.1, 1.1}}]], "Output",
 CellChangeTimes->{
  3.9090560518364916`*^9, {3.9090561101798167`*^9, 3.9090561548715925`*^9}, 
   3.9091127161095977`*^9, 3.910153148939886*^9, {3.9101612802787886`*^9, 
   3.910161292364663*^9}},
 CellLabel->"Out[52]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
96.],ExpressionUUID->"7ee16426-f490-4dcf-ae5a-abb143537df5"]
}, Open  ]],

Cell["\<\
The elementary nearest-neighbor model has constant hoppings -1 and vanishing \
onsite potential, such that the Abelian Bloch Hamiltonian on the primitive \
cell can be constructed as follows:\
\>", "Text",
 CellChangeTimes->{{3.9091100794507523`*^9, 3.909110119897537*^9}, {
  3.9101532932814474`*^9, 
  3.9101533277179966`*^9}},ExpressionUUID->"0a1e40eb-b992-4711-9e3c-\
48b30f41c3f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Hpc", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"AbelianBlochHamiltonian", "[", 
       RowBox[{"pcmodel", ",", "1", ",", 
        RowBox[{"0", "&"}], ",", 
        RowBox[{
         RowBox[{"-", "1"}], "&"}]}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.9091127598630133`*^9, 3.9091128051125402`*^9}, {
  3.909112887125308*^9, 3.909112890216216*^9}, {3.909114118715374*^9, 
  3.909114118938531*^9}, {3.910153339519004*^9, 3.9101533492091894`*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"38c40d56-e0c2-4481-806c-40558f39dfbe"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0"},
     {
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]]}], "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]]}], "0", "0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]]}], "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]]}], "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]]}], "0", "0", "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]]}], "0", "0", "0", "0", "0", "0",
       "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], "0", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]]}], "0", "0", "0", "0", 
      "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]]}], "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]]}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]]}], "0", "0", "0", "0", 
      "0", "0", "0"},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]]}], "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]]}], "0", "0", "0", "0", 
      "0", "0", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]]}], "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.909112806133675*^9, 3.9091128916577287`*^9, 
  3.909113216625798*^9, 3.9091141203995323`*^9, 3.91015335400698*^9, 
  3.910161299005518*^9},
 CellLabel->
  "Out[53]//MatrixForm=",ExpressionUUID->"ddca14ab-9bbf-4bf2-a25b-\
d05048d25c08"]
}, Open  ]],

Cell["We export the matrix", "Text",
 CellChangeTimes->{{3.90911280941973*^9, 
  3.9091128164730463`*^9}},ExpressionUUID->"eb6f2ed8-b3bb-496d-89ea-\
ea805068d26c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
       "\"\<H_{8,3}-tess_T2.1.dat\>\""}], "}"}], "]"}], ",", "Hpc", ",", 
    "\"\<Table\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.909112817642894*^9, 3.909112873040862*^9}, {
  3.9091135412614784`*^9, 3.9091135513819184`*^9}, {3.9091141224124656`*^9, 
  3.9091141227837057`*^9}, {3.9101533706269875`*^9, 3.910153387843902*^9}, {
  3.910161305435033*^9, 3.9101613071799307`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"493ddf19-00d7-49cf-acc4-8a1c9ca3b79b"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909112902255294*^9, 
  3.909112904377528*^9}},ExpressionUUID->"1606f219-d378-4d2b-9043-\
2f2ad2be2a2f"],

Cell["\<\
We approximate the density of states by randomly sampling momenta, i.e., \
one-dimensional irreducible representations, and diagonalizing the Bloch \
Hamiltonian evaluated at those. For faster evaluation, we compile the \
expression for the Bloch Hamiltonian:\
\>", "Text",
 CellChangeTimes->{{3.9091129164291873`*^9, 3.909112983734069*^9}, {
  3.9101534175388513`*^9, 
  3.910153418071595*^9}},ExpressionUUID->"08060aaf-6252-45ac-9e04-\
d3a80c9c83ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hpccf", "=", 
  RowBox[{"AbelianBlochHamiltonian", "[", 
   RowBox[{"pcmodel", ",", "1", ",", 
    RowBox[{"0", "&"}], ",", 
    RowBox[{
     RowBox[{"-", "1"}], "&"}], ",", 
    RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9091129849959536`*^9, 3.9091129967523327`*^9}, {
   3.909114125339196*^9, 3.909114125798375*^9}, 3.910153426194847*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"27569130-23e9-4fd3-aef2-43d81f33b05b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["CompiledFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  StyleBox[
                   PaneBox[
                    RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ContentPadding -> False, FrameMargins -> 0, 
                    StripOnInput -> True, BaselinePosition -> Baseline, 
                    ImageSize -> {{1, 300}, Automatic}], LineBreakWithin -> 
                   False], "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ImageSize -> {{1, 500}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Variables: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$649483", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649484", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649485", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649486"}], 
                    "}"}], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"Block", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Compile`$34", ",", "Compile`$35", ",", "Compile`$43", 
                    ",", "Compile`$47", ",", "Compile`$48", ",", 
                    "Compile`$49", ",", "Compile`$138", ",", "Compile`$139", 
                    ",", "Compile`$140", ",", "Compile`$56", ",", 
                    "Compile`$57", ",", "Compile`$58", ",", "Compile`$91", 
                    ",", "Compile`$92", ",", "Compile`$93", ",", 
                    "Compile`$105", ",", "Compile`$106", ",", "Compile`$107", 
                    ",", "Compile`$96", ",", "Compile`$97", ",", 
                    "Compile`$98", ",", "Compile`$60", ",", "Compile`$61", 
                    ",", "Compile`$67"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"Compile`$34", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649483"}]}], 
                    ";", 
                    RowBox[{"Compile`$35", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$34"]}], ";", 
                    RowBox[{"Compile`$43", "=", 
                    RowBox[{"-", "Compile`$35"}]}], ";", 
                    RowBox[{"Compile`$47", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649486"}]}], 
                    ";", 
                    RowBox[{"Compile`$48", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$47"]}], ";", 
                    RowBox[{"Compile`$49", "=", 
                    RowBox[{"-", "Compile`$48"}]}], ";", 
                    RowBox[{"Compile`$138", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649485"}]}], 
                    ";", 
                    RowBox[{"Compile`$139", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$138"]}], ";", 
                    RowBox[{"Compile`$140", "=", 
                    RowBox[{"-", "Compile`$139"}]}], ";", 
                    RowBox[{"Compile`$56", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649484"}]}], 
                    ";", 
                    RowBox[{"Compile`$57", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$56"]}], ";", 
                    RowBox[{"Compile`$58", "=", 
                    RowBox[{"-", "Compile`$57"}]}], ";", 
                    RowBox[{"Compile`$91", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649483"}]}], 
                    ";", 
                    RowBox[{"Compile`$92", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$91"]}], ";", 
                    RowBox[{"Compile`$93", "=", 
                    RowBox[{"-", "Compile`$92"}]}], ";", 
                    RowBox[{"Compile`$105", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649486"}]}], 
                    ";", 
                    RowBox[{"Compile`$106", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$105"]}], ";", 
                    RowBox[{"Compile`$107", "=", 
                    RowBox[{"-", "Compile`$106"}]}], ";", 
                    RowBox[{"Compile`$96", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649484"}]}], 
                    ";", 
                    RowBox[{"Compile`$97", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$96"]}], ";", 
                    RowBox[{"Compile`$98", "=", 
                    RowBox[{"-", "Compile`$97"}]}], ";", 
                    RowBox[{"Compile`$60", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$649485"}]}], 
                    ";", 
                    RowBox[{"Compile`$61", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$60"]}], ";", 
                    RowBox[{"Compile`$67", "=", 
                    RowBox[{"-", "Compile`$61"}]}], ";", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "Compile`$43", 
                    ",", "0", ",", "Compile`$49", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "Compile`$43", ",", "0", ",", 
                    "Compile`$58", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$67", ",", "Compile`$49", ",", "0", ",", "0", 
                    ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "Compile`$93", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "Compile`$98", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", 
                    RowBox[{"-", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "Compile`$107", ",",
                     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "Compile`$140", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    "Compile`$140", ",", "Compile`$58", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$93", ",", "0", ",", "Compile`$107", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", 
                    RowBox[{"-", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$98", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$67", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], 
                    "}"}]}]}], "]"}], ImageSize -> {{1, 500}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  CompiledFunction[{11, 13.3, 5468}, {
    Blank[Real], 
    Blank[Real], 
    Blank[Real], 
    Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {4, 2, 
   0}}, {{0, {2, 0, 0}}, {0., {3, 0, 4}}, {
     Complex[0., -1.], {4, 0, 0}}, {-1, {2, 0, 1}}, {
     Complex[0., 1.], {4, 0, 4}}}, {0, 2, 245, 266, 
   1}, {{11, 0, 4, 1}, {17, 0, 1, 2}, {40, 32, 4, 0, 2, 4, 0, 1}, {20, 1, 
    3}, {11, 3, 4, 5}, {17, 4, 5, 6}, {40, 32, 4, 0, 6, 4, 0, 5}, {20, 5, 
    7}, {11, 2, 4, 8}, {17, 0, 8, 9}, {40, 32, 4, 0, 9, 4, 0, 8}, {20, 8, 
    10}, {11, 1, 4, 11}, {17, 0, 11, 12}, {40, 32, 4, 0, 12, 4, 0, 11}, {20, 
    11, 13}, {11, 0, 4, 14}, {17, 4, 14, 15}, {40, 32, 4, 0, 15, 4, 0, 14}, {
    20, 14, 16}, {11, 3, 4, 17}, {17, 0, 17, 18}, {40, 32, 4, 0, 18, 4, 0, 
    17}, {20, 17, 19}, {11, 1, 4, 20}, {17, 4, 20, 21}, {40, 32, 4, 0, 21, 4, 
    0, 20}, {20, 20, 22}, {11, 2, 4, 23}, {17, 4, 23, 24}, {40, 32, 4, 0, 24, 
    4, 0, 23}, {20, 23, 25}, {10, 0, 5}, {11, 5, 4, 26}, {10, 1, 6}, {11, 6, 
    4, 27}, {10, 1, 7}, {11, 7, 4, 28}, {10, 1, 8}, {11, 8, 4, 29}, {10, 0, 
    9}, {11, 9, 4, 30}, {10, 0, 10}, {11, 10, 4, 31}, {10, 0, 11}, {11, 11, 4,
     32}, {10, 0, 12}, {11, 12, 4, 33}, {10, 0, 13}, {11, 13, 4, 34}, {10, 0, 
    14}, {11, 14, 4, 35}, {10, 0, 15}, {11, 15, 4, 36}, {10, 0, 16}, {11, 16, 
    4, 37}, {10, 0, 17}, {11, 17, 4, 38}, {10, 0, 18}, {11, 18, 4, 39}, {10, 
    0, 19}, {11, 19, 4, 40}, {10, 0, 20}, {11, 20, 4, 41}, {10, 1, 21}, {11, 
    21, 4, 42}, {10, 0, 22}, {11, 22, 4, 43}, {10, 0, 23}, {11, 23, 4, 44}, {
    10, 0, 24}, {11, 24, 4, 45}, {10, 1, 25}, {11, 25, 4, 46}, {10, 1, 26}, {
    11, 26, 4, 47}, {10, 0, 27}, {11, 27, 4, 48}, {10, 0, 28}, {11, 28, 4, 
    49}, {10, 0, 29}, {11, 29, 4, 50}, {10, 0, 30}, {11, 30, 4, 51}, {10, 0, 
    31}, {11, 31, 4, 52}, {10, 0, 32}, {11, 32, 4, 53}, {10, 0, 33}, {11, 33, 
    4, 54}, {10, 0, 34}, {11, 34, 4, 55}, {10, 0, 35}, {11, 35, 4, 56}, {10, 
    0, 36}, {11, 36, 4, 57}, {10, 1, 37}, {11, 37, 4, 58}, {10, 0, 38}, {11, 
    38, 4, 59}, {10, 0, 39}, {11, 39, 4, 60}, {10, 0, 40}, {11, 40, 4, 61}, {
    10, 0, 41}, {11, 41, 4, 62}, {10, 0, 42}, {11, 42, 4, 63}, {10, 1, 43}, {
    11, 43, 4, 64}, {10, 1, 44}, {11, 44, 4, 65}, {10, 0, 45}, {11, 45, 4, 
    66}, {10, 0, 46}, {11, 46, 4, 67}, {10, 0, 47}, {11, 47, 4, 68}, {10, 0, 
    48}, {11, 48, 4, 69}, {10, 0, 49}, {11, 49, 4, 70}, {10, 0, 50}, {11, 50, 
    4, 71}, {10, 0, 51}, {11, 51, 4, 72}, {10, 0, 52}, {11, 52, 4, 73}, {10, 
    1, 53}, {11, 53, 4, 74}, {10, 0, 54}, {11, 54, 4, 75}, {10, 0, 55}, {11, 
    55, 4, 76}, {10, 0, 56}, {11, 56, 4, 77}, {10, 0, 57}, {11, 57, 4, 78}, {
    10, 0, 58}, {11, 58, 4, 79}, {10, 0, 59}, {11, 59, 4, 80}, {10, 0, 60}, {
    11, 60, 4, 81}, {10, 0, 61}, {11, 61, 4, 82}, {10, 0, 62}, {11, 62, 4, 
    83}, {10, 0, 63}, {11, 63, 4, 84}, {10, 0, 64}, {11, 64, 4, 85}, {10, 0, 
    65}, {11, 65, 4, 86}, {10, 0, 66}, {11, 66, 4, 87}, {10, 0, 67}, {11, 67, 
    4, 88}, {10, 1, 68}, {11, 68, 4, 89}, {10, 0, 69}, {11, 69, 4, 90}, {10, 
    0, 70}, {11, 70, 4, 91}, {10, 0, 71}, {11, 71, 4, 92}, {10, 0, 72}, {11, 
    72, 4, 93}, {10, 0, 73}, {11, 73, 4, 94}, {10, 0, 74}, {11, 74, 4, 95}, {
    10, 0, 75}, {11, 75, 4, 96}, {10, 1, 76}, {11, 76, 4, 97}, {10, 0, 77}, {
    11, 77, 4, 98}, {10, 1, 78}, {11, 78, 4, 99}, {10, 0, 79}, {11, 79, 4, 
    100}, {10, 0, 80}, {11, 80, 4, 101}, {10, 0, 81}, {11, 81, 4, 102}, {10, 
    0, 82}, {11, 82, 4, 103}, {10, 0, 83}, {11, 83, 4, 104}, {10, 1, 84}, {11,
     84, 4, 105}, {10, 0, 85}, {11, 85, 4, 106}, {10, 0, 86}, {11, 86, 4, 
    107}, {10, 0, 87}, {11, 87, 4, 108}, {10, 0, 88}, {11, 88, 4, 109}, {10, 
    0, 89}, {11, 89, 4, 110}, {10, 0, 90}, {11, 90, 4, 111}, {10, 0, 91}, {11,
     91, 4, 112}, {10, 0, 92}, {11, 92, 4, 113}, {10, 0, 93}, {11, 93, 4, 
    114}, {10, 0, 94}, {11, 94, 4, 115}, {10, 0, 95}, {11, 95, 4, 116}, {10, 
    0, 96}, {11, 96, 4, 117}, {10, 0, 97}, {11, 97, 4, 118}, {10, 0, 98}, {11,
     98, 4, 119}, {10, 1, 99}, {11, 99, 4, 120}, {10, 0, 100}, {11, 100, 4, 
    121}, {10, 0, 101}, {11, 101, 4, 122}, {10, 0, 102}, {11, 102, 4, 123}, {
    10, 0, 103}, {11, 103, 4, 124}, {10, 0, 104}, {11, 104, 4, 125}, {10, 0, 
    105}, {11, 105, 4, 126}, {10, 0, 106}, {11, 106, 4, 127}, {10, 0, 107}, {
    11, 107, 4, 128}, {10, 0, 108}, {11, 108, 4, 129}, {10, 0, 109}, {11, 109,
     4, 130}, {10, 1, 110}, {11, 110, 4, 131}, {10, 1, 111}, {11, 111, 4, 
    132}, {10, 0, 112}, {11, 112, 4, 133}, {10, 0, 113}, {11, 113, 4, 134}, {
    10, 0, 114}, {11, 114, 4, 135}, {10, 1, 115}, {11, 115, 4, 136}, {10, 0, 
    116}, {11, 116, 4, 137}, {10, 0, 117}, {11, 117, 4, 138}, {10, 0, 118}, {
    11, 118, 4, 139}, {10, 0, 119}, {11, 119, 4, 140}, {10, 0, 120}, {11, 120,
     4, 141}, {10, 0, 121}, {11, 121, 4, 142}, {10, 0, 122}, {11, 122, 4, 
    143}, {10, 0, 123}, {11, 123, 4, 144}, {10, 0, 124}, {11, 124, 4, 145}, {
    10, 0, 125}, {11, 125, 4, 146}, {10, 0, 126}, {11, 126, 4, 147}, {10, 0, 
    127}, {11, 127, 4, 148}, {10, 0, 128}, {11, 128, 4, 149}, {10, 0, 129}, {
    11, 129, 4, 150}, {10, 0, 130}, {11, 130, 4, 151}, {10, 0, 131}, {11, 131,
     4, 152}, {10, 0, 132}, {11, 132, 4, 153}, {10, 0, 133}, {11, 133, 4, 
    154}, {10, 0, 134}, {11, 134, 4, 155}, {10, 0, 135}, {11, 135, 4, 156}, {
    10, 0, 136}, {11, 136, 4, 157}, {10, 0, 137}, {11, 137, 4, 158}, {10, 1, 
    138}, {11, 138, 4, 159}, {10, 0, 139}, {11, 139, 4, 160}, {10, 0, 140}, {
    11, 140, 4, 161}, {10, 0, 141}, {11, 141, 4, 162}, {10, 0, 142}, {11, 142,
     4, 163}, {10, 0, 143}, {11, 143, 4, 164}, {10, 0, 144}, {11, 144, 4, 
    165}, {10, 1, 145}, {11, 145, 4, 166}, {10, 0, 146}, {11, 146, 4, 167}, {
    10, 0, 147}, {11, 147, 4, 168}, {10, 0, 148}, {11, 148, 4, 169}, {10, 0, 
    149}, {11, 149, 4, 170}, {10, 0, 150}, {11, 150, 4, 171}, {10, 1, 151}, {
    11, 151, 4, 172}, {10, 0, 152}, {11, 152, 4, 173}, {10, 0, 153}, {11, 153,
     4, 174}, {10, 0, 154}, {11, 154, 4, 175}, {10, 0, 155}, {11, 155, 4, 
    176}, {10, 1, 156}, {11, 156, 4, 177}, {10, 0, 157}, {11, 157, 4, 178}, {
    10, 0, 158}, {11, 158, 4, 179}, {10, 0, 159}, {11, 159, 4, 180}, {10, 0, 
    160}, {11, 160, 4, 181}, {10, 0, 161}, {11, 161, 4, 182}, {10, 0, 162}, {
    11, 162, 4, 183}, {10, 0, 163}, {11, 163, 4, 184}, {10, 0, 164}, {11, 164,
     4, 185}, {10, 1, 165}, {11, 165, 4, 186}, {10, 0, 166}, {11, 166, 4, 
    187}, {10, 0, 167}, {11, 167, 4, 188}, {10, 0, 168}, {11, 168, 4, 189}, {
    10, 0, 169}, {11, 169, 4, 190}, {10, 0, 170}, {11, 170, 4, 191}, {10, 0, 
    171}, {11, 171, 4, 192}, {10, 0, 172}, {11, 172, 4, 193}, {10, 0, 173}, {
    11, 173, 4, 194}, {10, 0, 174}, {11, 174, 4, 195}, {10, 1, 175}, {11, 175,
     4, 196}, {10, 0, 176}, {11, 176, 4, 197}, {10, 0, 177}, {11, 177, 4, 
    198}, {10, 0, 178}, {11, 178, 4, 199}, {10, 0, 179}, {11, 179, 4, 200}, {
    10, 0, 180}, {11, 180, 4, 201}, {10, 0, 181}, {11, 181, 4, 202}, {10, 0, 
    182}, {11, 182, 4, 203}, {10, 0, 183}, {11, 183, 4, 204}, {10, 0, 184}, {
    11, 184, 4, 205}, {10, 0, 185}, {11, 185, 4, 206}, {10, 0, 186}, {11, 186,
     4, 207}, {10, 0, 187}, {11, 187, 4, 208}, {10, 0, 188}, {11, 188, 4, 
    209}, {10, 0, 189}, {11, 189, 4, 210}, {10, 0, 190}, {11, 190, 4, 211}, {
    10, 0, 191}, {11, 191, 4, 212}, {10, 0, 192}, {11, 192, 4, 213}, {10, 0, 
    193}, {11, 193, 4, 214}, {10, 0, 194}, {11, 194, 4, 215}, {10, 0, 195}, {
    11, 195, 4, 216}, {10, 0, 196}, {11, 196, 4, 217}, {10, 0, 197}, {11, 197,
     4, 218}, {10, 1, 198}, {11, 198, 4, 219}, {10, 0, 199}, {11, 199, 4, 
    220}, {10, 0, 200}, {11, 200, 4, 221}, {10, 0, 201}, {11, 201, 4, 222}, {
    10, 0, 202}, {11, 202, 4, 223}, {10, 0, 203}, {11, 203, 4, 224}, {10, 0, 
    204}, {11, 204, 4, 225}, {10, 1, 205}, {11, 205, 4, 226}, {10, 0, 206}, {
    11, 206, 4, 227}, {10, 1, 207}, {11, 207, 4, 228}, {10, 0, 208}, {11, 208,
     4, 229}, {10, 0, 209}, {11, 209, 4, 230}, {10, 0, 210}, {11, 210, 4, 
    231}, {10, 0, 211}, {11, 211, 4, 232}, {10, 0, 212}, {11, 212, 4, 233}, {
    10, 0, 213}, {11, 213, 4, 234}, {10, 1, 214}, {11, 214, 4, 235}, {10, 0, 
    215}, {11, 215, 4, 236}, {10, 0, 216}, {11, 216, 4, 237}, {10, 0, 217}, {
    11, 217, 4, 238}, {10, 0, 218}, {11, 218, 4, 239}, {10, 0, 219}, {11, 219,
     4, 240}, {10, 1, 220}, {11, 220, 4, 241}, {10, 0, 221}, {11, 221, 4, 
    242}, {10, 0, 222}, {11, 222, 4, 243}, {10, 0, 223}, {11, 223, 4, 244}, {
    10, 0, 224}, {11, 224, 4, 245}, {10, 0, 225}, {11, 225, 4, 246}, {10, 0, 
    226}, {11, 226, 4, 247}, {10, 0, 227}, {11, 227, 4, 248}, {10, 0, 228}, {
    11, 228, 4, 249}, {10, 0, 229}, {11, 229, 4, 250}, {10, 0, 230}, {11, 230,
     4, 251}, {10, 0, 231}, {11, 231, 4, 252}, {10, 0, 232}, {11, 232, 4, 
    253}, {10, 0, 233}, {11, 233, 4, 254}, {10, 0, 234}, {11, 234, 4, 255}, {
    10, 0, 235}, {11, 235, 4, 256}, {10, 0, 236}, {11, 236, 4, 257}, {10, 0, 
    237}, {11, 237, 4, 258}, {10, 1, 238}, {11, 238, 4, 259}, {10, 0, 239}, {
    11, 239, 4, 260}, {10, 0, 240}, {11, 240, 4, 261}, {10, 1, 241}, {11, 241,
     4, 262}, {10, 1, 242}, {11, 242, 4, 263}, {10, 0, 243}, {11, 243, 4, 
    264}, {10, 0, 244}, {11, 244, 4, 265}, CompressedData["
1:eJwt1GWMlkcUBtBvkS4lISFp0gQohUVanOKuNVwWd3fYxV1aKri7u7u7u7u7
u1NqtHA23zvJmUkm98fNMxLVODY6JiIUCn1iSmONR9JAclLwBSn5klSkJioU
rk9LOtLzFV+TgYxkIjNZyEo2svMNOchJLnKTh7zkIz8FKEghClOEohSjOCUo
ybd8x/f8wI+UojRlKEs5ylOBilSiMvGJJpIqVKUa1alBTWpRmzrUpR71aUBD
GtGYJjSlGc1pQUta0Zo2tKUdMcTSng50pFPQT2eS0IWudKM7PehJL3rTh770
4yd+pj+/8Cu/8TsDGMggBjOEoQxjOCMYSbIgh1GMZgxjGcf4UPg+TGAik5jM
FKYyjc+ZzgxmMovZzGEu85jPAhayiMUsYSnLWM4KVrKK1axhLZ+xjvVsYCOb
2MwWtrKN7SRmBzvZxW72sJd97A9q4nI+wEEOcZgjHOUYxznBSU5xOsjhTNDP
Wc5xngtc5BKXucJVrnGdG9zkFre5w13ucZ8HPOQRj3nCU57xnBe8DHJ+xWve
8DY4uz94x5/8xd/8w7+85z/+5wMhbz2CeMQnAQkjwn9AJIn4NG4/FB4fAaYF
gVs=
    "], {1}}, 
   Function[{
    PatrickMLenggenhager`HyperBloch`Private`k$649483, 
     PatrickMLenggenhager`HyperBloch`Private`k$649484, 
     PatrickMLenggenhager`HyperBloch`Private`k$649485, 
     PatrickMLenggenhager`HyperBloch`Private`k$649486}, 
    Block[{
     Compile`$34, Compile`$35, Compile`$43, Compile`$47, Compile`$48, 
      Compile`$49, Compile`$138, Compile`$139, Compile`$140, Compile`$56, 
      Compile`$57, Compile`$58, Compile`$91, Compile`$92, Compile`$93, 
      Compile`$105, Compile`$106, Compile`$107, Compile`$96, Compile`$97, 
      Compile`$98, Compile`$60, Compile`$61, Compile`$67}, 
     Compile`$34 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$649483; 
     Compile`$35 = E^Compile`$34; Compile`$43 = -Compile`$35; 
     Compile`$47 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$649486; 
     Compile`$48 = E^Compile`$47; Compile`$49 = -Compile`$48; 
     Compile`$138 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$649485; 
     Compile`$139 = E^Compile`$138; Compile`$140 = -Compile`$139; 
     Compile`$56 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$649484; 
     Compile`$57 = E^Compile`$56; Compile`$58 = -Compile`$57; 
     Compile`$91 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$649483; 
     Compile`$92 = E^Compile`$91; Compile`$93 = -Compile`$92; 
     Compile`$105 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$649486; 
     Compile`$106 = E^Compile`$105; Compile`$107 = -Compile`$106; 
     Compile`$96 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$649484; 
     Compile`$97 = E^Compile`$96; Compile`$98 = -Compile`$97; 
     Compile`$60 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$649485; 
     Compile`$61 = E^Compile`$60; 
     Compile`$67 = -Compile`$61; {{0, -1, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
       0, 0, 0}, {-1, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {-1, 0, 
       0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0, 
       0}, {-1, 0, 0, 0, 0, 0, 0, 0, Compile`$43, 0, Compile`$49, 0, 0, 0, 0, 
        0}, {0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 0, 0, 0, 0}, {
       0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, Compile`$43, 0, Compile`$58, 0}, {
       0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0}, {
       0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, Compile`$67, Compile`$49, 0, 0, 0}, {
       0, 0, 0, Compile`$93, 0, 0, 0, 0, 0, 0, 0, Compile`$98, 0, -1, 0, 0}, {
       0, 0, 0, 0, -1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, -1}, {
       0, 0, 0, Compile`$107, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, Compile`$140, 
        0}, {0, 0, 0, 0, -1, 0, 0, Compile`$140, Compile`$58, 0, 0, 0, 0, 0, 
        0, 0}, {0, 0, 0, 0, 0, Compile`$93, 0, Compile`$107, 0, 0, 0, 0, 0, 0,
         0, -1}, {0, 0, 0, 0, 0, 0, -1, 0, -1, 0, 0, 0, 0, 0, 0, -1}, {
       0, 0, 0, 0, 0, Compile`$98, -1, 0, 0, 0, Compile`$67, 0, 0, 0, 0, 0}, {
       0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, -1, -1, 0, 0}}]], Evaluate],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.9091129975570006`*^9, 3.909113219916849*^9, 
  3.909115025816557*^9, 3.9101534280800033`*^9, 3.910156813155707*^9, 
  3.9101614128065453`*^9, 3.9101652925382805`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"9a0b9b92-dfad-4dc6-b529-ba341c021fdf"]
}, Open  ]],

Cell[TextData[{
 "As stated in the paper, we compute the DOS with an energy resolution of \
0.005 (but for demonstration purposes with a smaller sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "0c09a8a6-25eb-49a7-a516-414cafa74411"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "8"], TraditionalForm]],ExpressionUUID->
  "4d99dfb2-1ef8-40c3-b984-89607010bc1c"],
 ")"
}], "Text",
 CellChangeTimes->{{3.909113068779531*^9, 3.9091131190954094`*^9}, {
  3.9101614549615393`*^9, 3.9101614564987535`*^9}, {3.910161500131562*^9, 
  3.910161500190627*^9}},ExpressionUUID->"4b4f3a38-c50a-4b93-aba7-\
b03f2b15e9bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dospc", "=", 
   RowBox[{"ComputeDOS", "[", 
    RowBox[{"Hpccf", ",", 
     RowBox[{"10", "^", "5"}], ",", "32", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], "-", "0.005"}], ",", "3"}], "}"}], ",", "0.005"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091130888235645`*^9, 3.9091130961532984`*^9}, {
  3.90911413019394*^9, 3.9091141332449045`*^9}, {3.910161490577303*^9, 
  3.910161498644859*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"afdd53c3-797e-4619-aae6-18a044d2efe4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"dospc", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.1); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(5\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909113125377311*^9, 3.9091131344978976`*^9}, {
  3.90911413604417*^9, 3.9091141363413095`*^9}, {3.9091150932516265`*^9, 
  3.9091150966947627`*^9}, {3.909126411615711*^9, 3.909126429281196*^9}, {
  3.910161469973936*^9, 3.910161470044631*^9}, {3.910161502500625*^9, 
  3.9101615076578336`*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"961292a7-59d7-40a3-b4ad-df480a357ba9"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.006944444444444445], AbsoluteThickness[2], LineBox[CompressedData["
1:eJxdnHmcnVdZx+9+K6BErLUgQhDFqggFRYpQn8NaNqUFhIoVCxZEUGgRsFbE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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxdnHmcnVdZx+9+K6BErLUgQhDFqggFRYpQn8NaNqUFhIoVCxZEUGgRsFbE
VEBa1pbFshNaSpO22dNsTXrObMlk1jtL9m2STGaSmcxk9v3OMO/5/X5vPpJ/
2jtz57znPd9znv05L/jgJ975oVwmk9lUyGSS/35x8KYdzyteETL8959Xrr/h
9Fw5zH3uo7s/9a032+3XP+3QQyPl8MP6lRs/+ZE77MPJv75y2Pm85C8/Z7d8
o3bymuP6/d32zh3Lv+gohwffuG282n2Pvfn0XVeu31cOb31G7o+/dNW9lgx3
+55ymKh233nhRffbnyb/tujv77c/TAZcUw7lu7/z+q/8ywMWH/Pjcsgv//WR
tgcsmd5d3y6H/Z956ifPeemPLBnu+i+XQ03TT5ef+COLL7GqHP4oTuyHNnXN
8v98uhxm3nX24R/Ur7bkdb/4sXL4y/iHD1oyvRs+UA7n59eOdv7Vg5b89Gnv
LYcXHptdXoGfWUvy7+3l8IJkdkM/s+VBb/nG68rh75Phb3nEkte96bpy+Flc
qDWWTO/Kl5TDn8UXe8ziz19YDj3v+NoDH3/WY/a95N+zy2Hf215572tvXWdx
mGeWQ0N8/XUGHnr/DQYepfDswnt+7U82byKPUvjm0GftFe/fTB6lcF+c2Gby
KIX/W/7r/vlN5FEKb08ed24reZTCQvK6H9xKHqVwMVmXwSfIoxR+M77INvIo
hZdf8fhz33fbdvIohWtP/F7p7u9sJ49S+MSzPh+afrqTPErhux9PfrCTPEph
4EUvWx5hF3mUwu+877ZXn3rHHvIohdXPeenyiHvIoxRecypZsKfIoxQ2Jcv/
WU8epXC0bXqZqCePEnkF8ihxfWvIo8T9UUMepXAmec7pWvIohefHha8jj1I4
mbze6+vIoxS+EJIB6sijGP4umf7XGsijSH4N5FHkftlLHsXw3mV6P7q0jzyK
oS6Zd+0+uyHyKPI87CePYlj33GSBmsmjyP3cQh7F8GiCb0WFPIrhPXH8CnkU
Q+/ybl+5sYM8iiE+96ZO8iiGb1+dbKgu8ihy/3eSRzH8a3/yg07yKIYNcaKd
5FEMB5Zn+7IrusijyPPdTR7F0LU8u5tf1UUexRD/7lAneRS5PzvJQ/PtJI9i
+K0jCeAKeRTDh5LlfqBCHsXwkuW3fWRvO3kUyK+VPAphS/Lrt7WSRyH8OPn4
ymbyKIQnGhMBsp88CuG/lk/Trrc0kkchDCfHa1cDeRTCjcnx/Xw9eRRCPEc3
1JFHgfKrhjwK4R92vWV5RTx5FMLrbj1X+d1je8ijwPXV+SiQxzbyKHD/bSGP
QjiebO9PbSGPQvjt5LjcvY48CmFVIq6vfpw8CuGeq5IFfIw8Cjx/j5JHIbw4
EafTj5GH1m8deRRCMW6oDeRRCB9Ipj+7njwK4Q0JvrWbyKMQ7ogLtYk88iGu
yzVbySPP8/cEeeRTeQIe+fCxZPqFXeSRD/+WHHfbQx558thDHvmwmByXlwXy
yHP/BPLIhziPu2rJI0/5WUceee73evLIh68mrzO6lzzy4esJ7tBo8Zh+Oh9+
JZnuq5vJIx/+Kb5IC3lovAp55Cn/Oqw18tB4Oh95yu8D5JHn+e0mj3zYPp4I
hG7yyFN/dZFHPvxBgvN9XeSRpzzqIg/Np4s8cpSvneSR43gd5JELuahfO8gj
x/E7yCNHXhXyyIXPxoVsI49cGEmO172t5JFL1wc8cpR3zeSRC9Wof5rIIxfe
FReiiTxy1K/7yCMX4rmY3EseOdoDDeSRC/4nyQvWk0culd/gofepJY9c+O94
XmrJIxeak+1ZrSWPHOVBLXnkKN/qyCNHfVRHHhq/njxylJfSH1rvveSR5XnZ
Rx5Zjr+PPLKcTxN5ZGmvNJGHvt9MHlnqb+mPbDgY5XMLeWTT/Qse2fDMZLs9
0kIeWcqnZvLIUt62kEc2/O2rti5LzGbyyHJ/N5OH5tdCHlme92byyJJPC3lk
KR9bySMbxhJ1dnMreWTDPy5rj62NLeSRpbxtJY/Ln8EjG7782uQF2skjm+5H
8MiGbJx4G3lkg0vwPqONPDKUv23kkaG8bSePDOVhK3lkwnWJOVVpI48M9U07
eWTCp7+VDFghjwzPcxt5ZMJfJMv5kzbyyITfSMynN0qfZyifW8kjQ37t5JGh
PK+QR4b6pJ08Lj8fPDKUrxXyyISHon3eRh4Z6tt28shQP7eTRybVv+CRIb8K
eWS4/9rJQ+tRIQ+tp/R5JvxHsj0flz7PUD5VMP/JJQ97qt16op225CEP2qHf
Wpa89H+cz44lD33H5z+05MGXz/vGkoe+bLc43F36fRv4fnjJw19pAc+bljzW
uxX8rl/ykDetFqd3zZKvJObnD1rA58ol3x3tnRbwyCx58OR5GFz0Oh8Hox20
6A/H/zZjfWsv/z4Ot37Rw/5uwfp9b9G/KZnena32hTjgYjrf+Lq3L3rIA+7P
WxY9/CPKhxsWPfZbi708bsBFD96Ux89b9ODXjP31tEUP/4Xne7LK9W8mj6q/
KdpDLeRR9TgPPK87qv7Xk+P7mTaLr/lQ1UM/t5FH1Wv/gUeV862QR9VDH1fI
o+p/PxHnX+kgj6rHOnWQR5Xr0UkeVf/0+B5d5FH1kD/d5LHgpW/BY8HDHjxI
Hgse/u9B8ljwOF8HyWOB++EQeSxwfofJY8FDfh0hjwUP/XWUPBY4v2PkofGO
k8cC98MJ8ljwkE8nyWPeQx6fJI95D3unhzzmwfNjPeQx76GPu8hj3sdz3vI4
ecx72LdbyWPewz7ZRh7z5En77KZ5D/20mzzmuT57yGPewx6h/XvlvP/z5Ljl
ashjnvsxkMecx89ryWPO9yXm5ueon2vnPOwZ6uP1c9xP9N++N+ehT+vIY87D
H60jjznOv548NH49ecyRTz15zHn43w3kMechTxvIY87L3wOPWQ/9WUcesx72
dAN5zHr4fw3kMUt51UAesx76rIE8ZtPngcesh79N//LDs1yPveQx6yFf6a9c
P+uhrxrIY5bypoE8Zv2aRD2+lvZuZtZDn9OeGpyhvGwgjxmeh3rymPGwv/eS
xwzlRQN5zPgnE/XwpXryuPz34DFDfuIx4+FfiMeMf3diLq0UjxkP/6qOPGa8
/DHwmPH/G59TRx7TPh6nafGY9ogn1JPHtIc/UUce01zvOvKY9rCHa+zr8YWn
Pfz5WvKY5v6tJY9pD3+8ljymuX415DFN+VxDHtMe+q6GPKa5/wJ5TFPe15DH
lIf+DeQx5f9f/KN2ysPfCuQxxf2/hzymvOIn4DHlFW8Bjynu1z3kMcX98iR5
TPm/iTx2k8fl8cFjiuuxizymvPxb8Jj0sO92ksekh326gzwmPeyd7eQxSX2z
nTwmPey3HeQx6RGP2U4ekx72leTVJOezjTwmPf7LeNf1k5SfW8hD89tEHpNe
8TbwmPTyh8Fjwnck4uOjG8ljwit+Bx4T/p8T9/UV68ljwsMeXUseE9zPa8lj
wsPeWkseEx7+y2PkMeG/H/9uLXlMcL5ryWPC/2rcsD8njwkP++wR8pjwiH+s
JY/x9HngMU6+a8hjPH0eeIyn8wGPcY941VryGOf5e4w8xtP3A49xr3gEOIxT
Pqwnj3HaO+vJY5zyaSN5jHv4UxvIY9wjvrSRPMZoz20mjzHK983kMUZ9vJk8
xmg/biGPMZ6nLeQxRvnD+MXtY5S328hjzC9F+beDPMaor7eRxxjlzS7y0Hx0
PjTeLvIYpb58kjxGPfzh3eQx6hHffYo8Rrn/PXmMUr8F8hj18A8kr0apz2rI
Y5T2kOTVKPdzLXmMpvoRPEZpH0l/jHr48w3kMcr33UseIx75gUbyGPGITzWR
xwjfp4k8RvzayFv27khqz4LHCO1B+me3j3j5C+Ax4hH/7SCPEcrjTvIYof7p
Jo8R8j5IHiM83ydsIM7/kp+P3z9hIc73kke866B9N87vEt+/i/O5lD7vTfH5
l2hfVey58XmXqL/bbSIu6DDft418hylP6c8+NMz3bSK/YY94+X67MfIapn/R
SD7DPN+Ml2SGUx5Y/yHKuwZ7PC7QEM+X9POQ35O4h++RPh6iPV3L9Rvyiqdc
EddryCP+W8v9epHrU8P9eZH2gPTnRcrfYLfF/XfRI14S7DURwEWet8D9dZHr
s5s8BqkfniSPQQ//8knyGKQ9sYs8Bmnv7iKPQdqHO8ljMD2/4DFA+bSdPAZo
r223B+OAA5TfT9idcYID3C9byGPA/3vivpzYSh4DlMebyWOA67WVPC5QXm4h
jwuc/2byuMDzyXzOLReo3zaTxwU+byN5XKD9sok8znO+m8jjfPp98Lj8GTzO
0/7cRB7neb6kD8+n+g88+r3iz+DR75Gv2EAe/R7xpfXk0U/7ZT159FO/byCP
fvJaTx59PF/ryKOP+mwDefRxfdeTRx/9h43k0Ud7fBN59FE+bCSPPuof6Ytz
9K82k8c5yout5HGO52UreZzzf52on61byeMc32cLeZzj+24jj176ZzvIo5fr
uZ08er3yZeDRS/27kzx6U30AHr2/dD7OesXLweMs57ebPM5S3zxFHmc98l9P
kcdZ7s9AHmcpb2rI40xqj4LHGer/GvI4Q3kVyOMM4wG15HGGPGT/nuH4deRx
hva8/L/THvnSOvI4zf0heXWa9k8deZz2/5Oot/4G8jhNf7yePE7Tnmsgjx7G
P+SP9VD+NpBHj1e8Fjx6qB8byaOH+nAfefR4xW+74/xPcb0bbVWc7ynOv9Gu
jfM7Rf3cxPmcpH3SZF+Nzz/J5zfadfF5J+nf7bfzkfcJ+i/7yfeER36hyd4Q
eZ7wiueOxAU/TvugxVZHXsdpnzWTz3H/orheil8d5/5o4fofo7xqtZvjeh+j
vGrh+h7zyLcqHnfUK96K9TtK+63ZVsT1Oko+TdyvR2ivN3J/HknXF/vxCM//
PmuM+++wh57cy/12OPVHsb8Op/4seBzi9+vJ41Cq78DjEOVhPXkcpD6tI4+D
HvmPOvK4/HvwOMDzV0ceBxhPqyGPA/QHasmj2ys/BR7dPppn/XXk0Z36n+DR
7ZE/rSGPLtqbteTRlepb8OjyykeCR2fqn4JHZ3pewaOT868hjw6erxry6EjP
P3h00N+pIY8K/csa8qhQfuu8V3w8bg/X2Jo4/3b608v+bpzv5c+3xvm10V7S
fFp5PmrtauR5uf+X5xef15J+v4K4ahovAt9m6otg98Du5HlYtl+QN6E9VWsu
8tpP/VlHPo20H2TvNtLfqOf670v328a43nvT/YX13Uv9o/hHQxoPwfrV8/Ne
WxnXqz6VV9ivdfTP93F/1qbfx36spfzbZ/fF/VdD/6aB+y3Qnm/k/gqpPLsx
zt9T/jZaJs73Kcb/Gi3E+e2mPbCf83mS9sZ+uzY+fxffd1mexeft4HhNtjry
3s7xmsh3G+3JVlsR3+sJ2o/NFiK/LWk8eRXqWtJ4OPhsSuPv1PuUX212a1zf
dWl8PMT1epTzbzcX338N/aF27q+HOf+KrYz75SHK8w5bFYGtZny6wzKoK/LI
b1W4fx/gea9YiP+93yPf0mmZyONevu/yZ9RN0T5a/hz37230F5Y/XxU/W/p5
Jeqs0u9Hw+BeS8eLhvX9puc5zMc0n1Wsg9J8A97H9D4O72t63x6sh2k9VmG9
TOuFArFHTeu5CuttWu8VtMNSHrQrxWs165TEswe8TbxXYj+Y9sPt2C+m/RKw
n0z7KRMDXztM+81hP5r2433Yr6b92oP9bNrPK7HfTfv9VpwH03m4mX6Lzgue
F0znaTXOm+m8OcplncfzrDPSeb2PcUqd52tx3k3nvQJ5kH7/TsodyQvMd69J
ngTIG5O8uZV5c8mjKyCvTPJqI+SZSZ7dCHlnkncjzCNLHspPl7y8jnkhydMe
5rEkb1dBHpvk8UrW5UheN0Kem+Q5+Lal318BfWDSBxuhL9LPL4Y+MekTPK9i
0jcV+t3SR3h+h0lffQr6zKTPMJ8Ok767GvrQpA8/An1p0pe7oU9N+nQF80zS
t1j/LpM+xvy7TPq6AH1u0ufYX90mfb8G9oDJHpiBvWCyF+CnHTDZEz+EvWGy
N8DvgMkewX48aLJXwPOgyZ7phb2T/h58D5nsoXtgL6X7C3HhQyZ7CjwOp/sN
PA6b7DHwOGyy18DjiMmeA48jJnsPPI6Y7EHwOGqyF8HjqMmeBI+jJntzBfNq
skfB45jJXgWPYyZ7FjyOm+xd8DhusofB47jJXgaP4yZ7GjxOmOxt8DhhssfB
44TJXgePkyZ7HjxOmux98Dhp8gfA45TJXwCPUyZ/AjxOmfyNq+CPmPwRPK8n
XV+sX08qz/D8HpO/swv+kMkfwnx6TP7SM+BPpfIK+/y0yd96P/wxkz+G+Z42
+WtY/9Mmfw7zP23y93LwB03+IPbXGZO/+G74kyZ/EnVIZ0z+JvbZmfS8tsFf
Nfmr4HcmPf/Yj2dN/i54njX5w5+Ev2zyl8H3rMmfroe/bfK3cQ7Pmvxx8Og1
+evg0Wvy58Gj1+Tvg0evKR4AHr2meAF49JriCeBxzhRvAI9zpngEeJwzxSvA
45wpngEe50zxDvA4Z4qHgEefKV4CHn2meAp49JniLeDRJ7uMPPpM8Rrw6DPF
c8CjzxTvAY9+UzwIPPpN8SLw6DfFk8Cj3xRvAo9+UzwKPPpN8SrwOG+KZ4HH
eVO8CzzOm+Jh4HHeFC8Dj8ufweO8Kd4GHhdM8TjwuJB+HzwumOJ54HHBFO8D
jwumeCB4XDDFC8FjwBRPBI8BU7wRPAZM8UjwGDDFK8FjwBTPBI8BU7wTPAZM
8VDwGDTFS7Eug6Z4KngMmuKt4DFoiseCx6ApXgseg6Z4Lnhc/KXzcdEUDwaP
i6Z4MXhcNMWTweNiqm/B46IpHg0eQ6Z4Nb43ZIpng8eQKd4NHkOpvgOPIVO8
HDyGTPF08Bg2xdvBY9gUjwePYVO8HjyGTfH8nyPeb4r3Q18Om/IB4DFsyheA
xyVTPgE8LpnyDeBxyZSPAI9LpnwFeFwy5TPA45Ip38F8iCkfwnyJKV+C9Rsx
5VPeinxL+jys54gpH4P5jJjyNdjHI6Z8DuTeiCnfw3yQKR/EfFFqh2L9R0z5
pGHkm0z5JvAYTXlgf42a8lWoox815bNgl42a8l3Mh5nyYcyXmfJlzKeZ8mmY
16gp3waeo6Z8HPbnqClfh/M2asrnQa+MpvoAdQCjpnwg84WmfCHziaZ8IniM
mfKN4DFmykeCx1h6fsFD420jjzFTvhM8xkz5UOZLTflS5lNN+VTw0Hw2k8eY
KR8LHuOmfC14jJvyueAxbsr3Yt7jpnww88WmfDHzyaZ8MvPNpnwz1nXclI8G
j3FTvho8xk35bPAYN+W7wWPclA8Hj3FTvpz5dFM+nfl2U74dPCZM+XjwmDDl
68FjIn0eeEyk88G8J9Ln4XsT6fuxnsBUT8B6A1O9AXhMmOoRwGPCVK8AHpOp
/gOPSVO9A3hMmuohwGPSVC/BegpTPQXrLUz1FpBvk6Z6jG+iXsNUrwEek6Z6
DvCYNNV7gMekqR4EPCZN9SLgofntVL2Jqd6E9SimehTwmDLVq4DHlKmeBTym
TPUu4DFlqocBjylTvQx4TJnqaVhvk47PehxTPQ7GnTLV64DHlKmeBzymU3sU
PKZN9UDgMW2qFwKPaVM9EeuNTPVGrEdK/VPwmDbVK4HHtKmeCTymU/8TPKZN
9VDgMW2qlwKPaVM9FeY5baq3Yj2WqR6L9Vqmei3wmDHVc4HHjKneCzxmTPVg
4DFjqhfDuDNpPAQ8Zkz1ZqxHM9WjsV4t9UfB4/Lfg8eMqd4NPGZTfxY8Zk31
cuAxa6qnA49ZU70d6/FM9Xis1zPV64HHrKmeDzxmTfV+4DFrqgcEj1lTvSB4
zJrqCcFj1lRvCB6zpnpE1iua6hVZz5g+D+s0Z6p3BI85Uz0keMyl+hE85kz1
lOAxZ6q3BI85Uz0m6zVN9Zqs50zjRVhHjV9LHnOmelDwmDfVi4LHvKmeFDzm
TfWm4DFvqkdlvaqpXpX1rKZ6VvCYN9W7gse8qR4WPOZN9bLgMW+qpwWPeVO9
LXjMm+pxsY7zpnpd1vOa6nlZ72uq9wWPBVM9MHgsmOqFwWPBVE8MHgumemPw
WDDVI4OHxjukemZTPTPrnU31zuCxYKqHBo8FU700eFRN9dTgUTXVW4NH1VSP
jfeqmuq1Wc9tqucGj6qp3hs8qqZ6cPComurFwaNqqicHj6qp3hw8qmk8GTyq
pnp1rFvVVM/OendTvTvr4U318Pj5oqleHjwWTfX04LFoqrcHj8XUngWPxTQ+
Dh6Lpnp+1vun8XD2A5j6AcBj0dQvAB6Xfw8eS6Z+A/BYMvUjgMdSGn/H3y2Z
+hnY72DqdwCPpXS+4LFk6pcAjyVTPwV46PcV8lgy9WOAx5KpXwM8lkz9HOCx
ZOr3YD+Ik7/AfhGnfpHvo5/EqZ/k4dtjv4lTv8kG9KM49aNEv+C6jFO/SvQD
Xpdx6mdhv4tTvwv7YZz6Ydgv47T/cM4zTv0009fEfhunfpto16zKOPXjPB39
Ok79OpHztzNO/TzPR7+PU78P+4Gc+oHYL+TULxT57ck49RO9Bf1G6fOjH9Gh
9WjHOh/POPUrRbnVl3HqZ7oD/U5O/U7sh3Lqh2K/lBN/9lM5xVvBI+vUbwUe
Wad+LPDIOvVrgcflz+CRder3Yj+YUz8Y+8Wc+sXYT+bUTwYeWad+M/DIOp0P
8Mg69auBR9apnw08sk79buCRdYrnsl/OqV8OPLJO/XTgkXXqtwOPrFM/Hnhk
nfr1wEPzayKPrFO/H3jo+/vUL+jUL8h+Qqd4LXjknPoNwSPn1I8IHjmnfkXw
yDn1M4JHzqnfETxyTv2Q7Jd06pcED41fq35Lp3gKeOSc+jHBI+fUrwkeOad+
TvDIOfV7gkfOqR8UPHJO/aLsJ3XqJwWPnFO/KXjk0v0IHjmnflXwyDn1s4KH
3qeDPHJO/bDgofXuUD+tUz8teOSd+m3BI+/Ujwseead+XfDIO/Xzgkfeqd8X
PPJO+hY88k79wuwnduonBo+8U78xeGg+FfLIp+sDHvl0/4KHxmskj7xTPzR4
aLx68sg79VOz39opPwUeead+bPDIO/Vrg0feqZ8bPPJO8XLwyDv1g4NH3qlf
HDzyTv3k7Dd36jcHj4JTPzp4FJz61cGj4NTPDh4FJ38YPApO/fDgUXDqlweP
glM/PXgUnOIR4FFw6scHj4JT/Bk8Ck79/OBRcOr3B4+C030A4FFw8m/Bo+B0
nwB4FJzuG+B9BE75SPAoON1XAB4FJ38MPApO9x2AR8HpPgTwKDjdlwAeBaf7
FMCj4HTfAu9jcLqPATyKTvofPIqp/gWPotN9D+BRdLoPAjyKTvdFgEcRZQ6H
Osmj6HTfBHgUne6jAI+i030V4FF0us8CPIpO912AR9HpPgzwKDrdlwEeRaf7
NMBD8+0gj6LTfRy8r8Ppvg7wKDrd5wEeRaf7PsCj6HQfCHgUne4LAY+i030i
4FF0um8EPIpO/h7vK3G6rwQ8Sk73mYBHKZXf4FFyug8FPEpO96WAR8npPhXw
KDndtwIeJaf7WMCj5BT/AI+SU/wEPEpO972AR8kp3gIeJaf7YsCj5HSfDHiU
nPJl4FFyuo8GPEpO99XwPptUnoBHyem+G/AoOd2HAx4lp/tywKPkdJ8OeJSc
7tsBj5LTfTzgUXK6r4f3+TjF28Cj7HTfD3iUneJ34FF2ui8IPMpO9wmBR9np
viHwKDvdRwQeZaf7isCj7HSfEXiUne47Ao+y031I4FF2ui8JPMpO9ymBR9np
viXwKDvdxwQeZaf7msCj7HSfE+97crrvCTzKTvdBgUfZ6b4o8Cg73ScFHmWn
+6bAQ39/N3mUne6rAg/9/g7yKDvdd/ULcI1BDg==
             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-3.0025, 2.9975}, {0, 0.515}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-3.0025, 2.9975}, {0, 0.515}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxdnHmcnVdZx+9+K6BErLUgQhDFqggFRYpQn8NaNqUFhIoVCxZEUGgRsFbE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          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-3.0025, 2.9975}, {0, 0.515}}, 
        "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.1); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(5\\)]\\)\"", TraditionalForm],
  PlotRange->{{-3.0025, 2.9975}, {0, 0.515}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9091131356996164`*^9, {3.9091151092543554`*^9, 3.9091151641818786`*^9}, 
   3.9091264885492506`*^9, 3.9101535294359417`*^9, 3.910161470725986*^9, 
   3.9101615136304626`*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"8c94fba0-fd77-4e4f-8ed2-e61ecb23194a"]
}, Open  ]],

Cell[TextData[{
 "The full data with larger sampling is stored  as ",
 StyleBox["data/DOS/dos_{8,3}-tess_T2.1.dat", "Input"],
 " and we can import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091134847660837`*^9, 3.9091134940495186`*^9}, {
  3.909113659447389*^9, 3.909113670420266*^9}, {3.9091257465881844`*^9, 
  3.909125770268137*^9}, {3.9091262842252073`*^9, 3.909126291202912*^9}, {
  3.9101535429748435`*^9, 3.9101535465590334`*^9}, {3.910161515340441*^9, 
  3.9101615174640436`*^9}},ExpressionUUID->"cd608bbd-1693-4fb3-af8e-\
7fa1f7341a85"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<data\>\"", 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos\>\"", "Input"], 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos_{8,3}-tess_T2.1.dat\>\"", "Input"]}], "}"}], "]"}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.6); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(8\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909126193404081*^9, 3.909126208623426*^9}, 
   3.909126263048504*^9, {3.909126423755125*^9, 3.909126426329094*^9}, {
   3.910153550359743*^9, 3.9101535525745273`*^9}, {3.9101542103107257`*^9, 
   3.910154210498105*^9}, {3.910161464469494*^9, 3.9101614645404596`*^9}, {
   3.910161519021552*^9, 3.9101615205223827`*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"e666d09d-03f0-4c90-aca2-eed95ae84ed8"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.006944444444444445], AbsoluteThickness[2], LineBox[CompressedData["
1:eJw9nHd4lUXTxk9OzjmhCFICShGQJqB0RHwFZ+kIKEWE0FR6kd57R6UJIgiI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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJw9nHd4lUXTxk9OzjmhCFICShGQJqB0RHwFZ+kIKEWE0FR6kd57R6UJIgiI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             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-2.9975, 2.9975}, {0, 0.51144575}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-2.9975, 2.9975}, {0, 0.51144575}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJw9nHd4lUXTxk9OzjmhCFICShGQJqB0RHwFZ+kIKEWE0FR6kd57R6UJIgiI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          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-2.9975, 2.9975}, {0, 0.51144575}}, 
        "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.6); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(8\\)]\\)\"", TraditionalForm],
  PlotRange->{{-2.9975, 2.9975}, {0, 0.51144575}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9091262633776493`*^9, 3.9091264330125885`*^9, 3.910153555690276*^9, {
   3.910154203418597*^9, 3.9101542110394254`*^9}, 3.9101542597030473`*^9, {
   3.910161521772915*^9, 3.910161545380699*^9}},
 CellLabel->"Out[61]=",ExpressionUUID->"79325e11-91c0-4ece-a286-e7e9f23af1ce"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the supercells", "Subsection",
 CellChangeTimes->{{3.909113688151761*^9, 
  3.909113691600689*^9}},ExpressionUUID->"da606e6b-2fd5-4c23-85f6-\
d56308944516"],

Cell["\<\
The model is extended to the supercells in the sequence by translation \
symmetry, which allows us to construct the Abelian Bloch Hamiltonians on the \
supercells\
\>", "Text",
 CellChangeTimes->{{3.909114061369022*^9, 
  3.9091140880436444`*^9}},ExpressionUUID->"aaa6298d-ea83-435e-b7e2-\
fdc67d8d4835"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"AbelianBlochHamiltonian", "[", 
          RowBox[{
           RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
           RowBox[{"0", "&"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "&"}], ",", 
           RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "&"}], "/@", "supercells"}],
     "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"2b90c46e-f644-45f9-ac38-b4699b316829"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<H_{8,3}-tess_T2.1_sc-``.dat\>\"", ",", "#"}], 
           "]"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@",
    "supercells"}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
  3.910154322749093*^9, 3.9101543310279417`*^9}, {3.91016160339386*^9, 
  3.910161605793605*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"a3967646-49e6-4f6e-989b-7dab6ee4bc75"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909114427990825*^9, 
  3.909114430083145*^9}},ExpressionUUID->"6b3832b2-1739-4102-b71c-\
e80fc0bfe94f"],

Cell["\<\
Increasingly better approximations of the true density of states in the \
thermodynamic limit are obtained by considering one-dimensional irreducible \
representations on increasingly larger supercells. Again, we first compile \
the expressions for the Abelian Bloch Hamiltonians to speed up the evaluation:\
\>", "Text",
 CellChangeTimes->{{3.9091144367949524`*^9, 3.909114603985526*^9}, 
   3.91015441714965*^9},ExpressionUUID->"4571d201-c92b-4feb-a7fc-\
f385687f1001"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hsccfs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{
         RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
         RowBox[{"0", "&"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "&"}], ",", 
         RowBox[{"PCModel", "->", "pcmodel"}], ",", 
         RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091146138495903`*^9, 3.909114652753991*^9}, 
   3.909119478873217*^9, {3.910154420411165*^9, 3.910154425008809*^9}, {
   3.910163134806413*^9, 
   3.9101631355361147`*^9}},ExpressionUUID->"e3ece56f-79b5-4591-87f5-\
619f5114ea74"],

Cell[TextData[{
 "Once more, we compute the DOS with an energy resolution of 0.005  and a \
sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "2"], TraditionalForm]],ExpressionUUID->
  "9c7756ad-789e-4be0-9883-f756ab63387d"],
 ":"
}], "Text",
 CellChangeTimes->{{3.9091148872154474`*^9, 3.909114904344953*^9}, {
  3.9101566973402805`*^9, 3.910156697549489*^9}, {3.910161660367123*^9, 
  3.9101616604374743`*^9}, {3.9101765211636477`*^9, 
  3.9101765332529097`*^9}},ExpressionUUID->"6d21be8a-b730-442d-b0a0-\
f9d4c09742ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dosscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ComputeDOS", "[", 
        RowBox[{
         RowBox[{"Hsccfs", "[", "#", "]"}], ",", 
         RowBox[{"10", "^", "2"}], ",", "32", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], "-", "0.005"}], ",", "3"}], "}"}], ",", 
         "0.005"}], "]"}]}], "&"}], "/@", "supercells"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9091148504724855`*^9, 3.909114863025732*^9}, {
  3.9101548693475285`*^9, 3.910154869724236*^9}, {3.9101549493832054`*^9, 
  3.9101549496375976`*^9}, {3.9101616621016417`*^9, 3.9101616850848536`*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"4d95add6-4807-4100-86ec-a027e9d7cd1e"],

Cell["\<\
We plot the successively better approximations of the (normalized) density of \
states as obtained from successively larger supercells:\
\>", "Text",
 CellChangeTimes->{{3.9091258353931103`*^9, 3.9091258729641294`*^9}, {
  3.909126315654191*^9, 
  3.9091263169689493`*^9}},ExpressionUUID->"eb247454-3d8b-4b43-aada-\
f6c7a26450a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Association", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<T2.1\>\"", "->", "dospc"}], "}"}], "]"}], ",", "dosscs"}],
     "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(2\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091194227381277`*^9, 3.9091194385257072`*^9}, {
   3.909125701919447*^9, 3.909125705158804*^9}, {3.9091264450645742`*^9, 
   3.9091264526411266`*^9}, {3.910154999941857*^9, 3.9101550239169064`*^9}, {
   3.9101562589192905`*^9, 3.910156259119133*^9}, {3.910157116954313*^9, 
   3.9101571172428455`*^9}, {3.910161666018202*^9, 3.910161678746447*^9}, 
   3.9101618458849573`*^9},
 CellLabel->"In[67]:=",ExpressionUUID->"0a04cab2-7240-4349-b830-d2b054f1f632"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxdnHmcnVdZx+9+K6BErLUgQhDFqggFRYpQn8NaNqUFhIoVCxZEUGgRsFbE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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxdnFuMXlUVx7/rlKCJfSgEElNrfEFiDFEfeBC+iTEWjQ+AGnmoBg2iiQ9W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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxdnFuIZldWgP9bVYcomIfMMILEFhFiEAleIAxm/h9RM4oPyag4DFGijKPg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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxdnG2IXmdax5/XSamC/dBdVpAakYVaRIpaKMXu8yDWruKHdFVcpEqV3bWw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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(2\\)]\\)\"", 
       TraditionalForm], PlotRange -> {{-3.0025, 2.9975}, {0, 0.515}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T5.1\"", "\"T17.2\"", "\"T33.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091194429099684`*^9, {3.909125698510269*^9, 3.9091257066406164`*^9}, 
   3.909126457110761*^9, 3.9101549712826576`*^9, {3.910155008395378*^9, 
   3.910155025671894*^9}, 3.9101562605065956`*^9, 3.9101571574389143`*^9, 
   3.910160994196726*^9, 3.910162121594056*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"94f26d6f-6f82-4221-9db5-796b7b7e6b25"]
}, Open  ]],

Cell[TextData[{
 "The full data is stored  as ",
 StyleBox["data/dos/dos_{8,3}-tess_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it due to the reduced \
noise:"
}], "Text",
 CellChangeTimes->{{3.9091257257973347`*^9, 3.9091257829464827`*^9}, {
   3.9091258161267524`*^9, 3.909125817972119*^9}, {3.9091263241669226`*^9, 
   3.9091263478044133`*^9}, {3.9101544811965094`*^9, 
   3.9101544880133915`*^9}, {3.9101556042258387`*^9, 3.910155604445711*^9}, 
   3.910161914298563*^9},ExpressionUUID->"1f14f433-7718-478f-ad9c-\
2070915719e8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{8,3}-tess_``.dat\>\"", ",", "#"}], "]"}]}], 
            "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.1\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(8\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091263566114464`*^9, 3.909126393410284*^9}, {
  3.9091264603821816`*^9, 3.909126463017381*^9}, {3.9101544932422967`*^9, 
  3.910154495640236*^9}, {3.910155610950552*^9, 3.910155611196024*^9}, {
  3.9101562410776777`*^9, 3.910156285321762*^9}, {3.9101617452884254`*^9, 
  3.9101617608664107`*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"68751a8c-af9d-49c1-91f0-c2a6834ba4c9"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJw9nHd4lUXTxk9OzjmhCFICShGQJqB0RHwFZ+kIKEWE0FR6kd57R6UJIgiI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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJw9nHd41FXThpPdzS7SDU1fpEtHpEufA1IMIopIFUEgNEEBAQUpAtKLVGkK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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxFnHd4VFUTxjfbAshHRwHpShPpCIjCHBCpIkURVIoiglRBEaUa6b0ovYkg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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxFnHd8zecXx2/uik2NamkVRWlL7aofzmOXKkWF2rVrK1qjVO1ZeytaqrS2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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(8\\)]\\)\"", 
       TraditionalForm], PlotRange -> {{-2.9975, 2.9975}, {0, 0.51144575}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T5.1\"", "\"T17.2\"", "\"T33.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091264714520893`*^9, 3.9101545008181863`*^9, 3.910155616253199*^9, {
   3.9101562517976747`*^9, 3.9101562871700735`*^9}, 3.910162253949086*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"8a43727d-52c2-4cad-b9d8-c0cb854202ea"]
}, Open  ]],

Cell["\<\
We observe convergence of the density of states with increasing size of the \
supercell.\
\>", "Text",
 CellChangeTimes->{{3.909125877711278*^9, 3.909126045253215*^9}, {
  3.9101545181845226`*^9, 
  3.9101545262977867`*^9}},ExpressionUUID->"e1e2ff00-1957-4574-a036-\
ecdd92acc227"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Convergence with momentum sampling", "Subsection",
 CellChangeTimes->{{3.910155431393157*^9, 
  3.9101554411912293`*^9}},ExpressionUUID->"78a67eaa-0fe9-48d0-b304-\
632e1ccbb3c3"],

Cell[TextData[{
 "We study the convergence of the DOS with the number of momenta from the \
Abelian Brillouin zone of the 32-supercell T33.1 sampled. The resulting data \
is stored  as ",
 StyleBox["data/dos/dos_{8,3}-tess_T33.1_<n>.dat", "Input"],
 ", where ",
 StyleBox["<n>", "Input"],
 " is the number of randomly sampled momenta. Note that for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "0"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "99b66c65-a57e-4a32-a3d1-4c5a0ed35c40"],
 ", we do not use random sampling and instead evaluate the Bloch Hamiltonian \
at ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["k",
     FontWeight->"Bold",
     FontSlant->"Plain"], "=", "0"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "9b328662-489e-46f3-aa0f-9b10abc3e9b2"],
 ". We import and plot it:"
}], "Text",
 CellChangeTimes->{{3.910155446902151*^9, 3.910155726445115*^9}, {
  3.910161772804531*^9, 3.910161778470578*^9}, {3.910162264219703*^9, 
  3.9101622669677677`*^9}},ExpressionUUID->"eafeb38b-e329-4813-b34f-\
88ebcee0afc0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"MovingAverage", "[", 
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos\>\"", "Input"], 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos_{8,3}-tess_T33.1_0.dat\>\"", "Input"]}], "}"}], 
       "]"}], "]"}], ",", "16"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLabel", "->", "\"\<T33.1\>\""}], ",", 
   RowBox[{"Filling", "->", "Axis"}], ",", 
   RowBox[{"FillingStyle", "->", 
    RowBox[{"Opacity", "[", "1", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9101563109926796`*^9, 3.910156458078571*^9}, {
  3.91016178122083*^9, 3.9101617882095437`*^9}, {3.9101623022276*^9, 
  3.91016230242206*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"3dddf41e-4444-4c10-82f7-572671e12626"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[GraphicsComplexBox[CompressedData["
1:eJzt3OmPZFUdxvGaHmcQMMYIyhsXTIyiMSQuMSQydiUkor4ggpq4oCbG7YUR
JIQY8IUxYIwxgEuIKEEFxCUILii4QDcDKogssszAwAzTPb1vdFV3TXXX9Exr
n++vfg/1+Cd46gXyEaipe7/33LpVdc953acvOO+zQ41G46zjG42t/7317LFL
T771uNH7r37dWd94ybXDN12464S9Nx432ojHD6/deshX7e6cdv5V8hXz5975
mivky07eeka5PN2F8ufKQz6/PKF83n+fbf5c+b1bL+9s+d1bT7dLfnt5yG8q
Tyi/trxAuby8k+XydCfIPOTDp2094c70wtbmzsvjWy9vTC5Pt1f+V3nIZfft
lsvm3inTQ6aHTA+ZHjI9ZHrI9JDpIdNDpodMD5keMj1keuyM4+vpYXrI9JDp
IfMsMj12jN72ybsu7cxNDtNDpodMD5keMj1kesj0kOkh00Omh0yPHaPXvOWj
v/vMA48N00Omh0wPmR4yPXZYD5keMj1kesj0kOkh00PmIdPjRWl6yPSQ6SHT
Q6aHTA+ZHjI9ZHrIV5cnlOkh00Omh0wPmR4yPWR6yPSQ6SHTQ6aHTA+ZHjIP
mR7b0/SQ6SHTQ6aHTA+ZHjI9ZHrI9Ng+Orb7ihNPOf3ZYXrI9JDpIdNDpodM
D5keMj1kesj0kOkh00Omh0wPma2W6TFkPWR6yPSQ6SHTQ6aHTA+ZHjI9ZHoM
5fmVHjI9ZHrI9JDpIdNDpodMD5keQ6PfOumN51x3xlj0kOkh00Omh8xWyvTY
lqbHtji/7o73D5keMj1kesj0kOkh00Omh0yPbdmHHjI9ZHrI9JDpIdNDpodM
D5keMj1kesj0kOkh85Dp0UjTQ6aHTA+ZHjI9Gnk80UOmh0wPmR4yPRo2Pho2
Pho2Pho2Pho2Pho2Pho2Pho2Pho2PmR6NOz6SvuDHjI95HjY/t8c6fupsr9l
9q/M/pTZfzL7a3NkcP/I7A+Z7ZfZXrnkfI3M9myO9K+3OJ6OjQxeD8ocLzLH
h8zxINNfprdMX5meMv2OjfSv38rLO02mj8xek8vumz+a3lN6yPQ4aj2OWo+j
1kOmh0wPmR4yPWR6yPSQ6bGRpodMD5keMj1kesj0kOkh02PDesj0kOkh8ywy
PY6k6SHTQ6aHTA+ZHjI9ZHrI9JDpIdNDpscR69GzHj3r0bMePevRsx4969Gz
Hj3rIdNDpodMD5mHTI/1ND1kesj0kOkh00Omh0wPmR4yPWR6yPRYtx5r1mPN
eqxZjzXrsWY91qzHmvVYsx5r1mPNeqxZjzXrsWY9utajaz261qNrPbrWo2s9
utajaz261qNrPbrWo2s9Duf7Cz1kesj0kOkh00Omh0wPmR4yPWR6yPSQYyvS
9Oik6SHTQ6ZHx3p0rEfHenSsR8d6dKxHx3p0rEfHeqza+JDpIdNDpodMD7k8
3aUyPWR6yPSQ6SHTQ+Yhc321YuNDpodMjxXrIV9eeqxYjxXrsWI9VqzHivVY
sR4r1qNtPdrWo2092tajbT3a1qNtPdrWo2092tajbT3a1qNtPVrWo2U9Wtaj
ZT1a1qNlPVrWo2XXuy273m3Z9W7Lrndleizb+WrZzlfLdr5atvPVsp2vlkc+
/8j1uy47vDBMD5keMj1kesj0kOmxPLL9uJe+6owLD8b5Smb/P59mf8ucf2T2
p8z+k9lfMvtnKc3+kNn+JTv+lux4W7Lja8mOp0U7fhbteFm040PmeFi08bho
42/BxtuCja8FG08LNn4WbLws2PhYsPEwb8f/vB3v83Z8y28rPWR6yAfLC5yz
84V8ZdmBc9ZDLrtv15z1kHl5s9Zj1nrMWo9Z6zFrPWatx4z1mLEeM9ZjxnrM
WI8Z6zFjPaatx7T1mLYe09Zj2npMW48p6zFlPaasx5T1mLIeU9Zj0npMWo9J
6zFpPSatx6T1mLAeE9ZjwnpMWI8J6zFhPSasxyHrcch6HLIeh6zHIetxyHqM
W49x6zFuPcatx7j1GLceY9ZjLN8P6CHTY8zev8bs/WrM3p8O2vvRQXv/kelx
0K6HD9r1r7xZHs+lf132v/zxsr/l48v+le8oL/hA+rNl/x3I/XFS2V/yPWX/
7E9fUPaH/Oqy/fKDZXufHen/HsD2yWyPzPH0TJrjR+Z4kTk+9qU5HuQzS395
rvR+Ol3yXiuX3Xe2zMeDp9Ll5d0ol6c7V6bH3jQ99ub+oIdMD5kee+x43mPH
7x47Xp+084XM8Shz/D1h4/8JG+9P2Ph+3Mbz4zZ+H7fx+piNT5kej9n4+3ea
HjI9ZHo8mqaHTA/5WOnxSPpjZf/Lfyw76OH0y8v+lb9U9udD+X3jP9mB6TeU
/SV/vWzQg+kDZX/8M/2usv3yD8r2PpBeLdt3f35/9YGyPfItZYf8I/3icvzI
nynHy9/To2WH/S39qnI8yF8p/e9LP1l26L3pt5a+9+b5gZ6704yne9LvKb3k
G0qf0fRG6TGSvr3s/7vTXyz7+67c/68v+/ev6f1lf/45fU3Zf39Kn8MbRHpn
2T93pO8uL/8P6UvK9t+ePr1s7+/T02X7fpv+cdme36RvK3/crelTy+u9Jf2d
8vp+mR4qr+fn6YvKn39Terz8eT9N31ye//r0Nxkg6S+U//776e+Vf//K9IfL
P79c21d8sb2ff+/M/t/dxz8f7vt6/vv0Pp4//W3+/PSveH3pB3j96VW2L305
258+mf2TvoH9l34b+zd9D/s//Qv6pJfplz6Dvumv0T99P8dH+mUcP+mPcHyl
f8Lxl57h+EyfzvGbvoTjO303x/9w//gfKv/vaPpmxk/6/Yyv9BLjL/1dxmf6
nYzf9D7G93B/fH+V8Z8+lfND+j7OH+kvcH5Jv4TzT/o3nJ/SH+L8lV7j/Ja+
jvPfcP/81+T8mJ7g/Jn+JufX9Fs4/6Yf5fycvpjzd/oUzu+5///C+T/9Kd4f
0tvKXx9Nf5D3l/TPeP9Jd3l/Sr+P968015Myn5dlPl8/lubzuMznd/kdvP+m
v8H7c5rfL+U38/6epr/8MNcHaY6HJ9MXcX2R5viQX8n1SZrjRf4z1zdpjp+9
6U9yfZTmeNprPZ4a7l9f0UOmh0wPmR5Pp3/E9V96kevD4cH7Zfal6SHTQ6bH
M2l6yPSQ6fFsmh4yPWR67Lce+63HfutxwHocsB4H8vxAj+fS9JDpIdPjYJrt
kePzS5rtk+PzT5rtlePzU5rtH0vH5680+0OOz2/pe/l8l2b8jeX+eAWfD208
yvH50sanHJ9PbbzK8fnWxq8cn49tPMvx+drGt8xjwsa7HJ/vbfzL8f2AnQ/k
+H7Bzg+T6fh+wo5POb7fsONVpsekHb9T1mPKjucp6zFlx/eU9ZBP5Psf6zFt
Paatx7T1mLYe09ZjxnrMWI8Z6zFjPWasx4z1mLEes9Zj1nrMWo9Z6zFrPWat
x5z1mLMec9ZjznrMWY856zFvPeatx7z1mLce89Zj3nosWI8F67FgPRasx4L1
WLAeC9Zj0XosWo9F67FoPRatx6L1WLIeS9ZjyXosWY8l67E03P89gB7Pp+kh
x+8PaXrI8ftFmh4yf+pyOn4fSXN/1/Kw/b4ybL+/DNvvM2n6yfH7Tjp+/0nH
70P2fiTH70v2/iTH71P2fiWz/1r2/iXH72P2ftay471lx0vLjv+WHT8tGw8t
O55aNj7a6fj90MZL2463to0fOX6/tPHUtuOxbeNLjt9Pbby17Xht2/iT4/db
G48yPeT4fdjONzI9VqzHivVYsR4r1mPFeqxYjxXrsWo9Vq3HqvVYtR6r1mPV
eqxaj1XrsWo9Vq3HqvVYtR6r1qNjPTrWo2M9OtajYz061qNjPTrWQ+Z6sJPj
jR4duz6UY6vSXC8etutfOe5fsethOe5/setjOe6fsetlOe6/ST/E/Tl2vjps
56vDdr7qWo+u9ehaD/kT3H9kPbrWo2s9utajaz1kesj0kHmspekh00OO+7ts
fMhxf5iNDznuL7PxIcf9aWl6yHF/m40POe6Psx7r1mPdeqxbj3XrsW491q3H
uvVYtx7r1mPdeqxbj5716FmPnvXoWY+e9ehZj5716FmPnvXoWY+e9ehZj571
OGI9juT3V/SQ4/7UND1kesj0kOP+2HTcP5umh0wPmR4yr3ojTQ+ZHnLcH5yO
+4fTcX+x9diwHhvWY8N6bFiPDeuxYT02rMdR6yHTQ477t218yPSQ6SHH/eM2
PmR6yPQ4mt830kPm3zqWpodMDznun0/H/fXW45h9nyvH/fvpuL8/Hff/p+kh
x/yBdMwvSMf8A/v+eNOudzftelemx6Zd78r0kGN+hfXYtB6b1kOO+R12vmo0
B48vmT5yzC9Jx/yT5uD2yjF/pTm4/XLMf2kOXv/LMX8m/WXm16Rj/k065uc0
B68f5Jjf0xy8npDZn3LMH0qzf2WOF+0P9rcc85fSMb8pHfOf0jy2WQ855ldZ
DznmZ6XpIcf8rnTM/0rH/LB0zB9Lx/yyND3kmJ+Wjvlr6Zjflo75b02bH9e0
+XNpesj0kOkh00OO+X3pmP+XjvmBTZs/2LT5hU2bf9i0+YlNm7+Ypocc8x9t
fAzZ+Biy8TFk42PIxseQjY8hGx9DNj6GbHwMZZ+YP5qmh0wPmR4yPWR6yDH/
NR3zY9MxfzbNY3vT5t+m6SHH/N10zO9tDv5eIcf84HTMH07H/OI0PWR6yPSQ
Y35zmh5yzI9Ox/zpdMyvth4yPWR6yPSQ6SHH/HDrIcf8cuvxojQ9ZHrIMb89
HfPf0/SQY/58OubXp2P+fZoeMj1kesgx/z9NDznWD0jH+gLpWH8gTQ+ZHjI9
ZHrI9JBj/YR0rK+QjvUX0jx2pOkh00OO9R/SsT5Emh5yrC+RjvUn0rE+RZoe
O5q2vkWaHjLXbzLXPzI9djRt/Y3m4PWdTA+ZHjK3C8j0kOkhx/oizcHPG3Ks
T9Ic/Pyxszn4fYPM9ZUc66OkY/0Uu77aaT12Wo+d1mOn9ZDpIdNDpodMD5ke
cqxPk471a9L0kOkh00Omh0wPOdbfScf6POlYvyfN47g0PWR6yLF+UDrWF0rT
Q471idKxflE61jdK00Omh0wPmR4yPWR6yLF+UzrWd0rT43886ub4q+tD8ajr
Q/Vd14cq7y91faiBR10fqu+6PlT5fJKu60NtPer6UPb9Rl0fqq4P9YJHXR/K
vh+v60MN/n5S14eq60OVR10fqvy+XteHGnjU9aH6rutDlfuzrEddH6pvetT1
ofqu60OV+3+tR10fqu+6PlSZP1DXhxo4/ur6UH3To64P1XddH2rrUdeH6pse
dX2owfenuj5UXR+KR10famuD6/pQdX0oXNeH2vrz6/pQfdf1obYedX2ouj4U
j7o+VLl+sh51fajBHnV9qL7r+lBbj7o+VN91fajy/Z31qOtD9f+urg9Vvv+3
HnV9qMH3o7o+VN91fajy+7L1qOtD9V3Xhyr3p9T1oQZ61PWh+q7rQ5X7G61H
XR+qrg/1wh51fai6PhSu60OV+TN1fah4xPwq61HXh6rrQ71wfNT1oer6UC/s
UdeH6ruuD7X1Auv6UHV9KB70qOtD9f3/vj7UfwBvju0G
       "], {{{}, 
         {RGBColor[0.368417, 0.506779, 0.709798], Opacity[1], EdgeForm[None], 
          GraphicsGroupBox[{PolygonBox[{{1, 1186, 2}}], 
            PolygonBox[CompressedData["
1:eJwV0UVyFGAQBtA/AmxYcQPWeNzQI3ACCBDPTIIeBifuGYkLcBQgLmNx583i
bbq6urr7u14ffRopDCFc5RpLRSHsscsOObJkSJNimy022WCdNVZZYZkbxSHU
UUsN1VRRSQXllFFKCfe4yx1uc4ub+XpBCE94zCMe8oD71FFLDdVUUUkF5ZRR
SglddkqSIE6MccYYZYRhhhhkgH766KWHbv6YlSNLhjQpttlikw3WWWOVFZZZ
4h9/2eeKx1/mEsUUUUhBPhAu9JxzxiknHHPEIQeMaF1kgXnmmGWGaaaYZIIk
CeLEGGeMUVJccM4Zp5xwzBGHHLDPHrvskCNLhjTP/KiTDqJEaKeNVlpopolG
GnjFS15Qz/N8Nu7/zS9+ssgC88wxywzTTDHJBEkSxInxkWGGGGSAfvropYdu
uvjBd77xlS985hMNbvvAe97xlje8ppMOokRop41WWmimiUb+A8zHh5s=
             "]], 
            PolygonBox[{{38, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 
             48, 47, 46, 45, 44, 43, 42, 41, 40, 39}, {1126, 1148, 1147, 1146,
              1145, 1144, 1143, 1142, 1141, 1140, 1139, 1138, 1137, 1136, 
             1135, 1134, 1133, 1132, 1131, 1130, 1129, 1128, 1127}}], 
            PolygonBox[{{965, 988, 987, 986, 985, 984, 983, 982, 981, 980, 
             979, 978, 977, 976, 975, 974, 973, 972, 971, 970, 969, 968, 967, 
             966}, {198, 221, 220, 219, 218, 217, 216, 215, 214, 213, 212, 
             211, 210, 209, 208, 207, 206, 205, 204, 203, 202, 201, 200, 
             199}}], PolygonBox[{{616, 640, 639, 638, 637, 636, 635, 634, 633,
              632, 631, 630, 629, 628, 627, 626, 625, 624, 623, 622, 621, 620,
              619, 618, 617}, {546, 570, 569, 568, 567, 566, 565, 564, 563, 
             562, 561, 560, 559, 558, 557, 556, 555, 554, 553, 552, 551, 550, 
             549, 548, 547}}], PolygonBox[CompressedData["
1:eJwNzkdWwgAARdEcZYCKlCTUUBIFC+zGJbgA2QKg0mwUG67WO7jnvNn/2f34
7uEoCIJjEipixJBbbrjmigF9LrkgI6VHlw5tElo0aVCnRpWYiJCJvT8O/PLD
N198smfHlg0fvPPGKy+sWbFkwZxnnnhkxpR8zmcyUnp06dAmoUWTBnVqVImJ
CKlQpkSRcwqcccoJ/3JYFtA=
             "]], 
            PolygonBox[{{375, 402, 401, 400, 399, 398, 397, 396, 395, 394, 
             393, 392, 391, 390, 389, 388, 387, 386, 385, 384, 383, 382, 381, 
             380, 379, 378, 377, 376}}]}]}, {}, {}}, {{}, {}, 
         TagBox[
          {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
           0.006944444444444445], AbsoluteThickness[2], 
           LineBox[CompressedData["
1:eJwl2NMSGAgSAMDYtm3btm3btm3btm3uxrZt29xcp+6ha2o+YJiwUftK7QIG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            "]]},
          Annotation[#, "Charting`Private`Tag#1"]& ]}}],
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", 
        GraphicsComplex[CompressedData["
1:eJzt3OmPZFUdxvGaHmcQMMYIyhsXTIyiMSQuMSQydiUkor4ggpq4oCbG7YUR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         "], {{{}, {
            EdgeForm[], 
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[1]], 
            GraphicsGroup[{
              Polygon[{{1, 1186, 2}}], 
              Polygon[CompressedData["
1:eJwV0UVyFGAQBtA/AmxYcQPWeNzQI3ACCBDPTIIeBifuGYkLcBQgLmNx583i
bbq6urr7u14ffRopDCFc5RpLRSHsscsOObJkSJNimy022WCdNVZZYZkbxSHU
UUsN1VRRSQXllFFKCfe4yx1uc4ub+XpBCE94zCMe8oD71FFLDdVUUUkF5ZRR
SglddkqSIE6MccYYZYRhhhhkgH766KWHbv6YlSNLhjQpttlikw3WWWOVFZZZ
4h9/2eeKx1/mEsUUUUhBPhAu9JxzxiknHHPEIQeMaF1kgXnmmGWGaaaYZIIk
CeLEGGeMUVJccM4Zp5xwzBGHHLDPHrvskCNLhjTP/KiTDqJEaKeNVlpopolG
GnjFS15Qz/N8Nu7/zS9+ssgC88wxywzTTDHJBEkSxInxkWGGGGSAfvropYdu
uvjBd77xlS985hMNbvvAe97xlje8ppMOokRop41WWmimiUb+A8zHh5s=
               "]], 
              
              Polygon[{{38, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 
               48, 47, 46, 45, 44, 43, 42, 41, 40, 39}, {1126, 1148, 1147, 
               1146, 1145, 1144, 1143, 1142, 1141, 1140, 1139, 1138, 1137, 
               1136, 1135, 1134, 1133, 1132, 1131, 1130, 1129, 1128, 1127}}], 
              
              Polygon[{{965, 988, 987, 986, 985, 984, 983, 982, 981, 980, 979,
                978, 977, 976, 975, 974, 973, 972, 971, 970, 969, 968, 967, 
               966}, {198, 221, 220, 219, 218, 217, 216, 215, 214, 213, 212, 
               211, 210, 209, 208, 207, 206, 205, 204, 203, 202, 201, 200, 
               199}}], 
              
              Polygon[{{616, 640, 639, 638, 637, 636, 635, 634, 633, 632, 631,
                630, 629, 628, 627, 626, 625, 624, 623, 622, 621, 620, 619, 
               618, 617}, {546, 570, 569, 568, 567, 566, 565, 564, 563, 562, 
               561, 560, 559, 558, 557, 556, 555, 554, 553, 552, 551, 550, 
               549, 548, 547}}], 
              Polygon[CompressedData["
1:eJwNzkdWwgAARdEcZYCKlCTUUBIFC+zGJbgA2QKg0mwUG67WO7jnvNn/2f34
7uEoCIJjEipixJBbbrjmigF9LrkgI6VHlw5tElo0aVCnRpWYiJCJvT8O/PLD
N198smfHlg0fvPPGKy+sWbFkwZxnnnhkxpR8zmcyUnp06dAmoUWTBnVqVImJ
CKlQpkSRcwqcccoJ/3JYFtA=
               "]], 
              
              Polygon[{{375, 402, 401, 400, 399, 398, 397, 396, 395, 394, 393,
                392, 391, 390, 389, 388, 387, 386, 385, 384, 383, 382, 381, 
               380, 379, 378, 377, 376}}]}]}, {}, {}}, {{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJwl2NMSGAgSAMDYtm3btm3btm3btm3uxrZt29xcp+6ha2o+YJiwUftK7QIG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              "]]}, "Charting`Private`Tag#1"]}}], <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-2.96, 2.96}, {0, 0.9050880626223091}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {{{}, {
               EdgeForm[], 
               Directive[
                RGBColor[0.368417, 0.506779, 0.709798], 
                Opacity[1]], 
               GraphicsGroup[{{
                  
                  Polygon[{{-2.96, 0.02446183953033268}, {-2.96, 0.}, {-2.955,
                    0.}}]}, {
                  
                  Polygon[{{2.015, 0.}, {2.1, 0.}, {2.095, 
                   0.3913894324853229}, {2.09, 0.3913894324853229}, {2.085, 
                   0.3913894324853229}, {2.08, 0.3913894324853229}, {2.075, 
                   0.3913894324853229}, {2.0700000000000003`, 
                   0.3913894324853229}, {2.065, 0.3913894324853229}, {2.06, 
                   0.3913894324853229}, {2.055, 0.3913894324853229}, {2.05, 
                   0.3913894324853229}, {2.045, 0.3913894324853229}, {2.04, 
                   0.3913894324853229}, {2.035, 0.3913894324853229}, {
                   2.0300000000000002`, 0.3913894324853229}, {
                   2.0250000000000004`, 0.3913894324853229}, {2.02, 
                   0.3913894324853229}}], 
                  
                  Polygon[{{2.37, 0.}, {2.455, 0.}, {2.45, 
                   0.44031311154598823`}, {2.4450000000000003`, 
                   0.44031311154598823`}, {2.44, 0.44031311154598823`}, {
                   2.435, 0.44031311154598823`}, {2.43, 
                   0.44031311154598823`}, {2.425, 0.44031311154598823`}, {
                   2.42, 0.44031311154598823`}, {2.415, 
                   0.44031311154598823`}, {2.41, 0.44031311154598823`}, {
                   2.4050000000000002`, 0.44031311154598823`}, {
                   2.4000000000000004`, 0.44031311154598823`}, {2.395, 
                   0.44031311154598823`}, {2.39, 0.44031311154598823`}, {
                   2.385, 0.44031311154598823`}, {2.38, 
                   0.44031311154598823`}, {2.375, 0.44031311154598823`}}], 
                  
                  Polygon[{{-1.44, 0.}, {-1.355, 0.}, {-1.3599999999999999`, 
                   0.3913894324853229}, {-1.3649999999999998`, 
                   0.3913894324853229}, {-1.3699999999999999`, 
                   0.3913894324853229}, {-1.375, 0.3913894324853229}, {-1.38, 
                   0.3913894324853229}, {-1.3849999999999998`, 
                   0.3913894324853229}, {-1.3900000000000001`, 
                   0.3913894324853229}, {-1.395, 0.3913894324853229}, {-1.4, 
                   0.3913894324853229}, {-1.405, 
                   0.3913894324853229}, {-1.4100000000000001`, 
                   0.3913894324853229}, {-1.415, 0.3913894324853229}, {-1.42, 
                   0.3913894324853229}, {-1.4249999999999998`, 
                   0.3913894324853229}, {-1.4300000000000002`, 
                   0.3913894324853229}, {-1.435, 0.3913894324853229}}], 
                  
                  Polygon[{{1.69, 0.}, {1.775, 0.}, {1.77, 
                   0.684931506849315}, {1.7650000000000001`, 
                   0.684931506849315}, {1.7600000000000002`, 
                   0.684931506849315}, {1.7550000000000001`, 
                   0.684931506849315}, {1.75, 0.684931506849315}, {1.745, 
                   0.684931506849315}, {1.7400000000000002`, 
                   0.684931506849315}, {1.735, 0.684931506849315}, {1.73, 
                   0.684931506849315}, {1.725, 0.684931506849315}, {
                   1.7200000000000002`, 0.684931506849315}, {
                   1.7150000000000003`, 0.684931506849315}, {
                   1.7100000000000002`, 0.684931506849315}, {1.705, 
                   0.684931506849315}, {1.7000000000000002`, 
                   0.684931506849315}, {1.6950000000000003`, 
                   0.684931506849315}}], 
                  
                  Polygon[{{-0.5599999999999999, 0.}, {-0.4749999999999999, 
                   0.}, {-0.4799999999999999, 
                   0.3913894324853229}, {-0.48499999999999993`, 
                   0.3913894324853229}, {-0.48999999999999994`, 
                   0.3913894324853229}, {-0.49499999999999994`, 
                   0.3913894324853229}, {-0.49999999999999994`, 
                   0.3913894324853229}, {-0.5049999999999999, 
                   0.3913894324853229}, {-0.51, 
                   0.3913894324853229}, {-0.5149999999999999, 
                   0.3913894324853229}, {-0.52, 
                   0.3913894324853229}, {-0.5249999999999999, 
                   0.3913894324853229}, {-0.53, 
                   0.3913894324853229}, {-0.5349999999999999, 
                   0.3913894324853229}, {-0.54, 
                   0.3913894324853229}, {-0.5449999999999999, 
                   0.3913894324853229}, {-0.55, 
                   0.3913894324853229}, {-0.5549999999999999, 
                   0.3913894324853229}}], 
                  
                  Polygon[{{-0.4549999999999999, 0.}, {-0.36999999999999994`, 
                   0.}, {-0.37499999999999994`, 
                   0.44031311154598823`}, {-0.37999999999999995`, 
                   0.44031311154598823`}, {-0.38499999999999995`, 
                   0.44031311154598823`}, {-0.38999999999999996`, 
                   0.44031311154598823`}, {-0.39499999999999996`, 
                   0.44031311154598823`}, {-0.39999999999999997`, 
                   0.44031311154598823`}, {-0.4049999999999999, 
                   0.44031311154598823`}, {-0.4099999999999999, 
                   0.44031311154598823`}, {-0.4149999999999999, 
                   0.44031311154598823`}, {-0.41999999999999993`, 
                   0.44031311154598823`}, {-0.42499999999999993`, 
                   0.44031311154598823`}, {-0.42999999999999994`, 
                   0.44031311154598823`}, {-0.43499999999999994`, 
                   0.44031311154598823`}, {-0.43999999999999995`, 
                   0.44031311154598823`}, {-0.44499999999999995`, 
                   0.44031311154598823`}, {-0.4499999999999999, 
                   0.44031311154598823`}}], 
                  
                  Polygon[{{-2.0999999999999996`, 0.}, {-2.015, 0.}, {-2.02, 
                   0.3913894324853229}, {-2.025, 
                   0.3913894324853229}, {-2.0300000000000002`, 
                   0.3913894324853229}, {-2.035, 0.3913894324853229}, {-2.04, 
                   0.3913894324853229}, {-2.045, 0.3913894324853229}, {-2.05, 
                   0.3913894324853229}, {-2.0549999999999997`, 
                   0.3913894324853229}, {-2.06, 0.3913894324853229}, {-2.065, 
                   0.3913894324853229}, {-2.0700000000000003`, 
                   0.3913894324853229}, {-2.075, 0.3913894324853229}, {-2.08, 
                   0.3913894324853229}, {-2.085, 0.3913894324853229}, {-2.09, 
                   0.3913894324853229}, {-2.0949999999999998`, 
                   0.3913894324853229}}], 
                  
                  Polygon[{{-1.775, 0.}, {-1.69, 0.}, {-1.6949999999999998`, 
                   0.684931506849315}, {-1.7, 0.684931506849315}, {-1.705, 
                   0.684931506849315}, {-1.71, 
                   0.684931506849315}, {-1.7149999999999999`, 
                   0.684931506849315}, {-1.72, 0.684931506849315}, {-1.725, 
                   0.684931506849315}, {-1.73, 
                   0.684931506849315}, {-1.7349999999999999`, 
                   0.684931506849315}, {-1.7399999999999998`, 
                   0.684931506849315}, {-1.7449999999999999`, 
                   0.684931506849315}, {-1.75, 0.684931506849315}, {-1.755, 
                   0.684931506849315}, {-1.7599999999999998`, 
                   0.684931506849315}, {-1.7650000000000001`, 
                   0.684931506849315}, {-1.77, 0.684931506849315}}], 
                  
                  Polygon[{{1.355, 0.}, {1.44, 0.}, {1.435, 
                   0.3913894324853229}, {1.4300000000000002`, 
                   0.3913894324853229}, {1.425, 0.3913894324853229}, {1.42, 
                   0.3913894324853229}, {1.415, 0.3913894324853229}, {
                   1.4100000000000001`, 0.3913894324853229}, {
                   1.4050000000000002`, 0.3913894324853229}, {1.4, 
                   0.3913894324853229}, {1.395, 0.3913894324853229}, {
                   1.3900000000000001`, 0.3913894324853229}, {
                   1.3850000000000002`, 0.3913894324853229}, {
                   1.3800000000000001`, 0.3913894324853229}, {1.375, 
                   0.3913894324853229}, {1.37, 0.3913894324853229}, {
                   1.3650000000000002`, 0.3913894324853229}, {1.36, 
                   0.3913894324853229}}], 
                  
                  Polygon[{{0.4750000000000001, 0.}, {0.56, 0.}, {0.555, 
                   0.3913894324853229}, {0.55, 0.3913894324853229}, {
                   0.5450000000000002, 0.3913894324853229}, {0.54, 
                   0.3913894324853229}, {0.5350000000000001, 
                   0.3913894324853229}, {0.53, 0.3913894324853229}, {
                   0.5250000000000001, 0.3913894324853229}, {0.52, 
                   0.3913894324853229}, {0.5150000000000001, 
                   0.3913894324853229}, {0.51, 0.3913894324853229}, {
                   0.5050000000000001, 0.3913894324853229}, {
                   0.5000000000000001, 0.3913894324853229}, {
                   0.4950000000000001, 0.3913894324853229}, {
                   0.4900000000000001, 0.3913894324853229}, {
                   0.4850000000000001, 0.3913894324853229}, {
                   0.4800000000000001, 0.3913894324853229}}], 
                  
                  Polygon[{{0.3700000000000001, 0.}, {0.45500000000000007`, 
                   0.}, {0.45000000000000007`, 0.44031311154598823`}, {
                   0.44500000000000006`, 0.44031311154598823`}, {
                   0.44000000000000006`, 0.44031311154598823`}, {
                   0.43500000000000005`, 0.44031311154598823`}, {
                   0.43000000000000005`, 0.44031311154598823`}, {
                   0.42500000000000004`, 0.44031311154598823`}, {
                   0.42000000000000004`, 0.44031311154598823`}, {
                   0.41500000000000004`, 0.44031311154598823`}, {
                   0.41000000000000003`, 0.44031311154598823`}, {
                   0.4050000000000001, 0.44031311154598823`}, {
                   0.4000000000000001, 0.44031311154598823`}, {
                   0.3950000000000001, 0.44031311154598823`}, {
                   0.39000000000000007`, 0.44031311154598823`}, {
                   0.38500000000000006`, 0.44031311154598823`}, {
                   0.38000000000000006`, 0.44031311154598823`}, {
                   0.37500000000000006`, 0.44031311154598823`}}], 
                  
                  Polygon[{{-2.455, 0.}, {-2.37, 0.}, {-2.375, 
                   0.44031311154598823`}, {-2.38, 
                   0.44031311154598823`}, {-2.385, 
                   0.44031311154598823`}, {-2.39, 
                   0.44031311154598823`}, {-2.395, 
                   0.44031311154598823`}, {-2.4, 
                   0.44031311154598823`}, {-2.4050000000000002`, 
                   0.44031311154598823`}, {-2.41, 
                   0.44031311154598823`}, {-2.415, 
                   0.44031311154598823`}, {-2.42, 
                   0.44031311154598823`}, {-2.425, 
                   0.44031311154598823`}, {-2.4299999999999997`, 
                   0.44031311154598823`}, {-2.435, 
                   0.44031311154598823`}, {-2.44, 
                   0.44031311154598823`}, {-2.4450000000000003`, 
                   0.44031311154598823`}, {-2.45, 0.44031311154598823`}}]}, {
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGAQB2IQbQwGbAcYoCBoh1zr60BWOD+m/9BXjRjWA9N0Ijel
nLxknwYGCH6BLdf1xQUIfrXIOveHVQg+0DCgiQg+2Lh+1gPr4/ZWfX311H7W
TBBA8JeADUTwQaaJrEPwwc7bgeCDjTuE4J8BAwQf6DiggQj+oyqQAxH8NyDn
vUbwv4GM+4rgQ0KB7cCJCYrObTw37bnABiL4YO+KIPjyYA8j+JrgAETwAY3A
tWg=
                   "]], 
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHbRDrvV1IKsDAxSYGIMAG5yvGdN/6KsGm8OJCYrO
bTw37eWBqnfIIfii69wfVokg+FzXFxfYciH4EFMQ/G8aIANZHdbH7a36+uqp
/ZtAkAMQ/EdVIkATEfwbIOOuI/hnz4AAgg90HNBABB/snR0IPth56xD8JSDj
FiP4s2aCAII/AWwggt8G8m4rq8M0nchNKScv2deAnFeF4BeCjCtA8NPAAMEH
B18Mgg8Axm6p8A==
                   "]]}, {
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAGIQffirRkz/ob/2DFAwayYI/Ifz214H7pBr/W9/YoKi
cxvPTfsiW67riwsQ/Nj+Q0ATEHyPh1Ui69wRfBNjEEDwFVpBBiL4INNsuf7b
r4/bW/X11VP7byDnfP0H5z8CGfcQwT97BgQQfKDjgAYi+EsKQA5E8CeAnNeP
4NeAjKtC8NPAAMEPAhuI4NuBHfjPfppO5KaUk5fstUDO00DwRUHGiSD4kFBD
8N+Agu/1Xzj/Bsi71xF8AB6Fxa0=
                   "]], 
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAGIQPWsmCPzfzwAFh75qxPQf+gvnX1tcYMt1/e/+aTqR
m1JOXrJ/HbhDrvU1gg9R9Q/OF1nn/rBKBMEHmfZVA8G347oONBHBDwIZF/hv
//q4vVVfXz21TwMDBL8abCCCPwHsQAR/Cch5ixF8sHE7EPwzYIDgP6oCGYjg
fwM7EMEHO4/rP5wPNk7u//4TExSd23hu2huDAYLv8RBkIIIP9m4Mgg92XgGC
DzauFcEHAPPr0Z0=
                   "]]}, {
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBGIQXWbLdX1xwV57BigQX+f+sErkHJxfApY/az9NJ3JT
yslL9hfOgAGcrxPTf+irBoLf8Tpwh1zraTj/SZUI0MRTcL4DyDhbBH/OTBA4
Cef/0AAZeMJ+fdzeqq+vntqHAE17HYjgbwA5b91xOJ8HZBwXgp+RBgLH4Pwj
X0EGHoXzFVpBDkTwa0DOqzoC598CGXf9MJxvZgwCh+1PTFB0buO5aT/pENhA
OP8dyLuvD8L5XiDnuSP4y0DGLT4A5zOBQxXB3wfy3o59cD4AzonGVg==
                   "]], 
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbTO/WGVyLn9DFCQY8t1fXHBXjh/i1zr68Ad+/af
mKDo3MZz0/7PfxDYD+cvKgBpOADnuwFNW+d+EM5/FbgDaAKC33foq0ZM/yE4
39AYBA7D+VcXgww8vH993N6qr6+e2leIgBx4BM6XATlH7iicfwBsHIKfkgYC
x+B8jusgA4/D+WtA3l2H4AeAnBd4As7/AjLuK4I/YyYInNw/TSdyU8rJS/bW
oOCxPQXn3wN59yGC3wRyXutpOF8NZJzGGTj/1BkwgPPzwOF9Fs4HAAKX2FA=

                   "]]}, {
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQvUuu9XXgjnf2DFBQZMt1fXHBRzg/pv/QV42Yj/Yn
Jig6t/HctPd4WCWyzh3BNzEGAQRfAWScHIIPMs2WC8H/pgEy8QOc/whk3EME
/9wZEEDwd4Ddh+AvKQA58IN9+vl5ttXf3thPADmvH8GvARlXheCngQGCHwQ2
EMG3AzsQwdcEexjBBxsn8sGemZ1PxqLgATRcEPwbIO9dfw/ng5WvQ/DbQMHR
iuBDwhPBh4Qfgs8NDi8EHxI+7+B8AFWfvTE=
                   "]], 
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQPWsmCDAdYICCCYe+asT0M8L5EHnGA9N0IjelnDxk
v6TAluv6YgR/nfvDKpF1CP4OudbXgTsQfLBxhxD8M2CA4F9fDDIQwX8ENM39
IYL/JhBkIoL/DWTcV8YDXcLqfnMsHtpDXMkE53OBDUTwRcAORPDlQc6TQ/A1
QcZpIPjGYIDg24ENZDpwYoKicxvPTXsPkHfdEfwgsIcRfLBxMQh+Ghgg+ODg
K0Dwq8EORPDBzmtF8CHxgeADAK05vHw=
                   "]], 
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQPeHQV42YfkYHBiiYNRMEmOB8iDyTw4kJis5tPDft
W18H7pBrRfCrRda5P6xC8Attua4vLkDw08AAwY/pBxmI4AcBTXsdiOB7PKwC
mojg24GMs0XwTYxBgMmhS1jdb47FQ3tNsIEIvjzYgQg+2HkiCD7YOC4EH+JL
BP+bBshARjj/Dci7rxkdpulEbko5ecj+Ech5DxH8GyDjriP4Z8+AAIJ/GBR8
hxB8sHd3IPhg561D8JeAjFuM4EPiA8EHAEi+rwE=
                   "]]}, {
                  Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAWIQXWDLdX1xwcf9DFAw4dBXjZj+d3D+DrnW14E73u1n
ZueTsSh4YP+oSmSd+0MEH6Tblus9nG8MBgh+TD/IQAQfZJpcK4IPNAxoIoJ/
DWTcdQQf4ooPcL4IWAOCrwG24MP+9PPzbKu/vbG3AzsIwQ8CewDBTwMDBB/s
nSoEH+J/BH8JOIA+7D8xQdG5jeemPSQ8EPwzYIDgQ8IHwf8GdiCCDwmvj3A+
2Dg5BB8Sfgi+Byh43BF8SHgi+ACd5NBc
                   "]]}}]}, {}, {}}, {{}, {}, 
              Annotation[{
                Hue[0.67, 0.6, 0.6], 
                Directive[
                 PointSize[0.006944444444444445], 
                 RGBColor[0.368417, 0.506779, 0.709798], 
                 AbsoluteThickness[2]], 
                Line[CompressedData["
1:eJxd3GuMnGX9xvHplG4ViDFS5Q0iJEbREBLRGBKpM4mJqC+IoCYeEBMDygsj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                 "]]}, "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-2.96, 2.96}, {0, 0.9050880626223091}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {{{}, {
              EdgeForm[], 
              Directive[
               RGBColor[0.368417, 0.506779, 0.709798], 
               Opacity[1]], 
              GraphicsGroup[{{
                 
                 Polygon[{{-2.96, 0.02446183953033268}, {-2.96, 0.}, {-2.955, 
                  0.}}]}, {
                 
                 Polygon[{{2.015, 0.}, {2.1, 0.}, {2.095, 
                  0.3913894324853229}, {2.09, 0.3913894324853229}, {2.085, 
                  0.3913894324853229}, {2.08, 0.3913894324853229}, {2.075, 
                  0.3913894324853229}, {2.0700000000000003`, 
                  0.3913894324853229}, {2.065, 0.3913894324853229}, {2.06, 
                  0.3913894324853229}, {2.055, 0.3913894324853229}, {2.05, 
                  0.3913894324853229}, {2.045, 0.3913894324853229}, {2.04, 
                  0.3913894324853229}, {2.035, 0.3913894324853229}, {
                  2.0300000000000002`, 0.3913894324853229}, {
                  2.0250000000000004`, 0.3913894324853229}, {2.02, 
                  0.3913894324853229}}], 
                 
                 Polygon[{{2.37, 0.}, {2.455, 0.}, {2.45, 
                  0.44031311154598823`}, {2.4450000000000003`, 
                  0.44031311154598823`}, {2.44, 0.44031311154598823`}, {2.435,
                   0.44031311154598823`}, {2.43, 0.44031311154598823`}, {
                  2.425, 0.44031311154598823`}, {2.42, 
                  0.44031311154598823`}, {2.415, 0.44031311154598823`}, {2.41,
                   0.44031311154598823`}, {2.4050000000000002`, 
                  0.44031311154598823`}, {2.4000000000000004`, 
                  0.44031311154598823`}, {2.395, 0.44031311154598823`}, {2.39,
                   0.44031311154598823`}, {2.385, 0.44031311154598823`}, {
                  2.38, 0.44031311154598823`}, {2.375, 
                  0.44031311154598823`}}], 
                 
                 Polygon[{{-1.44, 0.}, {-1.355, 0.}, {-1.3599999999999999`, 
                  0.3913894324853229}, {-1.3649999999999998`, 
                  0.3913894324853229}, {-1.3699999999999999`, 
                  0.3913894324853229}, {-1.375, 0.3913894324853229}, {-1.38, 
                  0.3913894324853229}, {-1.3849999999999998`, 
                  0.3913894324853229}, {-1.3900000000000001`, 
                  0.3913894324853229}, {-1.395, 0.3913894324853229}, {-1.4, 
                  0.3913894324853229}, {-1.405, 
                  0.3913894324853229}, {-1.4100000000000001`, 
                  0.3913894324853229}, {-1.415, 0.3913894324853229}, {-1.42, 
                  0.3913894324853229}, {-1.4249999999999998`, 
                  0.3913894324853229}, {-1.4300000000000002`, 
                  0.3913894324853229}, {-1.435, 0.3913894324853229}}], 
                 
                 Polygon[{{1.69, 0.}, {1.775, 0.}, {1.77, 
                  0.684931506849315}, {1.7650000000000001`, 
                  0.684931506849315}, {1.7600000000000002`, 
                  0.684931506849315}, {1.7550000000000001`, 
                  0.684931506849315}, {1.75, 0.684931506849315}, {1.745, 
                  0.684931506849315}, {1.7400000000000002`, 
                  0.684931506849315}, {1.735, 0.684931506849315}, {1.73, 
                  0.684931506849315}, {1.725, 0.684931506849315}, {
                  1.7200000000000002`, 0.684931506849315}, {
                  1.7150000000000003`, 0.684931506849315}, {
                  1.7100000000000002`, 0.684931506849315}, {1.705, 
                  0.684931506849315}, {1.7000000000000002`, 
                  0.684931506849315}, {1.6950000000000003`, 
                  0.684931506849315}}], 
                 
                 Polygon[{{-0.5599999999999999, 0.}, {-0.4749999999999999, 
                  0.}, {-0.4799999999999999, 
                  0.3913894324853229}, {-0.48499999999999993`, 
                  0.3913894324853229}, {-0.48999999999999994`, 
                  0.3913894324853229}, {-0.49499999999999994`, 
                  0.3913894324853229}, {-0.49999999999999994`, 
                  0.3913894324853229}, {-0.5049999999999999, 
                  0.3913894324853229}, {-0.51, 
                  0.3913894324853229}, {-0.5149999999999999, 
                  0.3913894324853229}, {-0.52, 
                  0.3913894324853229}, {-0.5249999999999999, 
                  0.3913894324853229}, {-0.53, 
                  0.3913894324853229}, {-0.5349999999999999, 
                  0.3913894324853229}, {-0.54, 
                  0.3913894324853229}, {-0.5449999999999999, 
                  0.3913894324853229}, {-0.55, 
                  0.3913894324853229}, {-0.5549999999999999, 
                  0.3913894324853229}}], 
                 
                 Polygon[{{-0.4549999999999999, 0.}, {-0.36999999999999994`, 
                  0.}, {-0.37499999999999994`, 
                  0.44031311154598823`}, {-0.37999999999999995`, 
                  0.44031311154598823`}, {-0.38499999999999995`, 
                  0.44031311154598823`}, {-0.38999999999999996`, 
                  0.44031311154598823`}, {-0.39499999999999996`, 
                  0.44031311154598823`}, {-0.39999999999999997`, 
                  0.44031311154598823`}, {-0.4049999999999999, 
                  0.44031311154598823`}, {-0.4099999999999999, 
                  0.44031311154598823`}, {-0.4149999999999999, 
                  0.44031311154598823`}, {-0.41999999999999993`, 
                  0.44031311154598823`}, {-0.42499999999999993`, 
                  0.44031311154598823`}, {-0.42999999999999994`, 
                  0.44031311154598823`}, {-0.43499999999999994`, 
                  0.44031311154598823`}, {-0.43999999999999995`, 
                  0.44031311154598823`}, {-0.44499999999999995`, 
                  0.44031311154598823`}, {-0.4499999999999999, 
                  0.44031311154598823`}}], 
                 
                 Polygon[{{-2.0999999999999996`, 0.}, {-2.015, 0.}, {-2.02, 
                  0.3913894324853229}, {-2.025, 
                  0.3913894324853229}, {-2.0300000000000002`, 
                  0.3913894324853229}, {-2.035, 0.3913894324853229}, {-2.04, 
                  0.3913894324853229}, {-2.045, 0.3913894324853229}, {-2.05, 
                  0.3913894324853229}, {-2.0549999999999997`, 
                  0.3913894324853229}, {-2.06, 0.3913894324853229}, {-2.065, 
                  0.3913894324853229}, {-2.0700000000000003`, 
                  0.3913894324853229}, {-2.075, 0.3913894324853229}, {-2.08, 
                  0.3913894324853229}, {-2.085, 0.3913894324853229}, {-2.09, 
                  0.3913894324853229}, {-2.0949999999999998`, 
                  0.3913894324853229}}], 
                 
                 Polygon[{{-1.775, 0.}, {-1.69, 0.}, {-1.6949999999999998`, 
                  0.684931506849315}, {-1.7, 0.684931506849315}, {-1.705, 
                  0.684931506849315}, {-1.71, 
                  0.684931506849315}, {-1.7149999999999999`, 
                  0.684931506849315}, {-1.72, 0.684931506849315}, {-1.725, 
                  0.684931506849315}, {-1.73, 
                  0.684931506849315}, {-1.7349999999999999`, 
                  0.684931506849315}, {-1.7399999999999998`, 
                  0.684931506849315}, {-1.7449999999999999`, 
                  0.684931506849315}, {-1.75, 0.684931506849315}, {-1.755, 
                  0.684931506849315}, {-1.7599999999999998`, 
                  0.684931506849315}, {-1.7650000000000001`, 
                  0.684931506849315}, {-1.77, 0.684931506849315}}], 
                 
                 Polygon[{{1.355, 0.}, {1.44, 0.}, {1.435, 
                  0.3913894324853229}, {1.4300000000000002`, 
                  0.3913894324853229}, {1.425, 0.3913894324853229}, {1.42, 
                  0.3913894324853229}, {1.415, 0.3913894324853229}, {
                  1.4100000000000001`, 0.3913894324853229}, {
                  1.4050000000000002`, 0.3913894324853229}, {1.4, 
                  0.3913894324853229}, {1.395, 0.3913894324853229}, {
                  1.3900000000000001`, 0.3913894324853229}, {
                  1.3850000000000002`, 0.3913894324853229}, {
                  1.3800000000000001`, 0.3913894324853229}, {1.375, 
                  0.3913894324853229}, {1.37, 0.3913894324853229}, {
                  1.3650000000000002`, 0.3913894324853229}, {1.36, 
                  0.3913894324853229}}], 
                 
                 Polygon[{{0.4750000000000001, 0.}, {0.56, 0.}, {0.555, 
                  0.3913894324853229}, {0.55, 0.3913894324853229}, {
                  0.5450000000000002, 0.3913894324853229}, {0.54, 
                  0.3913894324853229}, {0.5350000000000001, 
                  0.3913894324853229}, {0.53, 0.3913894324853229}, {
                  0.5250000000000001, 0.3913894324853229}, {0.52, 
                  0.3913894324853229}, {0.5150000000000001, 
                  0.3913894324853229}, {0.51, 0.3913894324853229}, {
                  0.5050000000000001, 0.3913894324853229}, {
                  0.5000000000000001, 0.3913894324853229}, {
                  0.4950000000000001, 0.3913894324853229}, {
                  0.4900000000000001, 0.3913894324853229}, {
                  0.4850000000000001, 0.3913894324853229}, {
                  0.4800000000000001, 0.3913894324853229}}], 
                 
                 Polygon[{{0.3700000000000001, 0.}, {0.45500000000000007`, 
                  0.}, {0.45000000000000007`, 0.44031311154598823`}, {
                  0.44500000000000006`, 0.44031311154598823`}, {
                  0.44000000000000006`, 0.44031311154598823`}, {
                  0.43500000000000005`, 0.44031311154598823`}, {
                  0.43000000000000005`, 0.44031311154598823`}, {
                  0.42500000000000004`, 0.44031311154598823`}, {
                  0.42000000000000004`, 0.44031311154598823`}, {
                  0.41500000000000004`, 0.44031311154598823`}, {
                  0.41000000000000003`, 0.44031311154598823`}, {
                  0.4050000000000001, 0.44031311154598823`}, {
                  0.4000000000000001, 0.44031311154598823`}, {
                  0.3950000000000001, 0.44031311154598823`}, {
                  0.39000000000000007`, 0.44031311154598823`}, {
                  0.38500000000000006`, 0.44031311154598823`}, {
                  0.38000000000000006`, 0.44031311154598823`}, {
                  0.37500000000000006`, 0.44031311154598823`}}], 
                 
                 Polygon[{{-2.455, 0.}, {-2.37, 0.}, {-2.375, 
                  0.44031311154598823`}, {-2.38, 
                  0.44031311154598823`}, {-2.385, 
                  0.44031311154598823`}, {-2.39, 
                  0.44031311154598823`}, {-2.395, 
                  0.44031311154598823`}, {-2.4, 
                  0.44031311154598823`}, {-2.4050000000000002`, 
                  0.44031311154598823`}, {-2.41, 
                  0.44031311154598823`}, {-2.415, 
                  0.44031311154598823`}, {-2.42, 
                  0.44031311154598823`}, {-2.425, 
                  0.44031311154598823`}, {-2.4299999999999997`, 
                  0.44031311154598823`}, {-2.435, 
                  0.44031311154598823`}, {-2.44, 
                  0.44031311154598823`}, {-2.4450000000000003`, 
                  0.44031311154598823`}, {-2.45, 0.44031311154598823`}}]}, {
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGAQB2IQbQwGbAcYoCBoh1zr60BWOD+m/9BXjRjWA9N0Ijel
nLxknwYGCH6BLdf1xQUIfrXIOveHVQg+0DCgiQg+2Lh+1gPr4/ZWfX311H7W
TBBA8JeADUTwQaaJrEPwwc7bgeCDjTuE4J8BAwQf6DiggQj+oyqQAxH8NyDn
vUbwv4GM+4rgQ0KB7cCJCYrObTw37bnABiL4YO+KIPjyYA8j+JrgAETwAY3A
tWg=
                  "]], 
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHbRDrvV1IKsDAxSYGIMAG5yvGdN/6KsGm8OJCYrO
bTw37eWBqnfIIfii69wfVokg+FzXFxfYciH4EFMQ/G8aIANZHdbH7a36+uqp
/ZtAkAMQ/EdVIkATEfwbIOOuI/hnz4AAgg90HNBABB/snR0IPth56xD8JSDj
FiP4s2aCAII/AWwggt8G8m4rq8M0nchNKScv2deAnFeF4BeCjCtA8NPAAMEH
B18Mgg8Axm6p8A==
                  "]]}, {
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAGIQffirRkz/ob/2DFAwayYI/Ifz214H7pBr/W9/YoKi
cxvPTfsiW67riwsQ/Nj+Q0ATEHyPh1Ui69wRfBNjEEDwFVpBBiL4INNsuf7b
r4/bW/X11VP7byDnfP0H5z8CGfcQwT97BgQQfKDjgAYi+EsKQA5E8CeAnNeP
4NeAjKtC8NPAAMEPAhuI4NuBHfjPfppO5KaUk5fstUDO00DwRUHGiSD4kFBD
8N+Agu/1Xzj/Bsi71xF8AB6Fxa0=
                  "]], 
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAGIQPWsmCPzfzwAFh75qxPQf+gvnX1tcYMt1/e/+aTqR
m1JOXrJ/HbhDrvU1gg9R9Q/OF1nn/rBKBMEHmfZVA8G347oONBHBDwIZF/hv
//q4vVVfXz21TwMDBL8abCCCPwHsQAR/Cch5ixF8sHE7EPwzYIDgP6oCGYjg
fwM7EMEHO4/rP5wPNk7u//4TExSd23hu2huDAYLv8RBkIIIP9m4Mgg92XgGC
DzauFcEHAPPr0Z0=
                  "]]}, {
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBGIQXWbLdX1xwV57BigQX+f+sErkHJxfApY/az9NJ3JT
yslL9hfOgAGcrxPTf+irBoLf8Tpwh1zraTj/SZUI0MRTcL4DyDhbBH/OTBA4
Cef/0AAZeMJ+fdzeqq+vntqHAE17HYjgbwA5b91xOJ8HZBwXgp+RBgLH4Pwj
X0EGHoXzFVpBDkTwa0DOqzoC598CGXf9MJxvZgwCh+1PTFB0buO5aT/pENhA
OP8dyLuvD8L5XiDnuSP4y0DGLT4A5zOBQxXB3wfy3o59cD4AzonGVg==
                  "]], 
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbTO/WGVyLn9DFCQY8t1fXHBXjh/i1zr68Ad+/af
mKDo3MZz0/7PfxDYD+cvKgBpOADnuwFNW+d+EM5/FbgDaAKC33foq0ZM/yE4
39AYBA7D+VcXgww8vH993N6qr6+e2leIgBx4BM6XATlH7iicfwBsHIKfkgYC
x+B8jusgA4/D+WtA3l2H4AeAnBd4As7/AjLuK4I/YyYInNw/TSdyU8rJS/bW
oOCxPQXn3wN59yGC3wRyXutpOF8NZJzGGTj/1BkwgPPzwOF9Fs4HAAKX2FA=

                  "]]}, {
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQvUuu9XXgjnf2DFBQZMt1fXHBRzg/pv/QV42Yj/Yn
Jig6t/HctPd4WCWyzh3BNzEGAQRfAWScHIIPMs2WC8H/pgEy8QOc/whk3EME
/9wZEEDwd4Ddh+AvKQA58IN9+vl5ttXf3thPADmvH8GvARlXheCngQGCHwQ2
EMG3AzsQwdcEexjBBxsn8sGemZ1PxqLgATRcEPwbIO9dfw/ng5WvQ/DbQMHR
iuBDwhPBh4Qfgs8NDi8EHxI+7+B8AFWfvTE=
                  "]], 
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQPWsmCDAdYICCCYe+asT0M8L5EHnGA9N0IjelnDxk
v6TAluv6YgR/nfvDKpF1CP4OudbXgTsQfLBxhxD8M2CA4F9fDDIQwX8ENM39
IYL/JhBkIoL/DWTcV8YDXcLqfnMsHtpDXMkE53OBDUTwRcAORPDlQc6TQ/A1
QcZpIPjGYIDg24ENZDpwYoKicxvPTXsPkHfdEfwgsIcRfLBxMQh+Ghgg+ODg
K0Dwq8EORPDBzmtF8CHxgeADAK05vHw=
                  "]], 
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQPeHQV42YfkYHBiiYNRMEmOB8iDyTw4kJis5tPDft
W18H7pBrRfCrRda5P6xC8Attua4vLkDw08AAwY/pBxmI4AcBTXsdiOB7PKwC
mojg24GMs0XwTYxBgMmhS1jdb47FQ3tNsIEIvjzYgQg+2HkiCD7YOC4EH+JL
BP+bBshARjj/Dci7rxkdpulEbko5ecj+Ech5DxH8GyDjriP4Z8+AAIJ/GBR8
hxB8sHd3IPhg561D8JeAjFuM4EPiA8EHAEi+rwE=
                  "]]}, {
                 Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAWIQXWDLdX1xwcf9DFAw4dBXjZj+d3D+DrnW14E73u1n
ZueTsSh4YP+oSmSd+0MEH6Tblus9nG8MBgh+TD/IQAQfZJpcK4IPNAxoIoJ/
DWTcdQQf4ooPcL4IWAOCrwG24MP+9PPzbKu/vbG3AzsIwQ8CewDBTwMDBB/s
nSoEH+J/BH8JOIA+7D8xQdG5jeemPSQ8EPwzYIDgQ8IHwf8GdiCCDwmvj3A+
2Dg5BB8Sfgi+Byh43BF8SHgi+ACd5NBc
                  "]]}}]}, {}, {}}, {{}, {}, 
             Annotation[{
               Hue[0.67, 0.6, 0.6], 
               Directive[
                PointSize[0.006944444444444445], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]], 
               Line[CompressedData["
1:eJxd3GuMnGX9xvHplG4ViDFS5Q0iJEbREBLRGBKpM4mJqC+IoCYeEBMDygsj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                "]]}, "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
        "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[
     GraphicsComplex[CompressedData["
1:eJzt3OmPZFUdxvGaHmcQMMYIyhsXTIyiMSQuMSQydiUkor4ggpq4oCbG7YUR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      "], {{{}, {
         EdgeForm[], 
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          Opacity[1]], 
         GraphicsGroup[{
           Polygon[{{1, 1186, 2}}], 
           Polygon[CompressedData["
1:eJwV0UVyFGAQBtA/AmxYcQPWeNzQI3ACCBDPTIIeBifuGYkLcBQgLmNx583i
bbq6urr7u14ffRopDCFc5RpLRSHsscsOObJkSJNimy022WCdNVZZYZkbxSHU
UUsN1VRRSQXllFFKCfe4yx1uc4ub+XpBCE94zCMe8oD71FFLDdVUUUkF5ZRR
SglddkqSIE6MccYYZYRhhhhkgH766KWHbv6YlSNLhjQpttlikw3WWWOVFZZZ
4h9/2eeKx1/mEsUUUUhBPhAu9JxzxiknHHPEIQeMaF1kgXnmmGWGaaaYZIIk
CeLEGGeMUVJccM4Zp5xwzBGHHLDPHrvskCNLhjTP/KiTDqJEaKeNVlpopolG
GnjFS15Qz/N8Nu7/zS9+ssgC88wxywzTTDHJBEkSxInxkWGGGGSAfvropYdu
uvjBd77xlS985hMNbvvAe97xlje8ppMOokRop41WWmimiUb+A8zHh5s=
            "]], 
           
           Polygon[{{38, 60, 59, 58, 57, 56, 55, 54, 53, 52, 51, 50, 49, 48, 
            47, 46, 45, 44, 43, 42, 41, 40, 39}, {1126, 1148, 1147, 1146, 
            1145, 1144, 1143, 1142, 1141, 1140, 1139, 1138, 1137, 1136, 1135, 
            1134, 1133, 1132, 1131, 1130, 1129, 1128, 1127}}], 
           
           Polygon[{{965, 988, 987, 986, 985, 984, 983, 982, 981, 980, 979, 
            978, 977, 976, 975, 974, 973, 972, 971, 970, 969, 968, 967, 
            966}, {198, 221, 220, 219, 218, 217, 216, 215, 214, 213, 212, 211,
             210, 209, 208, 207, 206, 205, 204, 203, 202, 201, 200, 199}}], 
           
           Polygon[{{616, 640, 639, 638, 637, 636, 635, 634, 633, 632, 631, 
            630, 629, 628, 627, 626, 625, 624, 623, 622, 621, 620, 619, 618, 
            617}, {546, 570, 569, 568, 567, 566, 565, 564, 563, 562, 561, 560,
             559, 558, 557, 556, 555, 554, 553, 552, 551, 550, 549, 548, 
            547}}], 
           Polygon[CompressedData["
1:eJwNzkdWwgAARdEcZYCKlCTUUBIFC+zGJbgA2QKg0mwUG67WO7jnvNn/2f34
7uEoCIJjEipixJBbbrjmigF9LrkgI6VHlw5tElo0aVCnRpWYiJCJvT8O/PLD
N198smfHlg0fvPPGKy+sWbFkwZxnnnhkxpR8zmcyUnp06dAmoUWTBnVqVImJ
CKlQpkSRcwqcccoJ/3JYFtA=
            "]], 
           
           Polygon[{{375, 402, 401, 400, 399, 398, 397, 396, 395, 394, 393, 
            392, 391, 390, 389, 388, 387, 386, 385, 384, 383, 382, 381, 380, 
            379, 378, 377, 376}}]}]}, {}, {}}, {{}, {}, 
        Annotation[{
          Hue[0.67, 0.6, 0.6], 
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]], 
          Line[CompressedData["
1:eJwl2NMSGAgSAMDYtm3btm3btm3btm3uxrZt29xcp+6ha2o+YJiwUftK7QIG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           "]]}, "Charting`Private`Tag#1"]}}], <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-2.96, 2.96}, {0, 0.9050880626223091}}, 
        "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {{{}, {
            EdgeForm[], 
            Directive[
             RGBColor[0.368417, 0.506779, 0.709798], 
             Opacity[1]], 
            GraphicsGroup[{{
               
               Polygon[{{-2.96, 0.02446183953033268}, {-2.96, 0.}, {-2.955, 
                0.}}]}, {
               
               Polygon[{{2.015, 0.}, {2.1, 0.}, {2.095, 0.3913894324853229}, {
                2.09, 0.3913894324853229}, {2.085, 0.3913894324853229}, {2.08,
                 0.3913894324853229}, {2.075, 0.3913894324853229}, {
                2.0700000000000003`, 0.3913894324853229}, {2.065, 
                0.3913894324853229}, {2.06, 0.3913894324853229}, {2.055, 
                0.3913894324853229}, {2.05, 0.3913894324853229}, {2.045, 
                0.3913894324853229}, {2.04, 0.3913894324853229}, {2.035, 
                0.3913894324853229}, {2.0300000000000002`, 
                0.3913894324853229}, {2.0250000000000004`, 
                0.3913894324853229}, {2.02, 0.3913894324853229}}], 
               
               Polygon[{{2.37, 0.}, {2.455, 0.}, {2.45, 
                0.44031311154598823`}, {2.4450000000000003`, 
                0.44031311154598823`}, {2.44, 0.44031311154598823`}, {2.435, 
                0.44031311154598823`}, {2.43, 0.44031311154598823`}, {2.425, 
                0.44031311154598823`}, {2.42, 0.44031311154598823`}, {2.415, 
                0.44031311154598823`}, {2.41, 0.44031311154598823`}, {
                2.4050000000000002`, 0.44031311154598823`}, {
                2.4000000000000004`, 0.44031311154598823`}, {2.395, 
                0.44031311154598823`}, {2.39, 0.44031311154598823`}, {2.385, 
                0.44031311154598823`}, {2.38, 0.44031311154598823`}, {2.375, 
                0.44031311154598823`}}], 
               
               Polygon[{{-1.44, 0.}, {-1.355, 0.}, {-1.3599999999999999`, 
                0.3913894324853229}, {-1.3649999999999998`, 
                0.3913894324853229}, {-1.3699999999999999`, 
                0.3913894324853229}, {-1.375, 0.3913894324853229}, {-1.38, 
                0.3913894324853229}, {-1.3849999999999998`, 
                0.3913894324853229}, {-1.3900000000000001`, 
                0.3913894324853229}, {-1.395, 0.3913894324853229}, {-1.4, 
                0.3913894324853229}, {-1.405, 
                0.3913894324853229}, {-1.4100000000000001`, 
                0.3913894324853229}, {-1.415, 0.3913894324853229}, {-1.42, 
                0.3913894324853229}, {-1.4249999999999998`, 
                0.3913894324853229}, {-1.4300000000000002`, 
                0.3913894324853229}, {-1.435, 0.3913894324853229}}], 
               
               Polygon[{{1.69, 0.}, {1.775, 0.}, {1.77, 0.684931506849315}, {
                1.7650000000000001`, 0.684931506849315}, {1.7600000000000002`,
                 0.684931506849315}, {1.7550000000000001`, 
                0.684931506849315}, {1.75, 0.684931506849315}, {1.745, 
                0.684931506849315}, {1.7400000000000002`, 
                0.684931506849315}, {1.735, 0.684931506849315}, {1.73, 
                0.684931506849315}, {1.725, 0.684931506849315}, {
                1.7200000000000002`, 0.684931506849315}, {1.7150000000000003`,
                 0.684931506849315}, {1.7100000000000002`, 
                0.684931506849315}, {1.705, 0.684931506849315}, {
                1.7000000000000002`, 0.684931506849315}, {1.6950000000000003`,
                 0.684931506849315}}], 
               
               Polygon[{{-0.5599999999999999, 0.}, {-0.4749999999999999, 
                0.}, {-0.4799999999999999, 
                0.3913894324853229}, {-0.48499999999999993`, 
                0.3913894324853229}, {-0.48999999999999994`, 
                0.3913894324853229}, {-0.49499999999999994`, 
                0.3913894324853229}, {-0.49999999999999994`, 
                0.3913894324853229}, {-0.5049999999999999, 
                0.3913894324853229}, {-0.51, 
                0.3913894324853229}, {-0.5149999999999999, 
                0.3913894324853229}, {-0.52, 
                0.3913894324853229}, {-0.5249999999999999, 
                0.3913894324853229}, {-0.53, 
                0.3913894324853229}, {-0.5349999999999999, 
                0.3913894324853229}, {-0.54, 
                0.3913894324853229}, {-0.5449999999999999, 
                0.3913894324853229}, {-0.55, 
                0.3913894324853229}, {-0.5549999999999999, 
                0.3913894324853229}}], 
               
               Polygon[{{-0.4549999999999999, 0.}, {-0.36999999999999994`, 
                0.}, {-0.37499999999999994`, 
                0.44031311154598823`}, {-0.37999999999999995`, 
                0.44031311154598823`}, {-0.38499999999999995`, 
                0.44031311154598823`}, {-0.38999999999999996`, 
                0.44031311154598823`}, {-0.39499999999999996`, 
                0.44031311154598823`}, {-0.39999999999999997`, 
                0.44031311154598823`}, {-0.4049999999999999, 
                0.44031311154598823`}, {-0.4099999999999999, 
                0.44031311154598823`}, {-0.4149999999999999, 
                0.44031311154598823`}, {-0.41999999999999993`, 
                0.44031311154598823`}, {-0.42499999999999993`, 
                0.44031311154598823`}, {-0.42999999999999994`, 
                0.44031311154598823`}, {-0.43499999999999994`, 
                0.44031311154598823`}, {-0.43999999999999995`, 
                0.44031311154598823`}, {-0.44499999999999995`, 
                0.44031311154598823`}, {-0.4499999999999999, 
                0.44031311154598823`}}], 
               
               Polygon[{{-2.0999999999999996`, 0.}, {-2.015, 0.}, {-2.02, 
                0.3913894324853229}, {-2.025, 
                0.3913894324853229}, {-2.0300000000000002`, 
                0.3913894324853229}, {-2.035, 0.3913894324853229}, {-2.04, 
                0.3913894324853229}, {-2.045, 0.3913894324853229}, {-2.05, 
                0.3913894324853229}, {-2.0549999999999997`, 
                0.3913894324853229}, {-2.06, 0.3913894324853229}, {-2.065, 
                0.3913894324853229}, {-2.0700000000000003`, 
                0.3913894324853229}, {-2.075, 0.3913894324853229}, {-2.08, 
                0.3913894324853229}, {-2.085, 0.3913894324853229}, {-2.09, 
                0.3913894324853229}, {-2.0949999999999998`, 
                0.3913894324853229}}], 
               
               Polygon[{{-1.775, 0.}, {-1.69, 0.}, {-1.6949999999999998`, 
                0.684931506849315}, {-1.7, 0.684931506849315}, {-1.705, 
                0.684931506849315}, {-1.71, 
                0.684931506849315}, {-1.7149999999999999`, 
                0.684931506849315}, {-1.72, 0.684931506849315}, {-1.725, 
                0.684931506849315}, {-1.73, 
                0.684931506849315}, {-1.7349999999999999`, 
                0.684931506849315}, {-1.7399999999999998`, 
                0.684931506849315}, {-1.7449999999999999`, 
                0.684931506849315}, {-1.75, 0.684931506849315}, {-1.755, 
                0.684931506849315}, {-1.7599999999999998`, 
                0.684931506849315}, {-1.7650000000000001`, 
                0.684931506849315}, {-1.77, 0.684931506849315}}], 
               
               Polygon[{{1.355, 0.}, {1.44, 0.}, {1.435, 
                0.3913894324853229}, {1.4300000000000002`, 
                0.3913894324853229}, {1.425, 0.3913894324853229}, {1.42, 
                0.3913894324853229}, {1.415, 0.3913894324853229}, {
                1.4100000000000001`, 0.3913894324853229}, {
                1.4050000000000002`, 0.3913894324853229}, {1.4, 
                0.3913894324853229}, {1.395, 0.3913894324853229}, {
                1.3900000000000001`, 0.3913894324853229}, {
                1.3850000000000002`, 0.3913894324853229}, {
                1.3800000000000001`, 0.3913894324853229}, {1.375, 
                0.3913894324853229}, {1.37, 0.3913894324853229}, {
                1.3650000000000002`, 0.3913894324853229}, {1.36, 
                0.3913894324853229}}], 
               
               Polygon[{{0.4750000000000001, 0.}, {0.56, 0.}, {0.555, 
                0.3913894324853229}, {0.55, 0.3913894324853229}, {
                0.5450000000000002, 0.3913894324853229}, {0.54, 
                0.3913894324853229}, {0.5350000000000001, 
                0.3913894324853229}, {0.53, 0.3913894324853229}, {
                0.5250000000000001, 0.3913894324853229}, {0.52, 
                0.3913894324853229}, {0.5150000000000001, 
                0.3913894324853229}, {0.51, 0.3913894324853229}, {
                0.5050000000000001, 0.3913894324853229}, {0.5000000000000001, 
                0.3913894324853229}, {0.4950000000000001, 
                0.3913894324853229}, {0.4900000000000001, 
                0.3913894324853229}, {0.4850000000000001, 
                0.3913894324853229}, {0.4800000000000001, 
                0.3913894324853229}}], 
               
               Polygon[{{0.3700000000000001, 0.}, {0.45500000000000007`, 
                0.}, {0.45000000000000007`, 0.44031311154598823`}, {
                0.44500000000000006`, 0.44031311154598823`}, {
                0.44000000000000006`, 0.44031311154598823`}, {
                0.43500000000000005`, 0.44031311154598823`}, {
                0.43000000000000005`, 0.44031311154598823`}, {
                0.42500000000000004`, 0.44031311154598823`}, {
                0.42000000000000004`, 0.44031311154598823`}, {
                0.41500000000000004`, 0.44031311154598823`}, {
                0.41000000000000003`, 0.44031311154598823`}, {
                0.4050000000000001, 0.44031311154598823`}, {
                0.4000000000000001, 0.44031311154598823`}, {
                0.3950000000000001, 0.44031311154598823`}, {
                0.39000000000000007`, 0.44031311154598823`}, {
                0.38500000000000006`, 0.44031311154598823`}, {
                0.38000000000000006`, 0.44031311154598823`}, {
                0.37500000000000006`, 0.44031311154598823`}}], 
               
               Polygon[{{-2.455, 0.}, {-2.37, 0.}, {-2.375, 
                0.44031311154598823`}, {-2.38, 0.44031311154598823`}, {-2.385,
                 0.44031311154598823`}, {-2.39, 
                0.44031311154598823`}, {-2.395, 0.44031311154598823`}, {-2.4, 
                0.44031311154598823`}, {-2.4050000000000002`, 
                0.44031311154598823`}, {-2.41, 0.44031311154598823`}, {-2.415,
                 0.44031311154598823`}, {-2.42, 
                0.44031311154598823`}, {-2.425, 
                0.44031311154598823`}, {-2.4299999999999997`, 
                0.44031311154598823`}, {-2.435, 0.44031311154598823`}, {-2.44,
                 0.44031311154598823`}, {-2.4450000000000003`, 
                0.44031311154598823`}, {-2.45, 0.44031311154598823`}}]}, {
               Polygon[CompressedData["
1:eJxTTMoPSmViYGAQB2IQbQwGbAcYoCBoh1zr60BWOD+m/9BXjRjWA9N0Ijel
nLxknwYGCH6BLdf1xQUIfrXIOveHVQg+0DCgiQg+2Lh+1gPr4/ZWfX311H7W
TBBA8JeADUTwQaaJrEPwwc7bgeCDjTuE4J8BAwQf6DiggQj+oyqQAxH8NyDn
vUbwv4GM+4rgQ0KB7cCJCYrObTw37bnABiL4YO+KIPjyYA8j+JrgAETwAY3A
tWg=
                "]], 
               Polygon[CompressedData["
1:eJxTTMoPSmViYGAQB2IQHbRDrvV1IKsDAxSYGIMAG5yvGdN/6KsGm8OJCYrO
bTw37eWBqnfIIfii69wfVokg+FzXFxfYciH4EFMQ/G8aIANZHdbH7a36+uqp
/ZtAkAMQ/EdVIkATEfwbIOOuI/hnz4AAgg90HNBABB/snR0IPth56xD8JSDj
FiP4s2aCAII/AWwggt8G8m4rq8M0nchNKScv2deAnFeF4BeCjCtA8NPAAMEH
B18Mgg8Axm6p8A==
                "]]}, {
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAGIQffirRkz/ob/2DFAwayYI/Ifz214H7pBr/W9/YoKi
cxvPTfsiW67riwsQ/Nj+Q0ATEHyPh1Ui69wRfBNjEEDwFVpBBiL4INNsuf7b
r4/bW/X11VP7byDnfP0H5z8CGfcQwT97BgQQfKDjgAYi+EsKQA5E8CeAnNeP
4NeAjKtC8NPAAMEPAhuI4NuBHfjPfppO5KaUk5fstUDO00DwRUHGiSD4kFBD
8N+Agu/1Xzj/Bsi71xF8AB6Fxa0=
                "]], 
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAGIQPWsmCPzfzwAFh75qxPQf+gvnX1tcYMt1/e/+aTqR
m1JOXrJ/HbhDrvU1gg9R9Q/OF1nn/rBKBMEHmfZVA8G347oONBHBDwIZF/hv
//q4vVVfXz21TwMDBL8abCCCPwHsQAR/Cch5ixF8sHE7EPwzYIDgP6oCGYjg
fwM7EMEHO4/rP5wPNk7u//4TExSd23hu2huDAYLv8RBkIIIP9m4Mgg92XgGC
DzauFcEHAPPr0Z0=
                "]]}, {
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBGIQXWbLdX1xwV57BigQX+f+sErkHJxfApY/az9NJ3JT
yslL9hfOgAGcrxPTf+irBoLf8Tpwh1zraTj/SZUI0MRTcL4DyDhbBH/OTBA4
Cef/0AAZeMJ+fdzeqq+vntqHAE17HYjgbwA5b91xOJ8HZBwXgp+RBgLH4Pwj
X0EGHoXzFVpBDkTwa0DOqzoC598CGXf9MJxvZgwCh+1PTFB0buO5aT/pENhA
OP8dyLuvD8L5XiDnuSP4y0DGLT4A5zOBQxXB3wfy3o59cD4AzonGVg==
                "]], 
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBGIQLbTO/WGVyLn9DFCQY8t1fXHBXjh/i1zr68Ad+/af
mKDo3MZz0/7PfxDYD+cvKgBpOADnuwFNW+d+EM5/FbgDaAKC33foq0ZM/yE4
39AYBA7D+VcXgww8vH993N6qr6+e2leIgBx4BM6XATlH7iicfwBsHIKfkgYC
x+B8jusgA4/D+WtA3l2H4AeAnBd4As7/AjLuK4I/YyYInNw/TSdyU8rJS/bW
oOCxPQXn3wN59yGC3wRyXutpOF8NZJzGGTj/1BkwgPPzwOF9Fs4HAAKX2FA=

                "]]}, {
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQvUuu9XXgjnf2DFBQZMt1fXHBRzg/pv/QV42Yj/Yn
Jig6t/HctPd4WCWyzh3BNzEGAQRfAWScHIIPMs2WC8H/pgEy8QOc/whk3EME
/9wZEEDwd4Ddh+AvKQA58IN9+vl5ttXf3thPADmvH8GvARlXheCngQGCHwQ2
EMG3AzsQwdcEexjBBxsn8sGemZ1PxqLgATRcEPwbIO9dfw/ng5WvQ/DbQMHR
iuBDwhPBh4Qfgs8NDi8EHxI+7+B8AFWfvTE=
                "]], 
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQPWsmCDAdYICCCYe+asT0M8L5EHnGA9N0IjelnDxk
v6TAluv6YgR/nfvDKpF1CP4OudbXgTsQfLBxhxD8M2CA4F9fDDIQwX8ENM39
IYL/JhBkIoL/DWTcV8YDXcLqfnMsHtpDXMkE53OBDUTwRcAORPDlQc6TQ/A1
QcZpIPjGYIDg24ENZDpwYoKicxvPTXsPkHfdEfwgsIcRfLBxMQh+Ghgg+ODg
K0Dwq8EORPDBzmtF8CHxgeADAK05vHw=
                "]], 
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQBmIQPeHQV42YfkYHBiiYNRMEmOB8iDyTw4kJis5tPDft
W18H7pBrRfCrRda5P6xC8Attua4vLkDw08AAwY/pBxmI4AcBTXsdiOB7PKwC
mojg24GMs0XwTYxBgMmhS1jdb47FQ3tNsIEIvjzYgQg+2HkiCD7YOC4EH+JL
BP+bBshARjj/Dci7rxkdpulEbko5ecj+Ech5DxH8GyDjriP4Z8+AAIJ/GBR8
hxB8sHd3IPhg561D8JeAjFuM4EPiA8EHAEi+rwE=
                "]]}, {
               Polygon[CompressedData["
1:eJxTTMoPSmViYGCQAWIQXWDLdX1xwcf9DFAw4dBXjZj+d3D+DrnW14E73u1n
ZueTsSh4YP+oSmSd+0MEH6Tblus9nG8MBgh+TD/IQAQfZJpcK4IPNAxoIoJ/
DWTcdQQf4ooPcL4IWAOCrwG24MP+9PPzbKu/vbG3AzsIwQ8CewDBTwMDBB/s
nSoEH+J/BH8JOIA+7D8xQdG5jeemPSQ8EPwzYIDgQ8IHwf8GdiCCDwmvj3A+
2Dg5BB8Sfgi+Byh43BF8SHgi+ACd5NBc
                "]]}}]}, {}, {}}, {{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxd3GuMnGX9xvHplG4ViDFS5Q0iJEbREBLRGBKpM4mJqC+IoCYeEBMDygsj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              "]]}, "Charting`Private`Tag#1"]}}, "GCFlag" -> True|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"T33.1\"", TraditionalForm],
  PlotRange->{{-2.96, 2.96}, {0, 0.9050880626223091}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.910156315990061*^9, 3.9101564306546116`*^9}, {
  3.91015646453283*^9, 3.9101564749888444`*^9}, {3.9101622944333315`*^9, 
  3.9101623027820826`*^9}},
 CellLabel->"Out[70]=",ExpressionUUID->"ff7138f1-e83b-4a7f-a2b6-aedae5de7631"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos\>\"", "Input"], 
         StyleBox[",", "Input"], 
         StyleBox[
          RowBox[{"ToString", "@", 
           RowBox[{"StringForm", "[", 
            RowBox[{"\"\<dos_{8,3}-tess_T33.1_``.dat\>\"", ",", "#"}], 
            "]"}]}], "Input"]}], "}"}], "]"}], "]"}], "&"}], "/@", 
    RowBox[{"Association", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<10\>\"", "->", "\"\<10\>\""}], ",", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[\(10\), \(2\)]\)\>\"", "->", 
        "\"\<10^2\>\""}], ",", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[\(10\), \(3\)]\)\>\"", "->", 
        "\"\<10^3\>\""}], ",", 
       RowBox[{
       "\"\<\!\(\*SuperscriptBox[\(10\), \(4\)]\)\>\"", "->", 
        "\"\<10^4\>\""}]}], "}"}], "]"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotLabel", "->", "\"\<T33.1\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.910155735825778*^9, 3.910155791197442*^9}, {
  3.910155864815923*^9, 3.9101559579728274`*^9}, {3.91015599876518*^9, 
  3.9101560324150867`*^9}, {3.910156065669032*^9, 3.91015608123988*^9}, {
  3.9101561179149127`*^9, 3.910156125200875*^9}, {3.910156220339597*^9, 
  3.9101562209536443`*^9}, {3.910161813546974*^9, 3.910161831706744*^9}, {
  3.910162331971196*^9, 3.9101623446344786`*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"146d2cdb-d151-4100-9344-5de2e0530a98"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxdnGmMnlUZhqcriokaLSYkCLjEVE2MChp+UL/GEIuGHxYTJVpNIIBEjYCJ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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxdnHts3WUZxw9jA8VEiQ4TE0W8xExNiIoa/nD+GkMcGv5wmCjRaSIBJGIU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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxdnHmQVVV+xx/SDQnu4GR0agAT1HKZmUJJFKuASxkUEatYUopGcEpxDEpK
MeUWFatHnWioGRYHddxSRpzopLQxw9JNL/De69dv6fV1CwgtskkD2g0C3Y2C
Dua++/38freK/qfrU79zzzn3fM459953z7l/e+/Ds391RiKR+LgskSj9f/qC
yql7Tg5NJvh7ZOKwT1cdifn+0t/+mOcuSw9cviPm2dWjftPTEfPNe566oDIX
86Qwu0X1MY8r/a2J+YpShh/EPPo3PbOq/yvmUvWeWhlzKbuJS2KO/ipiPn55
mOFjMffOCiu4MOZS9abeE3Mpu2FzjK8PWlvCv1uN7wzCs5277AZ45qNB6XRn
jYfnvhyUqnfBL+BrPw7eC7P7dAx8uDZ44/Xw7yL4yY1BqfnmngvXrAlKpzuq
HJ5TFcjHkIgr3s8E8iFOvLcpkA94aF0gH/ADmUA+4BnJQD7I79FkIB9wb2Mg
H6S/NhnIB/G5mUA+4O50IB9wZyqQD47PNQbyQXxaQyAfxB9uCOQDbs0E8gFf
mQ7kg+PXZvEBj0zjIz5f+YAn5fBB+scy+CA+PIsPeHsaH/CULD44fmIjPsrF
Zzbio9zTy0e5p5cP+JUcPsq9PPkgnsoHEyMfcLYBH/DDjfiAf8jiA16awUdc
nnzA9zbgA56Sx0d8vHzAt+TwAb/UiA84mcEH5zM6jw/itzfig/gc8wFf3YgP
0j9gPmKWD7gyhw+413yUiU/k8FHm5y8f8HNZfMAzs/gQJyob8QFvzuEDPmHj
Ax6fxwcc9jf5gOc34oPyrjYf8Lw8PuDrsvjg+Fl5fJR5e8oHPD+HD9InCvgg
Xp7FB/Hn8/iIz0c+SN+Vxwfxx80H8TfNR9y+8kH66QV8DBbnbHyIKx7P4wMO
+5d8wMPz+Bjs/UU+iJ9VwAd8YQ4fg0/zAYf9UT7gIXl8DPbzlQ/ii3L4IH5R
Mz6IX5oLeiIfxK/K42Ow+5cP+FXzEZ9PQ+QDftB8xPWVjzguH3F+8kH5iwr4
GOx+5QMe0YSPM8SHbHyIK4Y04QOebz7gzQV8wGF/lY8zvP3kg/zfyuMD7m/C
B1xr44PjE834OMPrLx/ERzfhAw7Hv3zA05vxAU8q4IP8VhfwAU83H6Qf34QP
4vcV8BHXTz6IX1TARxyXjzg/+SD9ngI+iD9vPgYpnm7CB3x2Mz7EFW814WOQ
+5cP+JoCPuChLfiI4/JBfkErPogvLuCD+GrzQTzsP/JBfEQLPuBrbHzAr5oP
jt/SjA94STM+4rh8xOcrH8QvbsEHvLwJH/C4VnzAj5gP+O0WfJD/nmZ8EF/V
jI+EeFArPuCf2fgQVyxswwe8uBkf8JJWfHB8oRUfxO9uwUecXj7gG1vwwfEr
2vABH27GB+nvaMUHfH0bPuAnWvDB8T9vwwf8ZBs+SH9ZKz7i+skH6c9pxwfx
i9vwAa9vwwf8Qhs+4Lfb8AG/1o6PuH5R/Qd+2FTCyWOKqu8ecan9W6I/+Dvq
Uw3f2q7yV4kTX7cHy6MLoDj5+6J8P0X8l23yez88siifs+AZRd0fT4S3tsvX
5dTvxaL8XABPKMpHAu4s6vrdc0o8rKj2/hS+rajrcxp+qKj2rIR7imq/1095
flF7/UacaCkG0ekuEic/LKp/ziW+skP9cSr8RlH9bxy8oBhEzTeK/N/oUP8a
FrN8/MXzlw/x5Gmd+CC+rQMf4ooXO/BB/Hcd8r8sZvn4i5cnH+LE+Z34IP2m
DnzEcfmA/7ETH3H+8hHXVz6+9/zkQ1wxpgMf8IxOfJD+xU58EL+tAx/iyWM7
8UH8nQ58wCM78UH6X3fgg3h3Jz4ob2cRH/Bd5uM7Hb+gAx/iimEd+IAnmA/S
jzQf8DtFfJD+URsf4uTNRXx85/1FPuD6dnxw/A1FfMBDmb8uIP2d7fiAJ7fj
46TSL2/BBzy7DR/ixMIWfJz08SsfpD+7FR9weP8mH/DJZnxwfHi9lQ/4iSZ8
kD68vssHPITr4TDSH+D5aeCE4vO4H9wD1xbwAT/O/V41HN7vywd8iPu5ZXD4
vCIfcPj8JR/wKJ5fZokTy7L4gLuy+ICvyuIDDp9/5QOeyPN4z7fKf3sGH/DT
DfgQJ15qwAfx8PlRPuDOFD7g8PlVPji+O4kP4j0pfBD/hOffcfDTKXyQ/to0
PohnU/j4hvGcwgf8UAof4sTYFD7gt+vwQforkviAy9JBlN1TpL9pIz7gczbh
4xuvn3wQv6MWH/CKjfiIj5ePmOXjOP2zBh/ws/X4OO71lw94Cb83vR7H5QPe
W48P+O4afMDtdfiAx9XjA95Siw+4vwYf8J4N+BhgvFTjAz65AR/w6g34gBMb
8AHX1eIDnr4BH/CJdfgY8PrLB3zNBnzAo6vxEcflA15XjQ94RA0++sVnVeGj
38uXD3hWNT76vf3lA760Ch9w33p8wKn1+Oj38uUDvrEGH/CotfiAe9fgA15s
Pvo8P/mA51ThA75wHT763Ld89Pn5yQc8qQof8Lz1+IDHV+Ojz/uHfPT5+coH
XL4WH33en+Wjz/urfBzz8uUDfsZ8wLVV+IAfrMbHMT8f+YBfWYePY95/5QM+
VIWPY95f5OOY91/5gCvX4eOY93f5OCpebj6Oelw+jnp/k4+j3n/kA15Yhw84
b+PjqLe/fBz1/iMfR328yAc8xMbHUe8f8hGn13nCl9Xi44j4XfNxxP3JB1yo
x8cRb1/5iFk+4Bfq8HHE5y/5gP9k4+OIt4d8wEPr8AH/pB4f8Cqr/9fig3XU
92s//g9R/eDXbP6EB9VTvrjihiTlEZ9dF/RHvg+7b/kVV5yXxCfxsmTwTNTg
h/185euwXx+i7C6Pj5ePmLdF7X9I6RckaW94YGPwQtS+cItdj+H6TcHfR+0H
z0jSXvCuVLA76mC9fj1T/4RPJXn+EldMSNH/er1+E6IM47j6V69fr+WjR7wh
hQ9xYmUKH3FcPojb7+tT4R/b/QMc3k/Ix1c6floDPr7y9PJBfGwD44n43HQw
Mzph+NsUPkg/Mo0P4jUN+PhS8WEpfHzp+cuHOJFM4wNemsYHPDODD45fk8bH
QfFjvA+phpMZfIgTj6XxQfz9DD6Ih/df8gH32v3hAfFzGXyIK06l8XHA85MP
+GF+X5/K8ddl8EF8bgYf+xU/P40Pcel9gHwQfyCDD+Lh/bF8EG/N4AMelcEH
XNmIj273Ix/iippGfHT7+cpHt5cvH6Tfn8UHPLERH/u8PPnY5+0jH8Sv4v3R
/fu8PPmAc7xPuAA+K4ePL07z8YW3t3wQv8Xuv2H7fX0q6cPnEfkgPr8RH3vd
j3zAvby/WSVOXNiIj73uSz6Iz8vig/h28wG/mcXHHvElvJ+oFJeeV+QDfpz3
OXNJf775IN5lPvac5mO34q+YD7gviw9x6flLPnZ7e8jHbm9/+YDfzFD/XTp+
rdV3l7fH2Kh+u7z9VJ+d3n9V/k7vDypvp5d3MPL9udJ/Yn4/9/4qn+LEB1n8
7VC8NRu8E/na4e0hP+LS+40for/PFD+zMfgoan84lwvuitr7M6/vX0ft+5mf
b1XUnl3u61dR+3X5+BgRtVeXt4f663YfH+qf8IlG+uN2r7/63zbFp2Tpb9u8
v6t/ET+UC7ZGPj71/i0fn3p9rol8fOr9Tz62+nhZGlVwq/eHqHoTt/r5Rdn1
bFH89sYg0vE6vDsXRM03dYvPx9HpDmz2/hZVb5W44plcEGU3a7Ofv3x84vWV
j098PpAP4hfm8BHH5aPTz18+Or18+SD+341BKqpgh7fvw9EJd3j7jox8EN+c
w0fR5zP5gOfn8CFO/JAJPozq3y6uzQV/FdW33cu/L6pfm5eXjOrT6u2h8uFU
Nvj3qLwWHy9bogZt1vFLM8HVkd9m72+/i3w2iUdlg6+iBi94/7sp8gUvywbv
Rn7ySl+ZC05FPnJ+Pf3nqP1z7m991N5ZL3941L5Zb8+HovZsFC/KBU1R+2V8
PF8WtRdcng2ejzpYg/tV/0yLP2pgfkj7eNR8kPLyNP6Tp83HSc//jqj+m3w+
OC+q70Zvj3xUvzpvj4qoPrXi3Y3B+Kj8Gk9/JCqv2vmDyHeVl39v5He9z5c/
jXyu8/ljc+RvjR//28jXn30+mhL5+T+vz7eRj9U+ny+I2vcj70/bovb6X2+P
m6Pz/8Cv39VR//qjzy+XR/1llZf/h8j/O57/eZGft8Sj88G30QTzmnhtJtgd
9acVyu/qXFAR+fhP788VUf94VukThUALmu4Th/fTiR9FHDhHL4SeDSx9UvkF
lp8WXK0IrLyLo/H0WmD1maz6Blbfj3U+gZ3PBJ1v4L7VHoG1xx1qr8Da66Da
M7D2fFLtHVh7l0WBjz3/W+UrMF8r5TMwnzvk28u/RP0hsP7wr+ovgfWXtepP
gfWn79Xf/Pgp6o/Ov1V/Day/blZ/9vr8VP3d09+n8aD8w/Fwu8aLOBwvJzWe
vPy3NN68PfT8rPv+0njcq/EqDsfrf2g8i8PxfKXGu+ffpvlAHM4H/6b5QvmH
88XfaD7x8mo03yh9ON/crflIHM5HZ0QJtc6kNF/9j+YzcTif3aL5ztvjsOZD
b4+XNV8qfThfXqv51M+/S/Otl/+s5mMdH87Hf6f5WhzO11nN5+JwPn9Q8733
53N0PfD+9GddL5Q+vF5cpeuJOLyeLNb1RunD643aD36f9WqjeA+0mfUPizq8
vAZd77w9f6TroZf/L7peKh5eLzfoeqp4eD09U9dbxcPr7Txdj93val2vPT5I
FVE8vJ7/k6733h5/1P2A+/tG9wte/jTdTyge3k+8qfsNcXi/cUj3I+LwfkQ3
wFt1fHi/skL3M4qH9zNf6H5H8fB+5x90P6R4eD/0ou6XvL7bdT/l5y8f23R8
eL8lH9u8fdt1v+bte7Hu53x+kY/tfv7ysd37n3x0eX+Tjy6vj3x0+fnJx2c+
f8jHZz4e5QMO72flY4fPR/IhLt0Py8cOnw/kY4fXXz4+V/rwfls+xKX7cfn4
3MezfOxU+vB+Xj52+niRj51eX/nYJQ6fF+Rjl7eHfOzy89X8sNvnS81Hu728
BXqeEc+3543d3h94HvL+pvlrt8/nPE95e/C8pXiXP48pHj6Pab4jHj6v8Tzn
vnjeU/pLbHzs9f6n+REOnxflR1x6ntTvY3u9PXgeVTx8Hm3V86q3n35vhW09
66gvvD14Hvb+rf5JPHxe1u+TX/h4UX/9wvs7z+OKh8/j6r/7vP3lY5/PB+rP
+zw9vwd4f1D/3ufzmXzs8/Gh/t59mo9uHx/q/91+/ZaPbi9P46Hb+yu/hyhe
04CP/V6efMCjzAfcmsHHfu+/Gj/7vXzNz/vdl3wQPz+NjwPuh9+LFL+O9c+L
Dnh7y8cBbx/5gE+l7feq03wcFPc24AP+pAEfBz0/fi9T/LE0Pg769VQ+Dvp8
LB9fitf473U6fmYGH/DSND7gZBofHD/Wfy8UD0vh4yv3Ix/i0u+N8kH82xQ+
4LlpfHzl+csH8R/b+1Pi0xrw0aP40/Z+tsfTywe8PY0Pcen3WPkgvtJ/z/W4
fPSKH0rhA56Qwgd8nv+e7HH5EJd+b5YPeMVGfBwSh/fT/J4tnpHEB1y/CR9w
SxIf8MBG+z1dvCCJj8NeP/mIWT7Epd/r+T1fvLceH3BZEh/x8fJBfHkNPr4W
z7b3s+LS+wb5ID6oHh/wa/X4gIfW2fsO8cE6ex8iXlVLefBP6mm/I34871vE
C+vsfYz4TzXU54ifr9oXfsHeh8IH7H1pzKovXKin/eEl/r5J/K6eCxKJo/p/
WS39C26vww88p8red4mH2PvJOL36H3xjDf7g8dX0Rzhv76uPenvwvk58aRXX
I/isKvorHL8PdN+8L/S4fMCV6/ABJzbY+0jxOn9fKT5UhY9j3r7yAb+yzt6H
iv39Nfyg+YBrq/ABP7PO3seKJ5mPPv2/uwYffe5PPuDytfY+WJxab++LxXs2
4KPP218+4Hnr8dHn5fO+2s+H99niLbX4gC9ch48+7x+8LxePMB/94sXmA+5d
gw941Fp7X+/9h/f5np989Pv5ygfct97WC3j/YT2B+O06fPT7+ckHfMJ89Ht/
k48BL18+Bry/yAccr5cQj7bxEcflY8DHi3wMePnyAU/39Rziulpb7+H9Vz4G
vL/LB3zS15N4/2W9ifcP+YD7a/Bx3H2znkU8zt4fH/f6y8dx76/ycdznL9bT
ePuz3sb7s3zEcfmAn6239TziJ/idIvGNXx/kI2b5+MavZ6wnEt9Ra+uNNP9f
m8ZHfLx8wDdtxAfpy9K23kl8RdLWQ3n95QMem8LHN369Zr2VeEzK1mMpfTaF
j2+9fvJB3O8n4PD+i/VgSt9j9xfEu5P4IO73f3CnvU+Fl9r9IMe/ZPdTxJ/2
9W5ifx91Qv8nNuADHm7PI/BVvt5O3OXr8cTL7HlVXPr9RD5gf98DP+frAcWH
CrZeUHwd+99a4Mfz+IBrC7YeUTwvb+sVGS/shxklLq1nlA844esh6Z9Ntl5S
fHYzPkh/shkf8EXNth5TfHarrdfU8b9swwe8sAUfpJ/dZutBxcv5HSnxnf5P
bscHfGc7PsSl9aasRxXf4OtVlb6+HR/wgiI+xKX1rvLB8Y8Wbb1sxKX1srrf
hEd2cL9G+gkd+ICH+XpdpV9g66u/V3l3deAD3lnEh7i0Hpj1wjr+176eWPGR
nfiA3+nAB+nH+nplxW/rsPXMKu/FTnwQn9GJD3hMh62XVvpNvp5a+U/rxIe4
tN5aPsSl9dis1xbH67k9P/mI4/JB/m904CPOn/XkzvIhLq03lw/i28xHXF/W
syv+oa2vPuXlyUfM8nHK+wvr6cVv+Hp78coOfJzy/OWDeIuv51f+nb7eX9xT
xAf8UBEf8G2+n0A8zPcbeH7yAU8o4gN+0fcz6Lit7bbfQTyjiA94pI2PH3z8
sp9C5/d7Gx/Ev27Hh7i0H0M+4O/a8QEv9P0eqt+You0HmRzl93PKO1dc2i/C
fhLx277fRPyC70cRr2+z/Srii9tsP4vyP6fd9rsovqTV9sOIL2tVfe8h/ZPM
Twvj+rHfRumfsP1R8PVttl9HfEer/Kzk+MPNtt9HvKLN9gMp/Y0t6n9r4vpp
vzZ8d4vtN9LxhVbbj+Tp2a8kXtwsv/vhsP3Z76Tjf2b70+BBrbZfSryqGR/i
0n4q9lsp/naL7ccSP2L75+BxrbafS7zc93uJL26x/WDK/60m2y+m+JZmfMBL
mvERx9mPpuNfbcYHfI3tn4JHtOCD40c02X44xVc32345xRcX8EE8MB/E4/14
4qEttl/P4+znE79awEd8vuwHVPxs258Gp5tsP6HSP9+ED3FpvyH7ERUf32T7
FcXxfkalv8j3O3qc/ZCK3+f7JT0/9lMqPr2AD3h1AR+kn1Sw/Zri6eYDrrT9
0PDoJnyQ3/O2fzeuH/tJFa/N4QPub8IH/JbvV9XxXba/GA7vj+QD3mw+4Pm+
X1Y8xPfTKv9Dtv95sHiE+Rjs9We/ro5fZPtHiYf+5QN+MK/5czw8Om/7hT3O
fmLxHN9v7PnJBzyJ9WELKf8q2+9P/FLf76z4RTY+iC/K4WOwtx/7qRUf4vut
vb7yAY/P44PjL/T93OKzbD9rfD7yQXx4Hh/wLeYDDu9/2W+u43ONth9dHPZP
+RCX9quzn138Ztb2uyu9vZ/4RZmfr3wQt/dTN5S5X/bbK3151vbjK54wH8Tn
mw/49kbb76/0s/x7AIpfl7XvBYjD/iof8NX+vQEdP9++D1Hm/uWj7DQf8fnw
vQPxZvs+BVxp36+gvJk8z+yHn8va9xa8ffkeg/iEf69B3MvzzrlwpfmA7f3N
mJjlQ1z6XoR8lHt/kY9yb0++R6F42B/lg7j9Xn8P/FKjfe9CfIvtL4eX8jxY
AU/J6/fkJfC9PB+uLPfz53scfjzf6xD/kLXveYjD51f5gLMN9j0QccrmK85n
e9q+J+LlyQc80b9HovRTsva9EsXPtPExxNPLxxBPz/dQvDy+lyIebj44/rEM
PohPMh/wA/Z9ENKP9O+5iNfyfvEe0l+Ztu/BiFsz9r0Y8cP2/RKOn9aAD+I5
3hevJN6Zsu/ViLvT9j0b8dyMfe9Gx1/r38NRvNfGB/xo0r6no/Qzkva9HT9f
+YCH1tn3esTvbbLv+Si/9zP2vR/F51ThA65ZY98LEj+50b4nJD5ca98bov4f
4wOe+zI+4JmP2veMxIk78WF8PT6M/XtJznxPyVk+YpaPmOUjZr7n5Mz3npzl
I2a+F+XM96Sc+d6Us3zELB8x8z0rZ7535fz/GtCG9A==
          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxVnAmQXlWVx7+vv6UxIDISsCYwbIqAjsJAGCggnosTSXScyFKODIulGQjo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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"T33.1\"", TraditionalForm], 
     PlotRange -> {{-2.9975, 2.9975}, {0, 0.4296875}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"10\"", "\"\\!\\(\\*SuperscriptBox[\\(10\\), \\(2\\)]\\)\"", 
       "\"\\!\\(\\*SuperscriptBox[\\(10\\), \\(3\\)]\\)\"", 
       "\"\\!\\(\\*SuperscriptBox[\\(10\\), \\(4\\)]\\)\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.910155931719056*^9, 3.910155959748472*^9}, {
   3.9101560003186345`*^9, 3.9101560154468517`*^9}, 3.9101560698861113`*^9, 
   3.910156121791444*^9, 3.9101562223461304`*^9, {3.9101623250377045`*^9, 
   3.910162345405427*^9}},
 CellLabel->"Out[73]=",ExpressionUUID->"d6736b00-294f-4655-aac4-17e863abe7e3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison of different sequences", "Subsection",
 CellChangeTimes->{{3.910156507967055*^9, 
  3.9101565164501762`*^9}},ExpressionUUID->"80185b0e-ff22-4cb5-a965-\
dd73fec4c933"],

Cell["\<\
We can also consider alternative sequences of supercells to verify \
independence of the limit on the particular choice of (valid) sequence.\
\>", "Text",
 CellChangeTimes->{{3.9101565178095937`*^9, 
  3.9101565432959876`*^9}},ExpressionUUID->"87f2b983-e1bf-4213-99c2-\
d4489859c498"],

Cell[CellGroupData[{

Cell["Alternative sequence 1", "Subsubsection",
 CellChangeTimes->{{3.9101565749255075`*^9, 
  3.910156579265273*^9}},ExpressionUUID->"f8209134-808f-4b0f-bdb4-\
6928aa33cc08"],

Cell["The first alternative sequence is:", "Text",
 CellChangeTimes->{{3.910156660637101*^9, 
  3.9101566672747507`*^9}},ExpressionUUID->"25bf66c2-579b-4808-a98f-\
33a8eaec8b83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<T5.1\>\"", ",", "\"\<T17.2\>\"", ",", "\"\<T65.1\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
  3.910156608462936*^9, 3.9101566170742188`*^9}, {3.91016236757955*^9, 
  3.9101623813994083`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"951767d9-5381-44c4-997f-22260b82b591"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{8,3}-tess_T2.1_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
  3.9091142248348513`*^9, 3.909114238346472*^9}, {3.9101623889941044`*^9, 
  3.9101623922496796`*^9}, {3.9101625063671646`*^9, 3.910162506634941*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"332f41d1-15d4-4e3d-b6dd-5203270587fa"],

Cell[TextData[{
 "The Abelian Bloch Hamiltonians can be constructed as shown above and we \
directly jump to the results (we have already constructed the Bloch \
Hamiltonian for the same supercells except for the last one, which is too big \
to handle interactively):, which are stored as ",
 StyleBox["data/dos/dos_{8,3}-tess_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9101647807219453`*^9, 3.910164821953132*^9}, {
  3.910165023308471*^9, 
  3.9101650431942453`*^9}},ExpressionUUID->"0ca4682f-bd47-4246-b420-\
11eba0529119"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{8,3}-tess_``.dat\>\"", ",", "#"}], "]"}]}], 
            "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.1\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(7\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.910157103833946*^9, {3.910162542930744*^9, 3.9101625511855717`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"c5aeea6f-e37b-4ccd-872e-ff146d28331f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJw9nHd4lUXTxk9OzjmhCFICShGQJqB0RHwFZ+kIKEWE0FR6kd57R6UJIgiI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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJw9nHd41FXThpPdzS7SDU1fpEtHpEufA1IMIopIFUEgNEEBAQUpAtKLVGkK
0jsYWgIkMCd1UyEJCQQSShISIAmQ3su3/Gbmyz/vlYvXzdlznzJn5nmmyeQ5
X081OTk5eVicnN7+75LaFwYnFtu0E//M61P5/tFMm/7mWc1589ts6Dvt7U+q
Tffc/v2ZfVcD+o7f6pfXKsGm81Z9OT+7aXLfr681XJMeZdPmD/erdzcV9v0s
8bfaF+w2Xe/gno1bFleDvo6Pm3vTpufPLPVr69YQOr/9uWzTo9+pu64ztoHW
bz/wlE3X+PTszs61P4FGa9KHXzto045/3G+2fApvh/fbLpt27bRt+p45X8Db
j+uz0aaxTb02FeNGgTHoFTa98+eCHn3HfQ/5rRwfuNCmq6/teW5u2HTIGO4Y
4CybbrH1ZIrtwlx4O7zBk2x69eS2M8ZN/hXeflzl0TadWOnr1r90WQER4Y6f
oTY9IefM7R9WrgXHtx2/tb9Nlw6P2bfks63w9usO727Tq3p7L033/wveDq92
e5teefWH+6u7HIRjjo+738ymuzYfu+7o2WOwf5/j532bnrrlt/WDvM7C2+kb
X8Omw736nvuk8iV4+3Ubuti0yXt/76mxnkA8rDpqZ6fTh6v5APGw6mED22z+
KEAD8bBq52Pd5v08xx+Ih1Wv3ZZTDq8DgXhYdVmR5/enGwYD8bDqX/PadOr5
NIR5WHXKlF9X7nANYx5Wndltzj+1d4cxD6uu/8ewSg3cw5iHVbcdnr/7559C
mYdV988YejjnRjDzsOr7M48dz54WxDysela14/lNN/ozD6u+NbR2k4XfauZh
1Wqo35re/W8wD6uOVTk9fv37CvOw6t51448d2e7BPKz6kL3VHZ9/zjMPx+8n
nf84tvU/5mHV/70zc0u/6ZeZh1XHd/7cFNPlOvOw6oOLe2Tc6qyZh1W7nmi1
J6hRAPNwfJ7vidtHk+zMw6oLUj8Z2qVVGPNw0Um7rhcNOhbBPFx0x5Yzdvrb
7jAPFz1jt+XU6YF3mIeLXry45+hdX99mHi56bWNb83D3cObholt5vVoSgyHQ
x+Dhok3TW48d5hfEPFz0nBmhw+CFP/Nw0QP/GXYp9i9f5uGivdt8tcm3lmYe
Ltr94hdt/pd+i3m46P7Lwv5pPwuZh4ue5f3OrZlnNPNw0Z2Lpv1dv7Mf83DR
f32045ejjvkgHi569hLv5j1UEPNw0XE3YiqVzQ5mHi7649KnS9PGhDIPF93u
fvy0NrlhzMNFFyZtyl/kHME8XPTFxJd/XZodwTxc9J7Q+HeHtY1gHi6614Lf
Hm/pGs48XPS88/ke9UJDmYeLHmxJfhrdJIR5WHTQpjVNft5vZx4WnT+5VcuH
C4OYh0VXK+lzcVhgIPOw6DvDrINDNsn+sOi4+44vdDOQeVh0xPmao6a0DmIe
Fv3uuTN7nlwXHha97PajC3sG2ZmHRU8dHjcw6rKdeVh0aFeXTr3S7czDohNi
zwa/eGpnHha9udbEV60O2pmHRcP/hu37u5GdeVi068Of2wc6xk88LHrn9sse
J88HMg+LXt2m65JDsQHMw6LrzroW3KfMn3lY9Nkl7vNj2/kzD4vOa/94a/xW
P+Zh0e9VMrm/eM+PeVj0sWexPazPfJmHRX/dzuvK/5J8mYdFL6n3xv6qpR/z
sOjhJecPtDrtxzwsusA6ce/Qkf7Mw6yL8j6d7dEhgHmY9fE8L8vTjwOZh1nv
SOuFrfoFMQ+z7j6sck7D0XbmYdb7L87o2WusnFdmfWd99OOnvWR/mPWNdavf
lD0KYR5m7Vc7JbpwYCjzMGsd/mtmrdGhzMOs3Y6aWsY3lvPKrFuufeaedCKE
eZi1d+XWcNoawjzMurdveXqCezDzMOtOIcFj45LtkG7wMOv+v7r9U8fXzjzM
etiyxouf1wxmHmZdpVrApX3Jsj/MOn7OqwFu3UPB3+Bh1keaOy6g57I/zPp0
14heww7L/jDr0Pc39npsucM8zHpfnmNBn7nDPMz6mP+n78F3d5iHWbfFqkHr
LbeZh1lnbLhQBeLkvDLpzd79rowaEMI8TLplx0rnPkiT/WHSXzbOqH12kOwP
k15uajVo97kA5mHSGy0jIs51lf1h0gH9z898fFH2h0k7F7m26X4umHmY9O4l
K8ceviY8TLqRborLZ4QzD5P++OtWVSZujWAeJr1t3S3vv5rfZh4m3aXjd+tj
P77NPEw64bMHTWfaI5iHSX+w27r8G3ME8zDpoDr1BqdYw5mHSd/64vf8Znmh
zMOke3i9UxCaEcI8TNrD4+lyXSuEeTh+PxsyYtT8YObh+P6p577s0SKYeZi0
q9/RLc26BTMPk765efL148eDmYdJfzShXdXt80OYh0l/f/5h1yZb5Lwy6QvV
6iSXnhcezrr+vW/qrtkSzjyc9YNJQ4uXvAxnHs56hjVrZYN/w5mHs77W75XX
L5fCmIeznj61ZJtX71Dm4awPzBjdJGVdMPNw1q5F7Y+3fyDnlbNeCaWlBXMD
mYeznu+9p+TZogDm4az/23Oi0tzKAczDWQ/9ZEO/7+sEMA9nfXGW4wLYF8A8
nPXDUZdvF/4UyDyc9czyvfdOrAxiHs76lWvst+azsj+ctXPpiDMDQmR/OOtn
7d/uWOHhrCesrVhgPi77w1lvfD7b+XBX2R/OOlXVuPrj+jDm4ayTHNdH1cNh
zMNZfzw7YtSEVWHMw1lfONDqnQ1dwpiHsx58dlz08MfCw1l3mFL5Xve/Q5mH
k77oWA7m+aHMw0mHV5pTo/+2UObhpI9ENQi4nRvKPJz04IjRIfYLwsNJb5q7
c/jUU3KfO+lr6cdbmxIimIeT9uj587HOje8wDyfd/3L6440fRjIPJz3hwBSV
vzGSeTjp48W3Px7iEck8nPSuR+EvBu+MZB6O8f3+GS7rE8k8nPSovytGN9hw
h3k46ciVKZXeP3WbeTjpFTdWmt7Uvs08nHS37fuqjK9+m3k46dnNDmZM232b
eTjp4rbuF6puvMM8nLS5uUtdPTSSeTjpRXs2FQ7ziWQeTvq/KtD9X1MU83DS
U5buvTm7fhTzcNKvI+bsnVEpink46fii5T/4PItkHk66otndw3e9I2n8eRWY
39ruPm9PJI03sQLXTNI7zq6PhHDjpwIXvYpe67+Kx3OtAs8s69mw87ZI+vtH
K3DvuqFFNf+JhG3GBViBo/eMME0+Ekm8f6vAywOjf8o9HEl8p1Vg7nsp+/Yc
jSSewyuw5sJGK2IORlJ83KcCm3v0sN05xrxaVeBiyydfe55iPrUrMOk52v67
yjycKtBxmlon3Y6k+zu9HJsVPhnyS0Ykzff9cvTt7R66zjEfxvD8yvGSt3Jb
WSeK5vNCOQ5cdXraPVeev33l6Bnfvsv9Ip6vNeWY3PkBfHk3EoyvO7ccX06+
O6TJ3khan+PLsUrVsY/SxkbSehxcjv9u7ZRkahxJ669zOYYPel5a+/kdMKav
YTluz975w7+37tD6qlyObQOaZWXH8HrKK8O2Tzq7Hn5XeJTh0qyBS3zGCI8y
jAibVNDgrPAow8e9Y5t8kiM8ytDt3fdHZbVg/lvL8Pz77z9r3zOKeZRh1O2Z
dWc0imIeZRiYfGTcgGfCowwXTZrlmb1DeJRhudvS15ZPhUcZHqs/afi7NYRH
GVZEhu+cZRIeZVjSK/7oJ+2ERynurZvn9nq98ChFj6RvZk2yCo9SnPxo0a/u
/wiPUlw2vn6boNbRzKMUty9tvs11UzTzKMXvR+88ee5ENPMoxfmFx2q9szya
eZSi4ygvbtEgmnmUYp0FS9ymnItiHo7fR7U5dWpIFPNwjA/7p4a+F8U8SvHO
mu0TYtpHMY8SPNWt+7tlq6KYRwm6Hlnar8o70cyjBFd4xp7rvDaaeZSgEX9e
i2YeJfjiYb3IKtOjmUcJxuxPbXAyTniU4IgLme3rtRYeJXgYI5sNmiM8SrBv
ZOWqY5fdYR4leO3ig+1p395mHiWY+iJryd/L+X6vXYJey4vv7K8IZx4lWDFx
4bPP7OHMoxidhztOZM9w5lGMPo5w5cr1cOZRjCMLO/uMvRzOPIrRdL9OZ78l
4cyjGIdU2TMyrjSMeRRjRsKV90/2C2Mejt+7RH+9+HM+v8cX47iCrWtefBXC
PIoxc22XNnMnc/zSuRh/8X26v9cZO/Nw/PcdWpTd7MLxe+VijP1vQd/eVThe
zyvC+Mc/uVVvxfddYhG++8GeeSPm25lHEf41KaHakRQ78yjC0QO+yC2awfHE
0SK833Vc9dynwcyjCLfVarF52kB+3/xWhMu3fNjv2o4Q5lGE5ojnCa/OhDCP
Ipy73H/AH7v4Pd/HMZ4RPw/LGB7CPIpw383ZvX58FMw8inD9w26bV6lg5lGE
iVV2nl610s48CrH3l72nVznF7737heg9Kf5IeFAg8yjEb3q3PzMwN4B5FCLm
5j8/0jGAeRRimro34uxWf+ZRiP3VrdWVq/szj0K81yuhejVvP+ZRiEFFf3+1
foUf8yjEWTWWHF7xnR/zKEQj/eTmxzwKcevWutOrOt6rxKMQu+5dm9isqR/z
KMA3Y2bv3Gj1Yx4FWP1Wh31t4nyZRwFWm3duU/wpX+ZRgDVvn/xz5A/8/jla
gD9uPpDp2s6XeRRg1A773exkDcbH/VaAO8IcF/ABzr9MK8B5Y9dEOI3WzKMA
ezZ9cjymjmYeBWjEW6eQeRTggoxDrvc7IvMowJLFI7ZX9r/FPAqwRs3wqOTR
t5hHPh5+sHDOQNMt5pGP+1ZMbObmcZN55OMfieP9q/54k3nk48iT5rFffnST
eeRj93Wzrq4r82Ee+XhkUse0cfE+zCMffS5M9Kjv6cM88tGvGNYV7fBhHvk4
fWDMgH/n+DCPfOzx6Tz73+N9mEc+lnU8/8WUXj7MIx933ar58+NGPswjD/93
wjOmX7k388jD8T2WTL8S68088nD/xAjnVfu8mUce7hjXat8/47yZRx4edIRz
V6p5M488PL3xdG6tCzeYRx5OcVx/2z6/wTzysG+TXnOm3L3OPPKw6Yi+lpGf
XmceeRjz+73SwrPXmEcexsU1P+NlvcY88rC0bLKn+0gv5pGHyxtVdz3yjyfz
yMWvuqVUfhN9lXnkYkjvbJu5xlXmkYtBp2a9WjbkCvPIxScnoGT7qsvMIxcT
HNf5zADO963Jxe7Gg/US88jFK7vatTy84CLzyMWr3afsrZXrwTxy0XhvbvNg
Hrn47XfD3lnv5sE8cnHi5fHderb0YB652GjIlWdZXTyYRw4emh1a5/FUD+aR
g/8G7zw2K8iDeeSgU+q4K05fXGQeObhr9sIezZ0uMY8c9LhQOWZy5CXmkYNB
wxa9M+zmZeaRg80S3L95P+gK88jBjDp1E2rEXWUejn9/+Odp72xP5pGDwybX
HNOjtvDIwYCJO7umNbnOPHLQc83z45Ob3WAeOZi2Y95m9xrezCMbnbs17j/+
gTfzyEbP1UsjLy/2YR7ZWDjy+ldFBT7MIxvTbAu39+8h+yMbN68r+GDMsJvM
Ixsdr+Nx7r1uMo9s7F1r/4e7c2V/ZOOj/Qu+bfqr7I9sbPio0qaNcd7MIxs3
ba7+mV9Db+aRjYenPoK6/W8wj2xctG/S0XMTrzOPLMxdN+3g+PnXmEcWris7
OObkRi/mkYWeK3t9ddLHk3lkYb+PE653cPVkHln4kafbwClbrjKPLDx96Eja
6J5XmUcWtgi0t3RveZV5ZOFPiYtPx40RHln4+WiPLYsc65l4ZOGM//o2LP7T
k3lkYeWhJxfW3+XFPLKwwz+z9h6OusY8svDwranD9gy8wTwyMTBlkcuR58Ij
Exc2rFPx6zE5rzKxz/60kNIpyDwycfC2IRePbud87L5MfL9J74fdJ/syj0x8
PK6Ff9YHfswjE493CvzAcl7uj0zs3mlrqW9Nf+aRiQe/u5U3qY8/83D8u+8n
X/z7kT/zyMT+6YlhAxLl/sjEfm8TTt9y/jP9DX75S+ejjbb48njf4C9fT9z9
y34Ne43xvcEdkbvntx6GPJ43+PHcxefe33eT//4b9J48aNGSDnI+vuH41xty
Dd6vcUBAxGn3FTeY72tc0NwUC5/dYJ6vsSAt+fCbn27AUmPCX+PG7c3nt3tz
g3m9xkNdoTz6iDcYH9fqNUZd/GPI+HU+zOM1rnIsl977b0KcMf+vcMNeV7fc
S7d4vl/h+ZOjJn4Xi7DamN9XWGVQ84Wm3zTP5yucsm/5hkUlGroY8/cKT/zu
1mbEbF+er1f4qsau+PwIX3hqLLAMTD1/o3psbc4vXsvAKgO+DD02yI/fXxm4
bOHIQ3Wn+PH6y8AfR7o+sI31g97GBzr++28b3as/0I/XVwbO+/bbRRMqC490
7JbW5H+PfIVHOl6vt7fORndf5pGOvZ58uWVPuWYe6fjd/zBzyA7NPNKx5efn
C+p/pJlHOqbuWrF39VlkHmnYtkvNsGntkXmk4YmY5snvvYPMIw1DS7rvb/Y5
8n5Kw4orww9Ut2j4yvjCaThy2JIht09r5pGGhV8dab51jy/zSEPTg/RHjdCP
ebzEjwas09udJH56iS+K7g5aOCSQebzEbauX9dqwiPOj419iNf/BAbtm2JnH
S8QBPgvLyyQefYklKvv24XbBzOMFlu/rt/T7+xJvvsCToQWbB1SyM48X2Hz7
sm1TfTkfO+0F2n9f2VjVDWAeL/DGmgsDDrURHi+wz/UTalpLrtekP8f9t4dZ
B2+Q8/U5tvusc90vBl9nHs+xQ2z4uMovPJnHc4xo3Ncj+d+rzOM5vv246fOu
Mo/neL/T+38+n+/JPFJx7Nru9wJ/vMY8UnH/soZHe9eSeCAVKz9qPm/UgFvM
IxVvfPmnaUCU8Eil/TjTj3mkYjVnfXH6E3/mkYrRp3RIt8aBzCMFe9+6OSuy
XhDzSMFj85dvTNZBzCMFR9xZ9dXjlnbmkYJ11x/c5fad8EhB51vxPvN+Fh4p
eHKCV6XNU+3M4xke6z64QYPRwuMZjnJfoFwHCY9nGPjiumPG7czjGZaYUzyX
fWlnHs/QHht84cpsrifUfoZHx/w0s+suideT8cfecZO90M48kvGMT4PEK5l2
5pGM3czjt31UP5h5JOO9BX2iFvbj/PrgZLx0I3Z+9LfBzCMZ/VeVONeYHcw8
krDYsTx7fh/MPJJw2xfZzZYPlPdLEnZf81flNv8LZh5J+LS240EbZ2ceSVhl
Qm6dYxvszCMJ/6rqNDKhFdc/nJKwJLU8bR4GMY9E/LDaT7OqTBQeiRi76GWL
jpWERyKu/PTU15ftnK8en4jttx0q7HgikHkkoku9tj90OBDIPBLxwLvHb/p6
BTKPp2j/46NfShICmcdTPK5NezvVDGIeT/F21/DIRV9zfnzaUxx36FGTwG1B
zOMp5pztoTrYg5jHU3yw23l66yIZ/xOMn9XvzZYmdh7vEzyNEyb59rFDB2N8
T7BibE7yx31kfTzG1Mu9a7xuL+vhMQY655aUVxP+j/Gl276YyNQgeGHwfoQZ
9TLW/ugdxHwf4eQ/1uzssjWIeT7CtmvPmhv/FMT8EvDb3f+FZTrm85DBKwFH
1di7bujYIOaTgH2jFibapgdBhfETj7P+/dNedXUQnDfmPx7fa3ryv+dng+Bb
Y77jsVb1m4H+8UHwjjG/8ejmHWVfWtMOXsZ8PsQhk92ul/S2w1Rj/h7iitZm
2xV3O9Qy5ush1hnjNMK6XNbrA3xj3vYwwLE+aH0+wBYVO3HJOnl/P6D31a/y
no7DU6bXi8u/sfN6i8PHC8KqZzWS9RWHo9MDUhalBME9g8d9/KHrh68vHpP1
cx+T5w3/qOm4IOhk8LiPAwfZPpxUI4h53MMmDTfsOXk3EP40BngPF0Q2/+C3
s4GUz+1zDwdsmv28ZF8g5VfTYzGw+++1Kh8OBAPHvli8VH3w6Je3AsGYvsGx
lI/MDQTj6+bF4OUMt+/ntw8CY3hHYzDL55vZ4bOCwPi44TE4Kq7q3H67hcdd
TNpW7dimA8LjLg4e803Ay9XC4y62mxw3aWhP4XEXd7/cs97L8feJRzReOBwz
YUD9QOYRjetOjg7t9E0A84jGv7fO+jRwvT/4GgOMwg6f9+q6J8wP5hhfOApV
aWnB065+0MDgEYV/dPBacv2NvKcjsd6hH7umZ/gyj0hc7TrtYflAOX8jcYIj
HLuZ5QfnjPHfwYx1cd8nPvOHSsZ472DgmBMTm5YHgLsxvtvYu87cOzmO81gb
44nARVnLE5a/Y+e/H4FjO3cK/u6YHRYbfy8cay9q+W/DMDvEGhMahtO+aJdZ
Z5kdOhp8w7BZe6ct0bFBsMXgGYqDLiZE//AiENKMCQ9Bv45hBy35ATDI4BWC
a17v6N7WFABHDD7BeNe17dHtH/tDucHDju28v58bccAPxhnzb0enhWaXx25+
4GnMdxDGVOkbEfK5H7ga8xuEm5L12ZQ//eAnYz4Dse/e2o3+bewPocb8BWCF
9VWsPdkfWhjzFUDxkn8A/GEsMH9s/enIocdRzi8/PPBR4ysNL8h55Ic7k5Jr
Xdop570vPh7z1Xu73OT81phumjAtLjiY97tG/8x3OzZ3DYExxvgRE5f8/kd+
5RCoaYz3Fr43wS17/J1gCDbG54Pt6x/IGTE+GFYY4/HGxllt7831tUN34+/f
wNd7vhxVtZ4dMo2/dw37T/rqRJR7EJwyeHvhqW82XPKKCYTJBl9P/HfbAa+L
MwPhA4PnVZzgfSXRo0sgxBj8LmPdeoNTWjjioc0Gr0uY9telqvPOBcIAg89F
9OvUbcFlx3lWaPD4Dye4Th8Y4zgPZhjzex7v5Lo6QthgiDPm6ww23nvU/uZm
CHxmfP9TuLvvgn7LSkLhmrG+jmNQYvh/qU7h0MpYL0fRfq/z6iknwmGvwf8Q
VtZwfMiVcKhp8PkHl3otTj72NAwKjQNmDw557bEhvDQEnhrraTvu+qq4f3BI
EKwweGzAnSN6+ce08IMVxvpYjg8GTGs/t8gLnIz1644NxhZN7TDoMDjVMX6H
///dKAgtB/n/a/o8kM9zMh4E20H+XmNjP+0BGY+i8YKM14O+D8j36U3fF+T7
BtN8gMzHGJovkPl6QfMJMp+LaL5B5tti3OceIDyGEi8QXruIJwjPBOINwvtD
Wg8g62E2rReQ9XKF1hPIeiql9Qay3gbQegRZj5tpvYKs1xhazyDr+QNa7yDr
3Z32A8h+GEX7BWS/FNN+AtlP/9B+A9lv9H72A9mPSbRfQfbrWtrPIPu5De13
kP1+m84DkPPgZzovQM6LunSegJwnN+i8ATlvJtB5BHIemQwewSDn1Qk6z0DO
syF03oGcd6/pPAQ5D3fQeQlyXnaj8xTkPH1I5y3IebuczmOQ87gpndcg53UQ
necg5/kPdN6DnPfV6T4AuQ8u0X0Bcl+0pfsE5D5ZRvcNyH1D8xcJch81ovsK
5L6aR/cZyH3mT/cdyH1Xh+5DkPtwOt2XIPfldbpPQe7TKnTfgty339F9DHIf
/0f3Nch97WzwiAG5z0fQfQ9y3x+neAAkHiigeAEkXnCjeAIknvib4g2QeOMV
xSMg8QgFwPdA4pXtFM+AxDPJFO+AxDtdKR4CiYfWUbwEEi89oHgKJJ4iHnEg
8RbxiAOJx+5QvAYSrzWmeA4kniMeD0DiPeLxACQeJB4PQeJF4vEQJJ4kHg9B
4k3iEQ8SjxKPeJB4lXjEg8SzxCMBJN4lHgkg8TDxSACJl4lHAkg8TTwegcTb
xOMRSDxOPB6BxOvE4zFIPE88HoPE+8TjMch7gHg8AXkvEI8nIO8J4vEE5L1B
58NTkPcInUdPQd4rM+g9A/Ke4fcOyHuH30Mg7yE6v56CvJf4PQXynuL3Fsh7
i99jIO8xOu8SQd5r/J4Dec/xew/kvUc8kkDeg3Q+JoG8F4lPEsh7kvJjSSDv
TX6PgrxHI+i9CvJepXxrEsh7ls6HZJD3Lr+HQd7DtD6TQd7LlJ9MBnlP03pN
Bnlv83sc5D1O6/cZyHudeDwDec/Ten4G8t7nfABIPoDW9zOQfAHxeAaST6D1
ngKSb+B8BEg+gtZ/Cki+gnikgOQzaD+kgOQ7OB8Ckg8hHqkg+RLikQqSTyEe
qSD5FuKRCpKPof2TCpKvofM5FSSfQzxSQfI9xOM5SD6I80Ug+SLi8Rwkn0Q8
noPkm4jHc5B8FOerQPJVxOMFSD6LeLwAyXcRjxcg+TDOl4Hky4jHC5B8GvF4
AZJvIx4vQfJxnK8DydcRj5cg+Tzi8RIk30c8XoLkAzlfCJIvJB5pIPlE4pEG
km8kHmkg+UjikQaSryQeaSD5TOKRBpLvJB5pIPlQ4pEOki/lfCpIPpV4pIPk
W4lHOkg+lnikg+RrOZ8Lks8lHhkg+V7ikQGSDyYeGSD5Ys4ng+STiUcGSL6Z
eDj+e85HE49XIPlqzmeD5LOJxyuQfDfxeAWSDycer0Dy5ZxPB8mnE4/XIPl2
4vEaJB9PPF6D5Os5nw+Szycer0Hy/cTjNUg9gHi8BqkXEI83IPUErjeA1BuI
xxuQegTxeANSryAeb0DqGVzvAKl3cD0EpB5Cfy8TpF5C85cJUk/hegtIvYXr
MSD1GBpPJki9huY3E6Sew/UekHoP14NA6kE03kyQehHNfyZIPYnrTSD1Jq5H
gdSjaH1lgdSriE8WSD2L610g9S6uh4HUw2j9ZYHUy4hfFkg9jdZjFki9jetx
IPU4rteB1OvoPsoCqefRes0CqfdxPRCkHsj1QpB6IfHIBqknEo9skHoj1yNB
6pFcrwSpVxKPbJB6JvHIBql3cj0UpB7K9VKQeinxyAappxKPbJB6K9djQeqx
XK8FqdcSjxyQei7xyAGp93I9GKQezPVikHox8cgBqScTD8e/c72ZeOSA1KO5
Xg1Sr+Z6Nkg9m3jkgNS7iUcOSD2c6+Ug9XKup4PU04lHLki9nXjkgtTjuV4P
Uq/nej5IPZ945ILU+4lHLogegPUCIHoB1hOA6AmIRy6I3oB45ILoEVivAKJX
YD0DiJ6BeOSB6B2IRx6IHoL1EiB6CdZTgOgpiEceiN6CeOSB6DGIRx6IXoP1
HCB6DtZ7gOg9iEceiB6EeOSB6EVYTwKiJ2G9CYjehHjkg+hRiEc+iF6F9Swg
ehbWu4DoXYhHPogehnjkg+hlWE8DoqdhvQ2I3oZ45IPocYhHPoheh/U8IHoe
1vuA6H2IRwGIHoh4FIDohVhPBKInYr0RiN6IeBSA6JGIRwGIXol4FIDomVjv
BKJ3Yj0UiB6KeBSA6KWIRwGInor1ViB6K9ZjgeixiEchiF6LeBSC6LlY7wWi
92I9GIgejHgUgujFiEchiJ6M9WYgejPWo4Ho0YhHIYhejXgUgujZWO8Gondj
PRyIHo54FIHo5YhHEYiejvV2IHo71uOB6PGIRxGIXo94FIHo+YhHEYjej/WA
IHpA1guC6AWJRxGInpB4FIHoDVmPCKJHZL0iiF6ReBSD6BmJRzGI3pH1kCB6
SNZLgugliYfjv2c9JfFw/M56S9ZjgugxWa8JotckHsUgek7iUQyi92Q9KIge
lPWiIHpR4lECoiclHiUgelPWo4LoUVmvCqJXJR4lIHpW4lEConclHiUgeljW
y4LoZSneLAHR01K8VgKityUeJSB6XNbrguh1Wc8LouclHqUgel/iUQqiB2a9
MIhemPXEIHpi4lEKojcmHqUgemTWK4PolVnPDKJnJh6lIHpn4lEKoodmvTSI
Xpr11CB6auJRBqK3Jh5lIHps1muD6LVZzw2i5yYeZSB6b+JRBqIHJx5lIHpx
1pOD6MmJRxmI3px4lIHo0YlHGYhenfXsIHp21ruD6N2JRzmIHp54lIPo5VlP
D6KnZ709iN6eeJSD6PGJRzmIXp/1/CB6ftb7g+j9iUc5iB+AeJSD+AXYTwDi
J2C/AYjfgHhUgPgRiEcFiF+B/Qwgfgb2O4D4HYhHBYgfgnhUgPgl2E8B4qdg
vwWI34J4VID4MYhHBYhfg3hUgPg52O8B4vdgP4gSP8g28oso8Yuwn0SJn4T9
Jkr8JuxHUeJHYb+KEr8K+1mU+FnY76LE78J+GCV+mCTyyyjxy5Af00mJn4b9
Nkr8NuzHUeLHYb+OEr9OHfLzKPHzsN9Hid+H/UBK/EBdyC+kxC9Efm0nJX4i
9hsp8RuxH0mJH4n9Skr8StPJz6TEz8R+JyV+J/ZDKfFDsV9KiV+KeDgr8VOx
30qJ34r9WEr8WOzXUuLXYj+XEj8X+72U+L3YD6bED8Z+MSV+MeLhrMRPRjyc
lfjN2I+mxI/GfjUlfjX2synxsxEPZyV+N/bDKfHDsV9OiV+OeDgr8dMRD2cl
fjv24ynx47FfT4lfj/18Svx8xMNZid+P/YBK/IDsF1TiF2Q/oRI/IfEwKfEb
sh9RiR+R/YpK/IrEw6TEz8h+RyV+R/ZDKvFDsl9SiV+S/ZRK/JTEw6TEb0k8
TEr8mOzXVOLXZD+nEj8n8TAp8XsSD5MSPyj7RZX4RdlPqsRPSjxMSvymxMOk
xI/KflUlflX2syrxsxIPx/dnvyvxMCnxw7JfVolflv20Svy07LdV4rclHmYl
flz26yrx67KfV4mfl3iYlfh9r5MfWIkfmP3CSvzC7CdW4idmv7ESvzHxMCvx
IxMPsxK/MvuZlfiZ2e+sxO9MPMxK/NDEw6zEL81+aiV+avZbK/FbEw+zEj82
8TAr8Wuzn1uJn5v93kr83sTDrMQPTjzMSvzi7CdX4idnv7kSvznxsCjxoxMP
ixK/OvvZlfjZ2e+uxO9OPCxK/PDEw6LEL088LEr89Oy3V+K3Zz++Ej8+8bAo
8euzn1+Jn5/9/kr8/sTDoqQfAPGwKOkXQDwsSvoJcL8BJf0GuB+Bkn4ExMOi
pF8B8bAo6WfA/Q6U9DvgfghK+iEQD4uSfgnEw6KknwL3W1DSb4H7MSjpx0A8
XJT0ayAeLkr6OXC/ByX9HrgfhJJ+EMTDRUm/COLhoqSfBPFwUdJvgvtRKOlH
QTxclPSrIB4uSvpZcL8LJf0uuB+Gkn4YxMNFSb8MI5+80UVJPw3i4aKk3wb3
41DSj4P7dSjp10H+Xxcl/TyIh4uSfh/cD0RJPxDuF6KkXwjxcFHST4R4uCjp
N8L9SJT0I+F+JUr6lRAPq5J+JsTDqqTfCfdDUdIPhfulKOmXQjysSvqpEA+r
kn4rxMPxedyPhfu1KOnXQjysSvq5EA+rkn4v3A9GST8Y7hejpF8M8bAq6SdD
PKxK+s0QD6uSfjTcr0ZJvxruZ6Oknw3xsCrpd8P9cJT0w+F+OUr65XA/HSX9
dIiHVUm/HeJhVdKPh/v1KOnXw/18lPTzIR42Jf1+iIdNST8g7hekpF8Q9xNS
0k+IeNiU9BsiHjYl/YiIh01JvyLuZ6SknxHxsCnpd0Q8bEr6IXG/JCX9krif
kpJ+SsTDpqTfEvGwKenHRDxsSvo1cT8nJf2cuN+Tkn5PxMOmpB8U94tS0i+K
+0kp6SfF/aaU9JsiHjYl/aiIh01JvyruZ6WknxX3u1JO/PN/dUdZFQ==
          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxFnHd4VFUTxjfbAshHRwHpShPpCIjCHBCpIkURVIoiglRBEaUa6b0ovYkg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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxFnHd8VFUThjeb3Q3SQRBQutJRkM6nMAeRJk0QkaYo0hEULBSRIiIKCAgI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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(7\\)]\\)\"", 
       TraditionalForm], PlotRange -> {{-2.9975, 2.9975}, {0, 0.51144575}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T5.1\"", "\"T17.2\"", "\"T65.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.9101569506659565`*^9, 3.9101571595324707`*^9, 
  3.9101610790210724`*^9, 3.910164291236824*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"e09b25e1-aa05-400f-963c-dce0eaeff21b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Alternative sequence 2", "Subsubsection",
 CellChangeTimes->{{3.9101565749255075`*^9, 3.910156579265273*^9}, 
   3.910156965807495*^9},ExpressionUUID->"28460305-97c8-48d4-94a8-\
4e43fe32a594"],

Cell["The second alternative sequence is:", "Text",
 CellChangeTimes->{{3.910156660637101*^9, 3.9101566672747507`*^9}, {
  3.9101570488956923`*^9, 
  3.9101570493925924`*^9}},ExpressionUUID->"b94218fb-7d59-46b8-b84a-\
6b469c71c85c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<T10.1\>\"", ",", "\"\<T28.1\>\"", ",", "\"\<T82.1\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
   3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
   3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
   3.910156608462936*^9, 3.9101566170742188`*^9}, {3.9101569766320734`*^9, 
   3.9101570153138638`*^9}, {3.910164845207321*^9, 3.9101648562790403`*^9}, 
   3.910164917138832*^9},
 CellLabel->"In[27]:=",ExpressionUUID->"e393cbc3-2a2b-42e7-85ec-4cc2c0f6f856"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{8,3}-tess_T2.1_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
  3.9091142248348513`*^9, 3.909114238346472*^9}, {3.910164877341959*^9, 
  3.9101648785235233`*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"27afd63b-22ed-4e39-818a-146089ab2398"],

Cell["\<\
We construct and export the Abelian Bloch Hamiltonians (except for the last \
one, which is too big to handle interactively):\
\>", "Text",
 CellChangeTimes->{{3.9101567017353535`*^9, 3.9101567119301167`*^9}, {
  3.910164933624643*^9, 
  3.9101649538836184`*^9}},ExpressionUUID->"562024e6-60c7-4c3d-8d45-\
ed7268a3d382"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"AbelianBlochHamiltonian", "[", 
          RowBox[{
           RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
           RowBox[{"0", "&"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "&"}], ",", 
           RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"supercells", "[", 
      RowBox[{"[", 
       RowBox[{";;", "2"}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}, {
   3.910164962512916*^9, 3.9101649637507553`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"fd960593-b340-4ac6-aaf5-50910e92335f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<H_{8,3}-tess_T2.1_sc-``.dat\>\"", ",", "#"}], 
           "]"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@", 
   RowBox[{"supercells", "[", 
    RowBox[{"[", 
     RowBox[{";;", "2"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
  3.910154322749093*^9, 3.9101543310279417`*^9}, {3.910164969431911*^9, 
  3.9101649737521353`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"89106dea-d119-48a2-8f9b-5e9d6c821c13"],

Cell["compile the expressions", "Text",
 CellChangeTimes->{{3.9101567165821447`*^9, 
  3.9101567199242735`*^9}},ExpressionUUID->"bdf68d73-440e-440a-ab59-\
a6c7408fc2fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hsccfs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{
         RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
         RowBox[{"0", "&"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "&"}], ",", 
         RowBox[{"PCModel", "->", "pcmodel"}], ",", 
         RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], "&"}], "/@", 
     RowBox[{"supercells", "[", 
      RowBox[{"[", 
       RowBox[{";;", "2"}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091146138495903`*^9, 3.909114652753991*^9}, 
   3.909119478873217*^9, {3.910154420411165*^9, 3.910154425008809*^9}, 
   3.9101649786161823`*^9, {3.9101650505488276`*^9, 3.910165051534382*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"32470280-4dee-4a31-8c50-4fd5579ef4c0"],

Cell[TextData[{
 "and compute the DOS with an energy resolution of 0.005  and a sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "2"], TraditionalForm]],ExpressionUUID->
  "3befe87b-148e-4a7d-8edf-19cf1a4af3f7"],
 ":"
}], "Text",
 CellChangeTimes->{{3.9091148872154474`*^9, 3.909114904344953*^9}, {
  3.9101567234788375`*^9, 3.910156729219191*^9}, {3.910164982050488*^9, 
  3.910164982050488*^9}},ExpressionUUID->"3b43be3d-364b-4277-b040-\
d80426c19156"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dosscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ComputeDOS", "[", 
        RowBox[{
         RowBox[{"Hsccfs", "[", "#", "]"}], ",", 
         RowBox[{"10", "^", "2"}], ",", "32", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], "-", "0.005"}], ",", "3"}], "}"}], ",", 
         "0.005"}], "]"}]}], "&"}], "/@", 
     RowBox[{"supercells", "[", 
      RowBox[{"[", 
       RowBox[{";;", "2"}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091148504724855`*^9, 3.909114863025732*^9}, {
  3.9101548693475285`*^9, 3.910154869724236*^9}, {3.9101549493832054`*^9, 
  3.9101549496375976`*^9}, {3.910164984026203*^9, 3.910164986545627*^9}, {
  3.9101651070144963`*^9, 3.9101651072136555`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"dd6860cb-56d5-4eec-91eb-9a6eb3a3d441"],

Cell["We plot the density of states for the given sequence", "Text",
 CellChangeTimes->{{3.9091258353931103`*^9, 3.9091258729641294`*^9}, {
  3.909126315654191*^9, 3.9091263169689493`*^9}, {3.910156746327403*^9, 
  3.9101567572332544`*^9}},ExpressionUUID->"b86d8a84-14b0-4941-bc25-\
4c9914bca2ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Association", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<T2.1\>\"", "->", "dospc"}], "}"}], "]"}], ",", "dosscs"}],
     "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(2\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091194227381277`*^9, 3.9091194385257072`*^9}, {
   3.909125701919447*^9, 3.909125705158804*^9}, {3.9091264450645742`*^9, 
   3.9091264526411266`*^9}, {3.910154999941857*^9, 3.9101550239169064`*^9}, {
   3.9101562589192905`*^9, 3.910156259119133*^9}, {3.9101570343676405`*^9, 
   3.9101570352338457`*^9}, 3.910157127253744*^9, {3.910164988185376*^9, 
   3.9101649915283117`*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"2d31482e-46a7-4962-8a0f-e6b58c9152a3"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxdnHmYnldZxr/9q4AQsdaCWMMiVtkKihSxPoe1giAtIFYsWLBAVYSKVGut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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxdnGuspdVZx/f9IJqUNNi0SYNjTBM0Ron6gQ/i3iFGqvZDqSb2AxI0FZv4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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxd3H+IpdV9x/H7e6wNZAlbiRCMTSloKa2kLfhHzPMgbdc2gURbaKBWTIlp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          "]]}, 
        Annotation[#, "Charting`Private`Tag#3"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(2\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-3.0025, 2.9975}, {0, 0.5132500000000001}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T10.1\"", "\"T28.1\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091194429099684`*^9, {3.909125698510269*^9, 3.9091257066406164`*^9}, 
   3.909126457110761*^9, 3.9101549712826576`*^9, {3.910155008395378*^9, 
   3.910155025671894*^9}, 3.9101562605065956`*^9, 3.910156947789962*^9, {
   3.910157155058463*^9, 3.91015716048361*^9}, {3.910165271521293*^9, 
   3.910165299415347*^9}},
 CellLabel->"Out[38]=",ExpressionUUID->"cbdbb545-887d-4ebb-8b9a-5e33a137385d"]
}, Open  ]],

Cell[TextData[{
 "and finally consider the full data for this sequences, which is stored as ",
 StyleBox["data/dos/dos_{8,3}-tess_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091257257973347`*^9, 3.9091257829464827`*^9}, {
   3.9091258161267524`*^9, 3.909125817972119*^9}, {3.9091263241669226`*^9, 
   3.9091263478044133`*^9}, {3.9101544811965094`*^9, 
   3.9101544880133915`*^9}, {3.9101556042258387`*^9, 3.910155604445711*^9}, {
   3.9101567591084995`*^9, 3.9101567776566224`*^9}, 
   3.910164994518736*^9},ExpressionUUID->"c2ff081f-e50b-4856-8981-\
0c0d3abb07bb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{8,3}-tess_``.dat\>\"", ",", "#"}], "]"}]}], 
            "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.1\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(7\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9101570404020367`*^9, 3.910157041144208*^9}, 
   3.910157132135954*^9, {3.9101649992455263`*^9, 3.9101650017431636`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"301ae744-bdaa-49ed-9d77-45cfd0791b45"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJw9nHd4lUXTxk9OzjmhCFICShGQJqB0RHwFZ+kIKEWE0FR6kd57R6UJIgiI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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxFnGd4lFUThpPN7gbpVap0kKoCUqTNoSsgHUQIAlJEOqIISJMqCAYUBKRI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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxFnGV4lFcThjdrwd3dpVBooUhb6By8eHEpUhxKixX4gOKEUkFTaNFCobgX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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxFnHV41EcTx5O73IUiBYqW4i59KVaczAIFirRIiluhWHEoULxQrEAhFCnF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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(7\\)]\\)\"", 
       TraditionalForm], PlotRange -> {{-2.9975, 2.9975}, {0, 0.51144575}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T10.1\"", "\"T28.1\"", "\"T82.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9101569506659565`*^9, {3.9101571561975183`*^9, 3.910157161799483*^9}, 
   3.9101652724535885`*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"cd0f655a-0347-4274-a20b-5b9f6bfdb4b3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Elementary nearest-neighbor model on the octagon-kagome lattice\
\>", "Section",
 CellChangeTimes->{{3.9091097560137053`*^9, 3.9091097636740923`*^9}, {
  3.909109820746976*^9, 3.909109821007987*^9}, {3.9101530821292405`*^9, 
  3.9101530911518974`*^9}, {3.910161201243699*^9, 3.9101612014819603`*^9}, {
  3.910165347636364*^9, 3.9101653621092367`*^9}, {3.9101654348830037`*^9, 
  3.910165443877036*^9}},ExpressionUUID->"49f37b0d-197a-458f-a522-\
4d493dec4b0a"],

Cell[CellGroupData[{

Cell["Import cells", "Subsection",
 CellChangeTimes->{{3.909109766864945*^9, 3.909109771535059*^9}, {
  3.909109823230064*^9, 
  3.9091098236720653`*^9}},ExpressionUUID->"2809b34e-b1f7-4c38-b3a2-\
8e1e5c8a5f4a"],

Cell["\<\
We first import the cell, model, and supercell model graphs as produced by \
the HyperCells package (see \
https://github.com/patrick-lenggenhager/HyperCells for the package \
repository):\
\>", "Text",
 CellChangeTimes->{{3.90910977524686*^9, 3.9091097920317583`*^9}, {
  3.9091099483552275`*^9, 
  3.909109968542066*^9}},ExpressionUUID->"cb23dc52-960f-44c5-8d0b-\
cd9ec821af3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcell", "=", 
   RowBox[{"ImportCellGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<(2,3,8)_T2.1_3.hcc\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9090560618564167`*^9, 3.9090560733680687`*^9}, {
  3.9090561514000225`*^9, 3.9090561514836597`*^9}, {3.9091128212745233`*^9, 
  3.909112832496519*^9}, {3.910161215877681*^9, 3.910161217541376*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"99b5509f-cde8-4248-9706-f881ea19edd4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcmodel", "=", 
   RowBox[{"ImportModelGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<8-kagome_T2.1_3.hcm\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.909055936914714*^9, 3.909055963188888*^9}, {
  3.9090560238348665`*^9, 3.909056040271286*^9}, {3.909112837065897*^9, 
  3.909112838796729*^9}, {3.9091137679617558`*^9, 3.909113768077687*^9}, {
  3.9101612202907867`*^9, 3.9101612228731327`*^9}, {3.910165372517359*^9, 
  3.9101653740399685`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"2f679673-cc5f-4860-80aa-a8d0a9d463e8"],

Cell["\<\
We consider the following sequence of supercells, defined in terms of \
quotients given in \
https://www.math.auckland.ac.nz/~conder/TriangleGroupQuotients101.txt by M. \
Conder:\
\>", "Text",
 CellChangeTimes->{{3.9091138575774813`*^9, 
  3.909113909312521*^9}},ExpressionUUID->"9bf13767-43f8-4181-84d2-\
903972d5d14e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<T5.1\>\"", ",", "\"\<T17.2\>\"", ",", "\"\<T33.1\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
  3.910161235495674*^9, 3.9101612492366943`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"c5c1f1b2-797f-4bf0-93f6-908b636f82cb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<8-kagome_T2.1_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
  3.9091142248348513`*^9, 3.909114238346472*^9}, {3.910161254190941*^9, 
  3.9101612556785207`*^9}, {3.9101654104848375`*^9, 3.910165411576088*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"4d58570a-87ec-4e4e-97c8-3d82e549509a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the primitive cell T2.1", "Subsection",
 CellChangeTimes->{{3.9091098104889455`*^9, 3.90910982999617*^9}, 
   3.9101612604916887`*^9},ExpressionUUID->"b39e346f-ee02-4116-b1f3-\
23549377c887"],

Cell["\<\
We define the model on the primitive cell given by the quotient group T2.1. \
The primitive cell (Wigner-Seitz unit cell) forms an octagon with a single \
site at its center and nearest neighbors in adjacent copies of the cell:\
\>", "Text",
 CellChangeTimes->{{3.909109834065158*^9, 3.909109920885654*^9}, {
   3.909109996816284*^9, 3.9091100631664762`*^9}, {3.9091138866924057`*^9, 
   3.909113887462228*^9}, 
   3.910161267524358*^9},ExpressionUUID->"d5e207c8-6314-432b-8475-\
7f0a17ed19d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VisualizeModelGraph", "[", 
  RowBox[{"pcmodel", ",", "\[IndentingNewLine]", 
   RowBox[{"Elements", "\[Rule]", 
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ShowCellGraphFlattened", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ShowCellBoundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ShowEdgeIdentification", "\[Rule]", "True"}], "}"}]}]}], 
     "\[IndentingNewLine]", "|>"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"CellGraph", "\[Rule]", "pcell"}], ",", "\[IndentingNewLine]", 
   RowBox[{"NumberOfGenerations", "\[Rule]", "4"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9090560452383413`*^9, 3.9090560491912336`*^9}, {
  3.909056084328685*^9, 3.9090561117988863`*^9}, {3.9101612828124905`*^9, 
  3.9101612870015707`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"d9d1f6e3-b0d6-4fd6-b0a4-01448f3969fc"],

Cell[BoxData[
 GraphicsBox[{{InsetBox[
     FormBox[
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJzs3cty68q25vcTthtu+hX8Fu666W45/ABV4eMKd8oRpxzh8Fv5dbglTUqc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         "], {{0, 300.}, {300., 0}}, {0, 255},
         ColorFunction->RGBColor,
         ImageResolution->288.],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
         Automatic],
        Selectable->False],
       DefaultBaseStyle->"ImageGraphics",
       ImageSize->300,
       ImageSizeRaw->{300., 300.},
       PlotRange->{{0, 300.}, {0, 300.}}],
      TraditionalForm], Scaled[{0.5, 0.5}], Scaled[{0.5, 0.5}], Scaled[1]], 
    CircleBox[{0, 0}]}, {
    {RGBColor[
      NCache[
       Rational[2, 3], 0.6666666666666666], 0, 0], AbsoluteThickness[2], 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAUJYdAADp5j8U1uileNSzP8yvYTjJ
yOY/jPfzdde3tD/Qbq7T5qjmP3zvnqAqnrU/JoF551mJ5j9cbJxRaoe2PyLP
UIYjauY/tGYtm45ztz9mJtG/REvmPyggZnaPYrg/Vv6coL4s5j9Y/XPDZFS5
P2VWUzKSDuY/3DjkSQZJuj+lroZ7wPDlPyRs67hrQLs/1hq0f0rT5T907K2n
jDq8P1VwOj8xtuU/NPmIlWA3vT8lj1G3dZnlPxS5XOreNr4/bMYB4hh95T/c
A9f2/ji/P6JUG7YbYeU/2Hpf+tsewD/PAy4nf0XlP/akoIOAosA/BuKAJUQq
5T9avZ6daCfBP4AWCp5rD+U/MNHJw4+twT+O02Z69vTkPzaOuWbxNMI/qmXT
oOXa5D+i8VTsiL3CP/NfI/Q5weQ/CFT6r1FHwz9Q5rlT9KfkP9DQpwJH0sM/
gRWCmxWP5D8mCCQrZF7EP2SJ56OeduQ/rDknZqTrxD+jAc9BkF7kP8K2hOYC
esU/GSWPRutG5D/SqlTVegnGPyJk6X+wL+Q/dDgeUgeaxj8i+gK44BjkP57p
AXOjK8c/Zw5etXwC5D/MceRESr7HP8L00jqF7OM/asCZy/ZRyD/0jYkH+9bj
PyxiEAKk5sg/O8jy1t7B4z/IL33aTHzJPzZAwmAxreM/rEiHPuwSyj9MAuhY
85jjPxZYdA99qso/2myKbyWF4z8aI1Um+kLLP1AzAFHIceM/Hl4yVF7cyz+F
gsql3F7jPybIOWKkdsw/WkaPEmNM4z+aiusRxxHNP/WQEzhcOuM/t9tHHcGt
zT+7IzazyCjjP2ni/DaNSs4/MxrqHKkX4z+12ZQKJujOPxO3MQr+BuM/ZXKk
PIaGzz+rCEtp
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVUH0s1HEcFpdTXacXlC2TaadLauUcOVZi87JW465GSfIWapKJY1IjdjqX
htGxRcNWUm3YrTQ9zGb0ojv3hvP2+1JyXOY9Y/Trj2efPXs+z+f57HGKuRsW
b25mZsal8X/WRtfpqEUK8l2iheXJYXQn9AS7z1PQLwpfepQMQ1RrPG8xR6Gg
e2kh4cww7O7t14aaKPhuM6qKJwxILttkO85SeNARwm2UGWD+3H49eYZC4lXx
ZKenARxpfo0HzVmrjDkdNYQ0sDZzab7AqeLNSofA+sy3CaT9c+KxWgZ/CBGR
PIOMvr9hfdPReXwQx1anA4V0PsM7ozrkySAS1aaQSvq/bKujZrm8QfDqJcqI
JQpVMwe8OkYHIOYrOqpWKbiGJrjZFA3gpx9nK2KdQlOgvDfHfQDhN3xvV25R
UHDylzdG9Cg/YjcexiCQ+HLllRI9ouLzeMU7CMSSxupL7nr0yVkCf2uCCymc
CZdRHUxJa52ZtgSnC+tEzkU6pEcFl3EPEVy5taIO4OmgULSlhzsT9OS98i8Z
06Ik9qsLw5Wg3Wrs8XapFpEun5KOuxNoBv0yG/laGIZki0oBQVwB+fuIaDCg
2509H0Dw7LLzL+lTDVrz+t7KLhIwk1/Y93lrIGGeFDSEE/gR1p2QKTWGXa5/
8YwlOHzwRKtFuRpGQfhWQAqBYuZd98Y5NQRhS1nfsmjdaW+G159+PEwf0X4v
IHBTlZZ+rO5H057qxqBSgn6TrTEvuB/swjKpTw2BjYEZVLmqQpTO2up1E4HQ
Ifj+WoMKFdln38ja6H0HW68mkQpp13w2pnvoPiyNwmYLFUpN7Nx2PYGyJbWI
3aLERGrze+YUQW9XXEVXjBLRQntWzwpByoccD80+JX4rTu3ctJwAO63ep7Dw
B/4BC3Z8jg==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVjn0s1HEAxi8uVEJFZcvMNC8rNXOOvOwpbuOsFY5G6c1bUlOaiJnZ6W7O
ORqWUF6GTZKKpqh0pplKunNv3Hn7fVnmkLxeIrr+ePbs88fzYhd9KzTOgEaj
Oev13yd3hS2uTA6j70qtklqiYLfMqXEvHMZifC/bbYFCf8/yYvyJYWRXa/0M
5ynwtmml+RMa+CXvU4TMUfgkDnJuFGnwsHjTzHaWQvP5e5NdHhq4PLJeT5yh
EKKjzyspNYKFOVXuemY6ljNmhWo8/mi6maVn1/SxajpTDWYn0zJAn/e1uGpr
Pz4EbhRDI9L3s7xSK4LyhsDRTQdw9PvtJk60LMYQHsjmgkr1/wZnDniKRwcR
VZcriVymkBAS72IpGEQNs01crqMwFVD2OdNtEGZ+DluR6xQWHHJWNkZUyL7s
e6N0i0KXr3NZaa4K7w/vHw+lE7zKbaw466YCP47LyN9BkJPkMOE4qsRqmam3
vzlBAr82zF6ghFXiWleaFUHetVUZi6HEk0vsYudDBH+5Df6FYwqMtnWkRNgT
/DIZu79dqEBbzFdH+hECI/WptEamAjzHd9ePuhGU8MjvbCKHgUa0JPEmEIfb
/xAWyEFT7c5YYBG4J1Za93vJMcztfy46Q5BETG8GTcnw0vi4d30EwemDx14b
lshAd7r4xSOGgMw092yclMHSJ2KLlUTAttuT6vlzALGhy+l96QTh0qKi9ooB
NKSMKL7xCP7MWWm57AHILSoaA4sIvDTGgaU6KTz5xUKfKoIMG/bdtXopBEpz
k6dNBDobK8+mMCnEGXgm6iA4Z6TltBhKUXnBZ2O6l2Cp9bbArFWCzjmzrA8q
Am137MPuaAnMk1teGE8RFLzNdJfvlSCfY23au0oQfKfOh8//Dss3rjs3jSbw
D5lJVec=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAmNXopXjUs78mlh0AAOnmvwz383XX
t7S/oq9hOMnI5r/87p6gKp61v6ZurtPmqOa/4GucUWqHtr/+gHnnWYnmvzhm
LZuOc7e/+M5QhiNq5r+kH2Z2j2K4vzwm0b9ES+a/1Pxzw2RUub8t/pygvizm
v1g45EkGSbq/PVZTMpIO5r+ca+u4a0C7v3yuhnvA8OW/7Outp4w6vL+uGrR/
StPlv6z4iJVgN72/LnA6PzG25b+MuFzq3ja+v/6OUbd1meW/VAPX9v44v79F
xgHiGH3lv456X/rbHsC/fFQbthth5b+upKCDgKLAv6kDLid/ReW/EL2enWgn
wb/g4YAlRCrlv+LQycOPrcG/WhYKnmsP5b/ojblm8TTCv2jTZnr29OS/VPFU
7Ii9wr+EZdOg5drkv7hT+q9RR8O/zV8j9DnB5L9+0KcCR9LDvyrmuVP0p+S/
1gckK2RexL9cFYKbFY/kv1o5J2ak68S/P4nno5525L9stoTmAnrFv34Bz0GQ
XuS/fqpU1XoJxr/0JI9G60bkvx44HlIHmsa//mPpf7Av5L9H6QFzoyvHv/z5
ArjgGOS/cnHkREq+x79CDl61fALkvw/Amcv2Uci/nfTSOoXs47/OYRACpObI
v86NiQf71uO/Zy992kx8yb8WyPLW3sHjv0xIhz7sEsq/EkDCYDGt47+zV3QP
farKvygC6FjzmOO/tiJVJvpCy7+0bIpvJYXjv7ddMlRe3Mu/KjMAUchx47+9
xzlipHbMv2CCyqXcXuO/MIrrEccRzb80Ro8SY0zjv03bRx3Brc2/z5ATOFw6
47/64fw2jUrOv5QjNrPIKOO/RdmUCibozr8NGuocqRfjv/VxpDyGhs+/7LYx
Cv4G47/yeHmJ
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAJNbopXjUs79Elh0AAOnmP5z383XX
t7S/wK9hOMnI5j+M756gKp61v8RurtPmqOY/cGycUWqHtr8cgXnnWYnmP8xm
LZuOc7e/Fs9QhiNq5j88IGZ2j2K4v1om0b9ES+Y/cP1zw2RUub9K/pygvizm
P/A45EkGSbq/W1ZTMpIO5j88bOu4a0C7v5quhnvA8OU/kOytp4w6vL/MGrR/
StPlP1D5iJVgN72/S3A6PzG25T80uVzq3ja+vxyPUbd1meU//APX9v44v79i
xgHiGH3lP+Z6X/rbHsC/mVQbthth5T8IpaCDgKLAv8UDLid/ReU/ar2enWgn
wb/94YAlRCrlPz7RycOPrcG/dxYKnmsP5T9Gjrlm8TTCv4XTZnr29OQ/tPFU
7Ii9wr+hZdOg5drkPxpU+q9RR8O/6l8j9DnB5D/i0KcCR9LDv0fmuVP0p+Q/
PAgkK2RexL95FYKbFY/kP8I5J2ak68S/XInno5525D/WtoTmAnrFv5wBz0GQ
XuQ/6KpU1XoJxr8RJY9G60bkP4s4HlIHmsa/GmTpf7Av5D+16QFzoyvHvxr6
ArjgGOQ/4nHkREq+x79gDl61fALkP4HAmcv2Uci/vPTSOoXs4z9DYhACpObI
v+yNiQf71uM/4C992kx8yb80yPLW3sHjP8RIhz7sEsq/MEDCYDGt4z8uWHQP
farKv0YC6FjzmOM/MiNVJvpCy7/UbIpvJYXjPzZeMlRe3Mu/SjMAUchx4z9A
yDlipHbMv3+CyqXcXuM/sorrEccRzb9URo8SY0zjP9LbRx3Brc2/75ATOFw6
4z+D4vw2jUrOv7YjNrPIKOM/0NmUCibozr8uGuocqRfjP4BypDyGhs+/Drcx
Cv4G4z9s02Ib
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA6gtU8vXk3D/KYKPW4fPhvyf0U6E1
j9w/8GbISTPx4b/UxvTyZjncP36g6kID7+G/iwHq0Yzj2z9AcRPVUe3hv8rA
Simqjds/k5P+Dh/s4b+0WnjkwTfbPyqYGftq6+G/V/cE79bh2j9Oi4OfNevh
vzwnmjTsi9o/mr8M/n7r4b84ed+gBDbaPzS+NhRH7OG/RBBhHyPg2T+AXDTb
je3hv0s6dptKitk/UPfpR1Pv4b/ACCgAfjTZP47T7UqX8eG/3usXOMDe2D9a
pIjQWfThv25RZi0Uidg/nDa2wJr34b/uR5nJfDPYPwpCJv9Z++G/+CaD9fzd
1z98Xz1rl//hv8g9KZmXiNc/uSQW4FIE4r+3iKqbTzPXP4JlgjSMCeK/im4m
4yfe1j/zmQw7Qw/iv3CGo1QjidY/Emr5wXcV4r+SZ/bTRDTWP5heSZMpHOK/
A4OoQ4/f1T/atrp0WCPiv/cI34QFi9U/smPLJwQr4r8M2kF3qjbVP4Anu2ks
M+K/nIXi+IDi1D/+2o3z0Dviv8dVI+aLjtQ//NYNevFE4r88ap4ZzjrUP9iC
zq2NTuK/duIMbErn0z+rBy87pVjiv1QYLrQDlNM//iddyjdj4r/p667G/EDT
Pw48WP9EbuK/UCERdjju0j9eUvR5zHniv13RkpK5m9I/onTd1c2F4r8B7hXq
gknSP84Qm6pIkuK/QNsHSJf30T8yhpOLPJ/iv4AdSXX5pdE/g9YPCKms4r/+
HRU4rFTRP7p6P6uNuuK/XAbqU7ID0T+YWzz86cjiv/qzcIkOs9A/uO0Ofr3X
4r/yw2SWw2LQPwhxsq8H5+K/lrh8NdQS0D+GUxkMyPbiv11ypDyGhs8/Drcx
Cv4G47/+j2va
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAtGCj1uHz4b/HC1Ty9eTcP9xmyEkz
8eG/BPRToTWP3D9qoOpCA+/hv7HG9PJmOdw/LnET1VHt4b9pAerRjOPbP4KT
/g4f7OG/p8BKKaqN2z8bmBn7auvhv5JaeOTBN9s/QIuDnzXr4b809wTv1uHa
P42/DP5+6+G/GieaNOyL2j8ovjYUR+zhvxZ536AENto/dlw0243t4b8iEGEf
I+DZP0j36UdT7+G/KTp2m0qK2T+G0+1Kl/Hhv54IKAB+NNk/VKSI0Fn04b+9
6xc4wN7YP5k2tsCa9+G/TVFmLRSJ2D8GQib/Wfvhv85Hmcl8M9g/el89a5f/
4b/YJoP1/N3XP7gkFuBSBOK/qT0pmZeI1z+EZYI0jAniv5mIqptPM9c/9pkM
O0MP4r9rbibjJ97WPxVq+cF3FeK/UoajVCOJ1j+eXkmTKRziv3Rn9tNENNY/
4La6dFgj4r/mgqhDj9/VP7pjyycEK+K/2gjfhAWL1T+KJ7tpLDPiv/HZQXeq
NtU/CtuN89A74r+CheL4gOLUPwjXDXrxROK/rVUj5ouO1D/mgs6tjU7ivyNq
nhnOOtQ/ugcvO6VY4r9e4gxsSufTPxAoXco3Y+K/PBgutAOU0z8gPFj/RG7i
v9Lrrsb8QNM/clL0ecx54r87IRF2OO7SP7h03dXNheK/SdGSkrmb0j/mEJuq
SJLiv+7tFeqCSdI/SoaTizyf4r8u2wdIl/fRP5zWDwiprOK/bx1Jdfml0T/U
ej+rjbriv+4dFTisVNE/s1s8/OnI4r9OBupTsgPRP9XtDn691+K/7LNwiQ6z
0D8ncbKvB+fiv+bDZJbDYtA/plMZDMj24r+LuHw11BLQPy63MQr+BuO/SnKk
PIaGzz+RZWhn
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAATpYdAADp5j8I1uileNSzv8qvYTjJ
yOY/gPfzdde3tL/Obq7T5qjmP2zvnqAqnrW/JIF551mJ5j9QbJxRaoe2vx/P
UIYjauY/qGYtm45zt79jJtG/REvmPxggZnaPYri/Uv6coL4s5j9I/XPDZFS5
v2JWUzKSDuY/zDjkSQZJur+iroZ7wPDlPxRs67hrQLu/0xq0f0rT5T9k7K2n
jDq8v1JwOj8xtuU/IPmIlWA3vb8ij1G3dZnlPwS5XOreNr6/acYB4hh95T/Q
A9f2/ji/v59UG7YbYeU/znpf+tsewL/MAy4nf0XlP+ykoIOAosC/AuKAJUQq
5T9SvZ6daCfBv30WCp5rD+U/JtHJw4+twb+K02Z69vTkPyqOuWbxNMK/pmXT
oOXa5D+a8VTsiL3Cv+9fI/Q5weQ//lP6r1FHw79M5rlT9KfkP8bQpwJH0sO/
fRWCmxWP5D8eCCQrZF7Ev2CJ56OeduQ/pDknZqTrxL+fAc9BkF7kP7a2hOYC
esW/FCWPRutG5D/JqlTVegnGvx5k6X+wL+Q/aDgeUgeaxr8d+gK44BjkP5Xp
AXOjK8e/Yw5etXwC5D/CceRESr7Hv7300jqF7OM/YMCZy/ZRyL/ujYkH+9bj
PyFiEAKk5si/Nsjy1t7B4z+9L33aTHzJvzFAwmAxreM/oUiHPuwSyr9HAuhY
85jjPwxYdA99qsq/1WyKbyWF4z8OI1Um+kLLv0szAFHIceM/EV4yVF7cy7+A
gsql3F7jPxrIOWKkdsy/VEaPEmNM4z+MiusRxxHNv++QEzhcOuM/q9tHHcGt
zb+0IzazyCjjP13i/DaNSs6/LRrqHKkX4z+p2ZQKJujOvw23MQr+BuM/W3Kk
PIaGz79vKV5Z
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVxXss1AEAB/BzNskfRKPLq9p5FGHUdKxFJiJ/OK6mzc77Vpg3KzGmPIuz
xpZHt1vOxHbYvE7h6xA/500ozOT38LpacrtJZtUfn30uRSeHxLFZLNaVf/7/
vdqKxdphkLK43fjkcwcS26J44wQDjfYgc7mnE2lJrQvMewbqHxKpg6QLqvyn
Ww9LGXxJqOfHF3eDmA4u4sYz4Imc6irSe2BoNwffewzaL4iyxNEKsE7qpQNX
GVDH6cOxgl6YPAh1e23IIINHBegFfICgtejZ4E8aIwl7igTvjyg278wLXKBh
qZY3vfLsg36Kp5drN42Nw5LqyBv9WKng92TW0JhVhO+uuw+AO6qzycmlUaW7
rD3hAeECi26LKBqK7IijVetBvNR1ts+7Q2NFJn2e/24QI9/ybX0daPj0S94+
slfC28xAkmBEgzM3PiyWKxG8IMrWaihYV/SK9q8PISluQUqvUKjcF6hL+ofQ
G8HVeCgpaEOP2vj+w+AwvaGaJgpDs01s//lhBJkW1JmKKVjq2zjGCkfgVrrV
IMmiIPOwF8n2RpCuM3O7UkhB0f2CYWd/wq6N2G/Pj8Jki2Ax+/QotDE7ee0u
FJJ51iGnakdx+Jut2OBQqN3RSW9wHIOXobArh01BlUr5Bg6MoV4z71moJhE/
WDOh5ROYLS899WeJhFP0GbaMIXCe+LW0riRBuOSuBOWMw8x7KNJVTkJ+t/iW
2kQFZ/Z22MEbEpywDKPcFhUGEsuSbQtJWHHv2x35TMD9GotPpJK4KHQTCNcm
kFSgalwTkrAnPKJlWZPw9RObxASRqCvbMx4znsJm5VleuCeJvlV/K6V8Cs1c
9w7iMonEzWP38sBp2JjvWjafI6H4WmVgtz0NvR5XgxM9Eo/TZDeLimbwFwDX
dvM=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVjn0s1HEAxq8ISYeismVmmkuvqzsveekRFmeLeWk7VIpoyZQSMZN5udE5
NiyOFg1boWw0iVWMmd64c+7O3Xn7fRnzlnAcc3P9+uPZs88fz4t9zMPQuL0M
BsOJ1n8fuF0np9YpzBwIX9uYGcNK/ACXvUrBXhP2xrlkDJm1Cz4GKxQG+zVr
8ZfGcDn5sCxkmQJ/z4KkaFqN0rJdpt0Shb7uQKdGoRqnKm12EhYptEQ+m+lx
VeOaILfGmeZQreGKnFKh8pvZbhbNrqwqzpJABfZXFyt/Os9On6w1dFHh+Q2O
Wkj3w+KOncOUEsHaef8wev+qe2p14AslhNLlwAr6X5fJSUYWRwlefYE4QkNB
tXjUrXtiFK9c2rurtBQSQuLPWhWOwtTHUR+xQ2HeX/Q9kz2KzGivBxV6ChrH
3A3duAIdJ45MhRoS9Hk5iSoKFMiJy+EU7SdoK2isDmYrsCYy8/A1J+AnOU6z
JuSwTNjuSbMmSOTXhTsUylF5i1vmdJyg+N6m1I8jh7K9M4XnQMDIfetbMilD
a+xPluFpgnWTybx9AhmyWV33z7AJTFVX0hpdZNhVCdfFHgSifLKVTUagkx/M
WPWj/1x3mBUUj2A0Z/C9MIjAPeG1zaD7CJqMz3s08AieELPEwDkp9KybP1xj
CUKOnftoUC4F05On90simF380K/zliI6VJP+K50gyN4y1e3PMOpSxmW/8wki
JaWln6uHMWRR3RhQSqBftl7I4Q7jIr9M4FlD4K02DqjQSpAnNzd510yQZct9
ut0gQWcGmoSdBDpba7fmcAkqozx18wMEUUYLYa0GEnQsM7O+KAi22h4VMtvE
ME1ubTGeI/jbe/dlb4wY/DAbs4FNgvKOTOeRQ2IwP10w3TWaRtTjek8+fwj/
AOc6V7g=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVjn0s1HEAxm+Rl7qQXGiZGjuuVGvO67GSW9y1lbg2elF5nWqS5C1T8zZv
l+ZaN26Lhk0X2jBJs4c005vu3AvucH5fljlv854YnT+ePXv+eD7PczzqYWjs
HhqNxjJo15n7BUurkyMIuVOjppYpxC+HvfUoG8HTuD6e+yIF296VpTifEdCr
9ReMFigM0PTy0gkt5EmHVFfnKDC6+CypUAuWaNvCcZaC0fX0yW4vLb6K7Tfv
zVCQrhkvqCkNZopzqzwMWcSsZM+WaOAL+nb2bk7XVRt7ajDU6WkTZOjXWN51
dBofhutNtlZo4Df5pEr4xcP4tzYdFGbYdzVzpWWzh+GnmOOLDf8uzdh6d40N
gV5bKItYoaALiTtlUzSEUM+2rsp1CtFBFd+y3IfwJYC5E7FJIZmZu7o1Ogjv
2/73xTsUgvxZFeLCQaQ7Hx4PNSbgFEolV9wHwY3NYZeaE1gnMidcxtRor6Bz
Ai0JtvJrBE5FamgSNrrTGATO8WsKLluNmEieiHWUQJJTH1imU6G+rSMl3IlA
ZKbL21uiQl70DxfjkwRNwwFpUk8VBC6fE9zcCQLzyd/nRAmVRrgs4xA8vub0
p+SFEkr1gcxFLsF8whv7fl8lWnP6G4WXCdwI/QF/SoEi0zOcunACK7vTrUav
FBh3ufXdK5pAOtPUu3VegSVO+A43kcDu+MFU7/kBcENXMn5mEJyQl5d/kgyg
NGVU9SufQDHH0OfwBtBhJZEGlxMc0ZoGi9flOFYgKvGrIoh04D3ZqJMjWW1p
9q6BgDgwvBsEcjRknnsv7CC4aKIPazaSo/SG39Z0H4G+JanIokWGxjmL7M5B
gqmemNc9UTLQHjV/MJ0ieNme5aG0luFZmD29b83AT671Kyj4DfOPZ/dtm0zg
P/rCe18=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAABNfopXjUsz/Hlh0AAOnmP2j483XX
t7Q/PrBhOMnI5j9E8J6gKp61PzpvrtPmqOY/FG2cUWqHtj+MgXnnWYnmP1hn
LZuOc7c/gc9QhiNq5j+0IGZ2j2K4P74m0b9ES+Y/1P1zw2RUuT+o/pygvizm
P0Q55EkGSbo/slZTMpIO5j+AbOu4a0C7P+yuhnvA8OU/xOytp4w6vD8XG7R/
StPlP2z5iJVgN70/kHA6PzG25T9EuVzq3ja+P1qPUbd1meU//APX9v44vz+a
xgHiGH3lP956X/rbHsA/ylQbthth5T/4pKCDgKLAP/ADLid/ReU/WL2enWgn
wT8h4oAlRCrlPyTRycOPrcE/lhYKnmsP5T8kjrlm8TTCP53TZnr29OQ/jvFU
7Ii9wj+yZdOg5drkP+pT+q9RR8M/9F8j9DnB5D+w0KcCR9LDP0zmuVP0p+Q/
AAgkK2RexD93FYKbFY/kP4Y5J2ak68Q/VInno5525D+UtoTmAnrFP4wBz0GQ
XuQ/oKpU1XoJxj/7JI9G60bkPz44HlIHmsY//mPpf7Av5D9m6QFzoyvHP/f5
ArjgGOQ/knHkREq+xz82Dl61fALkPy/Amcv2Ucg/ivTSOoXs4z/uYRACpObI
P7aNiQf71uM/hy992kx8yT/2x/LW3sHjP2xIhz7sEso/6z/CYDGt4z/UV3QP
farKP/wB6FjzmOM/1SJVJvpCyz+CbIpvJYXjP9ddMlRe3Ms/8jIAUchx4z/g
xzlipHbMPyGCyqXcXuM/U4rrEccRzT/vRY8SY0zjP3PbRx3Brc0/hJATOFw6
4z8l4vw2jUrOP0IjNrPIKOM/ctmUCibozj+0GeocqRfjPyRypDyGhs8/jrYx
Cv4G4z+eT1MC
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAdNXopXjUsz+2lR0AAOnmv/T283XX
t7Q/NK9hOMnI5r/s7p6gKp61PzxurtPmqOa/0GucUWqHtj+VgHnnWYnmvzhm
LZuOc7c/k85QhiNq5r+oH2Z2j2K4P9ol0b9ES+a/4Pxzw2RUuT/O/Zygvizm
v2g45EkGSbo/4FVTMpIO5r+4a+u4a0C7PyKuhnvA8OW/DOytp4w6vD9WGrR/
StPlv8z4iJVgN70/2G86PzG25b+8uFzq3ja+P6uOUbd1meW/fAPX9v44vz/0
xQHiGH3lv6h6X/rbHsA/LlQbthth5b/KpKCDgKLAP14DLid/ReW/Lr2enWgn
wT+Y4YAlRCrlvwLRycOPrcE/FRYKnmsP5b8Kjrlm8TTCPybTZnr29OS/ePFU
7Ii9wj9EZdOg5drkv9xT+q9RR8M/kF8j9DnB5L+k0KcCR9LDP+/luVP0p+S/
+gckK2RexD8kFYKbFY/kv4I5J2ak68Q/Conno5525L+UtoTmAnrFP0sBz0GQ
XuS/pKpU1XoJxj/DJI9G60bkv0Y4HlIHmsY/z2Ppf7Av5L9u6QFzoyvHP9H5
ArjgGOS/m3HkREq+xz8ZDl61fALkvzjAmcv2Ucg/dvTSOoXs47/2YRACpObI
P6qNiQf71uO/jy992kx8yT/0x/LW3sHjv3JIhz7sEso/8j/CYDGt47/aV3QP
farKPwoC6FjzmOO/2yJVJvpCyz+abIpvJYXjv9tdMlRe3Ms/EjMAUchx47/i
xzlipHbMP0qCyqXcXuO/UorrEccRzT8gRo8SY0zjv27bRx3Brc0/vpATOFw6
478c4vw2jUrOP4UjNrPIKOO/ZNmUCibozj8AGuocqRfjvxJypDyGhs8/4rYx
Cv4G479afmTV
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAASgxU8vXk3L8oYaPW4fPhP4P0U6E1
j9y/SmfISTPx4T8sx/TyZjncv9Cg6kID7+E/3wHq0Yzj27+OcRPVUe3hPxnB
Simqjdu/3JP+Dh/s4T//WnjkwTfbv26YGftq6+E/nPcE79bh2r+Mi4OfNevh
P30nmjTsi9q/0r8M/n7r4T9zed+gBDbav2a+NhRH7OE/ehBhHyPg2b+tXDTb
je3hP3w6dptKitm/ePfpR1Pv4T/sCCgAfjTZv7HT7UqX8eE/BewXOMDe2L94
pIjQWfThP49RZi0Uidi/tja2wJr34T8JSJnJfDPYvx5CJv9Z++E/DSeD9fzd
17+KXz1rl//hP9g9KZmXiNe/wiQW4FIE4j/BiKqbTzPXv4dlgjSMCeI/jG4m
4yfe1r/ymQw7Qw/iP2yGo1Qjida/DGr5wXcV4j+IZ/bTRDTWv45eSZMpHOI/
84KoQ4/f1b/Ktrp0WCPiP+AI34QFi9W/nmPLJwQr4j/v2UF3qjbVv2gnu2ks
M+I/d4Xi+IDi1L/g2o3z0DviP5xVI+aLjtS/2dYNevFE4j8Kap4ZzjrUv7CC
zq2NTuI/POIMbErn079+By87pVjiPxIYLrQDlNO/zyddyjdj4j+g667G/EDT
v9o7WP9EbuI/ACERdjju0r8mUvR5zHniPwXRkpK5m9K/ZXTd1c2F4j+i7RXq
gknSv4wQm6pIkuI/2toHSJf30b/shZOLPJ/iPxIdSXX5pdG/N9YPCKms4j+H
HRU4rFTRv2p6P6uNuuI/3gXqU7ID0b9EWzz86cjiP3OzcIkOs9C/YO0Ofr3X
4j9iw2SWw2LQv6xwsq8H5+I//rd8NdQS0L8lUxkMyPbiPxxxpDyGhs+/qbYx
Cv4G4z8XQmoo
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAQGCj1uHz4T8OC1Ty9eTcv2lmyEkz
8eE/TvNToTWP3L/5n+pCA+/hP/7F9PJmOdy/vnAT1VHt4T+5AOrRjOPbvxWT
/g4f7OE/+r9KKaqN27+vlxn7auvhP+hZeOTBN9u/1oqDnzXr4T+O9gTv1uHa
vyS/DP5+6+E/diaaNOyL2r/CvTYUR+zhP3V436AENtq/EFw0243t4T+FD2Ef
I+DZv+L26UdT7+E/jzl2m0qK2b8j0+1Kl/HhPwgIKAB+NNm/8qOI0Fn04T8q
6xc4wN7Yvzg2tsCa9+E/vlBmLRSJ2L+oQSb/WfvhP0FHmcl8M9i/HF89a5f/
4T9PJoP1/N3Xv1okFuBSBOI/JD0pmZeI178mZYI0jAniPxeIqptPM9e/mZkM
O0MP4j/tbSbjJ97Wv7pp+cF3FeI/1oWjVCOJ1r9CXkmTKRziP/1m9tNENNa/
hra6dFgj4j9ygqhDj9/Vv2JjyycEK+I/agjfhAWL1b8yJ7tpLDPiP4TZQXeq
NtW/sdqN89A74j8YheL4gOLUv7DWDXrxROI/R1Uj5ouO1L+Ogs6tjU7iP8Bp
nhnOOtS/YwcvO6VY4j/+4QxsSufTv7gnXco3Y+I/4BcutAOU07/KO1j/RG7i
P3rrrsb8QNO/G1L0ecx54j/mIBF2OO7Sv2F03dXNheI/99CSkrmb0r+OEJuq
SJLiP5/tFeqCSdK/84WTizyf4j/k2gdIl/fRv0bWDwiprOI/Jx1Jdfml0b9+
ej+rjbriP6gdFTisVNG/XFs8/OnI4j8MBupTsgPRv37tDn691+I/rrNwiQ6z
0L/QcLKvB+fiP6rDZJbDYtC/TlMZDMj24j9SuHw11BLQv9e2MQr+BuM/4HGk
PIaGz78AHmq/
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAASpYdAADp5r+Q1uileNSzP8SvYTjJ
yOa/APjzdde3tD/Gbq7T5qjmv+TvnqAqnrU/HIF551mJ5r/AbJxRaoe2PxXP
UIYjaua/FGctm45ztz9WJtG/REvmv3QgZnaPYrg/Rf6coL4s5r+g/XPDZFS5
P1RWUzKSDua/IDnkSQZJuj+RroZ7wPDlv2Bs67hrQLs/wBq0f0rT5b+o7K2n
jDq8Pz5wOj8xtuW/XPmIlWA3vT8Mj1G3dZnlvzy5XOreNr4/UMYB4hh95b/4
A9f2/ji/P4VUG7YbYeW/4Hpf+tsewD+wAy4nf0Xlv/ykoIOAosA/5OGAJUQq
5b9gvZ6daCfBP10WCp5rD+W/MNHJw4+twT9o02Z69vTkvzCOuWbxNMI/gmXT
oOXa5L+c8VTsiL3CP8pfI/Q5weS//FP6r1FHwz8k5rlT9Kfkv8LQpwJH0sM/
VBWCmxWP5L8WCCQrZF7EPzWJ56OeduS/mjknZqTrxD9yAc9BkF7kv6y2hOYC
esU/5CSPRutG5L+5qlTVegnGP+xj6X+wL+S/WjgeUgeaxj/q+QK44Bjkv4Hp
AXOjK8c/LQ5etXwC5L+sceRESr7HP4b00jqF7OO/RsCZy/ZRyD+1jYkH+9bj
vwRiEAKk5sg/+sfy1t7B47+gL33aTHzJP/M/wmAxreO/gkiHPuwSyj8GAuhY
85jjv+lXdA99qso/kmyKbyWF47/qIlUm+kLLPwYzAFHIceO/6l0yVF7cyz84
gsql3F7jv/LHOWKkdsw/CkaPEmNM479jiusRxxHNP6OQEzhcOuO/gdtHHcGt
zT9mIzazyCjjvy/i/DaNSs4/3BnqHKkX47962ZQKJujOP7q2MQr+BuO/K3Kk
PIaGzz/HjWNG
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwtknks1nEcxzF5xLOiBxMLj1pzjGXkSr1RKemJ2uMPosPVQhNWEumgFKYc
maYpc0RNrpCjdWwo2+OmmOd5ft+PI3lolHOWpa0/Xnv9+9p7b2FQ1KlQFSUl
JfMN/vnzueIh9pthXFP8a3F8FCTIW9ZaYujUCNbwFEqRPujWkLTCsMnWKTM7
UIqUFCt1yzWGRIE0vveJFCKzPqa7ztA9feeL6pAUEtMCeygTSnlZ8ZbbZMgP
m1wpUyWYmJXcO3RChuYaVQOROiHqW87siTQZ1CROaTZ8gn/P1Vee7TIsdLc6
irUIH7xfvLNVkUP54ltBvQ5hIb5DyD8gR76Fl7p4O4FVtQ32xstxbTRVxcaI
MD3FfU2ul6Os98qs105CqEblbuG8HDJ37boSM8JIYfo5sR6HhEovl33WhHDT
vf18Ow4z9vzorXaEyjDziKaTHPJ19jgKnQmTXHS5XxQHj5W0uMuuhOLjIs3Z
DA4rt74L/ngQivpsdGJfcnCt5s23iwgS6+6Dig4OW0JK5yVigvuglqHvBIfJ
gZhl7QCCl56JYbUKQ5a+4Vh2MCHALaxtzZjBucI91yeCMN+eWeCwn2FpLvXH
sViCr98D42B/hobh5A+3Ewiu/Iz+G3EMxec7FxeSCUdidZ1TcxlGbRUhJRkE
7fc/B5NqGJ4cjpl6+JjgPWxlEdLF8Dpuyq+xkBB006HZXsEQ7jKQZVBOeHP6
4+YlHqHHrflCUw2hdsfA06JdBAsTo9qclo2+R5JlRzfCDD/Zo6KNEFkV9Kwl
kDCXFbm62k1QainSN79OWD16tvDuCKHNc2HqVh4hpYDxjk8QnvoJ8z7VEsbv
JfJEcxt/OONdNtu1sVtI66X7a4Q6H7XnygqCTqONxrraGAz++y8lXlBc
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwdjAtIUwEYhS9qRCkiWqKVslC0lag5fDBfcz4IFV9QmjOnkuhqpeYSnaJD
zAcJleFbdE6d5kKny+UjO1YgaRNFZk2yhhi7d8OZJkFlWLd+OPx8fIdzNqcg
JdeCIAgmnX9f2exCEEYDhGvUQKlWBc12XYr+jwFRc7FfWAEqZESM1JOOJLwE
gkJh+zhcG8LCnbxJrHSl7rgfjkFkH2RfFE2CKlce8K+PoYNl7trLIDHJavRh
aJRY/W0lbheRGFoVncr3V+K2uSIyv5EEcUfdKOKMQqkYbrrWT+JhvNMtP+cR
1COUKHtB4tJ87LLt96dwTIpwn9aS4Ng59thqFdjfcmlhmEnMvZ6aDlAPg+3e
ua04QsFO/+Hb/c4n4Mo2Z3muFHxtso471AzBVlrR4xNIodC2XL1SMIgrH3ke
nkm0F5d0L2TKweGtGSIEFM71KXkWyQPo4QyKqqopTM7XlFXF9EPT9jNH30lz
ceDd6PA+WLKyorIn6L731mxasAxhpRvDVsv0flLus1l2L+qj9Z4LFIVdZpyi
NFSKN29j40csjFCqK5dO13VjiS8aUp0xwndzJ8iyows2Yg+NLsAIQhRJjqo6
kFghi3FJNoIxLz92XtuGA7lMLrlJ+yazquygBTWHPLFFLe0Zog05sxmuAZJE
mdQIyd4BbyrzMRRd4Sr+jBG7VIN5suMRVq3j/Njv6b6pISN95gFC1tfSLu4Z
IS0ZZgcnNuLHQut4lI0Jkrq6QLe9enw6urxY7GkCJ2FCx+i9h5POXK+XXBOk
ldZ5XH41Wtcjst0yTZi7sbxxIbUS/SWKfVkZze82xSk2pfAXmoQhzfRe9/NF
h89FuFrz6/JXpQnE7ivDifY8CHWCwBkNzQm1Ei4/FUxtensPRfP/04X8BYVM
acg=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwdzX0s1AEYB/CbWPOSiWZK2hVj0lLe56Wv9xkt3NaYkzvGMBrmR3dc3JCX
dVsrkbc4F4cjjovyVtp6cXbtbN7Lcpb8fnd1pJc/itSvnu27Z5999+w5mZLD
SjNgMBjOdP7tvQWqkzevQES9HYOh3YRmKnLD3UuBRH0Va+3PJlSZmbnZjUP4
GNRfTVqTIO7HbTnsD0JccwE2Z0ncFch3OamD0Fv6WOaFkcj2ELkyVXKYeOhb
dhJJpM4RxzI85fD/bVjUSJAQ5o+IiMABqPWCkAwRCZtLNlfdjvbDuE9250oH
Cc3rSLX5jz68fRbA4E/QPmzdZj7fC25MkMPYPAnui9ExrxEZPDbs6pl6ElOa
pa83m3tAODR/7jWiQB3imlhVdIOQrE+yT1BgWhSPzOZ0wUcsaHP1pvviwlZl
khT8d2xHpxgKmg452yC2Ewnshc2gTAoZ0xX80vAODAZ2EaVltAu8C8LwAIsN
P1PWminMun6YjPeTwMidG5o8TMGClfZo0rcdPrxVmaGagtglqpcXIEZR2JqT
kqLwZbTkjW1VKx5OR17sN9BCuLHlc6CpBQMcoltxXItz10LIAUUTSL6jatlL
i0Cl1Pj0fANOCSThdrFaMOr0Cv5uPV5JJVJhlhZMe2JV6lyHiH12kUGlFtzv
u+zRpFqseAqjJWItpj7V6J803UZSCxSccfrfdk1iwvgtXDeNcvNdpPtima9f
tAia5YX48zt0L6rytt+pRq3y3lComQ4a1vAys/0Gcg+qZ/KddGCUm6YHc8rQ
bhN85mkw7Xz1qktcCWxXgpLtk3QQzq0Xscx4YBb2fpPwaXc+nrF6n4eeLF22
fx3tveebRxrT8bL81+VtOX2fWikM5sRhdinTe1xF+/90T1TOJTS2UTr8BQYu
RxE=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwtzX8s1HEcx3HMnLgt4kwUTk1+pKUkST9OZYmT2rV2pSiSDcmPEkp+hMLk
V7amKUsizI9WccqrX1it/CZad/f9vPXjYtcoP7Msbf3x3OPPp/Bk5MFTWhoa
GnaL/bNTX/Jz6vMnNAXeHWS/GBr0gvS8hHL0GRXPGEwzqDZsyS04JkfCgOhx
0iyDv5E8vuemHLFXHHUd5hlqRlPfaA/K4W7bywQLDEm8/HiHZQrIrEtcdmgS
pteUZ+z2VSA95OtshTZBNFSo9s1SoKJB20ysS7DtPl/t1a7AxLstWU58Qvb+
+882aimh6HrqKjEgtMR3CPnblRgNbTJ6ZEyoqGsb6IlXItneW1eynFCt4j6k
PVIi8FOmlpMFYZVerY1wQomcnnNq71WEptLsQIkJh9cehg/LbQme1pv6+M4c
Amu93beuI2SG2IU1H+DQ7cKPWupMABdVKY3kkGi83lXoRkjwEeurczjYzmbF
nd1JiOt1Mo55wGEo+ZvRH09C2bquXWMdHKzqeRPtYoLxgIH5oS8c1EH3Jt5L
CCtMrMzrtRhe9UfPGPoTHEQhbfOWDGdMzUcKghZ/7bklm7cxCKo8ivzCCNbS
a5ZBRxi6xzO/74sh6PNz+i7FMeQNpz1PSSQYxAjcMosYEk+8nZpMIwy3/hhI
amBo3DgWXJ5DEAw72gd3MkTsiVZdv0GwubxZ5jLGkBKnkj4pJVw4+mLJNI/g
7t6fb1ZJiF3Zf6tsNeGOSHa6uYFgkfd+xlVE+G1p0VjYQlhbd/J2yzGCjJ/m
WdVGaJWVmdolEJ7lh8/NdRFSvSZVycWEV3sDStM/Eg5LhcUvGwniEsbz+UII
OL6/Qt1JqMm4yBOPE8L9dO5ojhFCg59GXJ0n9Dx20lvQGcHQf/8Crth1vg==

       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwdj3ks1nEcgHknr3i3yLFk0Usrx7TeHLnq0ytZcmZvW4oSko0mhFHpeHNm
ovROacpCjplrKORDGx3LfRTr9f6+H5EyjdxTlvrj2bPnz0cYFOl7gaekpGS2
wT8na0h+LX79gsWBz4fZPIMI9WB1N6Ec27Rly5pLDEr322fdD5Bj2JC4IWmF
gVBbntD3SI5BdyzVLNYYxP64/V5lWI4Wpv1Md52BBz8nwWLrGFYY59uCMsG7
PUUpLl5jGBc6uVKiQqD/+cGMV8YY5tWobPdUI9jUG1fh1jmGXz/aZ4gEBBHe
L15b8RQ42NNiJ9EkKEx4KxQcUiAX9lK7Xocgu6pjqC9BgfHm7moSfYLHU9wn
ab0CT31J5YkMCfTUK3cL5xSY0hc7425CUFdwN1Cix2Grs1ZdkSmBi7HNgMCa
Q/9KdyfHvQSpoWbhr05w2G0riNpiTdDORZX6RXKYqLPPTuhAkOThqTGTyaHp
Skb85cMb3S/SiSnncPTmN+0/rgTle3uOTL/l0KSaP9fpSWA0pGlwcoLDueDi
uS4JgZneToNqHsN3g9HLWv4EjuLQjjUjhle2GYzfDybo7czKP3CQoWGZc65P
OIGNX7pR8GmGo7Op34/HEAgFmQPX4xk+HpG23bpKYBqj65CayzDt/IfFBSnB
fOvPoaQahm1W0yFFmQSiEUvzkG6GSUejp+493Pi9caDJdpphbvyUX2MBQd6Z
9s1LfEIfp8Gc7aUEsh2DTwp3ETaImy6+qiEQZ3ct24kJNXca1j5oJvCtCnra
HEA4IJC6lnUQTDYVbjNLJPyUE7G62kNQ4bYwdVNGyB07V5A8SiD1E8re1BKG
5zO+xwRB5lnvkpluwo8p1/ieswT5PqrPlKcJ00NaLqWtEfAaRerrquP4u+G/
4S9nJWAR
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAPNbopXjUsz9Blh0AAOnmvxzBSuQz
NrM/Vu2HUt//5r8IamlwbJmyP99BrojnFue/rJ1X7iT+sT+aiT4/GC7nv8x8
sPtfZLE/6BI4EnFF57+kNIwvIMywPwY07ZzxXOe/mNN0Gmg1sD83/QR6mXTn
v/Bztox0QK8/y+18Q2iM57+IThhtMhmuPwasqpJdpOe/UMhKzw71rD/Xvz0A
ebznv0gSFp8O1Ks/XlBBJLrU57/QxLm6NraqPzPkHZYg7ee/KOHX8oubqT9y
JJvsqwXov0gOYAoThKg/c6LhvVse6L+QEHu20G+nPzegfJ8vN+i/UHx2nsle
pj9421smJ1DovzilsFsCUaU/WlvV5kFp6L/QyIR5f0akP7JAp3R/gui/0HU3
dUU/oz/XmPli35vovzgw471YO6I/BjNgRGG16L+AUmW0vTqhPzp43KoEz+i/
CCxLq3g9oD99Rd8nyejov9C6fs0bh54/sMhKTK4C6b9Q5e44A5qcP7JfdKiz
HOm/EHhD56+zmj/qeSbM2DbpvyDKpgkq1Jg/JnyiRh1R6b/gle2zefuWP8um
oqaAa+m/8CN03KYplT9M/lt6AobpvzD1+1u5XpM/3jWAT6Kg6b+Q7IntuJqR
P2ScP7Nfu+m/IPGJXFq7jz+DC0syOtbpv4B9qjo7T4w/59jVWDHx6b8Ajoc3
I/GIP5rJl7JEDOq/gFS12CChhT94B8/Kcyfqv8CEC2dCX4I/qRhCLL5C6r+A
ds/cK1d+PyPZQWEjXuq/wNbhelIMeD8pdqvzonnqvwCpt8oT3nE/smvqbDyV
6r+AA8LmFJlnP8+D+lXvsOq/AHSGgEJfVz/a12k3u8zqvwAAAAAAAMQ8kNNa
mZ/o6r8Xple5
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAwJUdAADp5r8w1uileNSzP9Tsh1Lf
/+a/GMFK5DM2sz9cQa6I5xbnvwhqaXBsmbI/GIk+Pxgu57+0nVfuJP6xP2US
OBJxRee/2Hyw+19ksT+CM+2c8Vznv7A0jC8gzLA/svwEepl057+o03QaaDWw
P0btfENojOe/CHS2jHRArz+Aq6qSXaTnv7BOGG0yGa4/Ub89AHm85794yErP
DvWsP9ZPQSS61Oe/eBIWnw7Uqz+s4x2WIO3nvwjFubo2tqo/6iOb7KsF6L9Y
4dfyi5upP+qh4b1bHui/gA5gChOEqD+tn3yfLzfov8AQe7bQb6c/7tpbJidQ
6L+QfHaeyV6mP89a1eZBaei/gKWwWwJRpT8mQKd0f4LovxDJhHl/RqQ/Spj5
Yt+b6L8Qdjd1RT+jP3kyYERhtei/gDDjvVg7oj+rd9yqBM/ov8BSZbS9OqE/
7kTfJ8no6L9ILEureD2gPyDISkyuAum/ULt+zRuHnj8iX3Sosxzpv9Dl7jgD
mpw/WXkmzNg26b+QeEPnr7OaP5R7okYdUem/oMqmCSrUmD84pqKmgGvpv2CW
7bN5+5Y/uP1begKG6b9wJHTcpimVP0o1gE+ioOm/sPX7W7lekz/Omz+zX7vp
v/Dsie24mpE/7ApLMjrW6b8A8olcWruPP0/Y1Vgx8em/IH6qOjtPjD8CyZey
RAzqv6COhzcj8Yg/3gbPynMn6r8gVbXYIKGFPw4YQiy+Quq/IIULZ0Jfgj+I
2EFhI17qv4B3z9wrV34/jHWr86J56r+A1+F6Ugx4PxVr6mw8leq/wKm3yhPe
cT8xg/pV77Dqv4AEwuYUmWc/OtdpN7vM6r8Ac4aAQl9XP/DSWpmf6Oq/AAAA
AAAAxDyKDVec
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwlkWss1XEYgHVmjjiWcpmYy1EztCyRW+oNZe6Xdmo7ShekmpqwMhUphSS5
pQuJkVKaS3OvvaphtSGXU5Rzzv/3oo4OjXLNsrQ+PHs+Ph8eYVj03mM8FRUV
qxX+ue9I2Uf2i8G4pujn7OgwTugUzGvPMejWCNfwFkoxX+LWkLTAgG/nnJUb
KsWbVzerb1pikKgjTei9J8X9ln1Mb5lBz/cr71Q/SlFiXugAqwjK+DkJm9bJ
sCTy60KFKoGxZXnq7gAZttWqGvqrE0QN5k0GZMhQq8s5w1ZAIPpw7pl3hwyX
el46ibQJmgIfv7LjyVH9ZJNOvS6BMqFTKNgpx2JrX3XReoLB6nZJb4IcE4fT
eLYmBHIF9ymlXo5VvWcnfTcQiDWeWwin5Ujua1+UWxL0F984ItLnMPm5r+t2
G4Iw8239AnsOpxwEMWvsCcojraKagzks0t3iJHQhkHIxT8TRHPosZMSf2UVw
389fczKTw9/J33T+eBLc6bPVjXvKoUcNf7rDn+CtTY+HspND7YhH010iAgeJ
ttG+MQ4VA7Hzaw8SgL6ZUQ2PYa6B0UhuOEGQW2T7kilD10r3/KAogtGOrELH
HQznptLGfeIIvMTXTcNDGDYMpbRdvkCwVZDZnxjPsOzo+9mZFAKnOD2XtHyG
X+yUEeWZBDz8IUmqZXh3T6zi1u2V3tBm64huhlXxCnFjMUHwJccWByXDE64D
OYZPVv4ceL16jk/Y7dZyvLmWoNR4oKh0I6GFmUldXiuBT3bXvJMboUKQ4lnZ
ThBSHfawNZRwIufU4mIPwURLqYHVecIZr8PF1z4T1HrPKJILCJMKGd9vjCBd
LCx4U0coS73I958iyD4UWDHZTVgY8fJ0+hLBgyC1klVKQq1GW41ltRFQ/W/8
C8+uZHU=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwtkX1MzHEcx+vWejycHkRZuUKq1UpXevAQWuQUcjY10bqe5mEoevDQIkRa
15MstdIkFaKa6IF32qoxuaUnT9f9vh96crJKXNbE2fzx3uuP9+uf997CiKPB
UTwtLS17Tf4xIfxWP/vOYGMkmfrx+SNkJgVqwU+GOQOpYYBQAVHfxoaUGQbn
1V5ZuWEKOFxw0necZSg2ViR3FyowYfeGmc0xDI2df6HTr8BhmyKPDdqEWt2c
ZEfjQYiih2cqdAg2duWX/IIGEVyrYxGoT4gdyBsPyhhE8SuvDFc+IUCecDeg
YxCX5C2eEgHhdtCdp248JbJjn5g8MiXIkzqF/PVK2DqI9SVLCPU17X3dyUr8
+ZDOc7Ui1I1wA2mPlHDoPjkutiWsMLi/UjipxP5NC+vLVxHcS66GSxZxUN8T
r/VxJrQK3Xv4Ig6RHvzjC0SEuSj7Q427OPBNXTyF3gQRd7wy5CiHBnVG4jFf
wldxoNF4psZPHTH57U8Y7nY1ja/mUPlAb7IjkDDPWb5Z1ckhTnp7sktCONsr
sNwzxMGvN069cB/hvNkyy4c8BpW55adcKUHmG90+a82QXbkpf+chwrKOrKI1
6xi2TKSPbYsnpO69Yi0NZeC9S2s9d5oQY5TZczaR4Uv4yx/TaYSDcWbe6fkM
Vm6qyPJMgsuzb30ptQz9fnGjsmua/q2TQ+RrhuGE0ZDHJYSklDVNHiqGEp/e
HItKQmfoc4Ofeprdvk0xjbWEtqW9xWXLCbutrerymjX/yLrUnhsJAn6af1U7
4URNRGlzGGF+zuFfv+QEnaayxfanCMZbD5RcfE/o2Do9mlpAuH6D6W0fIhTu
FRa01RGmLp7RC5wglIbtqBh/TaiWthy5PEuo2qF7U1tFMG9wNZzT/YR5//kX
gyxykQ==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwdjAss1AEAxv+T1oqsYSalaYxJi7zODn3eLSqP1piTwxKGMEd3unHzVree
I4c4F+c6xnGRR6LNypnG5jwaC8vu//9fnShtytDVt3379u337TudlBWVbEAQ
hKPe/zKixpogaA3M56hWrlqJW7qKqOV9DbZGQ9fcPJVY9++sJC1IrKWlZWeI
eiCvugDLcyQqn0ev2+11Y9vUyzQnmEQLX7HDvtkNC3ddw2YcCYG70NlmUoGL
u4YFIg4JzgzHKtVDgUUdPzBVSEKW2yfk+HXBokP+5EYLCa+rlpmuxztBjfgS
vDcktj+ETpn86sDtCH+7QTUJwtSiyUTdjqA16xobHQnu2MCgZ58cpXb139oP
Uphemf9xv/4lyiSrw6xTFLaPJhwxK5Xhkpjf5Myg4HXsbt90VhvuLbLsHSIo
EPz8RlW8FJmsWY1/GoWNFgXLILIVY35tnKJiCoLxUl5RSAu0tb+TluspcPMY
ecF4ASu3hKDEXv3e+ctwjLcEV7hLcsMpCi5Rya+Gmc14FLzsoKIo9DuFtXN9
xRgbD73caUDDZbDw44mKRrxnc2TKkzQUa+teB+oasMezn1zwpJF9J5DsUtaB
yZeEWEfSEKikh8+oa7EilUgF6TT8qnVK3k4NEvdYBQblNBJsOUtSx2pseQjC
JWIa4q0d1kD8U/AaoGQP0dj4WqXrr3uMWqMwV+YcDZuNqrjYoYfYXZiNOb+p
/+PLmd7hQihUz3qCjLVYEVYwbDcr8eDQ1ESugxYJ13oXbJrLMGIZcPZtgBbi
EqOUAHYxmJ/8E23jtRjlTC05RRcC+e0/JTwtBOrVgihjLibStRk+1VoQba8n
zD7nQFPy5/p3hZ7vv9OYi1KwOZ/GGJrU8/RyQQA7GrKZWFETpe//JfP5Cx4n
Sc0=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVzH0s1AEYB/DbpVoxM6RLaVfs0JvFOCN598dpc6xGTg5LiCbrxCEu5KVu
60XknLlzceTEcZH3b/WHxdhZO2FZkna/310dyVpELz/P9t2zz77PniNJmVHJ
dBqN5kple1vMkM25Og321TjQaAY9vr/mfPHw0sDFVB618E+P+atp1zMk3Xge
2FFB2BGoaIhedvrbhSuVZ/0Zpwi031Jv8i93odva2zorlOo9xW7MCTUmPUz1
q3EECnQC+1RPNba2zPIkAgJ92b1iQUAnxKaC4FQxAS6Xcc39QAdGVW2PLjUR
sBrnaC1/tqMKfjThEAGmrZ3MUqfCfm6g04COQO1o/4BXbxuMSw41TBOB9c8z
P+5Jn4HlJP2m2knCxSphr01pK1iKxWHeYRIJ1vm9U5kt0MsKZG5sqi+82TAW
r4TTBx7LmUuC2aLm0SObYcab1gemkWgdLxUWhTXhYkCLoKiYhDyHnR3q/xQF
tRtJC1ISVu5LwzG+CrS6J4Qk9pDgnk9+MezTiLmc+TYzLYmpk+GqXD857EMX
nMdIqh8pnDxY3gDOW865DroBU+Sy9466enD4glbNIQMe5AcTnZo6FAlZE7Ne
lCeVe47patGXrwhziDQgQGLSCDdrEKtUKEXpBiQ4C+aVrtWY+8PLo5dR9+ub
vP74KqR6iiIUcgM+rVSa+uoe4qvUX8MfNED+qzIudvA+dpuHu/u8p1zS5uMb
IUbq7HTM6VXq/+NytuNqBRhjT7pDLIyQx/bMMhvvYG2XdvyGM+W75ilB/GIc
ZQSdGAky4tVt7fzx6ELUzQYmOsZTXlzMi7LIRX22ak0hNEKkeTlu8zELjunG
jDPVlBlv9LaSFPiV/L6wojaCJi0TBfGjETqTxh6coLw9InJo412sREYa8R8D
0W5M
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwtkH0s1HEcxzE5D9eiw8SmrlqFHlxJpLy5SkOX1GkxIk+1aCklelBcpXST
p6zGxJJUa1GTOHqwYVkec6S5u9/3owcPUyk6sqxr64/3Xntvr79ewsiju2MM
9PT0HHT7Rz8z6Y/JjwPYH3Gnl/1k8DKNMvUVqpAqKNCa/2LIXOuelRumwkql
97PUKQYLgSql65buX1xl7DTDcGIk/Y1hrwq/l3czq1mGfbycFKf5alxYXOgK
fcLg8rLLW3eqERj7earckOD9Pm9sZ6YayVWGthJjgkdn0kPfZjVa37pniviE
yoB7DesMNHjRUe8mNSf8SGkR8j016D70XFBtSfj2uEnZlaJBgqO/sXQBwWiY
65NVa7B3IMNAZE/INn20TDiuwbWuk2P+Swja4msRUmsOb8QWT8tWELIWr3/H
d+Fw5JH/Jo/VhL5Yh7jaQA6fXfnH5rkQbNixiuCjHG5aOrsJNxIGdkjMxuQc
JFOZpxK8CKxbZJn4gMOctC+CPz4EyzUdW0ZbOARV8sabJYTrSnO7oE8cHKPv
jrdJCbetF9lVGjCYKI9rLUIJNd6xTTMLGRQ2doO5UYQ9LVmFGzYzxN8X5++K
IzQEX10YFcLgPJ4x7JdIeMyXvzt3ikHbL3uVdoZQn2i1MSOfYeRA6+SEjCB/
+VWZWsXg5DIaXSYndPavcoxuZ/i27fjQ9RuE4fMb6lxHGfjJQ8E1xQRx6GuT
Xzydt6knx7aC4GPfU1S6lOAprjtYW6Xrld2mdfMmlCyyf5KnIPArI28rwgiH
58p87jcRyhWlNg6nCUm58dPTHYQEv4mhCwWEy77hxZc+ECQhwoLGJwTbIsbb
8YkQGh5QPtZOSM84y5N81/mBRiX6o4TtMfVHrszo+taITGeNBtH4n38B5CVL
ow==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwlkH0s1HEcgDFzXm5LoUTh1ORlmYt0RJ+oLHmtTutEhNSmlghdSYUoGfOS
1ZiypOtFoSlv9cHmLCvy/rLu7vf9SCnTUl6nLK0/nj17/n0EEWcOHNdQU1Oz
WeafJXrinzOfPkJz+P0B9ouhq26krrdAAcMGRXP6swxjt7jk5Icq4HK/x8uU
eYa0SiHtvqOAxPTN2naLDIXfUt9qDijA3bqHGS0xVOflSe1WKaHRstgZ1AnP
byrP2O2vhPToz/MVmoStgwWT/llKKK/WNPHTJpR1JT7xlivh+zuXLCGfUCfg
4WtHDRWMdDWJxPqEImm7gL9DBZ9O1hnUGhJaPm/r75aq4Lytj7Z4LaHVODeY
VquCQx8zNYRmhCU6lVaCKRWkdidM+mwgPFd6M1y8moM6z5Uvyq0J1S239vKd
ODhY6eO23Z7QM9ompn4/B63O/LMrnAil3FmZ5AwHpwwdRAJXQidfP73JbA7W
zGclxe4kdOgRGsY/5kB+5YvBHy/CYPuuXRPtHPCreFNyP8J3ffqmQWMcDEY+
mHovJuw1sjCt0mDwtC9ubmUIIe2Mbls0ZxBkbDqaH0mYIM8p3ubO4LfMszAw
hnDo8A3zyGAGtT8yv+6LJ2zRy+69lMQgbjit+epFQnmckWtmIYOQYx0z02mE
OW++96dUM8h3nIgqzybsGNpsG9XJwHdP3HjuLcKRlG0NzhMMwpLGJa9KCe2O
tOjM8giM3fryTGSE1uv7Sso2EiR7NJyoryb8kPt+TuRB0GNuVlPQSKh8FnG3
MZQgn5/m9aiNMLahzNjmwnLnnVpY6Fr+4z09fqWI4PbesNJrI4TaEkFRaw2B
RTHj+Y4R6h8NqJjsJEjJSOb5/SBcF6h1T32CQBTVdPr6ImHqS6HuktYoyP4b
/wKiV14o
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAARNXopXjUs7/GlR0AAOnmPxTASuQz
NrO/5uyHUt//5j/4aGlwbJmyv3hBrojnFuc/lJxX7iT+sb8+iT4/GC7nP6R7
sPtfZLG/lhI4EnFF5z9wM4wvIMywv74z7ZzxXOc/WNJ0Gmg1sL/5/AR6mXTn
P1hxtox0QK+/l+18Q2iM5z/gSxhtMhmuv9yrqpJdpOc/iMVKzw71rL+4vz0A
ebznP4APFp8O1Ku/SFBBJLrU5z/wwbm6NraqvyjkHZYg7ec/MN7X8oubqb9y
JJvsqwXoP1ALYAoThKi/faLhvVse6D+IDXu20G+nv0ugfJ8vN+g/SHl2nsle
pr+W21smJ1DoPyiisFsCUaW/g1vV5kFp6D/AxYR5f0akv+VAp3R/gug/uHI3
dUU/o78Umfli35voPxgt471YO6K/TjNgRGG16D9gT2W0vTqhv4x43KoEz+g/
6ChLq3g9oL/ZRd8nyejoP6C0fs0bh56/F8lKTK4C6T8w3+44A5qcvyRgdKiz
HOk/4HFD56+zmr9meibM2DbpPwDEpgkq1Ji/rHyiRh1R6T/Aj+2zefuWv1yn
oqaAa+k/AB503KYplb/o/lt6AobpP3Dv+1u5XpO/hDaAT6Kg6T+w5ontuJqR
vxSdP7Nfu+k/4OWJXFq7j789DEsyOtbpP4Byqjo7T4y/q9nVWDHx6T9Ag4c3
I/GIv2jKl7JEDOo/AEq12CChhb9RCM/KcyfqP6B6C2dCX4K/jRlCLL5C6j9A
Y8/cK1d+vxLaQWEjXuo/wMPhelIMeL8hd6vzonnqPwCXt8oT3nG/tmzqbDyV
6j8A4sHmFJlnv9yE+lXvsOo/ADOGgEJfV7/x2Gk3u8zqPwAAAAAAAOk8stRa
mZ/o6j+0nle4
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAACJYdAADp5j8w1+ileNSzvxvth1Lf
/+Y/FMJK5DM2s7+gQa6I5xbnPwBraXBsmbK/Wok+Pxgu5z+snlfuJP6xv6YS
OBJxRec/zH2w+19ksb/AM+2c8VznP6w1jC8gzLC/7/wEepl05z+g1HQaaDWw
v4DtfENojOc/AHa2jHRAr7+5q6qSXaTnP5BQGG0yGa6/hr89AHm85z9YykrP
DvWsvwpQQSS61Oc/YBQWnw7Uq7/e4x2WIO3nP9jGubo2tqq/GiSb7KsF6D84
49fyi5upvxii4b1bHug/WBBgChOEqL/an3yfLzfoP5gSe7bQb6e/GdtbJidQ
6D9gfnaeyV6mv/ha1eZBaeg/UKewWwJRpb9NQKd0f4LoP+DKhHl/RqS/cJj5
Yt+b6D/gdzd1RT+jv5wyYERhteg/QDLjvVg7or/Md9yqBM/oP4BUZbS9OqG/
DUXfJ8no6D/4LUureD2gvz7ISkyuAuk/wL5+zRuHnr8+X3SosxzpP0Dp7jgD
mpy/cnkmzNg26T/we0Pnr7Oav6x7okYdUek/4M2mCSrUmL9OpqKmgGvpP6CZ
7bN5+5a/zf1begKG6T+wJ3TcpimVv101gE+ioOk/4Pj7W7lek7/fmz+zX7vp
PyDwie24mpG//ApLMjrW6T8g+IlcWruPv1zY1Vgx8ek/QISqOjtPjL8NyZey
RAzqP8CUhzcj8Yi/6AbPynMn6j8AW7XYIKGFvxYYQiy+Quo/IIsLZ0Jfgr+O
2EFhI17qPwCDz9wrV36/kXWr86J56j/A4uF6Ugx4vxhr6mw8leo/wLS3yhPe
cb8yg/pV77DqPwAawuYUmWe/OtdpN7vM6j8AnoaAQl9Xv+7SWpmf6Oo/AAAA
AACA6bzCFliX
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAYmCj1uHz4b9KC1Ty9eTcP4ITlvcQ
9uG/PwpjCkkh3T8w1UG2fvjhv4kyOY6SXd0/LoQtCCv74b8PE9150ZndP/wn
0uEV/uG/ceqCyQTW3T+CIps2PwHiv1UHkXkrEt4/Umbm+KYE4r/fJ6SGRE7e
P3qxBBpNCOK/PdiT7U6K3j/MzDmKMQzivzbQdqtJxt4/wM+8OFQQ4r+rT6e9
MwLfP9RouBO1FOK/7XnHIQw+3z9wKksIVBniv+ivxdXRed8/VtyHAjEe4r//
6ODXg7XfP4rRde1LI+K/iAqtJiHx3z/IQhGzpCjiv/Oei2BUFuA/bK1LPDsu
4r+JIjXTDDTgP+Q2DHEPNOK/02Ypa7lR4D+WFDA4ITrivxPhcahZb+A/SviK
d3BA4r/XTE0L7YzgPwKB5xP9RuK/3NIxFHOq4D9SsAfxxk3ivw4vz0Prx+A/
JmSl8c1U4r+J1RAbVeXgPwTVcvcRXOK/mRYgG7AC4T+3GBvjkmPiv7BBZsX7
H+E/ZqlClFBr4r9Mx46bNz3hPyrxh+lKc+K/tlmJH2Na4T/x2YPAgXviv6gM
jNN9d+E/5GHK9fSD4r+1cxU6h5ThPyQ062SkjOK/hb/u1X6x4T/oRXLoj5Xi
v8nZLSpkzuE/BXjoWbee4r/ifze6NuvhP8g81JEaqOK/OlzBCfYH4j82Qrpn
ubHivz4e1JyhJOI/mCAespO74r/ukM33OEHiP2ENg0apxeK/BLBin7td4j9s
kmz5+c/iv527oRgpeuI/fElfnoXa4r9oSvTogJbiPw+c4QdM5eK/RFohlsKy
4j94h3wHTfDiv1NfT6btzuI/PGW8bYj74r9mUQagAeviP7e3MQr+BuO/0rcx
Cv4G4z/bI1+e
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}}, {}}, {
    {Arrowheads[{{Small, 0.5}}], 
     {RGBColor[0, 0, 1], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQvSBXSjql76o9s8/NbVNvH7S/8i8x7H7TVfsD8fen
Hfp+wH6DXkXAx/Kr9rO1bxy+KHzAXqeqTmZW7lV7/jOVMzvj99k/Sew7czP5
qr0IX0Gj1fQ99hZeOws3RF21l5N2jdt5bpd9RyyHjFzQVfvrHUz+nGw77RUK
am4peV21V+RjKda13W7/4Snv7n1OV+1/c396qVGy1Z5n1ppTH62v2h8V3XP5
36rN9ion7EX3mF61V6ucHLDp4Ub7Gd+XLpU1uGqfcvRpg5vEBvuKF1taxbSB
5i9Zx1U7d429R5PlvmVqV+0P9lX/teJaab/iyPewc0pX7U84msqcLVtqv2bn
qrBe+av2ynnaKy0fL7SXyGI5/Fjmqv0FnvtneefPsS+4vHbBRamr9qemTDYo
K59qf+C+2+cwyav2W913MhTN77GPiU/bWyxx1d5o+wTe7vk19g4ssxg0gHyG
b/FS++ef3ZMAlb+9Dyy//whUf4k3WP9+mPlbpoHN3y8DtX89H9j+/Vug7hPL
B7tv/xao+7c6gd2/PwTqvw39YP/t74D6/9hSsP/3r4CGzx1I+Ow3gYbfLEj4
7VeAhq+dGDh897M8g4R/CQ84/PdbQONnKiR+9i+Axp9PJzj+9odA43cKJH73
MyRB4r8DEv/7faDpowmSPvafgaafq5D0s/8HNH39hKSv/Ueg6c8Wkv72AwD8
LUoA
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtyn0s1AEcBvDfzBy9ubVyRo7DEqPO2/TiPGFe1i5xrKjOW0THLXcc0RSW
YTOpvNW8dAh5Wdd5f+1uRqO8TOE4d05pwohrrdUf6tfWd3v27LPny4i+zYnV
IQjClsy/fs43MY0pmgXBXugqVcrh8qSPka2ehX/pqUTaVTnOO/GIzZNzaFKW
OYcuyGD0wN1HfH8OxRLRcGiYDF65isy66TlQV3xqnTveoLI83W2XMQ9m7hjj
dPcQpq139gqS50F1XE6Q9Q+izLM2kj9C7tHjqxPyAaQGFX59RlOA6da4HTXW
D+sWT8vDPAVkGfHrmTN9SGFtVcwMKECVzDpZqXqhceHMKw0XoLEqOB683oMS
8fs4hxuk/2yZGf7sxlk65+No1wICozySQvW6oZsmbGjctwiJMFvIpHWhOig0
bip8EZr8grQK205kzY7VsNrJ3Us79YjVgekQW8UuRQlmK33cLLgdiz9EFZvX
Sce6SVk8KSy57Hg7KenxEzPanNdYurI22UZZQiBDLPCokuBInkWwiLsEosSs
1Vv4Cpz9grtZ7UuQLbvnure1YZSpnZg0UIHIEe7c2mzBtmn4dESkCpEBegmT
9s1Qp1L1nbtV0OhL+YmCJuibU377HVJD86Uq0be3ATEfPtlVx6phQeXOh+u+
QMjnNbrroBqE64ZxD6cOO6q9sANHlyGj1ZeH1Isx5NkZYcUnfbmEx9fWwNjB
oz19hHSMtkpeW4mUvN4EiqEGWe8uZTSHPYWBPc9GcI60t1+jPa0MRUYjE7/i
SLuaDLOVj3GxUGouLtGAuBYyQmc/xEb4N9VNOemhVUvtdj4MfQ+OXdgm/2N0
6o7V5MDvTLKYbboCovgtP6D3DozGuTaJ/qSTHL/zquPBvrds8lJE+v/9Bdpm
OSM=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAxG0aG2SO1T84TNm2ldvBv1aTuiGB
3tU/iJUvbBdawb9kMmoA6y7WP+DbljNY2cC/NoQ8RaF/1j/IsHXDWFnAv2KF
2H2j0NY/kOFFojO0v7+8l3k38SHXP6CFySE4t76/8CTw/olz1z9wMd9rwLu9
v7JBomBtxdc/kGLK5M3BvL+SUYzomhfYP7A3p+5hybu/PqtBIhJq2D8we2jp
fdK6v4w97ZjSvNg/cLDVMiPdub/4NFLX2w/ZP0AkiSZT6bi/rqHMZy1j2T9A
AO4dD/e3v1AeUtTGttk/sGE+cFgGt78Wd3KmpwraPxBzgXIwF7a/slFYZ89e
2j9AiYl3mCm1v5TVyZ89s9o/AEPyz5E9tL/gVCnY8QfbP5CsHsodU7O/7vV1
mOtc2z+AZTeyPWqyvzBdTGgqsts/gMoo0vKCsb/oV+fOrQfcP6AhoXE+nbC/
IIcgU3Vd3D+glB2sQ3Kvv2ALcXuAs9w/YOA8hTytrb/QMPLNzgndP6CCcvBp
66u/+Bte0F9g3T/gTgZrziyqv+p2EAgzt90/gAmybWxxqL8QHwf6Rw7eP4Dm
nWxGuaa/atPiKp5l3j+gEF3XXgSlv1rj5x41vd4/YDXqGLhSo7/03f5ZDBXf
PyAYpJdUpKG/wEG1XyNt3z/AV5RqbfKfvxotPrN5xd8/wGXyncGinL92h7lr
Bw/gP0DMT3qqWZm/CixqJ3E74D9AREenLBeWv44Wxc35Z+A/QDYaw0zbkr9M
jLIfoZTgPwBdVMUeTI+/517v3WbB4D8Av+Qi8u6Ivw5GDclK7uA/AGYCoxyf
gr9EOXOhTBvhPwCUx21OuXi/E8pdJ2xI4T8AdjHzap5ov0l+3xqpdeE/AAAA
AAAAwLy7SVEl
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQzeBzc9vU2wftF+RKSaf0XbWvqP5tnJJzyH7BiuA1
m0yv2mssePtA5t8he4tyz9DEu1fsbzyfv2/fhMP2O25N3FDQesX+RFjWGQ+V
I/a/JktGPNS9Yv+ig49j144j9j9ElZ9uvnbZ/kHpzlxBv6P2kypdP7yov2x/
wpz1h++To/ZpRdmCjZpA+Su/5udVH7P/43Lpfs3lS/Yd3CKxRcLH7Vn2cXy6
U3vJfoKirWrEmuP2l7Te3V2occn+ztZrb+TcTtgzBW+0OHP5ov2MKduXHX1w
wj6r+Py0mPqL9lv69Fy8a07ay1gJ9wRrX7SvCGbZuk7ilP2Jw5NXb7x+wf6N
T+3zd1tP2bvN2txe3nLB3qU++gRXyGn7kC3ym5YaXrAPyXrgxPj5tL3K2znl
lfvO2yu8O+dwcdIZ+yvZfzOrpM7bPzHMXVVpfNb+RmlulH/5OfuK3ra0n1fO
2qdA6Q9Q8RNQdR+g+nig5jhAzbWA2hMDtVcD6o4gqLsuQN15BeruEKg/NKD+
mgP1ZwXU3y3QcBCBhssBaDg9gIZbAzQcRaDhWgANZy5XSLgfgMZDATReNkDj
aQE03g5A45FNDBKvF6DxzDYFEu8boOngBDRdHICmEw9ouhGApqM10HSVAE1n
66Dp7oU3JB0CAEodVF4=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAh4/pRa5cYa6XzTVZtU4Y57V88jIvhcWoqLWS17yeUl5LsU61
ipT3SreWl2PjQhM7Xd7zdrjf9/fjbCy9bMhKMkoubf3x7Pnr+ePZHRznF6rJ
YrH2r/HP6mOjjY9VcpTF7NgZcp/C11mj8oSKd2AiE7uciigEno/ZJ0hsw7dn
vSeLXlBoCqnijju140yyTsvFWgp3334OCNvSgbTOK1MNLRR0vwTJhsc64EXE
LSk9FMi9SHNeeSd2PUgSNBEK+h7P73hf6gI/28pB+JFCFU8mCUQ3bPeEvxHP
U1i1lCS46PSAU7Pw1FuD4Jpnlkyb7gE33kAp5BB8jy6IlYjfo1QV4KrLI0gS
hQXvje3FqSf5oybmBG5LFclpdn2ol7PTG44QqPnejyq1+sFTOhnKfNd6u5SH
NYP98GLp5+ACgVyY6y8qHoCXVeOAXSKB1h+zZkHoIMZdapuqRQQS28IRlaEC
HuwJ68JiAn0rsrIuXYHSossHVmoIyjape7gfFMjyWkpl5ARhc5MSPfchuGq4
s00JQe5ClN6iZAiFNnmty9ME7EmpsJUzjAiH0CRHFo31szM2cYnDqPYp4f42
oCHIF9JaY8PgKCNvmPFp/Ihok193HEFayuk8lTMNo45bERPiESgifQ+qA2n0
SUSHjTcocSg+06JYSKNR1CQ9GqWEwjwjtfo2jaxFG/uAQSX6/EynBWIavbnu
bs6WFDZKu4Ksm2mMvj7hubWAAjtnqrJGScPHf7VB/ovCuc7oVyVzNMIrNNV+
ZwlKl1/6sbQZcPX8C9rXPpP6TYNVxgxmGd15AxMa3dt/NvPBIGcm46ZbNo3j
PE+7hSAG9nW8loAZGvVtA1KLqwykvQXbXHwY8FszWZ/yGJhPyJY31zGw+u+/
OORN0A==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtkX0s1HEAxo9Y3oq8V1tdk6XlwrynPHmZl4ZhVNRaCbm8nlLeGmGd2oTI
eat0a6GjoU6T2+m8dnnnft/fj7Ox9LJhZiajlK6tP5599vzx+ePZcygqOTRG
ncViHVXlH+sS9+2PfkhhR8BU+2OlDDPctAGPKgorSwfrUxu6sfJs8FzVCwoX
ryRaOab14HKGruR6CwVJ9CvzGY9e5PbfmhdLKBR9+BYeu7sPwUQoyZRTMPwe
KZ2Y7gO7ON2xg1Bgiri27Pp+WBc6uPG+UDD1e/4g8MYAXA5fey9cpdDElooi
8BHGzWtPA9UItu1FqV66cpinmCh4BgQ5/gVSbVqOWmW4tz6bYDVBkCQSfsL5
JxVTlrYEmfzYqCNJg3gr07sjPk3gs9GQke06BLbCw0waQqDGCSxv1BhGAMu4
BFcJVlwzHzWPDiPYoX3ENY2gm1caxq8ewYxXS0cTn0Djt02nY8wo/PRmnSqr
CUQulZNKszHUVt08ttVMYORAtjTvjKEgYCOLkRHU6WzLzT+PwVvNV49DCGKX
50RGvuMody7r2lwgKF6LN1oXjSPOLSbdnUVDZ66N12UwgaagGvNfJjQ0lxad
k9MmYKDg3rWxpmFfwaM1pieQnXmhTOlJYzWuR5bjPokxbsjx7QgaB/ruxc0K
J3EyJd+umkdjUMQ/ZbFTgSHb3Kym+zTE/I62M/GqHspZcBTSyFt3PhE+qoBW
20CkUycNeamvj6c9Ba2S+cZmBQ3y7qz/HoHq5/6ENzXLNALC/ohlPylUbr4M
ZWkziG5Q3w69RJA+zIlSWjAwNQoT9Kp29+790WkNBguM/qqJpcpj+7uuRTIo
WszN8ymk0dIz0mZ3m4FTK1sSvkjDqiuf9bWMwetBgaFXEAOHWenmrlYGnP/8
C0DuS78=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlkm1Ik2EUht/C4KUkXnGErbGUVqhhUBJJVHdERpGWtMqhBhomtbYaFo7l
ZASrKGz0Yf0IQQOLKIk5c1k/dtbccul0H+9mZkkLikbkGNWPVRR9nB8PBx6e
55z73PdVdPjkviPzBUEo+Xv+Va9RuazZkUBF1Sv3jdfPyHtP2+9an4Cz/Wd5
s8FHdeZdB5pm49D1ziVVv300PXPVaToXh5Tq8XiujJCqa6nuXVkcQq0+tFPj
J+WSFR8Gp2QUXlwsPh32k8tSmUnZZEhtT4x5ewJkbz2ed7ZERnbDgmz1+wCp
KmNvrXIMUuJHz4n256TxiF/edMQwvEhxqDV/lL6VpmdvF8cQLNq8Utc/Shrt
QEVIjkJyT31W7whS56nwzQZbFKGux3cDySBt2pjfqV0dRcqxZvtu6wv6NHL9
wcDLCPq0OUMPC8ao5dbgBbM9goLqjo/poTEyPVruurM2ApOtPrhw/zg1znWb
LZ4w7Prktnlfx0ky/Dp2RhlGTXpya/RaiBRtxrq95klI64z3LeUT1Hf5fMv3
+AScXCmX71HI76iK/0HFfcjKfXGU55CB5+I06yAF64KedVI360aG96Bp3gtb
eE/y895wsA8ksC9YxT6Rl31Dln0kJ/uKUvaZRPYdas6BMpwLLnFOJHJucHOO
JHGuUHPOlDn4P3eomQMSmQvMMCdUw9yggTmiXuYKfuaMipk7+JhD+gNnGmBj

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAwG0aG2SO1T82TNm2ldvBv/RpdcdB
mdU/Gu0fp3Kowr8IoMtXmaTVP3phbSg1dcO/cHkLvGqw1T/QZKoY3EHEv4zG
duO1vNU/lsDmVWYOxb9U1qK8esnVPw7nWr7S2sW/II94NbnW1T/MjWkwIKfG
vyyINDtx5NU//kehik1zx78wJGe6ovLVP4sgvqtZP8i/CK30nk0B1j/TM6ty
QwvJvwhwFdRxENY/SEmEvgnXyb+E21VEDyDWP7Fsl26rosq/PJ2W2SUw1j8w
h2ZiJ27Lv5TBDH21QNY/8PeoeXw5zL/800EXvlHWP6EsTZSpBM2/IAAUkD9j
1j+HOXqSrc/NvyA0ts45ddY/TXGRVIeazr+kQ7C5rIfWP4f8L7s1Zc+/EAzf
Npia1j9mOJjT2xfQv1yZdCv8rdY/yzPW/AV90L9ATPh72MHWP1IK/8kY4tC/
/ABHDC3W1j8T7uCrE0fRv0Q3k7/56tY/OPRrE/ar0b8UO2V4PgDXP6/fsnG/
ENK/VE6bGPsV1z+j6+s3b3XSv7DTaYEvLNc/zpVx1wTa0r8YeluT20LXP4do
w8F/PtO/ZGlRLv9Z1z+uxIZo36LTv8xvgzGacdc/VquHPSMH1L9YMIB7rInX
PzyHubJKa9S/UFIt6jWi1z8E9jc6Vc/Uv4ixx1o2u9c/RpFHRkIz1b+Ej+Op
rdTXP1C3VkkRl9W/0MVss5vu1z/BU/61wfrVvwj5plIACdg/1acC/1Je1r/g
zC1i2yPYP4ISVJfEwda/JBn1uyw/2D9S2A/yFSXXv6gfSTn0Wtg/8OqAgkaI
178Iw86yMXfYP5SwILxV69e/fL6DAOWT2D8Iy5cSQ07Yv3zevvkNsdg/hN6+
+Q2x2L/Y919U
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAGkzZtpXbwT/QbRobZI7Vv/7sH6dy
qMI/BGp1x0GZ1b9fYW0oNXXDPxigy1eZpNW/tWSqGNxBxD+AeQu8arDVv33A
5lVmDsU/mMZ247W81b/15lq+0trFP2TWorx6ydW/s41pMCCnxj8sj3g1udbV
v+hHoYpNc8c/OIg0O3Hk1b9zIL6rWT/IP0AkZ7qi8tW/uzOrckMLyT8UrfSe
TQHWvzFJhL4J18k/FHAV1HEQ1r+cbJduq6LKP5DbVUQPINa/GodmYiduyz9I
nZbZJTDWv9z3qHl8Ocw/nMEMfbVA1r+NLE2UqQTNPwTUQRe+Uda/cjl6kq3P
zT8sABSQP2PWvztxkVSHms4/KDS2zjl11r90/C+7NWXPP7BDsLmsh9a/XjiY
09sX0D8YDN82mJrWv8Mz1vwFfdA/ZJl0K/yt1r9KCv/JGOLQP0hM+HvYwda/
C+7gqxNH0T8AAUcMLdbWvy/0axP2q9E/TDeTv/nq1r+o37JxvxDSPxg7ZXg+
ANe/nOvrN2910j9YTpsY+xXXv8eVcdcE2tI/tNNpgS8s17+AaMPBfz7TPyB6
W5PbQte/qMSGaN+i0z9oaVEu/1nXv1Grhz0jB9Q/0G+DMZpx1782h7mySmvU
P1wwgHuside///U3OlXP1D9YUi3qNaLXv0KRR0ZCM9U/iLHHWja7179Mt1ZJ
EZfVP4iP46mt1Ne/vFP+tcH61T/QxWyzm+7Xv9GnAv9SXtY/DPmmUgAJ2L9/
ElSXxMHWP+TMLWLbI9i/TdgP8hUl1z8oGfW7LD/Yv+3qgIJGiNc/rB9JOfRa
2L+SsCC8VevXPwzDzrIxd9i/BcuXEkNO2D+AvoMA5ZPYv4LevvkNsdg/fN6+
+Q2x2L9twF5/
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtzg0s1HEYB/A/lo1rbQmJHQ4tMSZ1XrbO95rJW415O+9dUgxRSom5rGit
wsK8jZzXc4Rz5kp60eZtoW4xiYVzd//YJFQ3RerX1rM9e/bZ93m2hxWXFnRe
m6Kow6T/TX/BvKk4QwHqf/UU751NLic2KFeaOMeh0a6hw6OX2NyeZWGdDs6m
VjZrlnjz6Hcn82wIWEUHDX8T8+JSmbtuwSW0tsTYYhG50V4rVVfuYGk+q9X2
xCKorduZBTP3MNkfE+B3jnjfWM26exF+vbyekJ1PXBqjUYw8hL1g5UOfiNw/
WMuh1ktgUTqRz3hDfEHRHWRUhvoat7CkFbJ/MXV5il0BWbCZ4/QeJXL3T6Tf
D6qCXJi2EXJESf7xFaUmV8NYxry7EExM6ysEuY8gstSezLqmhKWv2OOTjxCr
c1+eWVeSfMBxtSigDlsZzazZPiUW/GSSsJB6LOnSK8I5Jbi9cb1OvAb4xUdp
ZWipwP3z8TgzvBHVh1o9eTYqLLz2umzGa8LoUFKFt7cK/J/BhXYhzZCK7VRe
ScSFruO+ASJIkcIIKiD3mpbETJ8WeBmJNpIlJH9LV/dAjKZlb0HJhAqWGTIR
xW7FpQFJ8YhGhdyG+JFw2zZEM9wNGaZqCHWG8OLAY3wrd/gcyVGDP+wa6KDX
jtBx+dcnfDW4HCGnRdMOnY5IA6s84vi00w6LHZCsbzpXiogFtUN9o52wNHvH
Zo6qIZfPZIojJNAr1Oy0r6oRaHN2940xCbYbBen+BjTkaxLPUx5diB1OufqD
TdweO2jV2YXom8+X2iJo9EcMum2bS6EpOtOdmkOD/0r35HSBFDv6Hk85dTSo
PkaZbEuKYwkusyaDNISCvPdlid2IKmNS1DIN7tRSU+ZkN/4CTL89oQ==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQLepzc9vU2wf3z8mVkk7pu2p/Of7+tEPfD+y/8C8x
7H7TVfsN2jcOXxQ+sH+FXkXAx/Kr9jZnKmd2xu/br1FVJzMr96q9K19Bo9X0
PfsfJPaduZl81T5I2jVu57ld+w28dhZuiLpqz9vJ5M/JtnN/QyyHjFzQVftY
PpZiXdvt+yUKam4peV21t+T59FKjZOv+J095d+9zumrPLrbn8r9Vm/ezzFpz
6qP1VfvsyskBmx5u3C9zwl50j+lV+/VHnza4SWzY3/N96VJZg6v2RUvXcdXO
XbM/48WWVjHtq/ZJ/dV/rbhW7rdpsty3TO2qfZ6TqczZsqX75xz5HnZOCei/
PO2Vlo8X7p+zc1VYr/xVexO++2d558/Zz5PFcvixzFV792mTDcrKp+5PuLx2
wUWpq/ZnvXYyFM3v2b/hvtvnMMmr9i17J/B2z6/ZHxCftrdY4qq9zI6zCgd4
j+0xYJnFoAHkM+wAy9v7QOUZPMD67WH630wBm28PM/8yD9h+e5j9yhD32S+A
um+nI9j99jD3r+0D+88e5r/DS8D+ty+A+j8EEj72E6DhIwQJP3t4+ImCw9ce
Fr73uMHhb/8CGv7MkPixl4HGz7YOcPzZt0Dj77sUOH7tTaDx+4YXHP/2T6Dx
/+Q0OH3Y60DTRwsk/divgaafpZD0ZX8Fmr5eeIPTn/0CaPoDALf9Rug=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAGEzZtpXbwb+abRobZI7VP2iVL2wX
WsG/LpO6IYHe1T/A25YzWNnAvzwyagDrLtY/qLB1w1hZwL8QhDxFoX/WP1Dh
RaIztL+/PIXYfaPQ1j9ghckhOLe+v5SXeTfxIdc/QDHfa8C7vb/KJPD+iXPX
P1BiyuTNwby/jkGiYG3F1z9gN6fuYcm7v3BRjOiaF9g/8Hpo6X3Sur8cq0Ei
EmrYPzCw1TIj3bm/bD3tmNK82D8AJIkmU+m4v9Y0UtfbD9k/AADuHQ/3t7+O
ocxnLWPZP3BhPnBYBre/NB5S1Ma22T/gcoFyMBe2v/x2cqanCto/AImJd5gp
tb+WUVhnz17aP8BC8s+RPbS/eNXJnz2z2j9grB7KHVOzv8ZUKdjxB9s/UGU3
sj1qsr/U9XWY61zbP1DKKNLygrG/GF1MaCqy2z9wIaFxPp2wv9RX586tB9w/
QJQdrENyr78KhyBTdV3cPwDgPIU8ra2/Tgtxe4Cz3D9ggnLwaeurv8Aw8s3O
Cd0/oE4Ga84sqr/oG17QX2DdPwAJsm1scai/2HYQCDO33T8g5p1sRrmmv/4e
B/pHDt4/QBBd114Epb9a0+IqnmXePwA16hi4UqO/SuPnHjW93j/gF6SXVKSh
v+jd/lkMFd8/AFeUam3yn7+2QbVfI23fPwBl8p3Bopy/Di0+s3nF3z+Ay096
qlmZv3CHuWsHD+A/wENHpywXlr8GLGoncTvgP8A1GsNM25K/jBbFzfln4D8A
XFTFHkyPv0mMsh+hlOA/AL7kIvLuiL/lXu/dZsHgPwBlAqMcn4K/CkYNyUru
4D8AkcdtTrl4v0I5c6FMG+E/AHIx82qeaL8Ryl0nbEjhPwAAAAAAAAAASH7f
Gql14T+PIUpS
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwdx30s1AEAxvHfrKESVssZOQ5LjDovTS08aF5WN+ZlOi3v5Dpu5SQvTR3L
sOnN69W83CHkZem8v9VdpuYWbhfuzrkXpUkirlqrP9TVs3337ENJvhqZZkAQ
hLO+f0/QFIM1ShF4LCvr1HsLCK05kUm6KIJX1SilSL2ADmWtJ10hRKAHk9g4
voiy3pxJeqwQFnd8gvi3F2G+EtTs2f8SgSXywhbJIqgl05RTQy9QX5fvvUOR
gXDXZAjHJiBx3N4tz5bBPFm8OiMaR21AcyJrSgaqd/tW0vQY8iIqPj0mydFb
wFgvlI7CsSvA/iBTDqJ3wcNBNYLrvptc6bgcEofyo1Hrw9B6RcqUZgpI/mza
mP0cApf/Nt0tRQH/JL9rdMMh+JEj518PKsBjF7GppEEY5rLb2vctQVhWnst1
HgAvgp4+F7+EB4G6uYe+/ShemG7y7VuCXTdZbBPVB2m0s3zHSAnzNG+BL1MA
9Y8c7sYlvcXHpLri53CMozFcBEpQKfwsv4ZeqC+szfYYLYNXZdN9lv0MFqV2
UTlxy+BofEp8enpA3591k9O3DG0Re/vKRhfEVN3M7F4V7MIMM2ZdO6Gzjpck
JKrAMRawMrM6sHrD3NhzSAXex4bM4JE2mNoa/Q4xVUNoFieL3/MEjHfvXRrT
1OB4fbYcjmxBzIc18skJNfxJrXXRrXx8V+3GmhzWgIipZrJ0TXgVMJDgwNI7
Vdcgaq6HlZtfX/6UBkJxeEFn7CPklo5kGJlpIQwMaXcl1cLElemUdUZvL6tJ
mrISlRZTM7/SteDERk+RafcRXiGw5VdrQYyv2uu2yvAl/qvqskjvFIOWI03F
OBR8YPrclt5337DCRvJw/nQ2n2a9AoLh/o3ZyIClOM4pM1Tv/5sfD7+lsXqa
s4K/ZUI59w==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtx30s1HEAx3HMFNHoQVnXchaNtLCrPGx9zmNCojysbCgLxbryh5kRbbeY
rlW7SxRHHisP27VTUxihPLuh676/3+/O7yf5w9kxFyuJtPXHe6+9+VdFF66Z
mZiYuG71T/fprl82Cg08/yu2yHS0+6xBto/9qeI1Daw/ViXGajWwy1ycMgQS
CEyZGsqoQXhbdbn/A4IYuYiutiJw0j8ML1QTqDKzVxv5BJKXXorXhyjMhhBu
0ZugKXfn4+50Cua8yPs5UQTLNu2KHgUF98141j+dICJBQ1rWKOScODMWXkhg
+8VJJQ6koQzyCSgtI+DJkhJCJDSEZg6ufAVBjzg1YHmKhmONXLQwSFArdYwo
Pshgvf+82c8ZggqqCNtTGTySFIwGrhPkjzZ+u93KwPZFZOf4XgpMauVm3yqD
gbCmzufHKShjnl42hRaavOj3jWcp7HJWf3Ap0sJjbkhuTKHwKqt5XjCuRYWp
KK7gDoU4u4LWo/t0WHBOGQkrpyD17R+zStKhuPSZPlZJwdC+ffdEgw5KqVpe
PU4hxmEu4K5Bh7yMBpWbnoJo1Npl/8lpZJakZfywoDF1BeLS/GlUSIIv/XGi
4Vd/0Xm9bxpTkb7iYNAYvlGeftiCxcimjXokgYb93MKRLlcWHZ7x3tIcGgOy
ZkH4ORasPldW9oSGqns+a/gWC2FH8yTzhkZdb++n0zIWkkGDLklFA7zEPfXv
WCR/t6viG2gsieexQbHwkLet860ZCC3rjoVtsGCiQ9lkNwZvD6h6ivkceMJt
XrpQBk1NXWx7EAdB5QYpT2Ng7jd0U5vGobvOslt6j4HeGB9lLOGgbJ4YHq5n
UNj19frvFg7p3pOz/v1bH9dXtaLisLQjZnlllsFMcq2aM3L4C3jRYOU=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQLeVzc9vU2wftL+RKSaf0Xd1/Lf7+tEPfD9hz/E8M
u990df9G7RuHLwofsL+jVxHwsfzqfuszlTM74/fZx1TVyczKvbrfnq+g0Wr6
HnuRpL4zN5Ov7veQdo3beW6XfYrXzsINUVf3/+9g8udk22m/JZZDRi7o6n5v
PpZiXdvt9j4FNbeUvK7uV+L59FKjZKu9xDPe3fucru5/I7rn8r9Vm+1NZq05
9dH66n6fyskBmx5utPc4YS+6x/Tq/s6jTxvcJDbYH/i+dKmswdX9ykvXcdXO
XWM/58WWVjHtq/vZ+6v/WnGttM9psty3TO3qfiEnU5mzZUvtzxz5HnZO6er+
3DztlZaPF9qf2bkqrFf+6v5Q3vtneefPsbfJYjn8WObq/oCpkw3KyqfaT7i8
dsFFqav713vsZCia32P/5L7b5zDJq/vtdk7g7Z5fY18Tn7a3WOLq/lV8Eb5F
Dvv2xLDMYtAA8j/uAcvvh8lP9gLr3/8Aqt9pGtj8/T1Q8935wPbvt4Da/wzi
vv0w9/VB3L8f5v5aiP/2w/w3C+L//TD/n4SEz/490PDpgITffh9o+GmKgcN3
Pyx84yHhvx8W/m2Q+NnvAY0fm05w/O2HxV8rJH73J0DjtxoS//t5oPFfBkkf
+yOg6eM8JP3sh6WfL5D0tR+Wvqwg6W8/LP0BAOLkW3c=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAGEzZtpXbwT/QbRobZI7Vv2iVL2wX
WsE/XpO6IYHe1b/A25YzWNnAP2YyagDrLta/qLB1w1hZwD80hDxFoX/Wv1Dh
RaIztL8/WIXYfaPQ1r9whckhOLe+P6yXeTfxIde/MDHfa8C7vT/cJPD+iXPX
v1BiyuTNwbw/mkGiYG3F179wN6fuYcm7P3JRjOiaF9i/4Hpo6X3Suj8cq0Ei
EmrYvzCw1TIj3bk/ZD3tmNK82L8QJIkmU+m4P8o0UtfbD9m/8P/tHQ/3tz98
ocxnLWPZv3BhPnBYBrc/Fh5S1Ma22b/QcoFyMBe2P9h2cqanCtq/8IiJd5gp
tT9wUVhnz17av7BC8s+RPbQ/StXJnz2z2r9ArB7KHVOzP5JUKdjxB9u/MGU3
sj1qsj+a9XWY61zbvzDKKNLygrE/3FxMaCqy279QIaFxPp2wP4pX586tB9y/
AJQdrENyrz/ChiBTdV3cv+DfPIU8ra0/+gpxe4Cz3L8ggnLwaeurP2Qw8s3O
Cd2/YE4Ga84sqj+IG17QX2Ddv8AIsm1scag/dHYQCDO33b/g5Z1sRrmmP5Qe
B/pHDt6/4A9d114EpT/o0uIqnmXev6A06hi4UqM/1uLnHjW93r+AF6SXVKSh
P2rd/lkMFd+/QFaUam3ynz8uQbVfI23fv0Bk8p3Bopw/giw+s3nF37/Ayk96
qlmZPyeHuWsHD+C/wEJHpywXlj+6K2oncTvgv8A0GsNM25I/PBbFzfln4L8A
WVTFHkyPP/aLsh+hlOC/gLvkIvLuiD+QXu/dZsHgvwBiAqMcn4I/sUUNyUru
4L8AjMdtTrl4P+g4c6FMG+G/AGYx82qeaD+zyV0nbEjhvwAAAAAAANi8533f
Gql14b+K4FX+
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwdyXss1AEAB/DfrBFTyhZGLoflkThkbGGZSWu3cG7rNM5RouMWZ0SmjqKs
ppJXLY9DlEdd5/383mVXO3PczLk759wxC1kX11qrP6xffbfvvvvsS02/yciw
IAjCh+y/9aZrh+p0UszynF2uVatQVBeQ43hFiuTnY9SyVRU0uvpgllYCThCX
2PFfgkRUMM1KksD/fniM8O4SBGsxbcEDAKNCU9quXEJrhZwaNjyFzobi0D2q
GrmBhmzJ+CQWPXf3q/LVEKTPbCikE6iJauPwZGq0hnaZ0uTj4CY83nrpqAGt
JGu7dGEM9j1R7vZcDZ6KVEEe+lEkR3xrXJjQIN6z6mTi9gimzjDUOjst4gmT
q92vYfCFs5mnr2qhTIvMZVkOw5bCWPw0pAUtv4xPcxzCXCG/s8tmGZyqqluN
PoNIT2BlzrOXQYs2zz+LGMA5lbwlon8Zol7KjGtiPyqZPpo9Kx1EGaHiCK4Y
1T8LGneSSc94L5jLP2A2mZ7lK9ZBSRXmRTaJcOfy5lyf1QqIOtfeaP57vKt0
SyxIWYHRGF4R3teHLZu8EkH/Ctzu8Xdv7PSASTMr5qz14MRZZs/5daPQha1M
5ehhtBbzcvLeIL3wyMHgYdJfmnLOj3ZCQLH6E3t4FW5HU9TsA6+xuLDu25yx
CmPIV6cRRjs+rm9SQiZJO3U0MDuEYOr3k2yPGSBh1XJ55hY4RA2mevAMIDLN
TdK2V+D6RfYXywwQKOJudye9gMuD0WwrOyMEMbFdfo716D3F9co7SzrUeZqu
q0GAg0zxO9MIIpUpo9CfYPuR+ISwlvylG+5m00MI2N/116Xkn2XRfrylHB0x
h+QXTaQbP/MujRZBE5YvpLusgRAE/uA2Z6FDnuKVc4H0/2gm1KUG57cFa/gL
CMBn+g==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAe96++Q2x2D+A3r75DbHYv704FjeI
+tg/1AVsIBHH2L9Ta+/U7kPZP2DBn15V3di/irSgmUGN2T+AANyi2vPYv17q
j0uA1tk/qJ1v26AK2b/CpzKxqh/aPyBsdvanIdm/3XkOkcBo2j8wRtnh7zjZ
vyQNubHBsdo/UBtOi3hQ2b93WtjZrfraP3z+V+BBaNm/N9Qi0IRD2z/ENEfO
S4DZv0GTX1tGjNs/AEQ5QpaY2b/jg2ZC8tTbP4wBGSkhsdm/wpIgTIgd3D9s
oZ5v7MnZv7bZhz8IZtw/RMVPAvji2b+TzKfjca7cP9yLf81D/Nm/7mWd/8T2
3D9coE69zxXav8JTl1oBP90/EEqrvZsv2r8fJNa7JofdPyB8UbqnSdq/sXGs
6jTP3T905cqe82Pav1sQf64rF94/4ABvVn9+2r+TOcXOCl/ePzQlY8xKmdq/
67gIE9Km3j/IlZrrVbTav08Y5kKB7t4/9JLWnqDP2r9lzAwmGDbfP7xqptAq
69q/xmA/hJZ93z+siWdr9AbbvyqkUyX8xN8/2ItFWf0i279BaploJAbgPxBO
OoRFP9u/iuXsJ74p4D8I/w3WzFvbvzuUrDRLTeA/+DBXOJN4279AwOpyy3Dg
PxjrepSYldu/E8PDxj6U4D9wu6zT3LLbv60bXhSlt+A/xMju3l/Q279dhOo/
/trgP5DkEZ8h7tu/qgikLUr+4D9cnbX8IQzcvx8b0MGIIeE/CFFI4GAq3L8S
q77guUThP0Q/BzLeSNy/aTrKbt1n4T9gnP7ZmWfcv0/zV1DziuE/7KMJwJOG
3L/jvddp+63hP9yr0svLpdy/4FXEn/XQ4T+MN9PkQcXcvz9go9bh8+E/FAtU
8vXk3L8XwXKE
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtzH8slHEAx/FjDek0VkqjcoZGWmXKMevmZ6JE+bFoKEKYH/1hZgrbLSoN
HUL5UR1afqxrWmR8GEqIC7vu+zzPnecpmmGMi0kXaeuP917/vQXXUy/d0OXx
eHbb/XNQ3f3LSKZE638t9JItTT4qsSzc51ywoYS0tzYyRKVEQdLS5KInwSCP
eU5plEBbXaX7Q4LZ6lS6zpBAMlfkn6sgiE3OWGsUEGw0OspeHaaQ5kO4JSGB
adbukp4ECsXmAQ8yAwmuGnXIemUU2jfDWPcEgtfhStKyQWHHqbOj/rkEaZNW
crEnDTcvF4/yCoJsSVSETyGNQZ0DdgIZwSFxnMfKJA3ps5rUhU8E2keW5wsO
MsgeuKi7/o1gmeSLDOIYGBfmfPbUEoyPNH5Pb2VQXBfQNWZKwSGueqt/jYGX
X1PXk+MUdIIfh+uIVAjMDnrfeI5CpLWi0zZfhZczQzWaGAqa9OY5pzEV+Dqp
oTl3KFQZ57Qe3a9GtE3MiF8lBYXLwKhhlBrrZVXzIW3b/w6DPeMNalhKFDV1
YxRKzH545C2qMZ3YILefp9A0wrc1Oz0F5b34pJ96NPjXROLy21PgFXpf+WNF
I0V62UbbPwVhgKvYW0QjNrEywVqPhdOWkWIkgkbrzMKRbjsWFifDhJJMGlGl
zU7+F1i4zWeVVpTRiOmZuzWcxqKis3mCeUPDua/vw5lSFrODi+ooOY0v5pF7
69+xaJ82qRUs0sgTz4k2KRa51W+1Aj6DMQPpMb9NFg5Bvmy0PQNvc3lvgYBD
gkjfUe3LQNjUzXZ4cch9ukkq4xkUuQ6lqOI58KU7eyR3GWRowgI19zlom8aH
h+sZGHR/vfm7hUOz88S0+wAD/dD+2lU5hxO7gldWpxnER79QcBoOfwE4nIcp

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlkl1I02EUxlcsGAsksYZZFFKB1grEoojihKgUzhJXMcrCYsXSVmLpWGor
KDMosVxeROC6KGSJ+NFqBe0h3fSfTvf1n31aCwy9yDHMi1U0qvdcvBx4ed9z
nvM8v+yT58tPLVYoFLn/zv/qNGetMrZGkSh5/+zex9fk7NJ392+LwtTwO994
dpCKLfsOnZiSscwxF1udGqThD3d6a67LkGY6PZ62IVLbVxq+bpbhPlzl37ve
S2rNum8DkxG8a0lTvXR7yWEtSszaIpDqXpjT9/voYm11+tXcCHq3L0mWTvso
rSj8pTESRlD+1XmuYZg0HtX8p6YwapYuP1abMULTG+NTD3PCuJK9e4Ohe4Q0
+r4d/kgIkmvy+5piiS5fCHRU2EJosT9/7ItJpN2ZcUu/KQRH65bCksY39Hmo
/Unf2yAMeqWrJ3OUKu4P3LBcC8Kva5qJu0bJ9HRt/6O8ILS2o5L64BiVzT2w
WD0BbK2KFSz6MUbJ6j9nLmUFoIxP7And9ZOq3nzkgGUC3jyz05o/Tvbbzad/
yuOo5EpJvkewTryjXfwPEvchE/dFJs+hSp4LHesgZanQhQLWSW2sG17eg2Te
Cxrek9y8N4zsAy2wL0iVC5/Izb7Bzz5SF/uK1CvhMymiwncsFIocaJZzwXHO
iRT1Ijc0c46kuilyRWKFyJkSnDvm2wUHlGQu0MOcUBlzAy1zRA7mCh3MGeXo
BHewM4f0F6u0aHE=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAqG0aG2SO1b/xS9m2ldvBP+RpdcdB
mdW/3uwfp3Kowj/4n8tXmaTVv0phbSg1dcM/ZHkLvGqw1b+qZKoY3EHEP4TG
duO1vNW/esDmVWYOxT9Q1qK8esnVv//mWr7S2sU/II94NbnW1b/FjWkwIKfG
PzCINDtx5NW/Akihik1zxz88JGe6ovLVv5ogvqtZP8g/FK30nk0B1r/sM6ty
QwvJPxhwFdRxENa/a0mEvgnXyT+c21VEDyDWv95sl26roso/VJ2W2SUw1r9m
h2ZiJ27LP7TBDH21QNa/MPioeXw5zD8c1EEXvlHWv+ssTZSpBM0/SAAUkD9j
1r/bOXqSrc/NP0g0ts45dda/q3GRVIeazj/UQ7C5rIfWv+78L7s1Zc8/QAzf
Npia1r+gOJjT2xfQP5CZdCv8rda/CTTW/AV90D+ATPh72MHWv5UK/8kY4tA/
PAFHDC3W1r9a7uCrE0fRP5A3k7/56ta/hPRrE/ar0T9cO2V4PgDXv//fsnG/
ENI/pE6bGPsV17/56+s3b3XSPwTUaYEvLNe/KJZx1wTa0j9weluT20LXv+Zo
w8F/PtM/xGlRLv9Z178RxYZo36LTPyhwgzGacde/v6uHPSMH1D+8MIB7rInX
v6mHubJKa9Q/wFIt6jWi17939jc6Vc/UP/ixx1o2u9e/vJFHRkIz1T/4j+Op
rdTXv8y3VkkRl9U/SMZss5vu179BVP61wfrVP4j5plIACdi/WKgC/1Je1j9k
zS1i2yPYvwsTVJfEwdY/sBn1uyw/2L/d2A/yFSXXPzggSTn0Wti/guuAgkaI
1z+cw86yMXfYvyqxILxV69c/FL+DAOWT2L+hy5cSQ07YPxjfvvkNsdi/It++
+Q2x2D+rNWSF
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAFEzZtpXbwb+YbRobZI7VPwLtH6dy
qMK/0Gl1x0GZ1T9vYW0oNXXDv+ify1eZpNU/z2SqGNxBxL9YeQu8arDVP6DA
5lVmDsW/dMZ247W81T8l51q+0trFv0jWorx6ydU/7Y1pMCCnxr8Uj3g1udbV
PypIoYpNc8e/JIg0O3Hk1T/CIL6rWT/IvzAkZ7qi8tU/FDSrckMLyb8MrfSe
TQHWP5RJhL4J18m/EHAV1HEQ1j8IbZduq6LKv5TbVUQPINY/kYdmYiduy79M
nZbZJTDWP134qHl8Ocy/rMEMfbVA1j8YLU2UqQTNvxjUQRe+UdY/CDp6kq3P
zb9AABSQP2PWP9lxkVSHms6/RDS2zjl11j8c/S+7NWXPv9RDsLmsh9Y/tziY
09sX0L88DN82mJrWPyE01vwFfdC/lJl0K/yt1j+tCv/JGOLQv3hM+HvYwdY/
c+7gqxNH0b88AUcMLdbWP530axP2q9G/jDeTv/nq1j8Z4LJxvxDSv1w7ZXg+
ANc/EuzrN2910r+kTpsY+xXXP0KWcdcE2tK/BNRpgS8s1z8AacPBfz7Tv3B6
W5PbQtc/LMWGaN+i07/IaVEu/1nXP9qrhz0jB9S/MHCDMZpx1z/Eh7mySmvU
v8QwgHusidc/kvY3OlXP1L/EUi3qNaLXP9iRR0ZCM9W//LHHWja71z/mt1ZJ
EZfVvwCQ46mt1Nc/W1T+tcH61b9Uxmyzm+7XP3WoAv9SXta/kPmmUgAJ2D8n
E1SXxMHWv2zNLWLbI9g/+tgP8hUl17+8GfW7LD/YP53rgIJGiNe/RCBJOfRa
2D9HsSC8VevXv6jDzrIxd9g/v8uXEkNO2L8gv4MA5ZPYPz/fvvkNsdi/KN++
+Q2x2D9bJl2U
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAGd+++Q2x2L8g3775DbHYP105FjeI
+ti/dAZsIBHH2D/2a+/U7kPZvwDCn15V3dg/MLWgmUGN2b8kAdyi2vPYPwXr
j0uA1tm/SJ5v26AK2T9uqDKxqh/av8RsdvanIdk/inoOkcBo2r/URtnh7zjZ
P9MNubHBsdq/9BtOi3hQ2T8qW9jZrfravyD/V+BBaNk/7NQi0IRD279oNUfO
S4DZP/eTX1tGjNu/pEQ5QpaY2T+ahGZC8tTbvzQCGSkhsdk/fJMgTIgd3L8M
op5v7MnZP3Hahz8IZty/7MVPAvji2T9Tzafjca7cv4CMf81D/Nk/sWad/8T2
3L8AoU69zxXaP4hUl1oBP92/tEqrvZsv2j/mJNa7Jofdv8R8UbqnSdo/fHKs
6jTP3b8g5sqe82PaPyYRf64rF96/iAFvVn9+2j9iOsXOCl/ev9glY8xKmdo/
u7kIE9Km3r9wlprrVbTaPyIZ5kKB7t6/nJPWnqDP2j86zQwmGDbfv2RrptAq
69o/n2E/hJZ9379Yimdr9AbbPwOlUyX8xN+/hIxFWf0i2z+vaploJAbgv7xO
OoRFP9s/+eXsJ74p4L+4/w3WzFvbP6yUrDRLTeC/qDFXOJN42z+xwOpyy3Dg
v8jrepSYlds/hsPDxj6U4L8kvKzT3LLbPx8cXhSlt+C/dMnu3l/Q2z/RhOo/
/trgv0TlEZ8h7ts/HwmkLUr+4L8UnrX8IQzcP5Ub0MGIIeG/vFFI4GAq3D+K
q77guUThv/w/BzLeSNw/4jrKbt1n4b8Unf7ZmWfcP8nzV1DziuG/qKQJwJOG
3D9dvtdp+63hv5is0svLpdw/XFbEn/XQ4b9IONPkQcXcP7xgo9bh8+G/0AtU
8vXk3D8JRnQY
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlyw0s1HEYB/A/LVuuWYnyssOhksakXdjwY+a9YkcOpS4RQ5RSF3NZ0VqF
5ey85+Tl7uj4Yymdesy83PLSLSaxuDf/2C4h3Zjefq1ne/bss+/3YSRmsZIN
CYI4gvff/T9kXxBvwUqSo0KEWYXGwj0RyLK9c+kV2DZHGbYO2VDv3Nju24u9
dXzDzSYPPDYN8hhzKlTATsyk77wLXEbpQbNf2OcCddXX74PbmXr+fls1Kti+
xy2efQjqhdxWJ381IvaN1a15lcJEf0JE2CXs8gS9Sv4ENt7eSskrwv3Hq/nE
Gh8cebqPMpEa9V9WdbPMBWBZPllEe6dGflcyl6eZlVBT5xmTpsP5gcnsR6xq
6Iiydp0x0SCCHSrKTK8FuTBrPfoYNmWs4hU8BZMe+gNllAb5hUp8P4cIod7O
cCr3pgbZDbqulEY0ADX/9bVDFe6H95Ax0c/ge04LY06mQZzexF43diMojSid
cB7///nkTY9tAv+kswY5BlpEDARes2Y3A/9wawDbUYs4W1ElztEtMDCcVhkc
rEUFJR7joREiEEuctYFpWuSnF6dyQ8QgRhk0VjHuT1C1L5AEvM1F6+kkznN6
RASzFWqWg3n8SfzfmCSPdWqD5EGyTK7XIuGOYfTG8jmwaF5mNKtFxBnxiHTZ
JYWlCpcv8T7YPkIfsV4KYeOKby852ElZp1zU7bApjTe1L8Tm1Q/LRjugeW3T
vUq0iBSKWa4kjgRz6/dM+ijOHS/uvj1Gwq9i/W/pyiJSrpIBJ307YbWJlx1u
SiGl9PyQfUcnsEYybvxgUkgRN+T506YLIu/0LbXFUegqGAXNFHfBUumF7sx8
Cu2R0QQ9212wZuz7yqeBQiSv8IMgtRsOpZyYsxiikN/0UjN3qhtOC+gEsUyh
v1cyVQ4=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwdzAtI03EQB/C/RkJOokRjKdNNi8xQzDCVdC7EfBWLbakzNNusxMkkbbWU
DSmNMNbKlS8053ObOp0uzUd5gjnEB0pamiN1r38KZlNzGT7oVwfH8eHuexRO
NuOWPYZhp1H/m07iRTeVwADY/5oKE5Qc1fPKkB3LTMRADnB969uovcjEMxRP
7xzY+W2XT9Ejb577FeCRDxco0pMuewYoYHH4pIOPYJNVIzvmaYQCdtRqZe4T
aFjMa/a5iLz9WCiZLwbpYAo9jmsE7Mh49XqoFN4OPLiTX2QEWkmKzTDyEsyi
1dl+hREGi60ibF0Gs7LpIsIocrpBy3AthaTqkITMVfSPx1/5ElQOWUx3/7nD
Jhh0nc55xqiEQnn2BuusCWjXYhV8XhWMdpGeLjFNgJkdDeKCN5BMtp/Ju4/2
MSrqtxg5yBd+9HlXmIA85L8mpddCq6CJou9H93HdmgRWHVQ44KvyBbTv4fQG
JNbDH+51O4GdGcj7X8NISQ0Qf6o5MvGEGZYGo+66JzaCUJdZHh1tBto287kv
qwlSVb7mqExkSfBELF0BqRFZBIYE5beUGcIYJVhdFBs8DfIEXtUVoQL6SrRY
No3+5XYrsKBmIH7UlIzYUL4ufSTJpwUOEEJdCG4WSLPXRXw43goVZX7fk8Mt
QNYFX/U7pIad8amf79IsgIXJw5U2NSjVyc5ehcjc7Ct+xjZgrm8HViiQRTW6
/rF2GHKbDCKNofzUvFDF1kCzxLavXrOAxvum08NxDVQ1iHPinXEIsGoiL1M7
YE+XdW8rCAeyOnXYq70DdsXvl1vYyOzhkF2PTnglvaHli3DQDDhcmpN0QqUj
tSe8FgdaH6G0e6cTJm+f1xOHcbCKCj+VZmhh6zUJw1ZwePF5uVE4o4W/3y5o
LQ==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQreFzc9vU2wf3n8mVkk7pu7p/RvVv45ScQ/vPrAhe
s8n06n6PBW8fyPw7tD+t3DM08e6V/Qwv5u/bN+Hw/me3Jm4oaL2y/0VY1hkP
lSP7NaZIRjzUvbKfo5OPY9eOI/vVxJSfbr52ef+P0p25gn5H9x+odP3wov7y
/gfmrD98nxzdP6koW7BR8/L+D1d+zc+rPrZfw/XS/ZrLl/bP4BaJLRI+vt9g
H8enO7WX9q9QtFWNWHN8P4P2u7sLNS7tf7P12hs5txP7DYI3Wpy5fHH/iinb
lx19cGL/tOLz02LqL+4/0Kfn4l1zcr+HlXBPsPbF/Q3BLFvXSZza/+3w5NUb
r1/Y/8Gn9vm7raf2l8za3F7ecmG/S330Ca6Q0/trtshvWmp4YX9I1gMnxs+n
91e8nVNeue/8foV35xwuTjqzXyfnb2aV1Pn9dwxzV1Uan92vUZYb5V9+bn9F
b1vazytn9++B0m9KIeIyRhB1D7Ih+hJg5kDNnQC1Jwxqbw3UHT5Qd2n4Qtx5
BuruNVB/yEH99Qbqzyyov69Aw4EJGi4i2yDhdEkLEm4noOHIAg3XA9Bw/uEC
CXeBq5B4SIDGC4MFJJ56oPEmUQaJx0+ikHhVgMbzh8mQeGcIh6SDDdB0IQBN
J3rQdJMATUdToOlqBTSdTYGmOwtoOgQAEZ95Ow==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAh4+pJoq8DKW5JkuLMOfl8k55adgYFbZWQt51ijgspXUqJZF3
ra4WOrYjNLnu4/KecLjf9/fjjJZiY5lMRlnS1h/Pnj1/PociU4KjVVks1tFt
/tncf6LtiVIGedL+A1EPKWh/N6lNrfsAtfi0Po8KCukXk8zt0rqg92zwbMVL
CvKo14ZTHt3IzdSQxIspVHXOhcbs7UF1b/psq4SC0Xy4dGyyB7FEKOEPUJh8
EGfNru0FpzDDrp1Q0PV9fi/gah+c8zlOvK8UXrClojC3fvgevvxOuEJh2VaU
6qUxAOPG1acBKgQJfrel6vR2X9FX8LQJmMSyZJHwI6qVoSe12AQRgpjII8mD
CKkpnTCzJmCv12Vmcz+hQaaZ0+pOQFkElNSrDUFP4WEgDSLo5PIfN44MwZml
98jtEkEBryhEUDkMR07bMDeNoH/TqsMuegTdXuL2BgHBfcfycaWBHBaaM/bl
lQQ/bMnmjhw5MiquHdtsJODv3how/CLHBf/1LEZG4LL0WaTrMwpjFR9NS0IQ
vZqguyYaRaxDMTYWCKZnmnnQHgPHKTrDlUWDWlx0SEkbQ0ZgleFvfRqqpTxa
bXIMivG4m1YWNN7HdsluuI7DmR9RrPSkMd99J3ZGOI6CuKDjW2E0ikQCF9Nd
Ciyn5NlU8mhkCtqbTycokGudm9Vwl8apNYcToSMKZAdbLtgJaQiKfLw9bSm0
NPWF23fQKHl7xm9fGQVx4Wx9o4LGzpA/rbJfFFi9iW+qlmgcrFPdCj5PwNl4
FcxSZzCkE1LWvf2pPWQZqTRlUMNoreib0Thn9LPDwo2B+2LuLe98GlMmftzV
cAZzYrYkdJGGe9dws811BuGDZTpegQzE0jzWt2IGE9PSjT1NDFr++y8n6XVl

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAh49pJYq8jNLmGtbbCfOWLO8jDcvlKrK25EReTykvKaV1tAkh
b5V1s7ycWygi1326vCevd7/v78e1WMoWdn/YJWRJW388e/b8+eyLSubytVks
1sFN/rk2cY9F9EMKxkGT7WUqOWbi0vq9KymsLlrWpdZ/gKZm6GxlLYXIi4kH
nNO6EZmhJ73STOF1dKP5Z+8epPddn22TUrj1fo4Xs7MXJ4hImjlIYW0uQjYx
1QuTwnTnTkKhoyDOnl3XB+s8J3fBNwrqgOcPgq/2g2N9+a1oiUI2WyYO9xyA
jkTzLFiLYMBRnOqrN4htKaZKgSGBR+A9mS49iDwVz8+ATdCYUJ4kFn2E19PH
kzb2BIeEMVH7k4bwRK6f3eZFoP5Vn3HT7RN0lN5mslACESe4tEFnGPYskyLP
SwT5bpmPJKPD4Di1j7ilEYQKisOEVSPo8G3ubBISFKzbdTnzR8HWn3apqCJI
OFqhUJmNIaXy2uF1CcGYI1nfkj2Gc0ErWYycIHz7xqD51zGYaAXo2xICC/WM
2DhgHNGuJVidJ/DWxBsvi8fh5M5P92DR6JxuFcBwAukh1ea/TWm8XFhwTU6b
AKOIu2PHoTFVJqB1pibgl3m+ROVDozS2W37bQ4GiuNAjG+E03vXcj50WKbCS
nOtQJaDBFwuPW21VIs8+J6spn0awsLP1ZPxmc23nnUU0zJZdj/FGlZC29Ee4
dNEILw7w93GkIC2cbZAoaUS/ORO4q5yCfl/Cq2o1Der0nzb5GgW/1Rdcli6D
H3XaG9wLBHuHbaNUVgyqjMLKeza/Y3f/7OJ4MohlDJZMbWgsWga6aSIY6C7k
3PXPo3Gqe6TV4QYDSTNbylugMSDLZX0vYWA1VG7kG8Jg4ItsdUcLg5r//guT
/3Zk
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAA0Lzefd8aqXXhvwAKl+MY
MmI/R5IR22uX4b8AGSshHyNyPzYqo64+ueG/APQz9DAeez/O9wF7Idvhv4BU
Ym4dBYI/DiGPJRT94b8AWkXsmnOGP8ZUn5MWH+K/APmDeI3aij9333qqKEHi
v4AQzJ3xOY8/Y8BdT0pj4r+Akl324ciRP4i+d2d7heK/QIvwfQDxkz+4fezX
u6fiv0Bl4bNSFZY/q5PThQvK4r/Aa27p1jWYPy2dOFZq7OK/QBbTcotSmj9B
Uxsu2A7jv8BVSadua5w/WaBv8lQx47+A5ArhfoCeP5+1HYjgU+O/oEipPt1I
oD8vIALUenbjv2DDLu6PT6E/dt7tuiOZ479ASrawVlSiP4J1piHbu+O/gLhi
uTBXoz9wBubsoN7jv4D+2TwdWKQ/z2NbAXUB5L8gwUVxG1elPyEnqkNXJOS/
oPhTjipUpj9OxmqYR0fkv6CNN81JT6c/Nakq5EVq5L+A9ahoeEioPzU/bAtS
jeS/gM3mnLU/qT/IFKfya7Dkv2B0tqcANao/J+lHfpPT5L+gomTIWCirP/HD
sJLI9uS/wALGP70ZrD/bCjkUCxrlv6DGN1AtCa0/cpct51o95b+APKA9qPat
P9PM0O+3YOW/gGNvTS3irj+BrVoSIoTlv4B9n8a7y68/LfH4Mpmn5b9g0Np4
qVmwP5wazzUdy+W/8CNhDHnMsD+Ejfb+re7lv3DwsENMPrE/dqR+cksS5r9w
rV7FIq+xP9jGbHT1Nea/YFnFOPwesj/Wfrzoq1nmvwC/BkbYjbI/bo9fs259
5r+guguWtvuyP3UKPrg9oea/QH6E0pZosz+rZjbbGMXmv+DV6KV41LM/0ZUd
AADp5r+vF1XY
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQvSRXSjql7+p+YZ+b26bePrj/xr/EsPtNV/efj78/
7dD3A/s36FUEfCy/un+l9o3DF4UP7DeoqpOZlXt1v+aZypmd8fv2v0jsO3Mz
+ep+Hb6CRqvpe/ZbeO0s3BB1db+xtGvcznO79nfEcsjIBV3d/7KDyZ+Tbed+
hYKaW0peV/eb8rEU69pu3//mKe/ufU5X93PxfHqpUbJ1P8esNac+Wl/df0l0
z+V/qzbvVzhhL7rH9Op+w8rJAZsebtw/5fvSpbIGV/fnH33a4CaxYX/Biy2t
YtpX979Yso6rdu6a/S5NlvuWqV3df6qv+q8V18r9S458DzundHX/BUdTmbNl
S/cv2bkqrFf+6n7tPO2Vlo8X7hfIYjn8WAZoH8/9s7zz5+xPubx2wUWpq/sP
T5lsUFY+df+O+26fwySv7l/ovpOhaH7P/pD4tL3FElf3P9k2gbd7fs1+E5ZZ
DBpA/rvLzHcWvLtgA5Mv3A+Wt98D1X/HG6zfHmb+m2lg8+1h9n/gA9tvD3Of
bT7YffYw9z93ArvfHua/2/1g/9mXQP3/bSnY//aw8PkBCR97FWj47YCEnz0P
NHyjxMDha/8BGv4TIOFvrwKNnz2Q+LHvgcZfSSc4/uxtoPG7GxK/9rD43wKJ
f3sTaPrYBEkf9jug6ec1JP3YP4CmL6EEcPqyXwFNf+GQ9GcPAKNuYe8=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAApG0aG2SO1b8QTNm2ldvBvzSTuiGB
3tW/YJUvbBdawb8+MmoA6y7Wv7jbljNY2cC/EIQ8RaF/1r+gsHXDWFnAvziF
2H2j0Na/QOFFojO0v7+Ol3k38SHXv2CFySE4t76/viTw/olz179AMd9rwLu9
v4BBomBtxde/UGLK5M3BvL9cUYzomhfYv3A3p+5hybu/BqtBIhJq2L/wemjp
fdK6v1Q97ZjSvNi/QLDVMiPdub+4NFLX2w/ZvwAkiSZT6bi/bqHMZy1j2b8Q
AO4dD/e3vwoeUtTGttm/gGE+cFgGt7/QdnKmpwrav+BygXIwF7a/bFFYZ89e
2r8QiYl3mCm1v0jVyZ89s9q/0ELyz5E9tL+UVCnY8Qfbv3CsHsodU7O/mPV1
mOtc279gZTeyPWqyv95cTGgqstu/UMoo0vKCsb+QV+fOrQfcv4AhoXE+nbC/
xoYgU3Vd3L9AlB2sQ3KvvwQLcXuAs9y/IOA8hTytrb90MPLNzgndv4CCcvBp
66u/lhte0F9g3b+gTgZrziyqv4R2EAgzt92/IAmybWxxqL+mHgf6Rw7ev0Dm
nWxGuaa//tLiKp5l3r+AEF3XXgSlv+ri5x41vd6/IDXqGLhSo7+E3f5ZDBXf
vwAYpJdUpKG/UEG1XyNt37+AV5RqbfKfv6IsPrN5xd+/gGXyncGinL85h7lr
Bw/gvwDMT3qqWZm/zCtqJ3E74L9AREenLBeWv08Wxc35Z+C/ADYaw0zbkr8K
jLIfoZTgv4BcVMUeTI+/pV7v3WbB4L+AvuQi8u6Iv8hFDclK7uC/AGUCoxyf
gr8AOXOhTBvhvwCSx21OuXi/zMldJ2xI4b8AdjHzap5ovwB+3xqpdeG/AAAA
AAAAsLyzO2Cp
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAqm0aG2SO1b/wS9m2ldvBPzyTuiGB
3tW/QJUvbBdawT9EMmoA6y7Wv6DbljNY2cA/GIQ8RaF/1r+AsHXDWFnAP0CF
2H2j0Na/EOFFojO0vz+Wl3k38SHXvzCFySE4t74/yCTw/olz178AMd9rwLu9
P4xBomBtxde/IGLK5M3BvD9kUYzomhfYv0A3p+5hybs/EqtBIhJq2L/Aemjp
fdK6P2A97ZjSvNi/ILDVMiPduT/ENFLX2w/Zv/AjiSZT6bg/eKHMZy1j2b/w
/+0dD/e3PxgeUtTGttm/YGE+cFgGtz/ednKmpwrav9BygXIwF7Y/eFFYZ89e
2r/wiIl3mCm1P1TVyZ89s9q/0ELyz5E9tD+iVCnY8Qfbv1CsHsodU7M/qPV1
mOtc279QZTeyPWqyP+xcTGgqstu/UMoo0vKCsT+iV+fOrQfcv4AhoXE+nbA/
2IYgU3Vd3L9glB2sQ3KvPxQLcXuAs9y/IOA8hTytrT+GMPLNzgndv2CCcvBp
66s/qhte0F9g3b/gTgZrziyqP5h2EAgzt92/YAmybWxxqD+8Hgf6Rw7ev0Dm
nWxGuaY/FNPiKp5l3r+AEF3XXgSlPwLj5x41vd6/YDXqGLhSoz+Y3f5ZDBXf
v0AYpJdUpKE/ZEG1XyNt37/AV5RqbfKfP7gsPrN5xd+/wGXyncGinD9Eh7lr
Bw/gv4DMT3qqWZk/1itqJ3E74L/AREenLBeWP1sWxc35Z+C/gDYaw0zbkj8X
jLIfoZTgv4BdVMUeTI8/sF7v3WbB4L8AwOQi8u6IP9RFDclK7uC/AGcCoxyf
gj8MOXOhTBvhvwCVx21OuXg/2MldJ2xI4b8AfDHzap5oPw1+3xqpdeG/AAAA
AAAA0DwmW1GO
        "]]]}, 
     {RGBColor[1, 0, 0], ArrowBox[LineBox[CompressedData["
1:eJwtzA0s1HEYB/A/W7Zca2OU6HBkxJiUsHI/zeR97O68j+rS3LC7UnIx11W0
VjuKOi/zcl7PnY7j5krUo+VkXpZhZSyce+msoxiXJdWvrWd79uyz73cPhcmh
XTEnCOI43n83mrdkL8lXI+L/9FVYLeRUYdtUaez8mNDq2dJF7cd29KI4uebB
mR2zIsoC9s+TW76ORVBMKXez2VMjfjKTTd53F04lNFYeclpB/IwwY+31+6Bb
KpR6nMPeu8cVzD+E6aH0uKjL2LYT9RtB5fDjTUFWUSn2s3STevQJuPOMnwbE
Kyik7HsxsVEJR5/OlJLGcM5SK2i2QmioD0zMNuKcw1796F8NPXQHn7mDGkTY
z+Q9otXCuIizyTihQfyUSDE7pw6slOQHy3QNGjJYqnn8Bmh2Np8tvIkdJaF+
jhCBYXHtlWsNtspnvTyuCbbz2ykLAxokilHKExnNoLHQG0WL+P8As983qQVC
M9PM8s20yNls/iw5uRWE7tLQpGNatPwu7JpDUhsMj2RXh4drEX+XXubJaIdO
iac2LBv7ccBkZJwYpCiXRBNg73SwuBEdQLUVb+bItUg0pa/rQxJoWA3nVc5g
FyjFhL8UWMPyilGTFhHtmaPJHp1AJwXZkOx1yNliBL0+8hy+Vnl/SQ3WIWIs
IN57vwxiJ6e+vbiI8xBRcIdJBruyVGuXEuwsTqz3SheIN3b8asQ6FHKncWRg
vBsOO3zwJ4/rUPz0PFeSIoc/AtNv2boOLbtdOnBrQg5brby8aGs9uropD42h
9gDjfe6NbX894ndnqFy6eyDh9qChMwXnaarAX469sFZ+QcEu1iPntxbn5wS9
sG1JfRncpEdDgyShcrcXvLJOL9ipcJ9fMi1kKYAmJBPEKu7PGdq4swr4C3LS
VF8=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtkmFIk1EUhj9aiEEjUhAJayZNchhBfNAi8S1mWiZoI/tRSKFUVND2w3KO
aCSiPyoGSSZUxL651hi2qYXDFjcToWwgrbSZZTri2EpnJGhzi1qX++NyuRzO
ue95n3drvcl4eo0kSUXp8/+u6dwsSTFC9sQ3l+V9P7JO9pZtjxLGLWdyr37s
w1TzYrZninCj5GXb/JdeqDOjjpZxwhHduldvvvpx0xjSPB0jBAxtpoqwD8Uo
Cu4bJZwPn73we7IHdZ88inYkPU/WHx6c8UJWyamGF4RodOnzPfIgsmE2nnxG
iKx0JHw/3Kj2p+4vDBB2HbdbVT9dGHut0u15Qqj1nTC4l5ywNjr9036CQRPf
6112oE8dqJruISiRJqX01wN8P1WVo/cSro9cihUu38Wmua6C+UeE4YPDu3cm
7iCYp2pdfUiYdVfbmpIdsMbzKhtcBNetXDNW7TCXdF8r7CYcKp98bk+1I7+x
RS5zErwZXe+QskG9P3QuqBBspuZFljJBdXRIa0+/D2zMj/0ZWAiuF/UML68z
jeg3beP97KKYr63l85lF/N/u4P+zQaHP6OP6WI7QL9dw/WxO7JcI8f3YY7H/
lhm+P7ss/PlbwP1ho8K/rH7uH6sU/sbruL/srfC/M8n9ZzsEH4U4H3ZM8Lut
5/yYVvDVTXC+rFXwv1LB+bO1Ih9yMc8HC4v8mEt5flimyFfAyvPFykX+Vj7w
/LF/tQBrPw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtx30s1HEAx3GsCWEZFaN1Z1GoVUYe2nw8J+ShPBVDFMotstbMKlpXDK3a
XaI8XOWh5WG7YsIYoeb5hq77/n6/u/v9SiYM87RIVFt/vPfam5+QduaSloaG
hs3f/mmn7lgzkCrg8N/rLrud8tYVEGoLeEafFDAWzI/PeRHofKiIDVcqENwk
KfF4QHBIk3lJLSlwcOZhQI6cILA8jZboERS9tpe+2UehU3BjtYZP0Jxl+Lgz
hYLMl3DzzgTbDFukXVIKU+ZBBZkhBLHRClK/TmHnViTrkUJg/dlSJvSiEeV4
cjggh8BRHBftW0jjkbeLZ1ExgUqY5Lk4TsNUy8yGLyXoFvEC8/YyWHhRnjbb
R9BO5UInicFgb7DWz68ElUM13641MIgpzB7y2iDQTi7b6llloJAEtY/soqAO
e3peE0oU+te2Pz9CwdNK3madq4T4ZmhrzSkKyoy6aYcRJWa/95cvJVIoMMpu
sNujQohmWkT2bQqDrr3DenEqSKwSB/1LKNi06hiPVqvgXPRsJryRgshs0vPO
nArxInm5ZITCuyF9a9PjavBSq2W2MxTMEyAsuqWGSX5y6rI2jbtVZ602etRw
L/Q599uSxsKVkpT92izSg1yFPqDhNjl7oMOGhWDLQD4YTWNRXOcQcJpF1LFI
Z1EmjbXO6YyBdBaZM1ni4ic0ZN3dH93ELGRtdWPMWxoCi1iTqmYWvL45VZyM
Bu/eNDYpFlMTRhX8ORrpupWH/TdZvC9r2uDrM/hhLuvK43OICfVj420ZqGs7
2BZvDqXYbq/yY+Byov+qMplDY+kmKUlmYLkcGbKUz8G9UrdTdJ9BS8eXy7/q
ORytGx0YqPr7ET0VKzIOjNPYhEcvA4sLr+TcEoeLO8IWVyYY/AE4XV54
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQ/YQ75NPXJ3fszyQsvvbw80N74cnZcZXsd+2npV06
++nGQ/uqRKstU7Tu2rsbLmc33ffQ/jl3zy03v7v2931ColYufmg/UbFkc1/R
Xfuuf1WzAjof2ofJhctkT79rXzNXZbZ2/kP7uqbPb2/tuWvf8WO3rnXoQ/vd
/Nl/7jy6a7/pBJtSg/VDe3FtH/ECznv2Hwzk3X4rPrTvS57NOdngnr23d27a
Wo6H9v9k7s50ibhn3394ge/09w/sleLlu5ob7tmfqV91ZOe1B/ZhJ5hn+K28
Z386bNsk0X0P7HcvPlmz5NI9+y1XVGpXL31g36wU8bb5zz17Xr5W95reB/as
OzxmvVa7bx/a2Le5o/SBvdeMj/q3Au/bB7BLN16MfWB/JKIgzK/2vn3IJYW8
cLcH9ic3bdnotvK+/caaNWbS+g/sp6Z3Pzx49b59htrtKbISD+w3LbriEM/4
wD4LSm+AirNC1f2E6rOCmjMHaq4Z1J4ZUHv3Toe4Yx7UXeXbIe4Mg7r7myLE
H3+h/tKH+lMkHOLvU8ch4SDWAAmX6XGQcLoJDbdiaDhOg4YrMzScrQ2h4a4F
iYc/0HgxhMbTZWi8fWuExONxaLyek4XE8zVovHNB04G2LyRdJEDTyWRouvmc
AElHD6HpqncSJJ1JJELSXTw0HQIAhklQXQ==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAfN6++Q2x2D993r75DbHYv9QFbCAR
x9g/xjgWN4j62L9gwZ9eVd3YP2Nr79TuQ9m/jADcotrz2D+itKCZQY3Zv7Sd
b9ugCtk/fOqPS4DW2b80bHb2pyHZP+inMrGqH9q/SEbZ4e842T8Leg6RwGja
v2gbTot4UNk/WQ25scGx2r+Y/lfgQWjZP7Ja2Nmt+tq/6DRHzkuA2T961CLQ
hEPbvyhEOUKWmNk/ipNfW0aM27+4ARkpIbHZPzOEZkLy1Nu/mKGeb+zJ2T8Z
kyBMiB3cv3jFTwL44tk/FdqHPwhm3L8QjH/NQ/zZP/rMp+Nxrty/lKBOvc8V
2j9cZp3/xPbcv1BKq72bL9o/N1SXWgE/3b9gfFG6p0naP5ok1rsmh92/wOXK
nvNj2j82cqzqNM/dvygBb1Z/fto/5BB/risX3r+EJWPMSpnaPyM6xc4KX96/
HJaa61W02j+CuQgT0qbev1CT1p6gz9o/7RjmQoHu3r8ca6bQKuvaPwvNDCYY
Nt+/DIpna/QG2z91YT+Eln3fv0CMRVn9Its/3aRTJfzE3798TjqERT/bP51q
mWgkBuC/fP8N1sxb2z/r5ewnvingv3AxVziTeNs/oJSsNEtN4L+U63qUmJXb
P6fA6nLLcOC/9Lus09yy2z99w8PGPpTgv0jJ7t5f0Ns/GhxeFKW34L8c5RGf
Ie7bP82E6j/+2uC/8J21/CEM3D8eCaQtSv7gv6BRSOBgKtw/lhvQwYgh4b/k
Pwcy3kjcP42rvuC5ROG/AJ3+2Zln3D/nOspu3Wfhv5CkCcCThtw/0PNXUPOK
4b+IrNLLy6XcP2a+12n7reG/QDjT5EHF3D9nVsSf9dDhv8gLVPL15Nw/y2Cj
1uHz4b+GznMz
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlkm9Ik1EUxmfRzESFaBTpmgsZZJTrQwYZHANZYbYs5lxJposWuEqJgoqN
tiTpn35Yoy2lqFbE+ge5VcTCBynJ6A+0psTyffde8YMQI1SCKInWez5cDlzu
Ofc5z/MzOjv3HFqg0WjW5M7/WtsWGRdzgooKbbM/pyZQ7Ep+nP0qaGvA3Xo6
X8KI+X7+xiFBT9o2x4OVEpwNtn3RiCBD4ZW0xSph6d8z/Y0XBX0qPxHrOy5h
yY2KgbWdgsL65jJ3SMLKX4l1NU2CRvxz2fQrCfWj2tW+GkHaEvf8xKSEXrPB
8scoyFXZsLyrQEa2/qjr8WJBk86BgqtmGdWvb+0M/VDIViZdr3PIOHX2wZuX
4wp5Ww2Xun0yPPbnAd2QQs/eLgxbozI6UhXeh/cU0kfeee4mZYwWnd/m6VVo
2ujIds/L0Pn7YhdOKnTkxfb+76YMdPml/s/7c/2hmar07gwMyfJjzRaFzI4u
u9Wbgc/zqLq0SqFNg/GnlmgGW0zfgvoVCi06fFkMj2VQdydVeyAvN48rhl3q
PXXwO+RxH8V5DrQ8l/byP7jG/5KddaCFdVEL68QU66ZlxeoeMPFelOA98Z73
pi/sA26zLzTGPqGHfaMw+wjjQdVXatqh+owY+06/OQe0cy6U4Jyw/pyaGwU4
R5SsUnOlHs4ZNqOaOwWZAwwyFzTNnGBXu8oNNW5QOcIMc0U3mTN8YO4oxRzi
H59PXjc=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtjn0slHEAx7ESomV6YVTOULRWmYQ/Ou9dlJCXYkNZKJaYmYlou8WkpZ1E
cpTX5ZhrWgn3ZU7l/YZd93ue587zFNYwmotJXtLWH5999tm+f3x5N1JCburp
6Og4bPPP/RrZbxOpCpL/NnU7cLZgTYUd+snWpp9VaElanFjwJijuqYoOU6sw
11Zd7vmYoFOHeU1pVeibfRKQpySYqkyhq40ITjU6Sd8coRCbnLHSwCMIydrz
tDuRQrof4RZdCcQm7dIeKYUyy8BHmUEEq5Eq0rxGQb4ZwXomEmDCRiH0pmF+
5vxIQB7BiCgmyq+IRqiPm1dpGUGGMN5raYLGlK6FA09KECWyvlhwiIH8lThl
vp8gnMrnG8QzqO27rLf6jcB9uOF7agsDj6LcYe91gor4yi35yva+OrBrdP/2
r9Dnkbp8NbL9m7oqTlJQ2io77PPVKM4O/thwgUJqmmTWeVSNH9MDYm0chcOm
uS3HD2pwVTclPPc+hWj3vhGjGA1a7eKG/MspdLQbmI3VayAofTEX1kbBzmLG
68GCBtkipbh6lILPsLG9ucskBEn1Csc5Ck3X+cLSnEm4FiYk/dKnYVZ3xW5d
PonkIt9rGzY0PtwuT7TVZ9EY6C705dPYOTN/VOaw3VsmyqEoGu0lEueASyxe
no5wFWXSQPds2uBdFt1zWSVlz2iU9vZ+OlfCwqpTMs68peFkFb2v7j2L9P4F
TYyCxrRwlr9JsRBMm1bxFmi4GNae8N9kYS5+t84zZtBiqegp4HH4EixgYx0Z
1DTJ2HYfDns9djlpBAw23AfuqBM4HKvcJOUJDGa0EUHaQg6dtYbdoocM7sm+
3vrTzKFVMjY4WMcgJ1xetazgkOg6PuXZx0ATW6PktBx+7g5dWp5i8BdeQorR

        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQrcYd8unrkzv7AxIWX3v4+eH+yEnZcZXsd/fLp106
++nGw/1HEqy2TNG6u/+awXJ2030P95tw99xy87u7v8gnJGrl4of7HyuUbO4r
urtf+V/VrIDOh/vXyIbLZE+/u19qrsps7fyH+280fn57a8/d/do/dutahz7c
L8Gf/efOo7v7o06wKTVYP9xfruUjXsB5b/88A3m334oP939Ims052eDe/n9e
uWlrOR7uT5a5O9Ml4t5+98MLfKe/f7C/O06+q7nh3v6O+lVHdl57sP/AceYZ
fivv7e8J2zZJdN+D/RqLT9YsuXRvf9UVldrVSx/s/6QY8bb5z739N3lb3Wt6
H+wv3e4x67Xa/f2qjX2bO0of7N87/aP+rcD7+9XYpRsvxj7YbxFREOZXe3+/
/iWFvHC3B/vtNm3Z6Lby/v4JNWvMpPUf7OdO73548Or9/T5qt6fISjzYn7fo
ikM844P9IVA6Byr+KA2ibitUnwLUnCiouWpQe0Kh9m6HuiMK6q5qqDuF+SDu
ZlaC+GMn1F+uUH9ehPr7FTQcLsHCBRpOU6DhtgQajoHekHC1S4aE8zdouF+E
xsM2aLzUQeOpBxpv3k2QeGyAxquOHCSe+6DxXqAISQePoOniPDSdeBpC0k1W
IiQdTYOmK97JkHR2BprunkPTIQCWHXVS
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAGN+++Q2x2L8e3775DbHYP2QGbCAR
x9i/aDkWN4j62D/owZ9eVd3Yvwls79TuQ9k/CAHcotrz2L9GtaCZQY3ZPyie
b9ugCtm/IOuPS4DW2T+YbHb2pyHZv4+oMrGqH9o/pEbZ4e842b+yeg6RwGja
P7wbTot4UNm/AA65scGx2j/k/lfgQWjZv1tb2Nmt+to/JDVHzkuA2b8l1SLQ
hEPbP1xEOUKWmNm/NpRfW0aM2z/gARkpIbHZv+CEZkLy1Ns/uKGeb+zJ2b/G
kyBMiB3cP5DFTwL44tm/wtqHPwhm3D8cjH/NQ/zZv6nNp+Nxrtw/mKBOvc8V
2r8MZ53/xPbcP0hKq72bL9q/6FSXWgE/3T9QfFG6p0nav0wl1rsmh90/pOXK
nvNj2r/ocqzqNM/dPwgBb1Z/ftq/lxF/risX3j9UJWPMSpnav9k6xc4KX94/
6JWa61W02r85uggT0qbePxCT1p6gz9q/pBnmQoHu3j/QaqbQKuvav8XNDCYY
Nt8/vIlna/QG278tYj+Eln3fP+iLRVn9Itu/mKVTJfzE3z8YTjqERT/bv/xq
mWgkBuA/DP8N1sxb279J5uwnvingP/gwVziTeNu//5SsNEtN4D8Y63qUmJXb
vwbB6nLLcOA/bLus09yy27/ew8PGPpTgP7jI7t5f0Nu/exxeFKW34D+E5BGf
Ie7bvy+F6j/+2uA/UJ21/CEM3L+BCaQtSv7gP/hQSOBgKty/+RvQwYgh4T8w
Pwcy3kjcv/GrvuC5ROE/SJz+2Zln3L9LO8pu3WfhP8yjCcCThty/NPRXUPOK
4T+8q9LLy6Xcv8y+12n7reE/bDfT5EHF3L/NVsSf9dDhP+wKVPL15Ny/MGGj
1uHz4T/uF3Q2
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlkl1Ik2EUx5dB00lGgSTo0i2Tmpl60S4SOgayAnVUmBtBbk5a0YsfRF1U
G21JYFkWS5g6gtqM9faJOWZReIiE6YWSQyWW78dTXUhh0UQSEsnOc/Fw4OF5
zvmf//9ncLUfP52h0Wj2rJ//NeaMzLElhonshvTyt3nwuJOT6U8M/wSEpkta
Ccoqo9r9owydzQdivSYJxuoaTooRhlPZt1IWqwRta5cHjt5geMVwYbjnvASO
+8Wh0naGh3bYCoSgBOdW3pZVnWAoXFtaTL2TIDC+yeirYihuEVbnv0jwsaLQ
8tfAMLO0bntHlgym2lb380yGvpZQ1r0KGVo/PKgP/lIxXSD119hlEK8+GXsz
p2Keo/Bmp0+GaGM8kDuqonV8Y59VlOHOTLH36SMV45EJz2BShoXN1w97bqvo
M9oXO1dl2OfvGe66qGLG6yMDP0oU2K3N90+fUrG273d56pgCe5NFbTaLigl7
R6PVq0CX55k5v1zFyVexIYuowMGSz736PBVDZ7rZ+1kFqsMz1Y4N6/N4hZdu
usc4fwdfh+gfarzUByQb9cVBPgdagjQXw1wH6EdIFz7mOqHfQLrRlUN7wHSY
9kLdLO0JQoL2RqONfABzE/mCu3zkE2zjvuF37iM8dJGvGOU+g8lEvqO1knKA
qRzKBbdOUE5w10+54QLPEc7qKVeUec4QKaLc8SfnAFZ0xAXW1BMn0O0kbvAF
5wh2cq5wjXMGyzriDs3NxCH8AyqSYuU=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJw10H0s1HEcB/AfyZZrbSwmOhy1JEzqQos3SUdlZ8jjSJfGMBaRmMsKa7Xr
8jBP85iHc4TjSkliKw+FstxKbh7O3f2wHcVysyX17Y8+22efvfZ5f/75sHgp
gdd1KYo6Svrf/F8c/ryZOF0ByqRMaerMQ2eRoTyxjNj6GMvSJhU1dg0dHr3E
f078dLLIBntLJ5slJ47kJTN330UGS3h4/29ino+mMq0A9pdri00sF0Hp5mUK
Zh5gdj6r1daL2Gy8et1NiPeDUdwL14jLo7SK0UKsvbkVl52/CM/CHznUejEO
8jVf+0SLGExUSAONS2FYMpXP+EDyackrX9jlKKp2DUnQEFtMpT4MrERTkLnj
9D4lBqP8RMmJVRioS9kIPq6E56qBgp9bg109zPsLQcT+Yo9Z3zqUWOnKsjKI
Rx3XhNx6zMytvrKpUCKG2yMJCX4COr2ZJe9TYqGf1+sU2gCZPq2pm1PCSm/m
DDOsESdjI3XSdVSgRnxumIc2oeBIq3foIRUGd4Ie2QU349lwQjmHQ/YlLhN+
XBEqxXYqnwQVrLZb4jN9W1CBJEagQIUYGV31HGLYG4s2EiUq5Gb3iCh2KwQr
HH7xFLlvjR0Ns21D6DtJ0aiW5A2G0X/gKc4y3PYzzNTw/OgS4LCnHdNlDksR
7mrknqtzb9G24/TE5PcXMWryvxR/h8UOLLVHGFnnqUEV1A73jXWiZH3LuUKk
hkQ2kykOl0DP/BObOaZGjO3VvbfHJdAItDvtayS/KfG+5NGFhUZ+6kUjGlbd
0UPWnV3wGkm6uckmjh5y3bbohued18tt4TQm3+qfnxZ045vwijQ5h8bjAUZp
z69uLBh4vHSvpxFwL+9zabwUJnGn5KZDNCj5clOmTAr3UiZFrdD4CznYONQ=

        "]]], ArrowBox[LineBox[CompressedData["
1:eJw1kl9Ik1EYxj/6KvFCAivzYhZJW+mNN5MMnY+yQVCTwG6EAmMr/+DFujCm
gUoWq7tdLHJQYW4uXWNs9odZrY42kqxRmC2y2UoZJ21rjoSR29cfdzjfxeFw
eHnf87y/59lvMDWf2yIIQsXmyd/Kjyuung8PiO5GmSCsUsz3tJX2f75PtrVO
6A4tU5jrXliSXyfI2961ne4ohaqy8NWbuJ/8K1geGYxQaLQW09H3PtLfHN73
6B3FzFx71+8FL9mLimDDa4pCdc3xJ988RL/odihfUvxYWv9yi7rJAVEtGaco
JjO2DV9ijMzsWErlnlIkWqwXxbSL1Pul2z8DFHHvKe3YupM8nxUrjzykGC9L
1XoyI6Sz2+mP+Sn2RMyO+l/D5E7RpD7mpfBOX1hVZW6ST2f0JTUeCrsudLhq
Y4gUfLeXJ8cpDM4TA+acjbgV4pXsXYrstdLzyFpJe0pxzOii+FO78MwqXSWn
60YvqUYpHqeH5iENkKLuQbXOSbGrsXeNSCaSawh3Bh0UgeRc9aJP1KRPTiut
m+97MVZHltcvw57vh9zfYWTzIc9v9bP/0cb/Lw4wfZD1NbUw/dgu64+w/SDv
F1lh+0Pe33KQ8UEH5zMVYPwQ5PxCBsYXMl+bcD3PHzL/2QTzB+Xcn7iG+QfZ
v+Eo8xcK7m9JE/Mffdz/3VUsH/jL83G2keUHYZ6fUB/LF7byfBVHWf6g5fn7
Dxlablc=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAADX7fGql14b8AAAAAAADQPHeSEdtr
l+G/AB6X4xgyYj9mKqOuPrnhvwAmKyEfI3I//vcBeyHb4b8AAjT0MB57P0Ah
jyUU/eG/AF1ibh0Fgj/2VJ+TFh/iv4BjReyac4Y/qd96qihB4r8ABIR4jdqK
P5XAXU9KY+K/ABzMnfE5jz+7vndne4XivwCZXfbhyJE/6n3s17un4r9AkvB9
APGTP9+T04ULyuK/wGzhs1IVlj9hnThWauziv0B0bunWNZg/dVMbLtgO47/A
HtNyi1KaP4+gb/JUMeO/wF5Jp25rnD/VtR2I4FPjv0DuCuF+gJ4/ZiAC1Hp2
47+gTak+3UigP63e7bojmeO/4Mgu7o9PoT+7daYh27vjv+BPtrBWVKI/qAbm
7KDe479gvmK5MFejPwlkWwF1AeS/oATaPB1YpD9cJ6pDVyTkv4DHRXEbV6U/
i8ZqmEdH5L9A/1OOKlSmP3KpKuRFauS/YJQ3zUlPpz9yP2wLUo3kv6D8qGh4
SKg/BhWn8muw5L/A1OactT+pP2bpR36T0+S/4Hu2pwA1qj8xxLCSyPbkv4Cq
ZMhYKKs/HQs5FAsa5b/gCsY/vRmsP7WXLedaPeW/4M43UC0JrT8XzdDvt2Dl
vwBFoD2o9q0/xq1aEiKE5b9AbG9NLeKuP3Tx+DKZp+W/gIafxrvLrz/jGs81
HcvlvwDV2nipWbA/zI32/q3u5b+gKGEMecywP8CkfnJLEua/QPWwQ0w+sT8i
x2x09TXmv2CyXsUir7E/In+86KtZ5r9gXsU4/B6yP7yPX7Nufea/IMQGRtiN
sj/ECj64PaHmv9C/C5a2+7I/+mY22xjF5r+Qg4TSlmizPyKWHQAA6ea/UNvo
pXjUsz+/21P1
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtkl1Ik2EUx9/2XkRidFGUF7Mo0lwRs1i0ZXlmCkGuAgu6WETotERklcnU
QNcwuxxhqZBh7iMbSzezMj/y2CIoM7MPKV2aLTkkuk2SZM73IvfsuXh4eDic
8/zP7//fnm/MK5QJgqBYPbE7eDdZEGYJr479cVZ87ULv+c6ctADh1oqipOqJ
J1hVGd7o8hMOZPjq5n92YsfaQKtljLBEse7t+xkvKvOGtz37SOjLqjMe++zB
0UxFv3aIMHv0YklkvB1lP1y2lDeEN/erc3un3TghU0kFg4SG6cXJZnKhecOv
0Eof4Z5/9cueuTaMeqT7wW5C/VlrlbjgxOvvxN2ap4RnHuuz2xbtmHbN7p3y
Em6RhzLcS62Yv/6FbqqdMPzJZMv824LNF3Sb1W5C80D5bOrSPfxATTvmHxEW
Zb0+qFxuxCtysTb6kFD54FSNaaUe00Py4wVOwtuWpMsQtaLisONGqoOw4cD4
S6t0C/1lFlWOnXDhd+MXkGpwSDtc3G8jNO2qDKNkRN/pVynW1behdN+lkU0J
R0Z4PTnC6hDg/Xt1TbF+UPH5jmI2H7T8/5bn7H+o5frSe5k+mOH6z+mZfujm
+5V9Z/uBme//bY7tD7mcj6hgfMDG+Wl6GD/Y6Y3zPWRgfKGD8xdld2L8IVGM
+6MKMn9Azf07Acw/SIC4v2smmb9Qyv0vP8n8hzDPBypZPmCQ5yfxKMsPRHi+
CqtZvkDTEM9fl5/lD/4DWw9+Mw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlzAtIk1EUwPFPISEXUWZpk6nzgbZQlrHU0LkQnyXWHD7RalYTlZmmtpSt
URpRrZGGLzTnc5s2nQ7NV55luUYqWVqZkrrXl8IylVyWJt3owuXy43/OJbNz
mJetMQw7gu6/9/+ZHJrnLxDlBTrAiJUGRz82RJXtn8uqRHY9SnZxz4OTlKYO
ej/y7+M/qM7FMP3Tqpg8h5zI5pJ23QIHstjT/g9yapi55todeMeqLz/kogfh
1m2eaPYelC4UtXmfQrYbr1sLFEOeOjU2Ol0P2ONUi077CGqGr3OKS1F/sMrH
1sphjG/+NCjVA+OKTsU8WAEj5VOlhDd6UGdzlz/SqiC8LiA+04z2Haby7jNr
ICXOyXdmrwGE8VFSblYtFEpy1lnHkE22OoHwCQz3kO4uxhlgMVJO/xIpgXOu
1tNFhQZQv/RdEcc2QPX8twH3ajQf3auMZzWCrKCVPDdoAEkfu5+a0ASVNrhZ
Mo+88zmIlNgMv9JTrAqsjMB4EZbrlNACMV5toQkeRpBsxj2ksFpBoMmsiogw
glDkPxEVKwWOnGIMy0TekGXwImXACckmMEXIE3htT4gctu2l61lK9F9+rxSj
tUHacoSgfAr1xkvaRO92oLxSlmktyNaakOeHn4IDIdCeQDQBQ+N/1me3Ajor
fb4mB5vANUgSLLMo4MDE5PdnF1BPz4nx0XfAiCLZzq0EdX69ZnCsE3LXNv2q
pSagTs7y5ElKMBDf0khjJlC6X9xzY1wJ4yLLjmIF9VVl6Bl6F6ibBXmn7XCg
KtJG3Tq7wON1dv4GDYd9SaMB287d4HlzaKk9CQflsE34jKgbQHxexeXjwBgg
VPRudYPWlt4X3IDDIr/kfUWGCjDOiTnHURyuflhq4U2rwKuChGHLOPwFX1dn
1g==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtkm9Ik1EUxl8dZEoRVITQMlYozaAoVtkUj9RgsoyG9aGQ7I+rjD4sMNFF
KFoYgbZgVIJKubl0rbV3lha5OjYTWilZZmia2pBDQ52ZYE1fKLvv/XC5XA7n
3Of8nkd12px7JlYQBPXS+X8XD/xwln5+Am23NwhCmBBKzyaWfW2FK/k+3ZYQ
4d/0QNXUmA8Mlpk1rmHCXnX82/cTIlTEhRorBwjf7Ksy6z95YVluz8a2D4Q3
Pp678GfIAw8z1f6sd4QrNGkHXoy7YWzYZU/uJtwWmvtWTy7oiNVIBZ2E2t+2
qHeyGUyrvkcWOwg9x6yXFT+dMO6VGqafEYYf5+1vnnOAKahI3fuUcDYpku6e
b4S1lxziqEi4Y7DEnvnrHhhXPs8Z9RAau4vDKfN1UHMyZ12amzCQ3bVne/Qu
dFLtpqkWQmXLofKSRRsUKhXXFh4Q3rQlXoQFK6gjSkOBk1DUD720Stdhc0ZT
RUoT4fGE2n6QymGwqFKjcxDGWSwzKJkhmNVz3m8nvDUbf2SrNuTvOvw62br0
NjWwOvbxerWS9SPxfp+RzUctn19Uz/5HPf//6iOmD2u4vqSDTD9GuP66INsP
A3y/whG2P1bz/WNUjA8e5XymRcYPRc7vfh7jiztFma8qyvjjK84/ZoL5g0qF
7E/vLuYfZo/I/u3uZ/7iepD9PaVj/mMZ99+ayvKBwnI5H+0ZLD/Yx/MzKecL
E07I+Vr9heUPDXfk/P0DPId/4g==
        "]]]}}, {
     {Hue[0.6, 0.7, 0.5], Opacity[0], Arrowheads[0.0311281302845474], 
      ArrowBox[CompressedData["
1:eJyFkk0oRFEYhi83K43N2LiiLMjCgo2F1LEgi7GYZE8aSyk1pfzkPxt2d4qE
0ijKYvKzmpzYSJFZmIloxq1JLCyQhZTonm/13IXF7XTuc+/3vef5Tt3gSO+Q
bVlW899TKs/WsFMdW8kqu+fu2L0/VWeybzV7TR6ZKji7cU9NLyYe275n0uRN
hZOvUOpWtcjKevyf3JE61+a9Jh/Pm7oTZg3UiyZqLOvlSYVzz8mxm4NA3sOB
7Zz34enz8r73z+KD+omYfpvSh+ch5/nId0qWU/Ozbrpb+vL7V9fPp0ezfj5N
XpRclyanog+en7xRPF3JnnxudaPL7c+k85N+vkC9DulbYXIEeL3xqjvFM33T
b6XkWRM/9EVOf+RVxpOuFV/sFzde1ZF4Zj3mJ2+Qc0elLudFP/RNv+QX4nFf
VvKkrGF5z/vAPOzH78nph+ehH+blvMnpb0/O8yZz5zzJOV/ykJmTLltfiNlL
mXbmZX/umf+/+0ROf8zD+ZDTN+dNn+T0Qc5+zMv78Qsvs26+
       "]]}, 
     {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0]}], FaceForm[
      Opacity[0]], {DiskBox[{0.336815859287265, 0.13951369693913315`}, 0.], 
       InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}], 
        Offset[{2, 2}, {0.336815859287265, 0.13951369693913315}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.33681585928726687`, -0.13951369693913457`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}], Offset[{2, 2}, 
        {0.33681585928726687, -0.13951369693913457}], ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.5456128620971382, -3.1192699718763127`*^-17}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}], 
        Offset[{2, 2}, {0.5456128620971382, -3.1192699718763127*^-17}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.13951369693913301`, 0.33681585928726493`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "4"}], "}"}], 
        Offset[{2, 2}, {0.13951369693913301, 0.33681585928726493}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.38580655469148684`, 0.3858065546914871}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "5"}], "}"}], 
        Offset[{2, 2}, {0.38580655469148684, 0.3858065546914871}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.1395136969391338, -0.3368158592872676}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "6"}], "}"}], 
        Offset[{2, 2}, {0.1395136969391338, -0.3368158592872676}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.385806554691477, -0.38580655469147707`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "7"}], "}"}], 
        Offset[{2, 2}, {0.385806554691477, -0.38580655469147707}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.7159423830277749, 0.07746080446744256}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "8"}], "}"}], 
        Offset[{2, 2}, {0.7159423830277749, 0.07746080446744256}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.13951369693913362`, 0.33681585928726465`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "9"}], "}"}], 
        Offset[{2, 2}, {-0.13951369693913362, 0.33681585928726465}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.5610207740928872, 0.4514746538627005}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "10"}], "}"}], 
        Offset[{2, 2}, {-0.5610207740928872, 0.4514746538627005}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-7.462723925977589*^-17, 0.5456128620971378}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "11"}], "}"}], 
        Offset[{2, 2}, {-7.462723925977589*^-17, 0.5456128620971378}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.7159423830277639, -0.07746080446744033}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "12"}], "}"}], 
        Offset[{2, 2}, {-0.7159423830277639, -0.07746080446744033}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.13951369693913418`, -0.3368158592872675}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "13"}], "}"}], 
        Offset[{2, 2}, {-0.13951369693913418, -0.3368158592872675}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.45147465386270214`, 0.5610207740928899}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "14"}], "}"}], 
        Offset[{2, 2}, {0.45147465386270214, 0.5610207740928899}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-9.089046992381923*^-16, -0.5456128620971261}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "15"}], "}"}], 
        Offset[{2, 2}, {-9.089046992381923*^-16, -0.5456128620971261}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.5610207740928743, -0.45147465386269026`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "16"}], "}"}], 
        Offset[{2, 2}, {0.5610207740928743, -0.45147465386269026}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.38580655469148134`, -0.3858065546914798}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "17"}], "}"}], 
        Offset[{2, 2}, {-0.38580655469148134, -0.3858065546914798}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.33681585928726554`, 0.13951369693913265`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "18"}], "}"}], 
        Offset[{2, 2}, {-0.33681585928726554, 0.13951369693913265}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.07746080446744281, 0.7159423830277736}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "19"}], "}"}], 
        Offset[{2, 2}, {-0.07746080446744281, 0.7159423830277736}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.4514746538626916, -0.5610207740928761}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "20"}], "}"}], 
        Offset[{2, 2}, {-0.4514746538626916, -0.5610207740928761}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.3858065546914858, 0.38580655469148606`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "21"}], "}"}], 
        Offset[{2, 2}, {-0.3858065546914858, 0.38580655469148606}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.5456128620971313, 9.176715924896794*^-16}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "22"}], "}"}], 
        Offset[{2, 2}, {-0.5456128620971313, 9.176715924896794*^-16}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.33681585928726526`, -0.1395136969391336}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "23"}], "}"}], 
        Offset[{2, 2}, {-0.33681585928726526, -0.1395136969391336}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.07746080446744037, -0.7159423830277577}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "24"}], "}"}], 
        Offset[{2, 2}, {0.07746080446744037, -0.7159423830277577}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}}}, 
    {GrayLevel[0], AbsolutePointSize[5], 
     PointBox[{0.336815859287265, 0.13951369693913315`}], 
     PointBox[{0.33681585928726687`, -0.13951369693913457`}], 
     PointBox[{0.5456128620971382, -3.1192699718763127`*^-17}], 
     PointBox[{0.13951369693913301`, 0.33681585928726493`}], 
     PointBox[{0.38580655469148684`, 0.3858065546914871}], 
     PointBox[{0.1395136969391338, -0.3368158592872676}], 
     PointBox[{0.385806554691477, -0.38580655469147707`}], 
     PointBox[{0.7159423830277749, 0.07746080446744256}], 
     PointBox[{-0.13951369693913362`, 0.33681585928726465`}], 
     PointBox[{-0.5610207740928872, 0.4514746538627005}], 
     PointBox[{-7.462723925977589*^-17, 0.5456128620971378}], 
     PointBox[{-0.7159423830277639, -0.07746080446744033}], 
     PointBox[{-0.13951369693913418`, -0.3368158592872675}], 
     PointBox[{0.45147465386270214`, 0.5610207740928899}], 
     PointBox[{-9.089046992381923*^-16, -0.5456128620971261}], 
     PointBox[{0.5610207740928743, -0.45147465386269026`}], 
     PointBox[{-0.38580655469148134`, -0.3858065546914798}], 
     PointBox[{-0.33681585928726554`, 0.13951369693913265`}], 
     PointBox[{-0.07746080446744281, 0.7159423830277736}], 
     PointBox[{-0.4514746538626916, -0.5610207740928761}], 
     PointBox[{-0.3858065546914858, 0.38580655469148606`}], 
     PointBox[{-0.5456128620971313, 9.176715924896794*^-16}], 
     PointBox[{-0.33681585928726526`, -0.1395136969391336}], 
     PointBox[{0.07746080446744037, -0.7159423830277577}]}}},
  ImageSize->300,
  PlotRange->{{-1.1, 1.1}, {-1.1, 1.1}}]], "Output",
 CellChangeTimes->{
  3.9090560518364916`*^9, {3.9090561101798167`*^9, 3.9090561548715925`*^9}, 
   3.9091127161095977`*^9, 3.910153148939886*^9, {3.9101612802787886`*^9, 
   3.910161292364663*^9}, 3.9101655926503925`*^9},
 CellLabel->"Out[9]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
96.],ExpressionUUID->"0969c375-5bbe-41e8-aae0-c6373f13443b"]
}, Open  ]],

Cell["\<\
The elementary nearest-neighbor model has constant hoppings -1 and vanishing \
onsite potential, such that the Abelian Bloch Hamiltonian on the primitive \
cell can be constructed as follows:\
\>", "Text",
 CellChangeTimes->{{3.9091100794507523`*^9, 3.909110119897537*^9}, {
  3.9101532932814474`*^9, 
  3.9101533277179966`*^9}},ExpressionUUID->"679d70a2-5930-47f3-bcdb-\
beccdf68d04c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Hpc", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"AbelianBlochHamiltonian", "[", 
       RowBox[{"pcmodel", ",", "1", ",", 
        RowBox[{"0", "&"}], ",", 
        RowBox[{
         RowBox[{"-", "1"}], "&"}]}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.9091127598630133`*^9, 3.9091128051125402`*^9}, {
  3.909112887125308*^9, 3.909112890216216*^9}, {3.909114118715374*^9, 
  3.909114118938531*^9}, {3.910153339519004*^9, 3.9101533492091894`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"76a9f185-88e4-43cf-9074-24465b29b912"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]]}], "0", "0", "0", "0", "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "0", "0"},
     {
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]]}], "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]]}], "0", "0", "0", "0", "0"},
     {"0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]]}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]]}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]]}], "0", "0", "0", "0"},
     {"0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]]}], "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]]}], "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]]}]},
     {"0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]]}], "0", "0", "0", "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]]}], "0", "0", "0", "0", "0", "0",
       "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]]}], "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]]}], "0", "0", "0", "0", 
      "0", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]]}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]]}], "0", "0", "0", "0", 
      "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]]}]},
     {"0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], "0", "0", "0", "0", "0", "0",
       "0", "0", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]]}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]]}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]]}], "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]]}], "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]]}], "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]]}], "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]]}], "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]]}], "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], "0", "0", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]]}]},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]]}], "0", 
      RowBox[{"-", "1"}], "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0", 
      RowBox[{"-", "1"}], "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]]}], "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], 
      RowBox[{"-", "1"}], "0", "0", "0", "0", "0", 
      RowBox[{"-", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]]}], "0", "0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.909112806133675*^9, 3.9091128916577287`*^9, 
  3.909113216625798*^9, 3.9091141203995323`*^9, 3.91015335400698*^9, 
  3.910161299005518*^9, 3.9101656049358573`*^9},
 CellLabel->
  "Out[10]//MatrixForm=",ExpressionUUID->"7c25eaee-6e71-48ba-9ac4-\
3437448d7e4f"]
}, Open  ]],

Cell["We export the matrix", "Text",
 CellChangeTimes->{{3.90911280941973*^9, 
  3.9091128164730463`*^9}},ExpressionUUID->"e88406aa-0530-4485-ba3d-\
29648e177a84"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
       "\"\<H_8-kagome_T2.1.dat\>\""}], "}"}], "]"}], ",", "Hpc", ",", 
    "\"\<Table\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.909112817642894*^9, 3.909112873040862*^9}, {
  3.9091135412614784`*^9, 3.9091135513819184`*^9}, {3.9091141224124656`*^9, 
  3.9091141227837057`*^9}, {3.9101533706269875`*^9, 3.910153387843902*^9}, {
  3.910161305435033*^9, 3.9101613071799307`*^9}, {3.9101656107114687`*^9, 
  3.9101656118116646`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"a1acb124-c6f7-41a4-8b0b-1c1f0bb7a74e"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909112902255294*^9, 
  3.909112904377528*^9}},ExpressionUUID->"0c6113f1-0b03-44e2-9546-\
c3eaf63debf1"],

Cell["\<\
We approximate the density of states by randomly sampling momenta, i.e., \
one-dimensional irreducible representations, and diagonalizing the Bloch \
Hamiltonian evaluated at those. For faster evaluation, we compile the \
expression for the Bloch Hamiltonian:\
\>", "Text",
 CellChangeTimes->{{3.9091129164291873`*^9, 3.909112983734069*^9}, {
  3.9101534175388513`*^9, 
  3.910153418071595*^9}},ExpressionUUID->"d1b06afd-a354-469e-97aa-\
73f4e5895479"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hpccf", "=", 
  RowBox[{"AbelianBlochHamiltonian", "[", 
   RowBox[{"pcmodel", ",", "1", ",", 
    RowBox[{"0", "&"}], ",", 
    RowBox[{
     RowBox[{"-", "1"}], "&"}], ",", 
    RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9091129849959536`*^9, 3.9091129967523327`*^9}, {
   3.909114125339196*^9, 3.909114125798375*^9}, 3.910153426194847*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"c006109b-5ac4-4e84-b8b0-36b4037da23c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["CompiledFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  StyleBox[
                   PaneBox[
                    RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ContentPadding -> False, FrameMargins -> 0, 
                    StripOnInput -> True, BaselinePosition -> Baseline, 
                    ImageSize -> {{1, 300}, Automatic}], LineBreakWithin -> 
                   False], "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ImageSize -> {{1, 500}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Variables: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$334377", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334378", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334379", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334380"}], 
                    "}"}], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"Block", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Compile`$2", ",", "Compile`$3", ",", "Compile`$5", ",", 
                    "Compile`$6", ",", "Compile`$7", ",", "Compile`$8", ",", 
                    "Compile`$12", ",", "Compile`$13", ",", "Compile`$14", 
                    ",", "Compile`$21", ",", "Compile`$22", ",", 
                    "Compile`$23", ",", "Compile`$18", ",", "Compile`$19", 
                    ",", "Compile`$20", ",", "Compile`$9", ",", "Compile`$10",
                     ",", "Compile`$11", ",", "Compile`$15", ",", 
                    "Compile`$16", ",", "Compile`$17", ",", "Compile`$24", 
                    ",", "Compile`$25", ",", "Compile`$26"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"Compile`$2", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334380"}]}], 
                    ";", 
                    RowBox[{"Compile`$3", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$2"]}], ";", 
                    RowBox[{"Compile`$5", "=", 
                    RowBox[{"-", "Compile`$3"}]}], ";", 
                    RowBox[{"Compile`$6", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334377"}]}], 
                    ";", 
                    RowBox[{"Compile`$7", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$6"]}], ";", 
                    RowBox[{"Compile`$8", "=", 
                    RowBox[{"-", "Compile`$7"}]}], ";", 
                    RowBox[{"Compile`$12", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334380"}]}], 
                    ";", 
                    RowBox[{"Compile`$13", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$12"]}], ";", 
                    RowBox[{"Compile`$14", "=", 
                    RowBox[{"-", "Compile`$13"}]}], ";", 
                    RowBox[{"Compile`$21", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334377"}]}], 
                    ";", 
                    RowBox[{"Compile`$22", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$21"]}], ";", 
                    RowBox[{"Compile`$23", "=", 
                    RowBox[{"-", "Compile`$22"}]}], ";", 
                    RowBox[{"Compile`$18", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334378"}]}], 
                    ";", 
                    RowBox[{"Compile`$19", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$18"]}], ";", 
                    RowBox[{"Compile`$20", "=", 
                    RowBox[{"-", "Compile`$19"}]}], ";", 
                    RowBox[{"Compile`$9", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334379"}]}], 
                    ";", 
                    RowBox[{"Compile`$10", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$9"]}], ";", 
                    RowBox[{"Compile`$11", "=", 
                    RowBox[{"-", "Compile`$10"}]}], ";", 
                    RowBox[{"Compile`$15", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334379"}]}], 
                    ";", 
                    RowBox[{"Compile`$16", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$15"]}], ";", 
                    RowBox[{"Compile`$17", "=", 
                    RowBox[{"-", "Compile`$16"}]}], ";", 
                    RowBox[{"Compile`$24", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$334378"}]}], 
                    ";", 
                    RowBox[{"Compile`$25", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$24"]}], ";", 
                    RowBox[{"Compile`$26", "=", 
                    RowBox[{"-", "Compile`$25"}]}], ";", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "Compile`$5", ",", "0",
                     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "Compile`$8", ",",
                     "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    "Compile`$11", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "Compile`$5", ",", "0", ",",
                     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$8", ",", "0", ",", "0", ",", "Compile`$8", ",", 
                    "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "Compile`$14", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "Compile`$14", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    "Compile`$17"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", 
                    RowBox[{"-", "1"}], ",", "Compile`$20", ",", "0", ",", 
                    "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$23", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$23", ",", "0", ",", "Compile`$14", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "Compile`$8", ",", "0", ",",
                     "0", ",", "Compile`$20", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$20"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "Compile`$26", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "Compile`$5", ",", "0", ",", "0", ",", "0", ",",
                     "0", ",", "0", ",", "0", ",", "Compile`$11", ",", "0", 
                    ",", "0", ",", "Compile`$5", ",", "0", ",", "0"}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "Compile`$23", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "Compile`$17", ",", "0", ",", "0", ",", "0", 
                    ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "Compile`$17", ",", "0", ",", "0", ",", "0", 
                    ",", "Compile`$20", ",", "0", ",", "0", ",", "0", ",", 
                    "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "Compile`$23", ",", "0", ",", "0", 
                    ",", "Compile`$26", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "Compile`$26", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "Compile`$17"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$14", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", 
                    RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "0", ",", "0", ",", "Compile`$11", 
                    ",", "0", ",", "0", ",", "0", ",", "Compile`$26", ",", 
                    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", 
                    "0", ",", "0", ",", "Compile`$11", ",", "0", ",", "0", 
                    ",", "0"}], "}"}]}], "}"}]}]}], "]"}], 
                   ImageSize -> {{1, 500}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  CompiledFunction[{11, 13.3, 5468}, {
    Blank[Real], 
    Blank[Real], 
    Blank[Real], 
    Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {4, 2, 
   0}}, {{0, {2, 0, 0}}, {0., {3, 0, 4}}, {
     Complex[0., -1.], {4, 0, 4}}, {-1, {2, 0, 1}}, {
     Complex[0., 1.], {4, 0, 0}}}, {0, 2, 549, 570, 
   1}, {{11, 3, 4, 1}, {17, 0, 1, 2}, {40, 32, 4, 0, 2, 4, 0, 1}, {20, 1, 
    3}, {11, 0, 4, 5}, {17, 4, 5, 6}, {40, 32, 4, 0, 6, 4, 0, 5}, {20, 5, 
    7}, {11, 3, 4, 8}, {17, 4, 8, 9}, {40, 32, 4, 0, 9, 4, 0, 8}, {20, 8, 
    10}, {11, 0, 4, 11}, {17, 0, 11, 12}, {40, 32, 4, 0, 12, 4, 0, 11}, {20, 
    11, 13}, {11, 1, 4, 14}, {17, 4, 14, 15}, {40, 32, 4, 0, 15, 4, 0, 14}, {
    20, 14, 16}, {11, 2, 4, 17}, {17, 0, 17, 18}, {40, 32, 4, 0, 18, 4, 0, 
    17}, {20, 17, 19}, {11, 2, 4, 20}, {17, 4, 20, 21}, {40, 32, 4, 0, 21, 4, 
    0, 20}, {20, 20, 22}, {11, 1, 4, 23}, {17, 0, 23, 24}, {40, 32, 4, 0, 24, 
    4, 0, 23}, {20, 23, 25}, {10, 0, 5}, {11, 5, 4, 26}, {10, 1, 6}, {11, 6, 
    4, 27}, {10, 1, 7}, {11, 7, 4, 28}, {10, 1, 8}, {11, 8, 4, 29}, {10, 1, 
    9}, {11, 9, 4, 30}, {10, 0, 10}, {11, 10, 4, 31}, {10, 0, 11}, {11, 11, 4,
     32}, {10, 0, 12}, {11, 12, 4, 33}, {10, 0, 13}, {11, 13, 4, 34}, {10, 0, 
    14}, {11, 14, 4, 35}, {10, 0, 15}, {11, 15, 4, 36}, {10, 0, 16}, {11, 16, 
    4, 37}, {10, 0, 17}, {11, 17, 4, 38}, {10, 0, 18}, {11, 18, 4, 39}, {10, 
    0, 19}, {11, 19, 4, 40}, {10, 0, 20}, {11, 20, 4, 41}, {10, 0, 21}, {11, 
    21, 4, 42}, {10, 0, 22}, {11, 22, 4, 43}, {10, 0, 23}, {11, 23, 4, 44}, {
    10, 0, 24}, {11, 24, 4, 45}, {10, 0, 25}, {11, 25, 4, 46}, {10, 0, 26}, {
    11, 26, 4, 47}, {10, 0, 27}, {11, 27, 4, 48}, {10, 0, 28}, {11, 28, 4, 
    49}, {10, 1, 29}, {11, 29, 4, 50}, {10, 0, 30}, {11, 30, 4, 51}, {10, 1, 
    31}, {11, 31, 4, 52}, {10, 0, 32}, {11, 32, 4, 53}, {10, 0, 33}, {11, 33, 
    4, 54}, {10, 1, 34}, {11, 34, 4, 55}, {10, 1, 35}, {11, 35, 4, 56}, {10, 
    0, 36}, {11, 36, 4, 57}, {10, 0, 37}, {11, 37, 4, 58}, {10, 0, 38}, {11, 
    38, 4, 59}, {10, 0, 39}, {11, 39, 4, 60}, {10, 0, 40}, {11, 40, 4, 61}, {
    10, 0, 41}, {11, 41, 4, 62}, {10, 0, 42}, {11, 42, 4, 63}, {10, 0, 43}, {
    11, 43, 4, 64}, {10, 0, 44}, {11, 44, 4, 65}, {10, 0, 45}, {11, 45, 4, 
    66}, {10, 0, 46}, {11, 46, 4, 67}, {10, 0, 47}, {11, 47, 4, 68}, {10, 0, 
    48}, {11, 48, 4, 69}, {10, 0, 49}, {11, 49, 4, 70}, {10, 0, 50}, {11, 50, 
    4, 71}, {10, 0, 51}, {11, 51, 4, 72}, {10, 0, 52}, {11, 52, 4, 73}, {10, 
    1, 53}, {11, 53, 4, 74}, {10, 1, 54}, {11, 54, 4, 75}, {10, 0, 55}, {11, 
    55, 4, 76}, {10, 0, 56}, {11, 56, 4, 77}, {10, 0, 57}, {11, 57, 4, 78}, {
    10, 0, 58}, {11, 58, 4, 79}, {10, 0, 59}, {11, 59, 4, 80}, {10, 1, 60}, {
    11, 60, 4, 81}, {10, 0, 61}, {11, 61, 4, 82}, {10, 0, 62}, {11, 62, 4, 
    83}, {10, 0, 63}, {11, 63, 4, 84}, {10, 0, 64}, {11, 64, 4, 85}, {10, 0, 
    65}, {11, 65, 4, 86}, {10, 0, 66}, {11, 66, 4, 87}, {10, 0, 67}, {11, 67, 
    4, 88}, {10, 0, 68}, {11, 68, 4, 89}, {10, 0, 69}, {11, 69, 4, 90}, {10, 
    0, 70}, {11, 70, 4, 91}, {10, 0, 71}, {11, 71, 4, 92}, {10, 0, 72}, {11, 
    72, 4, 93}, {10, 0, 73}, {11, 73, 4, 94}, {10, 0, 74}, {11, 74, 4, 95}, {
    10, 0, 75}, {11, 75, 4, 96}, {10, 1, 76}, {11, 76, 4, 97}, {10, 0, 77}, {
    11, 77, 4, 98}, {10, 0, 78}, {11, 78, 4, 99}, {10, 0, 79}, {11, 79, 4, 
    100}, {10, 1, 80}, {11, 80, 4, 101}, {10, 0, 81}, {11, 81, 4, 102}, {10, 
    0, 82}, {11, 82, 4, 103}, {10, 0, 83}, {11, 83, 4, 104}, {10, 1, 84}, {11,
     84, 4, 105}, {10, 0, 85}, {11, 85, 4, 106}, {10, 1, 86}, {11, 86, 4, 
    107}, {10, 0, 87}, {11, 87, 4, 108}, {10, 0, 88}, {11, 88, 4, 109}, {10, 
    0, 89}, {11, 89, 4, 110}, {10, 0, 90}, {11, 90, 4, 111}, {10, 0, 91}, {11,
     91, 4, 112}, {10, 0, 92}, {11, 92, 4, 113}, {10, 0, 93}, {11, 93, 4, 
    114}, {10, 0, 94}, {11, 94, 4, 115}, {10, 0, 95}, {11, 95, 4, 116}, {10, 
    0, 96}, {11, 96, 4, 117}, {10, 0, 97}, {11, 97, 4, 118}, {10, 0, 98}, {11,
     98, 4, 119}, {10, 0, 99}, {11, 99, 4, 120}, {10, 1, 100}, {11, 100, 4, 
    121}, {10, 0, 101}, {11, 101, 4, 122}, {10, 0, 102}, {11, 102, 4, 123}, {
    10, 1, 103}, {11, 103, 4, 124}, {10, 0, 104}, {11, 104, 4, 125}, {10, 0, 
    105}, {11, 105, 4, 126}, {10, 0, 106}, {11, 106, 4, 127}, {10, 0, 107}, {
    11, 107, 4, 128}, {10, 0, 108}, {11, 108, 4, 129}, {10, 0, 109}, {11, 109,
     4, 130}, {10, 0, 110}, {11, 110, 4, 131}, {10, 0, 111}, {11, 111, 4, 
    132}, {10, 1, 112}, {11, 112, 4, 133}, {10, 0, 113}, {11, 113, 4, 134}, {
    10, 0, 114}, {11, 114, 4, 135}, {10, 0, 115}, {11, 115, 4, 136}, {10, 0, 
    116}, {11, 116, 4, 137}, {10, 0, 117}, {11, 117, 4, 138}, {10, 0, 118}, {
    11, 118, 4, 139}, {10, 0, 119}, {11, 119, 4, 140}, {10, 0, 120}, {11, 120,
     4, 141}, {10, 0, 121}, {11, 121, 4, 142}, {10, 0, 122}, {11, 122, 4, 
    143}, {10, 0, 123}, {11, 123, 4, 144}, {10, 1, 124}, {11, 124, 4, 145}, {
    10, 0, 125}, {11, 125, 4, 146}, {10, 0, 126}, {11, 126, 4, 147}, {10, 0, 
    127}, {11, 127, 4, 148}, {10, 0, 128}, {11, 128, 4, 149}, {10, 1, 129}, {
    11, 129, 4, 150}, {10, 0, 130}, {11, 130, 4, 151}, {10, 0, 131}, {11, 131,
     4, 152}, {10, 0, 132}, {11, 132, 4, 153}, {10, 0, 133}, {11, 133, 4, 
    154}, {10, 0, 134}, {11, 134, 4, 155}, {10, 1, 135}, {11, 135, 4, 156}, {
    10, 0, 136}, {11, 136, 4, 157}, {10, 1, 137}, {11, 137, 4, 158}, {10, 0, 
    138}, {11, 138, 4, 159}, {10, 0, 139}, {11, 139, 4, 160}, {10, 0, 140}, {
    11, 140, 4, 161}, {10, 0, 141}, {11, 141, 4, 162}, {10, 0, 142}, {11, 142,
     4, 163}, {10, 0, 143}, {11, 143, 4, 164}, {10, 0, 144}, {11, 144, 4, 
    165}, {10, 0, 145}, {11, 145, 4, 166}, {10, 0, 146}, {11, 146, 4, 167}, {
    10, 0, 147}, {11, 147, 4, 168}, {10, 1, 148}, {11, 148, 4, 169}, {10, 0, 
    149}, {11, 149, 4, 170}, {10, 0, 150}, {11, 150, 4, 171}, {10, 0, 151}, {
    11, 151, 4, 172}, {10, 1, 152}, {11, 152, 4, 173}, {10, 0, 153}, {11, 153,
     4, 174}, {10, 0, 154}, {11, 154, 4, 175}, {10, 0, 155}, {11, 155, 4, 
    176}, {10, 0, 156}, {11, 156, 4, 177}, {10, 0, 157}, {11, 157, 4, 178}, {
    10, 0, 158}, {11, 158, 4, 179}, {10, 0, 159}, {11, 159, 4, 180}, {10, 0, 
    160}, {11, 160, 4, 181}, {10, 0, 161}, {11, 161, 4, 182}, {10, 1, 162}, {
    11, 162, 4, 183}, {10, 0, 163}, {11, 163, 4, 184}, {10, 0, 164}, {11, 164,
     4, 185}, {10, 0, 165}, {11, 165, 4, 186}, {10, 0, 166}, {11, 166, 4, 
    187}, {10, 0, 167}, {11, 167, 4, 188}, {10, 0, 168}, {11, 168, 4, 189}, {
    10, 0, 169}, {11, 169, 4, 190}, {10, 0, 170}, {11, 170, 4, 191}, {10, 0, 
    171}, {11, 171, 4, 192}, {10, 1, 172}, {11, 172, 4, 193}, {10, 0, 173}, {
    11, 173, 4, 194}, {10, 0, 174}, {11, 174, 4, 195}, {10, 0, 175}, {11, 175,
     4, 196}, {10, 0, 176}, {11, 176, 4, 197}, {10, 0, 177}, {11, 177, 4, 
    198}, {10, 0, 178}, {11, 178, 4, 199}, {10, 0, 179}, {11, 179, 4, 200}, {
    10, 0, 180}, {11, 180, 4, 201}, {10, 0, 181}, {11, 181, 4, 202}, {10, 0, 
    182}, {11, 182, 4, 203}, {10, 0, 183}, {11, 183, 4, 204}, {10, 0, 184}, {
    11, 184, 4, 205}, {10, 0, 185}, {11, 185, 4, 206}, {10, 0, 186}, {11, 186,
     4, 207}, {10, 0, 187}, {11, 187, 4, 208}, {10, 0, 188}, {11, 188, 4, 
    209}, {10, 0, 189}, {11, 189, 4, 210}, {10, 0, 190}, {11, 190, 4, 211}, {
    10, 0, 191}, {11, 191, 4, 212}, {10, 0, 192}, {11, 192, 4, 213}, {10, 0, 
    193}, {11, 193, 4, 214}, {10, 1, 194}, {11, 194, 4, 215}, {10, 0, 195}, {
    11, 195, 4, 216}, {10, 0, 196}, {11, 196, 4, 217}, {10, 0, 197}, {11, 197,
     4, 218}, {10, 0, 198}, {11, 198, 4, 219}, {10, 0, 199}, {11, 199, 4, 
    220}, {10, 0, 200}, {11, 200, 4, 221}, {10, 1, 201}, {11, 201, 4, 222}, {
    10, 0, 202}, {11, 202, 4, 223}, {10, 0, 203}, {11, 203, 4, 224}, {10, 0, 
    204}, {11, 204, 4, 225}, {10, 0, 205}, {11, 205, 4, 226}, {10, 0, 206}, {
    11, 206, 4, 227}, {10, 0, 207}, {11, 207, 4, 228}, {10, 1, 208}, {11, 208,
     4, 229}, {10, 0, 209}, {11, 209, 4, 230}, {10, 0, 210}, {11, 210, 4, 
    231}, {10, 1, 211}, {11, 211, 4, 232}, {10, 0, 212}, {11, 212, 4, 233}, {
    10, 0, 213}, {11, 213, 4, 234}, {10, 0, 214}, {11, 214, 4, 235}, {10, 0, 
    215}, {11, 215, 4, 236}, {10, 0, 216}, {11, 216, 4, 237}, {10, 0, 217}, {
    11, 217, 4, 238}, {10, 0, 218}, {11, 218, 4, 239}, {10, 0, 219}, {11, 219,
     4, 240}, {10, 0, 220}, {11, 220, 4, 241}, {10, 0, 221}, {11, 221, 4, 
    242}, {10, 0, 222}, {11, 222, 4, 243}, {10, 0, 223}, {11, 223, 4, 244}, {
    10, 0, 224}, {11, 224, 4, 245}, {10, 0, 225}, {11, 225, 4, 246}, {10, 0, 
    226}, {11, 226, 4, 247}, {10, 0, 227}, {11, 227, 4, 248}, {10, 0, 228}, {
    11, 228, 4, 249}, {10, 0, 229}, {11, 229, 4, 250}, {10, 0, 230}, {11, 230,
     4, 251}, {10, 0, 231}, {11, 231, 4, 252}, {10, 0, 232}, {11, 232, 4, 
    253}, {10, 1, 233}, {11, 233, 4, 254}, {10, 0, 234}, {11, 234, 4, 255}, {
    10, 0, 235}, {11, 235, 4, 256}, {10, 0, 236}, {11, 236, 4, 257}, {10, 0, 
    237}, {11, 237, 4, 258}, {10, 0, 238}, {11, 238, 4, 259}, {10, 1, 239}, {
    11, 239, 4, 260}, {10, 0, 240}, {11, 240, 4, 261}, {10, 0, 241}, {11, 241,
     4, 262}, {10, 0, 242}, {11, 242, 4, 263}, {10, 0, 243}, {11, 243, 4, 
    264}, {10, 1, 244}, {11, 244, 4, 265}, {10, 0, 245}, {11, 245, 4, 266}, {
    10, 0, 246}, {11, 246, 4, 267}, {10, 0, 247}, {11, 247, 4, 268}, {10, 0, 
    248}, {11, 248, 4, 269}, {10, 0, 249}, {11, 249, 4, 270}, {10, 0, 250}, {
    11, 250, 4, 271}, {10, 0, 251}, {11, 251, 4, 272}, {10, 0, 252}, {11, 252,
     4, 273}, {10, 0, 253}, {11, 253, 4, 274}, {10, 1, 254}, {11, 254, 4, 
    275}, {10, 0, 255}, {11, 255, 4, 276}, {10, 0, 256}, {11, 256, 4, 277}, {
    10, 0, 257}, {11, 257, 4, 278}, {10, 0, 258}, {11, 258, 4, 279}, {10, 0, 
    259}, {11, 259, 4, 280}, {10, 0, 260}, {11, 260, 4, 281}, {10, 0, 261}, {
    11, 261, 4, 282}, {10, 0, 262}, {11, 262, 4, 283}, {10, 0, 263}, {11, 263,
     4, 284}, {10, 0, 264}, {11, 264, 4, 285}, {10, 0, 265}, {11, 265, 4, 
    286}, {10, 0, 266}, {11, 266, 4, 287}, {10, 0, 267}, {11, 267, 4, 288}, {
    10, 0, 268}, {11, 268, 4, 289}, {10, 0, 269}, {11, 269, 4, 290}, {10, 0, 
    270}, {11, 270, 4, 291}, {10, 0, 271}, {11, 271, 4, 292}, {10, 0, 272}, {
    11, 272, 4, 293}, {10, 0, 273}, {11, 273, 4, 294}, {10, 0, 274}, {11, 274,
     4, 295}, {10, 0, 275}, {11, 275, 4, 296}, {10, 0, 276}, {11, 276, 4, 
    297}, {10, 1, 277}, {11, 277, 4, 298}, {10, 0, 278}, {11, 278, 4, 299}, {
    10, 0, 279}, {11, 279, 4, 300}, {10, 0, 280}, {11, 280, 4, 301}, {10, 0, 
    281}, {11, 281, 4, 302}, {10, 0, 282}, {11, 282, 4, 303}, {10, 0, 283}, {
    11, 283, 4, 304}, {10, 0, 284}, {11, 284, 4, 305}, {10, 1, 285}, {11, 285,
     4, 306}, {10, 0, 286}, {11, 286, 4, 307}, {10, 0, 287}, {11, 287, 4, 
    308}, {10, 0, 288}, {11, 288, 4, 309}, {10, 0, 289}, {11, 289, 4, 310}, {
    10, 0, 290}, {11, 290, 4, 311}, {10, 0, 291}, {11, 291, 4, 312}, {10, 0, 
    292}, {11, 292, 4, 313}, {10, 0, 293}, {11, 293, 4, 314}, {10, 1, 294}, {
    11, 294, 4, 315}, {10, 0, 295}, {11, 295, 4, 316}, {10, 1, 296}, {11, 296,
     4, 317}, {10, 0, 297}, {11, 297, 4, 318}, {10, 0, 298}, {11, 298, 4, 
    319}, {10, 0, 299}, {11, 299, 4, 320}, {10, 0, 300}, {11, 300, 4, 321}, {
    10, 0, 301}, {11, 301, 4, 322}, {10, 1, 302}, {11, 302, 4, 323}, {10, 0, 
    303}, {11, 303, 4, 324}, {10, 0, 304}, {11, 304, 4, 325}, {10, 0, 305}, {
    11, 305, 4, 326}, {10, 0, 306}, {11, 306, 4, 327}, {10, 0, 307}, {11, 307,
     4, 328}, {10, 1, 308}, {11, 308, 4, 329}, {10, 0, 309}, {11, 309, 4, 
    330}, {10, 0, 310}, {11, 310, 4, 331}, {10, 0, 311}, {11, 311, 4, 332}, {
    10, 0, 312}, {11, 312, 4, 333}, {10, 0, 313}, {11, 313, 4, 334}, {10, 0, 
    314}, {11, 314, 4, 335}, {10, 0, 315}, {11, 315, 4, 336}, {10, 0, 316}, {
    11, 316, 4, 337}, {10, 0, 317}, {11, 317, 4, 338}, {10, 0, 318}, {11, 318,
     4, 339}, {10, 0, 319}, {11, 319, 4, 340}, {10, 0, 320}, {11, 320, 4, 
    341}, {10, 0, 321}, {11, 321, 4, 342}, {10, 0, 322}, {11, 322, 4, 343}, {
    10, 0, 323}, {11, 323, 4, 344}, {10, 0, 324}, {11, 324, 4, 345}, {10, 0, 
    325}, {11, 325, 4, 346}, {10, 0, 326}, {11, 326, 4, 347}, {10, 0, 327}, {
    11, 327, 4, 348}, {10, 0, 328}, {11, 328, 4, 349}, {10, 0, 329}, {11, 329,
     4, 350}, {10, 1, 330}, {11, 330, 4, 351}, {10, 0, 331}, {11, 331, 4, 
    352}, {10, 0, 332}, {11, 332, 4, 353}, {10, 0, 333}, {11, 333, 4, 354}, {
    10, 0, 334}, {11, 334, 4, 355}, {10, 0, 335}, {11, 335, 4, 356}, {10, 0, 
    336}, {11, 336, 4, 357}, {10, 1, 337}, {11, 337, 4, 358}, {10, 0, 338}, {
    11, 338, 4, 359}, {10, 0, 339}, {11, 339, 4, 360}, {10, 0, 340}, {11, 340,
     4, 361}, {10, 0, 341}, {11, 341, 4, 362}, {10, 0, 342}, {11, 342, 4, 
    363}, {10, 0, 343}, {11, 343, 4, 364}, {10, 0, 344}, {11, 344, 4, 365}, {
    10, 0, 345}, {11, 345, 4, 366}, {10, 0, 346}, {11, 346, 4, 367}, {10, 1, 
    347}, {11, 347, 4, 368}, {10, 0, 348}, {11, 348, 4, 369}, {10, 0, 349}, {
    11, 349, 4, 370}, {10, 0, 350}, {11, 350, 4, 371}, {10, 0, 351}, {11, 351,
     4, 372}, {10, 0, 352}, {11, 352, 4, 373}, {10, 0, 353}, {11, 353, 4, 
    374}, {10, 1, 354}, {11, 354, 4, 375}, {10, 0, 355}, {11, 355, 4, 376}, {
    10, 0, 356}, {11, 356, 4, 377}, {10, 0, 357}, {11, 357, 4, 378}, {10, 0, 
    358}, {11, 358, 4, 379}, {10, 0, 359}, {11, 359, 4, 380}, {10, 0, 360}, {
    11, 360, 4, 381}, {10, 0, 361}, {11, 361, 4, 382}, {10, 0, 362}, {11, 362,
     4, 383}, {10, 0, 363}, {11, 363, 4, 384}, {10, 0, 364}, {11, 364, 4, 
    385}, {10, 0, 365}, {11, 365, 4, 386}, {10, 0, 366}, {11, 366, 4, 387}, {
    10, 0, 367}, {11, 367, 4, 388}, {10, 0, 368}, {11, 368, 4, 389}, {10, 0, 
    369}, {11, 369, 4, 390}, {10, 0, 370}, {11, 370, 4, 391}, {10, 0, 371}, {
    11, 371, 4, 392}, {10, 0, 372}, {11, 372, 4, 393}, {10, 0, 373}, {11, 373,
     4, 394}, {10, 0, 374}, {11, 374, 4, 395}, {10, 0, 375}, {11, 375, 4, 
    396}, {10, 0, 376}, {11, 376, 4, 397}, {10, 0, 377}, {11, 377, 4, 398}, {
    10, 0, 378}, {11, 378, 4, 399}, {10, 0, 379}, {11, 379, 4, 400}, {10, 1, 
    380}, {11, 380, 4, 401}, {10, 0, 381}, {11, 381, 4, 402}, {10, 0, 382}, {
    11, 382, 4, 403}, {10, 0, 383}, {11, 383, 4, 404}, {10, 0, 384}, {11, 384,
     4, 405}, {10, 0, 385}, {11, 385, 4, 406}, {10, 0, 386}, {11, 386, 4, 
    407}, {10, 1, 387}, {11, 387, 4, 408}, {10, 0, 388}, {11, 388, 4, 409}, {
    10, 0, 389}, {11, 389, 4, 410}, {10, 1, 390}, {11, 390, 4, 411}, {10, 0, 
    391}, {11, 391, 4, 412}, {10, 0, 392}, {11, 392, 4, 413}, {10, 0, 393}, {
    11, 393, 4, 414}, {10, 0, 394}, {11, 394, 4, 415}, {10, 0, 395}, {11, 395,
     4, 416}, {10, 0, 396}, {11, 396, 4, 417}, {10, 0, 397}, {11, 397, 4, 
    418}, {10, 0, 398}, {11, 398, 4, 419}, {10, 0, 399}, {11, 399, 4, 420}, {
    10, 1, 400}, {11, 400, 4, 421}, {10, 0, 401}, {11, 401, 4, 422}, {10, 0, 
    402}, {11, 402, 4, 423}, {10, 0, 403}, {11, 403, 4, 424}, {10, 0, 404}, {
    11, 404, 4, 425}, {10, 0, 405}, {11, 405, 4, 426}, {10, 0, 406}, {11, 406,
     4, 427}, {10, 0, 407}, {11, 407, 4, 428}, {10, 0, 408}, {11, 408, 4, 
    429}, {10, 0, 409}, {11, 409, 4, 430}, {10, 0, 410}, {11, 410, 4, 431}, {
    10, 0, 411}, {11, 411, 4, 432}, {10, 1, 412}, {11, 412, 4, 433}, {10, 1, 
    413}, {11, 413, 4, 434}, {10, 1, 414}, {11, 414, 4, 435}, {10, 0, 415}, {
    11, 415, 4, 436}, {10, 0, 416}, {11, 416, 4, 437}, {10, 0, 417}, {11, 417,
     4, 438}, {10, 0, 418}, {11, 418, 4, 439}, {10, 0, 419}, {11, 419, 4, 
    440}, {10, 0, 420}, {11, 420, 4, 441}, {10, 0, 421}, {11, 421, 4, 442}, {
    10, 0, 422}, {11, 422, 4, 443}, {10, 0, 423}, {11, 423, 4, 444}, {10, 0, 
    424}, {11, 424, 4, 445}, {10, 1, 425}, {11, 425, 4, 446}, {10, 0, 426}, {
    11, 426, 4, 447}, {10, 0, 427}, {11, 427, 4, 448}, {10, 0, 428}, {11, 428,
     4, 449}, {10, 0, 429}, {11, 429, 4, 450}, {10, 0, 430}, {11, 430, 4, 
    451}, {10, 0, 431}, {11, 431, 4, 452}, {10, 0, 432}, {11, 432, 4, 453}, {
    10, 0, 433}, {11, 433, 4, 454}, {10, 0, 434}, {11, 434, 4, 455}, {10, 0, 
    435}, {11, 435, 4, 456}, {10, 0, 436}, {11, 436, 4, 457}, {10, 0, 437}, {
    11, 437, 4, 458}, {10, 0, 438}, {11, 438, 4, 459}, {10, 0, 439}, {11, 439,
     4, 460}, {10, 0, 440}, {11, 440, 4, 461}, {10, 0, 441}, {11, 441, 4, 
    462}, {10, 0, 442}, {11, 442, 4, 463}, {10, 0, 443}, {11, 443, 4, 464}, {
    10, 0, 444}, {11, 444, 4, 465}, {10, 0, 445}, {11, 445, 4, 466}, {10, 0, 
    446}, {11, 446, 4, 467}, {10, 0, 447}, {11, 447, 4, 468}, {10, 0, 448}, {
    11, 448, 4, 469}, {10, 0, 449}, {11, 449, 4, 470}, {10, 0, 450}, {11, 450,
     4, 471}, {10, 1, 451}, {11, 451, 4, 472}, {10, 0, 452}, {11, 452, 4, 
    473}, {10, 0, 453}, {11, 453, 4, 474}, {10, 0, 454}, {11, 454, 4, 475}, {
    10, 0, 455}, {11, 455, 4, 476}, {10, 0, 456}, {11, 456, 4, 477}, {10, 0, 
    457}, {11, 457, 4, 478}, {10, 0, 458}, {11, 458, 4, 479}, {10, 0, 459}, {
    11, 459, 4, 480}, {10, 0, 460}, {11, 460, 4, 481}, {10, 0, 461}, {11, 461,
     4, 482}, {10, 0, 462}, {11, 462, 4, 483}, {10, 0, 463}, {11, 463, 4, 
    484}, {10, 0, 464}, {11, 464, 4, 485}, {10, 0, 465}, {11, 465, 4, 486}, {
    10, 1, 466}, {11, 466, 4, 487}, {10, 1, 467}, {11, 467, 4, 488}, {10, 0, 
    468}, {11, 468, 4, 489}, {10, 0, 469}, {11, 469, 4, 490}, {10, 0, 470}, {
    11, 470, 4, 491}, {10, 0, 471}, {11, 471, 4, 492}, {10, 0, 472}, {11, 472,
     4, 493}, {10, 0, 473}, {11, 473, 4, 494}, {10, 0, 474}, {11, 474, 4, 
    495}, {10, 1, 475}, {11, 475, 4, 496}, {10, 0, 476}, {11, 476, 4, 497}, {
    10, 0, 477}, {11, 477, 4, 498}, {10, 0, 478}, {11, 478, 4, 499}, {10, 0, 
    479}, {11, 479, 4, 500}, {10, 0, 480}, {11, 480, 4, 501}, {10, 0, 481}, {
    11, 481, 4, 502}, {10, 0, 482}, {11, 482, 4, 503}, {10, 0, 483}, {11, 483,
     4, 504}, {10, 0, 484}, {11, 484, 4, 505}, {10, 0, 485}, {11, 485, 4, 
    506}, {10, 0, 486}, {11, 486, 4, 507}, {10, 0, 487}, {11, 487, 4, 508}, {
    10, 0, 488}, {11, 488, 4, 509}, {10, 0, 489}, {11, 489, 4, 510}, {10, 0, 
    490}, {11, 490, 4, 511}, {10, 0, 491}, {11, 491, 4, 512}, {10, 1, 492}, {
    11, 492, 4, 513}, {10, 0, 493}, {11, 493, 4, 514}, {10, 0, 494}, {11, 494,
     4, 515}, {10, 0, 495}, {11, 495, 4, 516}, {10, 0, 496}, {11, 496, 4, 
    517}, {10, 1, 497}, {11, 497, 4, 518}, {10, 0, 498}, {11, 498, 4, 519}, {
    10, 0, 499}, {11, 499, 4, 520}, {10, 0, 500}, {11, 500, 4, 521}, {10, 0, 
    501}, {11, 501, 4, 522}, {10, 1, 502}, {11, 502, 4, 523}, {10, 0, 503}, {
    11, 503, 4, 524}, {10, 0, 504}, {11, 504, 4, 525}, {10, 0, 505}, {11, 505,
     4, 526}, {10, 0, 506}, {11, 506, 4, 527}, {10, 0, 507}, {11, 507, 4, 
    528}, {10, 0, 508}, {11, 508, 4, 529}, {10, 0, 509}, {11, 509, 4, 530}, {
    10, 0, 510}, {11, 510, 4, 531}, {10, 0, 511}, {11, 511, 4, 532}, {10, 0, 
    512}, {11, 512, 4, 533}, {10, 0, 513}, {11, 513, 4, 534}, {10, 0, 514}, {
    11, 514, 4, 535}, {10, 0, 515}, {11, 515, 4, 536}, {10, 1, 516}, {11, 516,
     4, 537}, {10, 0, 517}, {11, 517, 4, 538}, {10, 0, 518}, {11, 518, 4, 
    539}, {10, 0, 519}, {11, 519, 4, 540}, {10, 1, 520}, {11, 520, 4, 541}, {
    10, 1, 521}, {11, 521, 4, 542}, {10, 0, 522}, {11, 522, 4, 543}, {10, 0, 
    523}, {11, 523, 4, 544}, {10, 0, 524}, {11, 524, 4, 545}, {10, 1, 525}, {
    11, 525, 4, 546}, {10, 0, 526}, {11, 526, 4, 547}, {10, 0, 527}, {11, 527,
     4, 548}, {10, 0, 528}, {11, 528, 4, 549}, {10, 0, 529}, {11, 529, 4, 
    550}, {10, 0, 530}, {11, 530, 4, 551}, {10, 0, 531}, {11, 531, 4, 552}, {
    10, 0, 532}, {11, 532, 4, 553}, {10, 0, 533}, {11, 533, 4, 554}, {10, 0, 
    534}, {11, 534, 4, 555}, {10, 0, 535}, {11, 535, 4, 556}, {10, 0, 536}, {
    11, 536, 4, 557}, {10, 0, 537}, {11, 537, 4, 558}, {10, 0, 538}, {11, 538,
     4, 559}, {10, 0, 539}, {11, 539, 4, 560}, {10, 1, 540}, {11, 540, 4, 
    561}, {10, 0, 541}, {11, 541, 4, 562}, {10, 0, 542}, {11, 542, 4, 563}, {
    10, 0, 543}, {11, 543, 4, 564}, {10, 0, 544}, {11, 544, 4, 565}, {10, 0, 
    545}, {11, 545, 4, 566}, {10, 0, 546}, {11, 546, 4, 567}, {10, 0, 547}, {
    11, 547, 4, 568}, {10, 0, 548}, {11, 548, 4, 569}, CompressedData["
1:eJwt1gWwVFUAgOF9DxBBOqTj0d2NlISUICAlIIJKp4R0I41KK4KApHRJo0gY
IKJ0N9JIilJ+O3t35pt/9+65d+ace8/OxrTuWr9LVCgUqhYdCmVRCaUOpCUd
6clARjKRmZhQZHxWspGdHOQkF7nJQ17ykZ8CFKQQhSlCUYpRnBKUpBSlKUNZ
XqMc5alARSrxOpWpQtXwHHiD6tSgJrWozZvUoS5vUY/6xKIBb9OQRjSmCU15
h2Y0pwXv0pL3aEVr3ucDPqQNbWlHezrQkU50pgtd6UZ3PqIHPelFbz6mD33p
R38GMJBBDGYIQxnGcOIygpF8wihGM4axjGM8E5jIp3zG50xiMlOYyjSmM4Mv
+JKZfMUsZvM1c5jLPL5hPgtYyCIWs4RvWcoylrOClaxiNWtYyzrW8x0b2Mgm
krOZLWxlG9v5nh/YwY/sZBe72cNPwf39mV/4lb3s47dgzfbze/D+AH/wJwc5
xGGOcJRjHOcEJznFac5wlnOc5wIXucRlrvAXV7nGdW5wk1vE5zZ3+Ju7wbF7
3OcBD3nEPzzmX/7jCU95xnNeELKhXw1Ho4lFbOLwEnF5mXjE5xUSkJBEJCYJ
SUlG8vBn10uhKcPXJhWpSUNa0oXPNya9ZiAjmchMDFnIGozJFhWZX3bNQU5y
kZs85CUf+SlAQQpRmCIUpRjFKUFJSlGaMpTlNcpRngpUpBKvU5kqVKUab1Cd
GtSkFrV5kzrUjYo8H29pvWAt6msD3qYhjWhME5oGY97RZjSnBe/SkvdoRWve
5wM+pE14PZ3XVtvRng50pBOdCf9Yd6Ub3fmIHvSkF735mD70pR/9oyL7YIAO
ZBCDGcLQqMj+GqbDg3EjdCSfMIrRjGEs4xgf3McJOpFP+YzPmcRkpjCVaUxn
Bl/wJTP5ilnM5mvmMJd5fMN8FrCQRSxmCd+ylGUsZwUrWcVq1rCWdaznOzaw
kU1sjorsjS26lW1s53t+YAc/BmN26i52B/dzj/7Ez/zCr+xlH7+xn985EKzP
H/pncE8P6iEOc4SjHON48P0JPckpTnOGs5zjPBe4yCUuc4W/uMo1rnODm9zi
Nnf4m7vc4z4PeBjM75H+w2P+5T+e8JRnPOcF4T8FUUQTi9jRkf0bR18iLi8T
L3ycV0hAQhKRmCQkJRnJSUFKXiUVqUlDWtKRngxkJBOZiQn/RyEr2chODnKS
i9zkIS/5yB8debYLaEEKRUfWurAWoSjFKE6JYGxJLUXp8DxDkdf/558J0w==

    "], {1}}, 
   Function[{
    PatrickMLenggenhager`HyperBloch`Private`k$334377, 
     PatrickMLenggenhager`HyperBloch`Private`k$334378, 
     PatrickMLenggenhager`HyperBloch`Private`k$334379, 
     PatrickMLenggenhager`HyperBloch`Private`k$334380}, 
    Block[{
     Compile`$2, Compile`$3, Compile`$5, Compile`$6, Compile`$7, Compile`$8, 
      Compile`$12, Compile`$13, Compile`$14, Compile`$21, Compile`$22, 
      Compile`$23, Compile`$18, Compile`$19, Compile`$20, Compile`$9, 
      Compile`$10, Compile`$11, Compile`$15, Compile`$16, Compile`$17, 
      Compile`$24, Compile`$25, Compile`$26}, 
     Compile`$2 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$334380; 
     Compile`$3 = E^Compile`$2; Compile`$5 = -Compile`$3; 
     Compile`$6 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$334377; 
     Compile`$7 = E^Compile`$6; Compile`$8 = -Compile`$7; 
     Compile`$12 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$334380; 
     Compile`$13 = E^Compile`$12; Compile`$14 = -Compile`$13; 
     Compile`$21 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$334377; 
     Compile`$22 = E^Compile`$21; Compile`$23 = -Compile`$22; 
     Compile`$18 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$334378; 
     Compile`$19 = E^Compile`$18; Compile`$20 = -Compile`$19; 
     Compile`$9 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$334379; 
     Compile`$10 = E^Compile`$9; Compile`$11 = -Compile`$10; 
     Compile`$15 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$334379; 
     Compile`$16 = E^Compile`$15; Compile`$17 = -Compile`$16; 
     Compile`$24 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$334378; 
     Compile`$25 = E^Compile`$24; 
     Compile`$26 = -Compile`$25; {{0, -1, -1, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}, {-1, 0, -1, 0, 0, -1, -1, 0, 0, 0, 0,
        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
       0}, {-1, -1, 0, 0, 0, 0, 0, -1, 0, Compile`$5, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0}, {-1, 0, 0, 0, -1, 0, 0, 0, -1, 0, -1, 0, 0, 0, 0, 
       0, 0, 0, 0, 0, 0, 0, 0, 
       0}, {-1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, Compile`$8, 0, -1, 0, 0, 0, 0, 
        0, 0, 0, 0, 0, 0}, {0, -1, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, -1, 0, -1, 
       0, 0, 0, 0, 0, 0, 0, 0, 0}, {
       0, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, Compile`$11, 
        0, 0, 0, 0, 0}, {
       0, 0, -1, 0, 0, 0, 0, 0, 0, Compile`$5, 0, 0, 0, 0, 0, 0, Compile`$8, 
        0, 0, Compile`$8, 0, 0, 0, 0}, {0, 0, 0, -1, 0, 0, 0, 0, 0, 0, -1, 0, 
       0, 0, 0, 0, 0, -1, 0, 0, -1, 0, 0, 0}, {
       0, 0, Compile`$14, 0, 0, 0, 0, Compile`$14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
        0, 0, 0, -1, 0, 0, Compile`$17}, {
       0, 0, 0, -1, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 
        Compile`$20, 0, 0, 0, 0}, {
       0, 0, 0, 0, Compile`$23, 0, 0, 0, 0, 0, 0, 0, 0, Compile`$23, 0, 
        Compile`$14, 0, 0, 0, 0, 0, -1, 0, 0}, {0, 0, 0, 0, 0, -1, 0, 0, 0, 0,
        0, 0, 0, 0, -1, 0, -1, 0, 0, 0, 0, 0, -1, 0}, {
       0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, Compile`$8, 0, 0, Compile`$20, 0, 0, 
        0, 0, 0, 0, 0, 0, Compile`$20}, {
       0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, -1, Compile`$26, 0, 0, 0, 0, 0, 0,
         0, 0, 0, -1}, {
       0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, Compile`$5, 0, 0, 0, 0, 0, 0, 
        Compile`$11, 0, 0, Compile`$5, 0, 0}, {
       0, 0, 0, 0, 0, 0, 0, Compile`$23, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, -1,
         0, 0, -1, 0}, {0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        0, 0, -1, -1, -1, 0}, {
       0, 0, 0, 0, 0, 0, Compile`$17, 0, 0, 0, -1, 0, 0, 0, 0, Compile`$17, 0,
         0, 0, Compile`$20, 0, 0, 0, 0}, {
       0, 0, 0, 0, 0, 0, 0, Compile`$23, 0, 0, Compile`$26, 0, 0, 0, 0, 0, -1,
         0, Compile`$26, 0, 0, 0, 0, 0}, {
       0, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0,
         Compile`$17}, {
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, Compile`$14, 0, -1, 0, 0,
         0, 0, -1, 0}, {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 
       0, -1, -1, 0, 0, 0, -1, 0, 0}, {
       0, 0, 0, 0, 0, 0, 0, 0, 0, Compile`$11, 0, 0, 0, Compile`$26, -1, 0, 0,
         0, 0, 0, Compile`$11, 0, 0, 0}}]], Evaluate],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.9091129975570006`*^9, 3.909113219916849*^9, 
  3.909115025816557*^9, 3.9101534280800033`*^9, 3.910156813155707*^9, 
  3.9101614128065453`*^9, 3.9101652925382805`*^9, 3.910165619004306*^9, 
  3.910165724183712*^9, 3.9101665511186914`*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"2dd6e1eb-2516-4e7f-aa9b-1ee5b6abc051"]
}, Open  ]],

Cell[TextData[{
 "As stated in the paper, we compute the DOS with an energy resolution of \
0.005 (but for demonstration purposes with a smaller sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "75188b97-a78d-4b6b-a390-83d8797407c8"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "8"], TraditionalForm]],ExpressionUUID->
  "24c4ff33-14ce-426f-801c-4735ef2d5607"],
 ")"
}], "Text",
 CellChangeTimes->{{3.909113068779531*^9, 3.9091131190954094`*^9}, {
  3.9101614549615393`*^9, 3.9101614564987535`*^9}, {3.910161500131562*^9, 
  3.910161500190627*^9}},ExpressionUUID->"a82f339f-fef6-4bb2-9b25-\
b2b09da625b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dospc", "=", 
   RowBox[{"ComputeDOS", "[", 
    RowBox[{"Hpccf", ",", 
     RowBox[{"10", "^", "5"}], ",", "32", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], "-", "0.005"}], ",", "2.1"}], "}"}], ",", 
     "0.005"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091130888235645`*^9, 3.9091130961532984`*^9}, {
  3.90911413019394*^9, 3.9091141332449045`*^9}, {3.910161490577303*^9, 
  3.910161498644859*^9}, {3.9101656308871603`*^9, 3.9101656373735223`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"8c71c0a2-bf16-43d9-96b0-8b527dfc7726"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"dospc", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.01"}], ",", "0.51"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.1); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(5\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909113125377311*^9, 3.9091131344978976`*^9}, {
  3.90911413604417*^9, 3.9091141363413095`*^9}, {3.9091150932516265`*^9, 
  3.9091150966947627`*^9}, {3.909126411615711*^9, 3.909126429281196*^9}, {
  3.910161469973936*^9, 3.910161470044631*^9}, {3.910161502500625*^9, 
  3.9101615076578336`*^9}, {3.9101657725552626`*^9, 3.9101657844493575`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"a21ecc2f-90ce-4a0e-81c0-f244c9b9ba69"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.006944444444444445], AbsoluteThickness[2], LineBox[CompressedData["
1:eJxdnHd83VX5x292crNQURkOFFRUVARRHPhUVEBBZSmogBUBcSCIqIj8sDhQ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          "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQXX5EUdqDn8EhaIdc6+vAB/YTDn3ViAHyGaBg9kwg
kETwlxbYcl1XRvDXuz+sEtFD8HeCjLFA8A8Djet3QvDPngECHwT/+mKggeEI
PtC0de6JCP6bQKDDshH870DjDpUi+IwgogHB5wYZ2IXgi64DOnAKgi8PdN6O
eQi+JtC4rysQfGMQ2Izg23EBDdyL4HuAHHgcwQcAlodB1g==
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxdnHd83VX5x292crNQURkOFFRUVARRHPhUVEBBZSmogBUBcSCIqIj8sDhQ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             "]], 
            Line[CompressedData["
1:eJxTTMoPSmViYGAQAWIQXX5EUdqDn8EhaIdc6+vAB/YTDn3ViAHyGaBg9kwg
kETwlxbYcl1XRvDXuz+sEtFD8HeCjLFA8A8Djet3QvDPngECHwT/+mKggeEI
PtC0de6JCP6bQKDDshH870DjDpUi+IwgogHB5wYZ2IXgi64DOnAKgi8PdN6O
eQi+JtC4rysQfGMQ2Izg23EBDdyL4HuAHHgcwQcAlodB1g==
             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-4.0024999999999995`, 2.0975}, {-0.01, 0.51}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-4.0024999999999995`, 2.0975}, {-0.01, 0.51}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxdnHd83VX5x292crNQURkOFFRUVARRHPhUVEBBZSmogBUBcSCIqIj8sDhQ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          "]], 
         Line[CompressedData["
1:eJxTTMoPSmViYGAQAWIQXX5EUdqDn8EhaIdc6+vAB/YTDn3ViAHyGaBg9kwg
kETwlxbYcl1XRvDXuz+sEtFD8HeCjLFA8A8Djet3QvDPngECHwT/+mKggeEI
PtC0de6JCP6bQKDDshH870DjDpUi+IwgogHB5wYZ2IXgi64DOnAKgi8PdN6O
eQi+JtC4rysQfGMQ2Izg23EBDdyL4HuAHHgcwQcAlodB1g==
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-4.0024999999999995`, 2.0975}, {-0.01, 0.51}}, 
        "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.1); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(5\\)]\\)\"", TraditionalForm],
  PlotRange->{{-4.0024999999999995`, 2.0975}, {-0.01, 0.51}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9091131356996164`*^9, {3.9091151092543554`*^9, 3.9091151641818786`*^9}, 
   3.9091264885492506`*^9, 3.9101535294359417`*^9, 3.910161470725986*^9, 
   3.9101615136304626`*^9, {3.910165766576762*^9, 3.910165784706767*^9}},
 CellLabel->"Out[13]=",ExpressionUUID->"0645e163-d9af-45b9-b736-921435290170"]
}, Open  ]],

Cell[TextData[{
 "The full data with larger sampling is stored  as ",
 StyleBox["data/DOS/dos_8-kagome_T2.1.dat", "Input"],
 " and we can import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091134847660837`*^9, 3.9091134940495186`*^9}, {
  3.909113659447389*^9, 3.909113670420266*^9}, {3.9091257465881844`*^9, 
  3.909125770268137*^9}, {3.9091262842252073`*^9, 3.909126291202912*^9}, {
  3.9101535429748435`*^9, 3.9101535465590334`*^9}, {3.910161515340441*^9, 
  3.9101615174640436`*^9}, {3.910165801435964*^9, 
  3.91016580427374*^9}},ExpressionUUID->"4d1e2b78-2536-4a0d-8d76-\
55b3a379b4de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<data\>\"", 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos\>\"", "Input"], 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos_8-kagome_T2.1.dat\>\"", "Input"]}], "}"}], "]"}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.01"}], ",", "0.51"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.1); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(8\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909126193404081*^9, 3.909126208623426*^9}, 
   3.909126263048504*^9, {3.909126423755125*^9, 3.909126426329094*^9}, {
   3.910153550359743*^9, 3.9101535525745273`*^9}, {3.9101542103107257`*^9, 
   3.910154210498105*^9}, {3.910161464469494*^9, 3.9101614645404596`*^9}, {
   3.910161519021552*^9, 3.9101615205223827`*^9}, {3.9101658069587917`*^9, 
   3.9101658124585643`*^9}, {3.9101658669637184`*^9, 3.9101659131198244`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"dfeea4c9-d523-434f-83fd-fe8841a5b024"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.006944444444444445], AbsoluteThickness[2], LineBox[CompressedData["
1:eJxdnHd8z9f3x7P3sGtTNWvv7Zg1q6UoitasUbO1tbVqK61qadVMrBBZJJFw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          "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/XDK5SRNLgaHoB1yra8DH9hzXV9cYAvkM0CByDr3
h1UiCL48UNUOOQRfM6b/0FcNBN8YDBB8O7CBCL4H0LR17gg+xF4EH2xcDIKf
BgYIfqEtyEAEvxrsQAQf7LxWBH8CyLh+BH/WTBBA8JcUgAxE8MHeXYfgg523
A8E/DDLuEIJ/9gwIIPgA5k9IHg==
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxdnHd8z9f3x7P3sGtTNWvv7Zg1q6UoitasUbO1tbVqK61qadVMrBBZJJFw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             "]], 
            Line[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/XDK5SRNLgaHoB1yra8DH9hzXV9cYAvkM0CByDr3
h1UiCL48UNUOOQRfM6b/0FcNBN8YDBB8O7CBCL4H0LR17gg+xF4EH2xcDIKf
BgYIfqEtyEAEvxrsQAQf7LxWBH8CyLh+BH/WTBBA8JcUgAxE8MHeXYfgg523
A8E/DDLuEIJ/9gwIIPgA5k9IHg==
             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-4.1, 2.1}, {-0.01, 0.51}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-4.1, 2.1}, {-0.01, 0.51}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxdnHd8z9f3x7P3sGtTNWvv7Zg1q6UoitasUbO1tbVqK61qadVMrBBZJJFw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          "]], 
         Line[CompressedData["
1:eJxTTMoPSmViYGAQBWIQ/XDK5SRNLgaHoB1yra8DH9hzXV9cYAvkM0CByDr3
h1UiCL48UNUOOQRfM6b/0FcNBN8YDBB8O7CBCL4H0LR17gg+xF4EH2xcDIKf
BgYIfqEtyEAEvxrsQAQf7LxWBH8CyLh+BH/WTBBA8JcUgAxE8MHeXYfgg523
A8E/DDLuEIJ/9gwIIPgA5k9IHg==
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-4.1, 2.1}, {-0.01, 0.51}}, 
        "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.1); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(8\\)]\\)\"", TraditionalForm],
  PlotRange->{{-4.1, 2.1}, {-0.01, 0.51}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.9101665701922455`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"8804f3e7-a41e-4018-8994-0a2ff9541062"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the supercells", "Subsection",
 CellChangeTimes->{{3.909113688151761*^9, 
  3.909113691600689*^9}},ExpressionUUID->"f69101ea-69ad-417a-b569-\
e82b10379938"],

Cell["\<\
The model is extended to the supercells in the sequence by translation \
symmetry, which allows us to construct the Abelian Bloch Hamiltonians on the \
supercells\
\>", "Text",
 CellChangeTimes->{{3.909114061369022*^9, 
  3.9091140880436444`*^9}},ExpressionUUID->"a256d9a9-32f5-42cc-941e-\
a866bfa9cae6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{
        RowBox[{"AbelianBlochHamiltonian", "[", 
         RowBox[{
          RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
          RowBox[{"0", "&"}], ",", 
          RowBox[{
           RowBox[{"-", "1"}], "&"}], ",", 
          RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "&"}], "/@", "supercells"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}, {
   3.910166185826136*^9, 3.910166187276629*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"6b7c8950-cf63-4ebe-9475-ebcb0b888d98"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<H_8-kagome_T2.1_sc-``.dat\>\"", ",", "#"}], "]"}]}]}],
         "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@",
    "supercells"}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
  3.910154322749093*^9, 3.9101543310279417`*^9}, {3.91016160339386*^9, 
  3.910161605793605*^9}, {3.9101661483799353`*^9, 3.910166149293952*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"0db6c4a8-0acc-4207-815a-72e1dba3cba1"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909114427990825*^9, 
  3.909114430083145*^9}},ExpressionUUID->"78cb7662-4405-462e-90fb-\
9648ea721abb"],

Cell["\<\
Increasingly better approximations of the true density of states in the \
thermodynamic limit are obtained by considering one-dimensional irreducible \
representations on increasingly larger supercells. Again, we first compile \
the expressions for the Abelian Bloch Hamiltonians to speed up the evaluation:\
\>", "Text",
 CellChangeTimes->{{3.9091144367949524`*^9, 3.909114603985526*^9}, 
   3.91015441714965*^9},ExpressionUUID->"8f1abd0f-29fb-46cc-9013-\
cbc11b890705"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hsccfs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{
         RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
         RowBox[{"0", "&"}], ",", 
         RowBox[{
          RowBox[{"-", "1"}], "&"}], ",", 
         RowBox[{"PCModel", "->", "pcmodel"}], ",", 
         RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091146138495903`*^9, 3.909114652753991*^9}, 
   3.909119478873217*^9, {3.910154420411165*^9, 3.910154425008809*^9}, {
   3.910163134806413*^9, 3.9101631355361147`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"8005e28c-1c5f-464b-857e-b5fb53204377"],

Cell[TextData[{
 "Once more, we compute the DOS with an energy resolution of 0.005  and a \
sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "3"], TraditionalForm]],ExpressionUUID->
  "f20d9153-f9c8-49ab-a5be-cb2bef35c9d7"],
 ":"
}], "Text",
 CellChangeTimes->{{3.9091148872154474`*^9, 3.909114904344953*^9}, {
  3.9101566973402805`*^9, 3.910156697549489*^9}, {3.910161660367123*^9, 
  3.9101616604374743`*^9}, {3.9101765103884735`*^9, 
  3.9101765103884735`*^9}},ExpressionUUID->"aa4949b9-061f-4cb2-b2c6-\
7fd6a89e3f7c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dosscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ComputeDOS", "[", 
        RowBox[{
         RowBox[{"Hsccfs", "[", "#", "]"}], ",", 
         RowBox[{"10", "^", "3"}], ",", "32", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], "-", "0.005"}], ",", "2.1"}], "}"}], ",", 
         "0.005"}], "]"}]}], "&"}], "/@", "supercells"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9091148504724855`*^9, 3.909114863025732*^9}, {
   3.9101548693475285`*^9, 3.910154869724236*^9}, {3.9101549493832054`*^9, 
   3.9101549496375976`*^9}, {3.9101616621016417`*^9, 3.9101616850848536`*^9}, 
   3.9101674081448646`*^9, {3.9101687920816994`*^9, 3.9101687939546127`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"237a1314-4308-40b2-8466-dfb379ff8d6e"],

Cell["\<\
We plot the successively better approximations of the (normalized) density of \
states as obtained from successively larger supercells:\
\>", "Text",
 CellChangeTimes->{{3.9091258353931103`*^9, 3.9091258729641294`*^9}, {
  3.909126315654191*^9, 
  3.9091263169689493`*^9}},ExpressionUUID->"d875982f-f8a4-42a2-bb90-\
3c3cf39b45a4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Association", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<T2.1\>\"", "->", "dospc"}], "}"}], "]"}], ",", "dosscs"}],
     "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4.1"}], ",", "2.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.01"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(3\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091194227381277`*^9, 3.9091194385257072`*^9}, {
   3.909125701919447*^9, 3.909125705158804*^9}, {3.9091264450645742`*^9, 
   3.9091264526411266`*^9}, {3.910154999941857*^9, 3.9101550239169064`*^9}, {
   3.9101562589192905`*^9, 3.910156259119133*^9}, {3.910157116954313*^9, 
   3.9101571172428455`*^9}, {3.910161666018202*^9, 3.910161678746447*^9}, 
   3.9101618458849573`*^9, 3.9101674115207944`*^9, {3.9101686910398192`*^9, 
   3.910168707914562*^9}, 3.910168774761067*^9},
 CellLabel->"In[27]:=",ExpressionUUID->"67cd92ae-b6f7-4ad1-adaa-47a587a251f4"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxdnHeYnVW1xs/0PhMVBUQRpQiCiiKCFBeigiAoEVRUQESaIhIRuAhcDFIU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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQbT3pdL0HP4MDAxg8sJ9w6KtGDJzPwDB7JhBIIvhL
C2y5risj+OvdH1aJ6CH4O+VaXwdaIPiHgcb1OyH4Z88AgQ+Cf30x0MBwBB9o
2jr3RAT/TeAOudZsBP870LhDpQg+I4hoQPC5QQZ2Ifii64AOnILgywOdt2Me
gq8JNO7rCgTfGAQ2I/h2XEAD9yL4HiAHHkfwAdfYP40=
          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxd3H2MXNV5x/HZ3Znd2dmdtaVYiKqRA0pVkShKIU1VUoUeFNEaRamCUaXS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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQbT3pdL0HP4MDAxg8sJ9w6KtGDJzPwDB7JhBIIvhL
C2y5risj+OvdH1aJ6CH4O+VaXwdaIPiHgcb1OyH4Z88AgQ+Cf30x0MBwBB9o
2jr3RAT/TeAOudZsBP870LhDpQg+I4hoQPC5QQZ2Ifii64AOnILgywOdt2Me
gq8JNO7rCgTfGAQ2I/h2XEAD9yL4HiAHHkfwAdfYP40=
          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxd3HmQXVWdB/DXr/v13p1QpBBHK4I4CJQiII7MFPhjFCeMy0jQYRgnQ8Gw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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQbT3pdL0HP4MDAxg8sJ9w6KtGDJzPwDB7JhBIIvhL
C2y5risj+OvdH1aJ6CH4O+VaXwdaIPiHgcb1OyH4Z88AgQ+Cf30x0MBwBB9o
2jr3RAT/TeAOudZsBP870LhDpQg+I4hoQPC5QQZ2Ifii64AOnILgywOdt2Me
gq8JNO7rCgTfGAQ2I/h2XEAD9yL4HiAHHkfwAdfYP40=
          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxd3Hl0XFd9B/CRNJJGI43sHNwQCjUJpDTsCYUSaMLPhEDC1ixQmqYuNUty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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQbT3pdL0HP4MDAxg8sJ9w6KtGDJzPwDB7JhBIIvhL
C2y5risj+OvdH1aJ6CH4O+VaXwdaIPiHgcb1OyH4Z88AgQ+Cf30x0MBwBB9o
2jr3RAT/TeAOudZsBP870LhDpQg+I4hoQPC5QQZ2Ifii64AOnILgywOdt2Me
gq8JNO7rCgTfGAQ2I/h2XEAD9yL4HiAHHkfwAdfYP40=
          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(3\\)]\\)\"", 
       TraditionalForm], PlotRange -> {{-4.1, 2.1}, {-0.01, 0.5}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 
        Scaled[0.02]}, {0, 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T5.1\"", "\"T17.2\"", "\"T33.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091194429099684`*^9, {3.909125698510269*^9, 3.9091257066406164`*^9}, 
   3.909126457110761*^9, 3.9101549712826576`*^9, {3.910155008395378*^9, 
   3.910155025671894*^9}, 3.9101562605065956`*^9, 3.9101571574389143`*^9, 
   3.910160994196726*^9, 3.910162121594056*^9, 3.910168626815968*^9, {
   3.910168691810589*^9, 3.9101687086129065`*^9}, 3.910168775520574*^9, 
   3.9101695184383307`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"14c6487f-935a-43d0-9e2c-90201a5ce8d2"]
}, Open  ]],

Cell[TextData[{
 "The full data is stored  as ",
 StyleBox["data/dos/dos_8-kagome_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it due to the reduced \
noise:"
}], "Text",
 CellChangeTimes->{{3.9091257257973347`*^9, 3.9091257829464827`*^9}, {
   3.9091258161267524`*^9, 3.909125817972119*^9}, {3.9091263241669226`*^9, 
   3.9091263478044133`*^9}, {3.9101544811965094`*^9, 
   3.9101544880133915`*^9}, {3.9101556042258387`*^9, 3.910155604445711*^9}, 
   3.910161914298563*^9, {3.9101688116050744`*^9, 
   3.9101688125306997`*^9}},ExpressionUUID->"53addfa9-a828-402d-a987-\
6e5715e051f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_8-kagome_``.dat\>\"", ",", "#"}], "]"}]}], 
            "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.1\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4.1"}], ",", "2.1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.01"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(8\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091263566114464`*^9, 3.909126393410284*^9}, {
  3.9091264603821816`*^9, 3.909126463017381*^9}, {3.9101544932422967`*^9, 
  3.910154495640236*^9}, {3.910155610950552*^9, 3.910155611196024*^9}, {
  3.9101562410776777`*^9, 3.910156285321762*^9}, {3.9101617452884254`*^9, 
  3.9101617608664107`*^9}, {3.910168721689234*^9, 3.910168728542076*^9}, {
  3.910168760533145*^9, 3.9101687649604893`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"b92303ef-646d-4f10-97d6-d1b1d69c3ccd"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxdnHd4V0XThtN7oUsHkSq9d4YqVRQEBASUKkWq0lFp0hEUUVCkJrRASCMd
dtJIo3cQAoFQQyghIZ184bfPLNf35p/3Om/k5Jy99+zuzDzPfDhu5uCJNlZW
VnF2Vlbv/neS5acUW+Hn3qJyvr3Hvr8etSk6u/6o99fX9s3q7PLl++vBodV/
SR/0/vrM6ZKfAe+v+6S+u+H763d329T9/XUXl3d3fH9tuV2799etWr77eX/t
27vkhk3eXzewPOD7a6+Sx7v20fvrGiW3C63+/vrv7SU/ld5fl7Pc8P315ncP
6Pn+2vJ4Lu+vV727nf37a/1TiiMqf/4q4VJ9elP/3QN5ctnp1naebiPo2aB3
b+TJ+2+t7He63RSyDEeqJ/f4PveD3ilzyHL7a578+7IT8U27LSTL+J325Loz
f/D7KfFnink3XtGe7BMyLGeOywoKezc+oZ7cs2ugr/eXq8jy+L6eXG9RG9cj
F9aS5f33efLlkYtvlim7kSzvu92Tq2y0LXel4WayvN8mT55/ZduJUzd/I8vw
/OLJrc+O2dnr3y202DIgnjw06nqd6Jlbafa7283y5ErxBcnl6vxF31rmiydv
b9ZueaMH20jPD08u6Gezbf0/f5OeD57cddiq9KwfdpDm78nlU/c+2z5oJ2ne
nvxk5pYLP7jvJgvelp78y7Ed4aOt9pDm6cnjUtf7bsncQ5qfJ7tH7b51KXUv
lbe8sCevOr41dPXtfaT5ePL5txf6JCd4kebhyZVPF38++6o3eHiwe8e4OVcf
7QcPDy5YNsw98tEB8PDgxyGNPut37yB4ePDw/6Y98nlwCDw8OPnxte4nXX3A
w4MPRbwI+KzlEfDw4KHvJkC7o+DhwQHZfUftH+wLHh78/Z91my1YcQw8PHhS
RujFrl/5gYcHO1yuPsYpxw88PHj0nic/V//NHzw8+NSP2+aUbREAHh78ZEzZ
PfNSAsDDg51vN3/xemMgeHhwxMon5/5uEwQeHjzjXrVuF+4FgYcHxySp2lv+
OQ4eHrz+q6LUbeOCwcODh+17dH5IvRDw8OAXPmOrBuWEgIcHr3Z1rT3gdCh4
eHDQ1Lsn3gaGgUfJ8/U/9NPtXeHg4cGDn9f+rf32CPBwZ4+uiTkt9kSChztn
lEn9NjbhBHi485yNA+Mf5J8ED3fOd01u8WddBg933tsjcfqKOwwe7jz51vdJ
/wRHgYc7By1t0N/qZDR4uLPVbZe6bdrEgoc77y70rZgYFwceJc9zYMW0HZdP
gYc7txzz2/aXf8eDhzv7rnPZUNAqATzcediA0HJVAxPAw51bTP7oi5xyieDh
zve3/LbiwNhE8HDnPCvn65P3JoKHO+/acm7dtNhE8HDn643mVq93NxE8Su43
0OGeepQIHu5c2atbZa/URPBw54SfEsp22JYIHu6cPCCwv/oqATzc+e3kKZ19
aseDhzsPuhI1a96rOPBw5/qjOzR1i4sFDzduY3P5oPveGPBw4wHeh/OaL44G
DzcuE9Ox96JvosDDjb/PGPrMr7/wcGOvM4H3PaedBA83tjtmN7Xfl5Hg4cbp
a9On2vcKBw839p/bKGFh21DwcOPuY1fMWNwyGDzcuPmqcgcndA4CDzfOafRN
UpmuAeDhxuUGVmlz+Us/8HDjT3ZnFyTePAIebny+/8z+RU0OgYcbf37+RHql
cvvBw41bPhyWvSZ0H3i4cbca03dW+3oveLgxu05rOPvFHvBw49IH8iIGZu8B
DzceuXL+F6c37QUPN759tGjxpU37wMONrzap/XjyFS/wcONDMwb7Veu8Hzzc
eI3NjPtl8g+AhxvX2+3yecrzQ+DhyquaHYv/0vMIeLhyV+cnj6MH+pJlf051
5T0NZl/OnOYHHq7sdaf+xv+O+4OHK9ddt+rvFdUDwcOVs0pf3/TVr0Fked1Q
Vx73eYMy0U2CwcOVJ2/IGWV9IwQ8XHlH+bG89Ncw8HDl3wZ2btP6hwjwcOUr
iRW7dPv2BHi4sotHwq9f+CjwcOXnS47PeFE6CjxcuWxy9bY0PRo8XLlVu9wl
H5SLBY+S+//9QG1vcwo8XNmWSlaApkng4cqFm3IuDqpyGjxcuXzj/vPenksG
D1dOiR9afsLMZPBw5Qo38ms3cUwGD1eumh/8y+SVSeDhyhMq23cJdUoCD1f+
p8ft09XnJIKHK7u6e3S5czsBPFz4VdKJDnv6JICHC5/tEJTpvT0ePFw4Knnh
XMdXp8DDhXsHbVJr6RR4uPCViZ1bd10fBx4unOp8wL3KxVjwcOHaH/f89GvH
WPBw4T/sn36b3jkGPFw4fGLCDYdZ0eDhwis6Fly4+GcUeLjwsXPFp6JCGTxc
eOMXm7uvChAeLly1asjDCSknwMOFGxYGptbJiwAPF558c+11q4bh4OHCf82+
v8blwzDwcOGAY18fLHMgFDxcuMeRNj+XWR4KHi5cut2o4TUPhYKHi+ZdOgw8
XNjfceXtiiFh4OHCBesfn4reGA4eLtyxdJVvlqyJAA8Xjt46dE/RyUjwcGF7
rx/bzqt2Ejyc2WXOvr+GhCjwcOYdAYuafZrE4OHMKeUfbx7vLeuVM/v82d+z
5+Mo8HDm142eLvzGNRo8nDkzf8zYlh9Hg4czR4VUvrl7sOwfzjx05pxTG+ZE
g4cz13PxauK3VXg488aDV9xqH4sGD2e+Mb9+05Nno8HDmaOvdjzfKiMaPJx5
2K067Wo6xoCHM6dGOrs+qRdD+jzuzKHOI2dV7BQDHs7c8/mAz2aNjAEPZ+7f
sH/HqzNiwMOZPXM6WG9eEwMeztz47fWCSrtiwMOZV7wY3GdGUAx4OPOFxL0Z
v16MAQ9nLvKziVh6OwY8nPm/5XUCeubFgIczO8Ru2X/NNRY8nHmXQ7eL52rI
/uHEy9M2Z3RtFQseTjx43PpB03rGgocT/1zm4oVfxsaChxM3+3Jy/q6vY8HD
iQ8HdZrgvyQWPJy4cPzE0IHr5ftw4h/t00dN2CffhxP3jfixzTI/2c+deFvp
DzZsOxULHk5cy6txhNOlWPBw4nld65WflBELHk5c0Ses65OiWPBw4rbvHtA5
DjycuM53I6udqBEHHk5c9VyltBaN4sDDic8MuTD+dps48HBir6odr9/qEwce
Tjzq0zEO2aPjwKPk+YKeX2g9JQ48nHjx1mrDPZfFgYcTN9q/cGf4H3HgUTJ+
yU1DZu6LAw8nbjyo1eWqQXHg4cTtBpyZ3Cxe9nMnvt8g1+tKUhx4OPKCx52d
wlbHgYcj31qwJbdzxzjwcORra6a3HZ8jPBz5XErEjSkBwsOR/9u66fLtacLD
kX/dMWLs8ubCw5EjN0a1a5wTAx6OPMjvnldplvXKkfvMSqrzdGMMeDjyvjrX
K1b4OgY8HDltVc2v27WKAQ9HnjuqyYJ2ZWLAw5E7qIXXM3KjwcOR/WIX/JFx
Lxo8HNnz/Owem2OiwcORW83PCgsMjgYPR878NLx9m5LvUfNw5IO31Jw6Jdea
hyO/SNu14mefaPBwZLsbR34P2BINHo58u93e7pe/iwYPR562896wn7+JBg9H
Lk5el932y2jwKBmf6Mb7g0ZGg4cj9/qjS/1z66LBw4HT3o603Z0UDR4OvLr9
6mZP28aAhwN/N2tSv9SDMeDhwOf/SQ/9q53wcNDx1xnh4cATKjQfuXxuHHiU
/Pfuk1c3qXkKPBz4zNnsvDtpp8DDgW/++GHjx7viwcOB+wYH3fhxdgJ4OLDz
lbX11lAieDjo/ateEng4cNMB+3fNqZEMHiX/3qF574plT4OHA19qFOtdpfwZ
8HDg6DoxsdZVzoKHA78a0ebBtU7nwMOBU3vczAhsfB48HHjeje/2FMacBw8H
HjNktXevry+AhwPPHzVl929WF8HDgX/6c82Hmw5cBA8HPu17Z91P/S6BhwMf
8u0xaXXOJfBw4BebP2txbOdl8LDnKh8EjnVqewU87Pnl/Hodeh2/Ah72PDAp
NuMFXwEPey7o617jZA0f8LDn83FbUouz9oOHPc/d+t0d251HwMOeKc252piJ
fuBhz2/uhnT1tQ8AD3v+aOlPm5PGB4KHPTf+5VBK2gY579pz2VHLLpX69zh4
2POp7IsVFi8IBg977v5B3FX/PiHgYc+xm+O/+8ImFDzsOW5vpwo1toaChz1/
N6J+zzJNZT+35wULfBqe2BUGHva8c9VHXfbVDAcPe57q88Xi58vCwcOeh/rO
sG1wIxw87Dn+89J3un8cAR72fHHdfr/MmRHgYc/VDs/tWu+o7Of2nFnbcd0/
zyPAw559R6/I/bhSJHjY8aJ/42os/kziQTsO3eJ8sv/YSPCw4+FrSnkeWhoJ
HnacvLKw/YlNkeBhxwuOlj822CsSPOz4r5HeyzsGRoKHHT+1LWXtFBEJHna8
ZcPPtUYfigQPO7Zb4JdVqeS/1zzseHmz9vO990aChx0HftDvxN5tkeBhx4XB
vHnQkkjwsOPoj25cnPRtJHiU3P9G1Tqbvo4EDzv+8seBQYvbRYKHHV9dMSXA
oVYkeNjxRzWWZzZ/HQEedry49/pbnvER4GHHnZoMnjD3nwjwsOMLKW+sY2ZF
gIcdPzvVLuXrNsLDjo/HOy0Yax9BOr9lx5tiB/PB0+HgYccHBnxQL2GbxOd2
3HFT2ZtBo8PBw5YnjSvn1rVCOHjYck7/Zbz/Xhh42HK3gSkfrS2JDzQPW267
/FWnDiPCwMOWD5ea5f2JRxh42PLpDguTBviEgoctjxx57uMJ00LBw5aX9i/V
flBpiQdtuWjEpbe9o0LAo+TvN5w2qNcPIWQZvk22fHtVq5OXKoSAhy3vfeDT
4Ytg+T5sOTPG5ZnNjGDwsOW40cttA2yDcd615XHdtlwas+s4eNhy4X+7RgV/
ehw8bHnRrC4bDt+RfIktL9mZzXsWBpHldp1t+cYnZ0JCygaBhy1/1XPVv+MO
BYKHLU8NLOg+smsgeNhy4tsHByadC8D3YctPky5s7/RtAHjY8uqDtf+oWOgP
HrZcJ2HjmME/+oOHDVez+XtuY3t/8LDhrIJfbUb+4Yf43Ibdnteb5dVA4kEb
bhI0dMOhkcfAw4bLDcrf3WmaL3jYcPNfajT9a8RRxOcl131tRo8fdwQ8bLig
cGbVDVN8wMOGndp/7NRs9GHwsOEdH/QPqDLwEHjY8JSZBUvH9jwIHjb8ZvX4
qcs6HgCPkr9f2jn9Yu394GHDGx1e0xA3b/Cw4Qpf2fhkF+0DDxtuPXn7vkPO
Ep/bcPCGKr2HtJP43IY/PJc0qsuWPeBhwx/1GtZ2Qk2Jz234acUJ5Ttd2A0e
NvzapeT/8d4NHjb8cT/X1qdX7gYPG36c55gzcOlu8LDha+O2Zzb7dTd42LCV
dfaCMz67wcOaX5wZ+6Nf3G7wsObiZadHzyi3BzyseeKKtOTyI/eAhzU/uHZ6
el7EHvCw5rQx4+pPa7gXPKx5weJ1f9b5Zy94WLNV2yFzmzXaBx7W3ODzRJd/
ffaBhzUnZU4pjB3kBR7WPNr7xPghuV7gYc3HB94Y2SjQGzys2X9+hfBy3+4H
D2uOuesU8EfnA+BhzXNrFfy1q/JB8LDmdR7f3Jlkdwg8rHmM68lVfTMPgYc1
37rm7dWx8DB4WPOcySUTwPoIeFhzy34t3q6tfRQ8rPlS1qKQaiN8wcOaj0Vu
9aq//Bh4WPPP8/d+MaRkv9Q8rDnh23Xu0zz8wcOaH10v9KgZLN+HNQe5ni1t
PT4APKx4SJNBMwsbB4KHFR9Nbd+nVUYgeFhx5N/Tf8k+FQQeVtz4crNL/r8f
Bw8r7uZSad2Tkv1V87Di2oNtVjaaHAIeVpxeu8qTNhNlvbLi8fOKhmVNCwMP
K95fdZ5Vm/nh4GHFAVXLVt6/JQI8rPjs6kHZ1+Jl/7Dikx9XuDDY/SR4WPHw
K0dL/zdMgYcVO9dx2FprLIOHFW9oM6LLxoZR4GHF16cuuZf9Ngo8rPjmFwvt
lr6Q864Vx/rcGDb8RQx4WHHoptY3y5eR+MOKHWpcnLFr4inwsOKtJ3uNv58V
Dx5WnFA5w6X9y0TwsOIy3VpFBRw/DR5W3OOve1NT/M+DR8l49JvW6VW2nKeK
1fj7fgmrZ5yn65bxLlblR9zebJ2VjPEtVscfVX8UXS8R41mszs4puruvmpxP
i1XNzVty+vweR5Z6yy/FKiWh36/Ne8difIrVsrI23x9pKvFxser7e9Kqh23l
/YvVkF3XY+M+jSJdPypW1acttF2/jvF+xWr16kpHnvgrvE+xCg7be7P2cMkv
vFXBv5ds4E1PYL97q+zyoq3Luch5462yeVSm2YvccOxnb1WFb5Id86zCMR/e
qoCr9SeVcQrD+eGtOpo7f6Btw1DwfqtS6o3u0HRACM4Hb1XW9n/TX68OBs+3
qmDBT14Nzkl+/q2a9PTGt9cdj4PXW9V5W91pu0cFYX9/qz6fGfXpssBA8Hir
yi/f3HVHRfkeilQF91lN33wfgPlfpFr+8XLrF4/8waNIVbJueuToEH/wKFL+
r2t3DzjtBx5Fqt9A+4xPBvqBR5Gq9aTWm7MBx8CjSB0esHH+ouO+4FGkfpj+
/dLbF4+CR5Fqn5Gdtt7uKHgUqW7jOqsX7Y6AR5E637ruyYIffMCjSDknR/aq
n3wYPAoV1zrUvGv5w+BRqGp3jP1x9FSpzxSqtH9++P67lIPgUajGj9sZsXHQ
QfAoVI2frHz0IPQAeBSq0udCMqv0k/2pUP12POfQzkv7waNQ1S1dcmKbsB88
ClXFYxtr13DfDx6Fym2w7ULvo97gUaicutvMjp7uDR6Fqua8eatKt/cGj5Ln
7Tuxx2t7b/AoUEvThsY9SvUCjwKV3+hq5bjTXuBRoM40Karuc9wLPArUPqu8
Af7+st4XqGa3Bqafi/MCjwIV+GL9qivpXuBRoHIvjPrYq5w3eBSouqXG2S0b
7g0eJdfvEs6+3uBRoOZWa9FxR7E3eBSokKs3Uqr9I/nqAlXl69WObT8/AB75
aonroRatmxwEj3wVttL3QLdmwiNfDRn0Sd9Tnx0Gj3y1r7PrtoAJcp7IV/vj
m7XZtu4IeOSrNhenH74cfRQ88lXhNPel4bd9wSNf9Xl2/ejq9GPgka92rIvM
+3mtH3jkq8l/b6v1V1V/8Ci5ftS6TuLf/uCRr55cGX66VPMA8MhXZ/YNH344
NAA88tTvv/zmM7FPIHjkqUjbMul5ZyR/nqfG7pqb0npMEHjkqSp9uyxq/TAI
PPKUOu942H/6cfDIU1OS2vdt8Pw4eOSphzn3bo1cHgweecq304JShR4h4JGn
XANjn6dtCgGPPPW6W5df/6gUCh55aujl7n2+2hkKHnnq3ec8rXYYeOSqctvP
fjLNV87nuarWmrrD27QIB49c9a7cNiJU1qtcteNpTPX+XSLAI1d99v3W5iFJ
kt/PVeGNf053GiDxTa4adXDH2chkiWdylWdM3Jv43ifAI1fF150SfPPBCfDI
VcejqcqYcSfBI1d9+DhzyMGXJ8EjVw1u1Gio0ywFHrmqRergWY1yJJ+bo+qv
Pd3Xsz2DR446Pvhol3HLmSyPF52jmk105tYxDB456kzuv7X6OEeBR45q2/jI
nB09o8AjR2XMfl02+jepR+SoBS8fnKudJPtpjvrkRsvxWyvI/pGjSv84aMvD
4dHgkaNq/xc5/Pd/o8kyfNVzVK3iaSvO35X8T46KrOsYF1MjBjzeqB5/Zrwq
NUryO2/UCIee/h12x5AFx+k3qnXi1m7db8aAxxuV+uvGt/3cJJ/5Ri2ukhfl
dknyZW/UvVouTVJSo2iJZQDfqPCONf133mHweKNs/pm6f10LBo83qv2kOjZR
bRR4vFHTuoXvqPrlSfrY8sJv1PplF+omrz4BHm9U5dlRaw7dknz7G3X3o9if
BreUeDxbBQ96nZFxJAL7ebbqufBV+dktI8AjW40/cWvFUB+p72Wr/BYlG0x/
OQ9lq0S/Lxp9ezsMPLJV7dkfLeLfw8jyurOy1brPO66e1iEMPLKV+5pxc53e
SL0hW12/0GbY1wGh4JGt4q/knJszKxQ8slX/uc6XdrWW7yNbdWyXVm2JdSh4
ZKm722qEDkoJAY8sVfnDXlU8fULAI0u5HnWoVG5tCHhkqbLHrxzqPFPqYVmq
JLqwejwkBDyy1PiiM+1V+xDwyFJful58kNZM9vMs9dN3d3Pr1gkBjyyV+/Ob
pBkNQ8AjS90bU8+qTMnvNY8stW91YtMlTUPAI0uVsio7tVbzEPDIUhkznWvV
6xcCHq9V1eVLUq2mhoDHa9Vv2S8/dVscAh6vVXLrub1e7gkBj9eqwaCTK6Ze
k3j6tUoKHvDxby6h4PFadXr8rV9q71DweK0i3I41bLlG8kclvy9V95HvM+Hx
Wk1xK/+qcc8w8HitHjfc4rkkKgw8XqsOPpU7r54n+YbXqmLVbn8GDJL6f6Zy
HlexZIpFgEem6nD5zLMP60WCR6by/Sv4eswayd9kqnL5SWm21yRfk6msM7eP
i6l8AjwyVcPSTm9GfHkCPDLVu3LyeO8T4JGpMp7Wap6TLutVpire79PgUuuT
4JGpHJsN3vXvSvk+MtW6p3M3nHso61Wm6lm2UZUrn8l6lan2xO4eXDtS1qtX
amly4zM/VmXweKUOLjr7lZoh69UrVbGHy5CAaFmvXqmjFbySE8vLevVKjfV/
utp6uqxXr9SHpffb9UiMAo9XyuFaUcKsupLvfqUmHj66tvwKWa9eqeg538S3
TJX16pXq0L9sxcheMeDxSu3sXc/a0VfqOa/Us3mRs+JKSf3mpVrX+cKEi4ul
XvNSHehfyzf/Vix4vFRVa/w56ExfyTe/VFfaRtXfeyAOPF6qQfWr9V1YRvQT
L9WFu3dfj156Cjxeqg5PPrQelnoKPF6qXc41O7frEQ8eL1WFT3z/jAqMB4+X
Kj5qWyu36gng8VKtqVOywsxPAI+XKqR/64rVniaAx0sVE/zN2kbNEzH+L8zv
9Xi/MP9ej+8Lc389ni/M39fj98I8nx6vF+b59fg8N++nx+P5/7z/czM++n2f
m/HT7/fcjK9+n+dm/PV8yjB89Pkjw/DT8yXD8NX7WYbhr+dDhpkf+vyQYeaP
5v3MzC99Pnhm5p/m+czMT73/PzPzV/N6Zua33t+fmfmveTwz34fmkW6+H80j
3Xxfmke6+f40j3TzfWoe6eb71TzSzfeteTw137/m8fR/1oenZv3QPJ6a9UXz
eGrWH83jqVmfNI8nZv3SPJ6Y9U3zeGLWP83jiVkfNY8nZv3UPJ6Y9VXzeGzW
X83jsVmfNY/HZv3WPB6b9V3zeGzWf83jsdkfNI/HZv/QPB6Z/UXzeGT2H83j
kdmfNI9HZv/SPB6Z/U3zeGT2P83jodkfNY+H/7N/PjT7q+bx0Oy/msdDsz9r
Hg/N/q15PDD7u15fH5j9X/N4YM4Hev18YM4PmscDc77QPB6Y84fmkWbOJ5pH
mjm/aB5p5nyjeaSZ84/mkWbOR3r9SjPnJ80jzZyvNI/75vyledw35zPN4745
v2ke9835TvO4b85/msd9cz7UPO6Z86Pmce9/zpf3zPlT87hnzqeaxz1zftU8
7pnzreaRas6/mkeqOR9rHqnm/Kx5pJrzteaRas7fer9KNedzzeOuOb9rHnfN
+V7zuGvO/3q/uWviA83jrokfNI+7Jr7QPO6a+EOP/x0Tn4y2jPcdE7+4Wsb3
jolvdH4wxcQ/Ol+XYuIjnT9LMfGTXj9um/hKrxe3TfxV0/L+t018dt7yvrdM
/Kbf75aJ7yzDU/+Wif/0fPrPxIdrLPPnPxM/6vnyn4kv71qG/6aJP/V8uGni
064W/jdN/Kp53zDx7TYL3xsm/tU8b5j4ONfygNdN/Kx5XTfx9ecWPtdN/K15
XDfxuZ+FxzUTv+v5f83E9046QDTxv57fV01+YLKFx1WTP9Dz96rJL7CFxxWT
f9Dz84rJT2geV0z+QvO4bPIbmsdlk//QPC6b/IjmccnkTzSPSya/onlcMvkX
zeOiyc9oHhdN/kbzuGjyO5rHBZP/0TwumPyQ5nHB5I80j/Mmv6R5nDf5J83j
vMlPaR7nTf7qG8v4nzP5LT3eZ03+q5RlfM+a/JgezzMmf6bH77TJr+nxOm3y
b0st45Ns8nN6PJJM/k6/f5LJ7+22vG+iyf/p90sw+UH9Pgkmf6jnU7zJL5ay
zJ94k3/U8+WUyU/q+RFn8pd6PsSZ/OZSC/9Yk//UvGNMfrSZhW+MyZ9qntEm
v/rSwi/K5F81ryiTn91tGUA2+Vuk201+ly3jf9Lkf/V4nzD54ZqW8Y00+WM9
nuEmv6zHL8zkn/V4hZr8tDZ8hJj8tR6P4ya/rd8/yOS/u1reN9Dkx/X7+Zv8
uX4fP5Nf18/va/LvXS3Pe8Tk5/XzHTL5e/08B0x+X/99L5P/14aUPaY+oO+/
09QPllrut93UF/S//8PUH7Rh5FdTn9C/X2nqF9ow8oOpb6D+YSX1D/yepD6C
f09SP8H9Seor+Psk9Rc8H0l9Bs9PUr/B+5HUd/D+JPUfjA9JfQjjR1I/wviS
1Jcw/iT1J/AhqU/d1fxI6ld6PgeS1LfAn6T+hflBUh/D/CGpn2F+kdTXMP9I
6m+YnyT1Ob0+RJLU7zC/Sep7+nYnSep/+D5I6oN6fWOS+iG+L5L6ol4/o0jq
j/g+SeqTen2OIalf4vsmqW/q9T+WpP6J9YGkPhqr1w+S+inWF5L6qptef0jq
r1ifSOqzWL9I6rdZen0jqe/q9T6RpP7bSa+PJPVhrJ8k9eOVen0lqS9j/SWp
P+vl+TRJfRrrN0n9Wu+fZ0nq21j/Serfen8+R1Ifx/5BUj/X57HzJPV17D8k
9Xd93jtPUp/H/kVSv9fnyQsk9X3sfyT1f31evUiiD8D+SaIf0OfhiyT6Auy/
JPoDfd6+RKJPwP5Nol/A/k6ib1ik938S/YMevssk+gh9nr1Cop/A+YJEX6Gn
2xUS/QXOJyT6DH0ev0qi38D5hkTfoc/710j0HzgfkehD9Hn2Gol+BOcrEn2J
5nGdRH+C8xmJPkXzuE6iX8H5jkTfonncING/4HxIoo/RPG6S6GdwviTR12ge
N0n0NzifkuhzNI//SPQ7ON+S6Htw/iXR/2get0j0QZrHLRL9kOZxm0RfpHnc
JtEfaR63SfRJmkcKiX5J80gh0TdpHikk+ifN4w6JPkrzuEOin0J8QaKvQvxB
or/S8ftdEn0W4hcS/ZaON++S6LsQ/5DovxAfkejDED+R6Md0vJtKoi9D/EWi
P9PxSCqJPg3xG4l+TccvqST6NsR/JPo3xIck+jitP7hHop9DfEmir9P6iHsk
+jvEpyT6PP1490j0e4hvSfR9Ws9wn0T/h/iYRB+o9Rb3SfSDiK9J9IX687lP
oj9EfE6iT9Q80kj0i4jvSfSNiP9J9I/ID5DoI5E/INFPIr9Aoq9E/oFEf4n8
BIk+U/N4QKLfRH6DRN+peTwg0X8iP0KiD9Xx50MS/SjyKyT6UuRfSPSnmsdD
En0q8jck+lXN4yGJvhX5HxL9q+bxiEQfi/wRiX5W83hEoq9F/olEf6t5PCLR
5yJ/RaLfRX6LRN+L/BeJ/hf5MRJ9MPJnJPph5NdI9MXIv5Hoj5GfI9EnI39H
ol9Gfo9E34z8H4n+GflBEn008ock+mnN4ymJvhr5RxL9NfKTJPpszeMpiX4b
+U0Sfbfm8ZRE/438KIk+XPNIJ9GPI79Koi/XPNJJ9OfIz5Lo0zWPdBL9OvK7
JPp25H9J9O/ID5Po45E/JtHPI79Moq9H/plEf4/8NIk+H/lrEv0+8tsk+n7k
v0n0/8iPk/gDkD8n8Q8gv07iL9A8npP4D5CfJ/EnIH9P4l/QPJ6T+BuQ/yfx
P2gez0n8EagfkPgnNI8XJP4K1B9I/BeaxwsSfwbqFyT+Dc3jBYm/A/UPEv8H
6iMk/hDN5yWJfwT1FRJ/CeovJP4T1GdI/Cma30sS/wrqOyT+FtR/SPwvqA+R
+GM035ck/hnUl0j8Nag/kfhvUJ8i8edo/q9I/Duob5H4e1D/IvH/oD5G4g9C
/YzEP6TH9xWJvwj1NxL/EepzJP4k1O9I/Euo75H4m1D/I/E/oT5I4o9C/ZDE
P4X6Iom/CvVHEv8V6pMk/izUL0n8W/p8k0ni70L9k8T/hfooiT8M9VMS/xjq
qyT+MtRfSfxnqM+S+NNQvyXxr6G+S+JvQ/2XxP+G+jCJPw71YxL/HOrLJP46
1J9J/HeoT5P481C/JvHvob5N4u9D/ZvE/4f6OIk/EPVzEv8g6usk/kLU30n8
h6jPk/gTUb8n8S+ivk/ib9Q8skj8j9AHkPgjoR8g8U9CX0Dir4T+gMR/CX0C
iT8T+gUS/yb0DST+TugfSPyf0EeQ+EOhnyDxj0JfQeIvhf6CxH8KfQaJPxX6
DRL/KvQdJP5W6D9I/K/Qh5D4Y6EfIfHPQl9C4q+F/oTEfwt9Cok/F/oVEv8u
9C0k/l7oX0j8v5rHGxJ/MPQzJP5h6GtI/MXQ35D4j6HPIfEnQ79D4l+GvofE
3wz9D4n/GfogEn809EMk/mnoi0j81dAfkfivNY8cEn829Esk/m3om0j83dA/
kfi/oY8i8YdrHjkk/nHoq0j85dBfkfjPoc8i8adrHrkk/nXou0j87dB/kfjf
oQ8j8cdrHrkk/nnoy0j89dCfkfjvoU8j8edrHrkk/n3o20j8/dC/kfj/oY8j
6Q+geeSR9A+Avo6kvwD0dyT9B6DPI+lPoHnkkfQvgL6PpL8B9H8k/Q+gDyTp
j6B55JH0T9A88kj6K0B/SNJ/AfpEkv4M0C+S9G+AvpGkvwP0jyT9H6CPJOkP
Af0kSf8I6CtJ+ktAf0nSfwL6TJL+FNBvkvSvgL6TpL8F9J8k/S+gDyXpjwH9
KEn/DM2jgKS/BvSnJP03oE8l6c8B/SpJ/w7No4Ckvwf0ryT9P6CPJekPAv0s
Sf8QzaOApL+I5lFA0n8E+lyS/iTQ75L0L4G+l6S/CfS/JP1PoA8m6Y8C/TBJ
/xToi0n6q0B/TNJ/Bfpkkv4s0C+T9G+Bvpmkvwv0zyT9X6CPJukPA/00Sf8Y
6KtJ+stoHkUk/WegzybpTwP9Nkn/Gui7SfrbaB5FJP1voA8n6Y8D/ThJ/xzo
y0n662geRfT/++8UkfTngX6dpH8P9O0k/X2gfyfp/wN9PEl/IOjnSfoHQV9P
0l8I+nuS/kPQ55P0J4J+n6R/EfT9JP2NoP8n6X8EfwBJfyT4B0j6J8FfQNJf
Cf4Dkv5L8CeQ9GeCf4GkfxP8DST9neB/IOn/pHkUk/SHgn+CpH8U/BUk/aU0
j2KS/lOaRzH9//5UxST9q+DvIOlvtbfRwsFHSq4lj/V/heyh9A==
          "]], 
         LineBox[CompressedData["
1:eJxFzyEMglAURuE7IxkrzibZjNqwOckkN61i1RnJULVqfvllDBbNVk0Gs13u
DZ5/e2NfObv0F+ts2RGRbvv0+57tr3EgE7E9x8HjVCR/i4QufW1D3Cs/cx/h
OK+a7wAPbXhkQTxtay7FmY/aIrZcjlc2vEk0iHd2ILbzSlxrrsLHgw6fCw1i
+12H7TyPL5pr8P2mwz/0EUUF
          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxdnHVc19f3x+n4UM7OqdjdzilynFPRGbOdNcWes3MGxmZ3t5goBiolIHEP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          "]], 
         LineBox[CompressedData["
1:eJxFzyEMglAURuE7IxkrzibZjNqwSia5aRWjmslQteqMNLeXMVg0WzWb7b57
g+ff3thXzi79+SpbdESk659+L+fNLQ5kIrbXOHgei+RvkbBJ39sQ98rPzEU4
zqv2O8BDGx5ZEE99rUlx5iJfxJbL8dKG14kG8c4OxHZeiWvNVfiw1+FToUFs
v9tgO8/hq+Za/Ljr8A8fIUUm
          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxdnHV4lFfTxjcbtw0upVhpcSnFLQMEdygaHIoXpxSHlmBtgULxEhqCW4hB
bDdnEiK4BggeI4QQ4q7fsmfm5Ppe/ul1rjRPnuf8js7c9zSetXTMHK1Go4m0
0Gi+/Heu6V8V1NC/hHU1vAbOrGxP2Rue13xKZfv5qWW97CZUtscENtj2aXRl
+95d479hle1B8V8eWNn+8rS9fSvbznZfnljZNj2ua2W7Y4cv/yrbXgOND2xb
2W5hesHK9mnj6z1vUtluaHxcYIPK9rGjxn91K9s1TA+sbP/95QWdKtum17Or
bG//8jjLyrb8V9nOb/7lhZxUO230ly+qbJu6I76ybXr888q2qf/uVrZvfOmv
8Mp20Jf+Caxsm17fq7Jt+v5TlW3T9x51Qr9bAX1OTRvgbPq+vU4Y0rXPgM5T
NjqbumebEx4oGOQ5zvmc83pThzjh1OFH2474+5Hz8i+PW+aEC4KC6rR6nus8
zzRenLD1oCmL/thaG+T4cMJv585s+E92Z5DjwQm3Hi9YuuifH0Hyd8KoAr1N
rd6LQfJ2wlOfTnfdmPE7mPB2cMKAoZ3q1O94ECRPJ7z4rGfklTGnQfJzQuvm
F5/77PSGmqYPdkKLDvnxl92ug+TjhKfj6ltd6BAE8qud8FrLDOuD76+D5KHD
U1mzdPf/9AHJQ4fTx+4407/8MkgeOixxeul8JtsHJA8drhrX26zP/SCQPHT4
ZFYTz03+oSB56HDz7bJWE86HgOShwypv6v89UfiD5KHDOrm/T5/z0RckDx0m
xPzq+zYjECQPHV4Dl68H/yFA8tCh/c065nWPhILkocOq24pcH6cHgOShwzbR
bts/5vqD5KHDATf9fqj9LAgkDx3enp01es9jQTx0WOtF8bdeCaHEQ4eDW9Y7
1i4ukHjocOnV2OdXz14nHjqsPTfCssmIEOKhw9Z1P71/q0XiocOYnzO3TpsZ
Sjx0GH+yoFHSpSDiocMwyyvjGs0MIh46/CUp58mowwbiocPYRqFDLgcJ4uGI
27a06pTtaCAejvggefbJpz2CiYcjJt7K3Gw3J4R4OKJzo7SorhNDiYcjzpjf
eIHlYebhiKtunQ3Lrq0nHo7o1u9J9zkBwcTDEV3Ff5d/WK4nHo7Y9Nuw/+Yd
CyUejti2/aTdB6qGEg9HLL/tOnbfrRDi4Ygr9n1zqd7KEOLhiFdfhjVeKgzE
wxFHvVnQdVYvQTwc8cP6mLG9ggzEwxGnFGvbrogJIR6OuLRF2WLfT3ri4YjP
DnxMcFskiIcj7vRLTu/fRxAPR1zz8njfU/564uGIhw+Fj80APfFwxBqjiz16
poQSD0eMXLtrbr/GSDwcsct65/R6ZczDESebeyxpZaEnHg74riC/x+o85uGA
ixbNirQYi8TDAW/Zua+f+asgHg5YbOk4tf9MPfFwwPEeNnN/ztETDwcUHicv
de2AxMMBZ45OnLV6ARIPB9xT7WL1kfMNxMMBcw7ueZfUW088HLD2zWtf257n
+eGAVzecTt/0GomHA3b4dlrQBO9Q4uGAQ6qUNy+MDSEeDrhf/75Rrc2hxMMB
j1c5MrtXjTDi4YBXYML6pFpIPBxwVMejuV8lhhAPB7xxoo1dFVsD8TC23bvu
06Yj8XBAl4WTnw9P5vnhgI2+btOl9n3m4YCbc7xfLX8aQjwccNKZgdVnTWQe
Dnjxv5SRhllhxMMBWya3az3UK5R42OPaA5+vp7TUEw97rJiaYPccBZj253h7
PPEw/mnajDDiYY+Hm4x2/NMSiYc9rtuxYf/aBgbiYfz9g62KYqYKMH1uoD3+
OPNQrHurMOJhjyPmvZ2qn4fEwx7/exHkvLkBzw979MjP7LtmKvOwxwHl1dp1
L2Ue9pj41ay52YeReNhj5ybv/u6ZFko87DHlm5CzH/fx/LDHZi8GBbSIQ+Jh
j59tRnqVXWMe9lhe7273ooOCeNjjy8TkZm6pPD/scVp8zWnxr5mHPZovSazW
/RHzsEezBq03Rjkh8bDHgFUp0QHNkHjYY81N+inJH5mHPdbrub/NZ2Nb8jD2
b0qNcYOHIvGwwyY/N8w7NRmJhx3Om/TrnQFlSDzssNiz6b3RGuZhh0OOXVnd
agPzsEPduPoO5/5E4mGHPzc973vYOB4lDzv8fs3KhD21mIcdXllqWOt+jnnY
4eNlu2D9dSQedpiT8bxtw7ZhxMMOFxx8EPmkTRjxsMMxt7s7e95kHnbos8a+
w6xXSDzs8GzcxLbaYWHEww737uyU7u/C88MOn4/6dvCZBOZhhy96ap7V1oYR
D+PzV6em7VsWRjzssPCrpoNnTA0jHnYYFhHVdEEp87DDp5adq/zSLox42OGD
QeMCe5wJIx52WE/saf37r2HEww7vrT/W2L06zw87XG+3dt+ehWHEwxb/zV6U
vPpjGPGwxT2LU14d+iuMeNhi74KV0KUF87DFI/NGP7gREUY8bPG/rDRDva7h
xMMWj1XvedZhN/OwxQFPftltMYJ52OL5N/6ffhgSTjxscVPREp++G8KJhy3a
bxuUMOBn5mGLWrfWHiWnmYctTv6+mbZnUTjxMP69P1cP6bg+nHjY4oO5v3UK
HxAG8jxui3e7r73tMCeceNhih66Gsc67bhAPW4z+5uDjbx3CiYctWnskra+7
kXkY//6Ie6fqbLxBPGxx7on2b3PW3yAetlh1qfe9vzcyD1uM/8+x3a2V4cTD
Fs3Nx4UcGxxBPGyxzySPTZ0vhBMPW/xrW9wPx04yDxsMWrT9au1XN4iHDTb6
8bfL1lYRxMMGs3ZfyniXzDxscEI7fdeeseHEwwabLK6xJOufCOJhg7VP37m1
vDSceNjgabuotlX7hxMPG/R2fXft3+4RxMMG/zrWceAehwjiYYN+86JaGn4L
Jx42uGZk4XrPQzeIhw1+t6/bx5M7I4iHDf5ws+Wavj1vEA8b3HGhrmPT3jeI
hw1md3C/Wb4+gnjYYGgjt9oOeczDBrfFjlxYOP0G8bDBE9229/Ax9p/kYYNe
TdttXTc3gnjYYApkX5wVzTxsMOJ88aeMzhHEwwafNV7zr8e/EcTDBse/GHCv
S0/mYfz9vA7VJ02KIB42OMy1IMXVEEE8rDFimU9Ze48I4mGNIZ0njP3Xg3lY
48JQg3t0WgTxsMb4FoYNpbkRxMMa23yeeKdeEfOwxpsDNn9X2iqSeFhjr4q4
t7cGRBIPa6zzu9U+3dhI4mGN1d/8E/fHxkjiYY3RPQy3R/wXSTys8ZH/iBfH
/CKJh7F988qqPi8jiYc1Luky2z6jJJJ4WOORE2f65daJIh7WWIE3j93uEUU8
rHGId775lalRxMMaT8xu+9PRDVHEwxpXuPzdbop7FPGwxoH2Yn04RhEPaxzr
GdAu/VUU8bDG6XuCt70tiSIe1jguIdGxfc1o4mGNngPOxy5qF008rLFpk7tN
XQdFEw9rdNQ5v4t0jSYeVniq6b19pxZFEw8rfOV4e03k2mjiYYWWf8yIcnaL
Jh5W6DJjT16bv6KJhxUmb5ur63cwmnhYYe1x/Z5+eyCaeFhhc4dbg346FE08
rNAuG1uFGduShxXuD6zay2N3NPGwwsCvI/Yv/zuaeFjh8Ss+T2yNf0/ysEL7
2FPBthuiiYcV/nbibLcrxveTPKww6chBm35bo4mHFbYyn/d9vyXRxMMKXdOM
s8f4PMnD+P3+o27c/SOaeFhhn6deVjHzo4mHFbbut3NHDb9o4mGFTdNnnurn
GU08rDA1d214kvH/lzys8Ndjy37yML9JPKzQt7B5tO4o87DCLg1qdVw7nXlY
ocX20cHtJt8kHpY49I5LrT8bMw9LFL9tuZY0jnlY4u6/7l/Y1+Ym8bDEmb7v
NE5fRxEPS+x27XL+cEMU8bDEmtcth/6UFkU8LHGFxYFs4cDzwxLnbLGcuXgr
zw9LbF59w+HwZJ4fljg6tea2izMjiIcl9r+wv+fW3hHEwxJzdzTvm5LL65Ul
DrgUMD7AOoJ4WOLtXvUdX/fh9cr4vtopSz7ev0E8LPF+r3+m7jnP65UlFnl5
rvHz5v3DEtMCD9e57R5OPCzxcZehsRkp4cTDEgdP8GyjmRROPCyx3s7uAaOD
ef+wxAOLrs6yfsT7uSX+GJzqNSSS93NLzDn9bYNB7Xk/t8R+4cEdr9zh85UF
Bu7t9HLcXT5fWeCWzdtcjrrz+coC7QZnflj7DRIPC7zoGR38/qQgHhb4LGnO
qIbLBPGwwL37o8+tt+TzrgUG23g0PD08lHhYYMeKoJrDLvP9wwJHTh12utM4
A/GwMN3PfijUEw8LHGM9fFeThXriYYEfTp4/mvGU74MW+CJ9sevE+Xz/sMCz
CX0b1deFEA8LvLHvN8PAC8HEwwIfnb1SPbJlMPGwwPWPurd08QkiHha4+vnv
V2eODiIexvaq4w29KgKJhwW2aKEZ7n4hkHhY4Kv793q06BNIPCzwZ/fPb3ze
BYCMb1lgV8dHrQ7sDCAeFpg675Ptrr4BxMMC7Xc2G35VE0A8zNHzq1qhKX7X
iYc5Ls7YM6f3jOvEwxzNbzV+9ZvDdeJhjpeSozdMu3mNeJij1cMh6x7vu0Y8
jD//fnuN5rOuEQ9zHHtry+crLa4RD3Ns9W+Ay+4Uf+JhjvF1eg0rP+NPPIx/
P3bU9KzF/mDqvr3mGL7kr8Syvv7EwxyPd/75/NXv/ImHOdY5NKf1NXOOl5hj
WOx34SPv+tF51xznfzNt09XtfsTDHHdZr5i/tLcf8TDHroOK3Ip1fsTDHGsd
amnxusQXTI/rZY6615/TffJ9iYc5FkV8suyU4ks8zHFOx6nPbwb6Eg9z0/2q
53xfmh/muLr1zbUVVXyJhzkGuXmdC3voQzzM8W7VqK9+CPMhHlo0t7Ox6xbL
8Sst3t/V40N2ug/dz7UY8NuBGltiOX6lxZPdsyyyfvchHlpc9r5LzP4Kb+Kh
xemedRv33+dN93Mttvox0f3tQm/iocVklz/ngqc38dDi3RcbWnes6kM8tLip
ZOKpqfN8iIcW9a8HtVn3ow/x0KJXjeAXbdGbeGixyqsOJwyGq8RDiwnLjl94
M9mLeGjletPTi3hocVj99+5Hjf+/5KHFvDNjRXoDH+KhxYcr2/x++2vmocW+
b/bl16nCPLRYvyS56d6T3sRDiw3tr1jV9blMPLT4sv3aU1svniceWpyTFLfA
a9k54mHsnzd91l26cYF4aHFNt6vpjUZ6EQ8zrNEturHHaOZhhj+GuZfNH+FL
PMzwqXbCGYdXzMMM53uML5y3ypt4mGGXMX86m2m9iIcZVk8cff3V5svEwwyt
Fv+UeiL1MvEww3Yr1iWdRi/iYYZLRPN5O5Z5Ew8zfF61ucPgr5iHGT5atC14
WlXmYYbm++/NGb2SeZihe3/th2p9mIcZ3tz45NjP9ZmHGdZvMbtDm4orxMMM
Z5x27tGt0It4mOGlpDd/uHTzJh5m2G3z8OKWsd7EwwybrurlqHXwIR5mGNKw
7oi7UczDDGvt3OU8ALyJhxkGPRzf/uy+q8TDDKt2XjF32+SrxMMMnUPq9U+1
8CYeZnhg/sOCE0a+kocGYaZjg1udmIcG21fz+uC7mueHButPTh/qOpB5aPB4
9V/vv3/MPDQ46tols5qzeX5ocPQw6+NVBvP80GBmrVbHLx/h+aHBThN1aYXt
fIiHBsd3XrrjWCjPDw22KU233WzhSzw0eK7+2ZOv3zMPDV6Ksz23e48P8dDg
3+My3Z4M9SEexr8/yS9l4gQf4qFB/0tRaZ0MPsRDg49vJNV2HuRLPDTYa13x
50n+vsRDg1Ni2n4U0Tw/NPhd6wXznuzl+aHB6Tusu/QexuuVBo8+/mpkaQ9e
rzToczI0YcNmXq80eFczILWD1o94aNB1Sduo27/6EQ8Nbve+O9nioh/1f4XY
V443v/rHD2JN/V0hZuxNbbptjh/1b4XYv79X4ZUpftSfFSJn/9VVpUf8qP8q
xCj9tFF+FX5gyrdsqxC7vnEbs8qV1/MKcSXzwfbDG/ypPyrEY0PTvovn+dP3
V4iDq5cb/If6g8wfVYjDg78b02uWP31fhXj9/MzpkKv+9D0VYsWDFksX1rxG
46lcNJ7Rpshp0jXa78rFoEvZmx7O4P2tXHQJaXfacgzvZ+Vi4JTvZ7U0/lyO
h3IxbylOtPG4RueHcrHkfuiZ1OJrxLtc9Oh1ZV1F7+t0PigXmb4j/7k08jrx
LBcJz8fXj3bh+Hy5OHp3ytpWxp9LXuUi7Y5Zj9kHrtP+Xi4WB/T/tW/edeJR
LsrXflzcolMA8SgT7XeWH60wtuX4LxMuQ7vHFzULIB5l4s6Mah/OuAQQjzKx
3bx5R+tjAcSjTKybu/zikJIA4lEmnLbG9J7WOJB4lIkv15fjmkDiUSaso690
q5sWQDzKRMNDo+8dbRdIPMrEgoU/fDvNj88rZSJ7+em/hus4f2D8/fjbF0fl
BhKPUpGUWjIv6FIg8SgVS/9d23NwZCDxKBUnT15a4zoriHiUigWe66tNKQoi
HqWi76bNQ/5NDyIepcKwcfmFcXOCiEepSHSfNmdH7yDiUSo2uGsGxRQGEY9S
kePSfMvVtGDiUSp2L7oR5lkUTDxKxfBW22dfbRRMPEqF5bqnuj2XOB9VKjrk
FgSf+D2YeJSIyWtKzl18yvmNEjHnyl+5ZdkhxKNETKp3JDLdn/MXJSJS4zp4
pPF9JI8S4dT08vb1TiHEo0Q0cajzsE6QnniUiIDGuzM6XtYTjxLhuFI3M0bL
8e0SsTSy8Zz2g4OJR4k4kp130O1ZCPEoEfU7O23J22UgHiVi6xrH+jFxnC8o
Fo2isnNavQomHsWiyZZNfw+5GEw8ioWh7iGPsRF64lEsLnq8uXm7eijxKBaH
JvyZsfYgn6+LxbYTX//x7lgw8SgWyzMsrq8YzefnYnH7bNiKuGsG4lEsDh+I
nRXzdSjxKBaXxrtOelkWQjyKxe6eY3oGXGYexaLLYvfmVgP1xKNYhPT/vH/T
6FDiUSR2t452szI+X/IoEuY3W8/quJl5FIkv5+caP4QQjyLx8NA3Uw4A3xeK
xPifPv3TdXEo8SgSpvtcNc4PFYklXuc72y4IIR5FYqbHwgnmOs7/FInhc730
Bz8YiEeRCH6XtnRXI863FYnb9a1PrPtTTzyKxAFzzeqHoSHEo1D0tzmTsiVD
TzwKxVS/aS0WduB8WaGo/ca2veGcgXgUCt8ZsX79R3M+rFDcGeY3VExhHoXi
XtjgK4fPGohHoViSuz/1eNNQ4lEojKPjaV575lEo0tq9cUlaqicehaKk+69x
rl8ZiEeh6JOqrbezbijxKBQnVh/ZviKJ81GF4tn1jy6/feR8R4Fwbera6OtY
PfEoEF6l212rRRnA9HrhBcJ/S4uhW7rwfa5AXFt15b9pO5hHgah3u+b0Z2l6
4lEgqrtMenV2GfMoEFt9hrr91zWUeBSIJW4a3Un7UOJRILLanL4d04t5FIgq
Vo9gZTcDmLqvQYEYcTvi81KzUOJRIGZM/uXrXlM5f5Mv3teMaT8o2EA88sX4
V9+LMZ0NYMJxN19E/mF7WOvLPPKFtplFcuwCnh/5YsTpzPO92nE+Ml/8mFfN
xme+ATaYOjBfjF00O7jsJwPxyBfu/RyX9O/E+V7j8yKrPVjxG8+PfBHTbVl2
4h0DtDR9cL74sNq+MKi7gXjkiyeZZ598iGIe+aLfmOYTsw7w/MgTR8/8E3Jp
YCjt53liXNK9CvvhzCNPLGjwx7GiPgbikScso1dURRfOH+WJKpk7fLMu8vzI
E2c9Ry/0CzCA6XOX5Yk633u0r/uR16s8odv4qq+/u4F45IltotmKPQGhxCNP
tJq9ZJzT2FDikSewOLU4W8PrVZ6YsOiFnXcqr1e5Im75+OJHA0KJR67ou8dO
O+xBKPHIFZc/FNTftp955IoDc5Mt3Xbz/MgVDQ42br1yvYF45Io5h13mld4P
JR65IvNZt+S+Q3l+GH/eL2XP2ig98TC2BzzeciCC50eu8NRNT/3cN5R45Iqt
5r6JYwN5fuSKfWV3Rg6fxjxyRRXfLenfbOT5kSOabWhUNmCtgXjkiEPrf+lb
9Xgo8cgR9Ue1zmpdyjxyRL11R7NCLnB+NUe8uW/zk/Yez48ccbysTZ8km1Di
kSNWbXnjubo/z48cMSDNfZtXY+aRI5YtLmt3aZOeeOSIrOIm3V4O4fmRI57U
dd36e12eHzmi6/Qufw4+aiAe2WLy2sxGaw7xepUtCjL7Fk4zvp/kkS0snqTr
4w8yj2yxRmv8jVscr8kWdbx/d0/L5fUqW1h9XLGi50964pEtAuu+bzY4W088
skV21Mfxiy7xepUt1q1ovilyCud3s8XJOlmncrfqiUe2CEpd6Tl1pZ54ZIvk
oR3aturNPLJF6m4xIuQ/zpdnif7ZkydvztcTjyzRcW+zbqOG6YlHlsjc6xo0
019PPLLE3qievi7/8HqVJbokfn45ZqeBeGSJ9Dov5yw5oiceWWJw/aXD57nw
/MgSztYR9++3Yx5ZYkqDz1t2aXh+ZIl9o5o1fziJeWSJPu+7hbp9z/tHloj3
TDvqs5bnR6bo+X5n/6LqPD8yxUTHgoqJW3l+ZIpdS1q/nviU9/NMsXXnkRi3
YyHEI1Po9rebMH86z49McfC48YKZLohHpvjbrtcq/SueH8bn6b4LcHzL8a9M
Md3ZuU7EJz5fZYrqxXv1LauGEY9MERkT3fauxw3ikSl6L3pZ0bwl7+eZ4sin
vgPntvKg/s9QP5f9naF+X/Zvhnq+7M8M9fdl/2Wo95P9laHeX/ZPuvo+2R/p
//P96ap/5Pemq/6T35eu+ld+T7rqfzmePis+8vzxWfGT4+Wz4iv3s8+KvxwP
n9X4kOeHz2r8SN5panzJ80GaGn+SZ5oan3L/T1PjV/JKU+Nb7u9pavxLHmlq
fkgen9T8kTw+qfkleXxS80/y+KTmp+TxSc1fyeOTmt+SR6qa/5JH6v+sD6lq
/ZA8UtX6InmkqvVH8khV65Pk8VGtX5LHR7W+SR4f1foneXxU66Pk8VGtn5LH
R7W+Sh4pav2VPFLU+ix5pKj1W/JIUeu75JGi1n/JI0XtD5JHito/JI8Pan+R
PD6o/Ufy+KD2J8njg9q/JI8Pan+TPD6o/U/ySFb7o+SR/D/7Z7LaXyWPZLX/
Sh7Jan+WPJLV/i15vFf7u1xf36v9X/J4r84Hcv18r84Pksd7db6QPN6r84fk
kaTOJ5JHkjq/SB5J6nwjeSSp84/kkaTOR3L9SlLnJ8kjSZ2vJI9Edf6SPBLV
+UzySFTnN8kjUZ3vJI9Edf6TPBLV+VDySFDnR8kj4X/Olwnq/Cl5JKjzqeSR
oM6vkkeCOt9KHvHq/Ct5xKvzseQRr87Pkke8Ol9LHvHq/C33q3h1Ppc84tT5
XfKIU+d7ySNOnf/lfhOn7geSR5y6P0gecep+IXnEqfuH7P936n4y1dTf79T9
xd7Uv+/U/UbGB9+q+4+M171V9yMZP3ur7k9y/Xij7ldyvXij7l+NTN//Rt3P
Hpq+97W6v8nve63ud6buaf5a3f/keHql7oc7TePnlbo/yvHySt0v40zd/1Ld
P+V4eKnup71N/F+q+6vk/ULdb4+Y+L5Q91/J84W6HxeaXjBW3Z8lr1h1vx5l
4hOr7t+SR6y6n3ubeDxX93c5/p+r+72NvCCq+78c389UfGC+icczFT+Q4/eZ
ii+gicdTFX+Q4/Opik9IHk9V/ELyiFHxDckjRsU/JI8YFR+RPJ6o+Ink8UTF
VySPJyr+Ink8VvEZyeOxit9IHo9VfEfyeKTiP5LHIxUfkjweqfiR5PFQxZck
j4cq/iR5PFTxKcnjoYpfzTD1/wMV35L9fV/Fv6qY+ve+io/J/ryn4mey/+6q
+Jrsr7sq/rbF1D93VHxO9sdtFb+T339bxfc8TN97S8X/5PfdVPFB+T03VfxQ
jqdoFV+sYho/0Sr+KMdLlIpPyvERqeKXcjxEqvjmFhP/CBX/lLxvqPjo9ya+
N1T8VPIMV/HVTBO/MBV/lbzCVHzWw9SBqOK3FG5X8V009X+oiv/K/jao+HAj
U//qVfxY9mewii/L/gtS8WfZX4EqPi0NCgEqfi3745qKb8vv91fx796m7/VT
8XH5fT4qfi6/x1vF1+X7e6n4e2/T+15W8Xn5fhdU/F6+zzkV35d//7SK/0tD
ykmVH5DPP6HyB1tMzzuq8gvy9w+o/IM0jOxR+Qn5czeVv5CGkVUqv0H5Dw3n
P+jnwPkR+n3g/Ak9Hzi/Qn8fOP9C7wecn6H3B87f0PcB53fo+4HzP9Q/wPkh
6j/g/BH1L3B+ifofOP9EfIDzU3GSH3D+So5nP+D8FvEHzn/R+ADOj9H4Ac6f
0fgCzq/R+APOv9H4BM7PyfVBD5y/o/ENnN+TjwsFzv/R/ADOD8r1DYHzhzS/
gPOLcv0MA84/0vwEzk/K9fkGcP6S5jdwflOu/xHA+U9aH4DzoxFy/QDOn9L6
ApxfdZDrD3D+ldYn4PwsrV/A+dtcub4B53flen8LOP/bU66PwPlhWj+B88du
cn0Fzi/T+gucf5bL813g/DSt38D5a7l/3gfOb9P6D5z/lvvzA+D8OO0fwPlz
eR57CJxfp/0HOP8uz3sPgfPztH8B5+/lefIRcH6f9j/g/L88rz4G1gfQ/gms
H5Dn4cfA+gLaf4H1B/K8/QRYn0D7N7B+gfZ3YH3DOrn/A+sfZPfFAOsj5Hn2
KbB+gs4XwPoKOdyeAusv6HwCrM+Q5/FnwPoNOt8A6zvkef85sP6DzkfA+hB5
nn0OrB+h8xWwvkTyiAXWn9D5DFifInnEAutX6HwHrG+RPF4A61/ofAisj5E8
XgLrZ+h8CayvkTxeAutv6HwKrM+RPF4B63fofAus76HzL7D+R/J4DawPkjxe
A+uHJI83wPoiyeMNsP5I8ngDrE+SPN4C65ckj7fA+ibJw/hz0j9JHu+A9VGS
xztg/RTdL4D1VXT/ANZfyft7HLA+i+4vwPoted+MA9Z30f0HWP9F9yNgfRjd
n4D1Y/K+Gw+sL6P7F7D+TN5H4oH1aXR/A9avyftLPLC+je5/wPo3uh8C6+Ok
/iABWD9H90tgfZ3URyQA6+/ofgqsz5OvlwCs36P7LbC+T+oZEoH1f3Q/BtYH
Sr1FIrB+kO7XwPpCOX0SgfWHdD8H1idKHknA+kW63wPrG+n+D6x/pPgAsD6S
4gfA+kmKLwDrKyn+AKy/pPgEsD5T8ngPrN+k+AawvlPyeA+s/6T4CLA+VN4/
k4H1oxRfAdaXUvwFWH8qeSQD61MpfgOsX5U8koH1rRT/Ada/Sh4fgPWxFD8C
1s9KHh+A9bUUfwLW30oeH4D1uRS/AtbvUnwLWN9L8S9g/S/Fx4D1wRQ/A9YP
U3wNWF9M8Tdg/THF54D1yRS/A9YvU3wPWN9M8T9g/TPFB4H10RQ/BNZPSx6p
wPpqij8C668pPgmsz5Y8UoH12xTfBNZ3Sx6pwPpvio8C68Mlj0/A+nGKrwLr
yyWPT8D6c4rPAuvTJY9PwPp1iu8C69sp/gusf6f4MLA+nuLHwPp5ii8D6+sp
/gysv6f4NLA+n+LXwPp9im8D6/sp/g2s/6f4OLA/gOLnwP4Biq8D+wskj3Rg
/wHF54H9CRS/B/YvSB7pwP4Giv8D+x8kj3RgfwTlD4D9E5JHBrC/gvIPwP4L
ySMD2J9B+Qtg/4bkkQHs76D8B7D/g/IjwP4QyScT2D9C+RVgfwnlX4D9J5Sf
AfanSH6ZwP4Vyu8A+1so/wPsf6H8ELA/RvLNBPbPUH4J2F9D+Sdg/w3lp4D9
OZJ/FrB/h/JbwP4eyn8B+38oPwbsD6L8GbB/SPZvFrC/iPJvwP4jys8B+5Mo
fwfsX6L8HrC/ifJ/wP4nyg8C+6Mofwjsn6L8IrC/ivKPwP4ryk8C+7Mofwns
35Lnm2xgfxflP4H9X5QfBfaHUf4U2D9G+VVgfxnlX4H9Z5SfBfanUf4W2L9G
+V1gfxvlf4H9b5QfBvbHUf4Y2D9H+WVgfx3ln4H9d5SfBvbnUf4a2L9H+W1g
fx/lv4H9f5QfB/YHUv4c2D9I+XVgfyHl34H9h5SfB/YnUv4e2L9I+X1gf6Pk
kQvsfyR9ALA/kvQDwP5J0hcA+ytJfwDsvyR9ArA/k/QLwP5N0jcA+ztJ/wDs
/yR9BLA/lPQTwP5R0lcA+0tJfwHsPyV9BrA/lfQbwP5V0ncA+1tJ/wHsfyV9
CLA/lvQjwP5Z0pcA+2tJfwLsvyV9CrA/l/QrwP5d0rcA+3tJ/wLs/5U88oH9
waSfAfYPk74G2F9M+htg/zHpc4D9yaTfAfYvk74H2N9M+h9g/zPpg4D90aQf
AvZPk74I2F9N+iNg/7XkUQDszyb9ErB/m/RNwP5u0j8B+79JHwXsD5c8jL9P
/nHSVwH7y0l/Bew/J30WsD9d8igE9q+TvgvY3076L2D/O+nDgP3xkkchsH+e
9GXA/nrSnwH770mfBuzPlzwKgf37pG8D9veT/g3Y/0/6OOD6AJJHEXD9ANLX
AdcXIP0dcP0B0ucB1yeQPIqA6xeQvg+4vgHp/4DrH5A+ELg+guRRBFw/QfIo
Aq6vQPpD4PoLpE8Ers9A+kXg+g2kbwSu70D6R+D6D6SPBK4PQfpJ4PoRpK8E
ri9B+kvg+hOkzwSuT0H6TeD6FaTvBK5vQfpP4PoXpA8Fro9B+lHg+hmSRwlw
fQ3SnwLX3yB9KnB9DtKvAtfvkDxKgOt7kP4VuP4H6WOB64OQfha4fojkUQJc
X0TyKAGuP0L6XOD6JKTfBa5fQvpe4PompP8Frn9C+mDg+iikHwaun0L6YuD6
KqQ/Bq6/Qvpk4PospF8Grt9C+mbg+i6kfwau/0L6aOD6MKSfBq4fQ/pq4Poy
kkcZcP0Z0mcD16ch/TZw/RrSdwPXt5E8yoDr35A+HLg+DunHgevnkL4cuL6O
5FEG/7/+ThlwfR7SrwPX7yF9O3B9H9K/A9f/IX08cH0g0s8D1w8ifT1wfSHS
3wPXHyJ9PnB9ItLvA9cvIn0/cH0j0v8D1z8ifwBwfSTyDwDXTyJ/AXB9JfIf
ANdfIn8CcH0m8i8A128if4PKO5D/QbUlj8o2+SdUm/wVqi15VLYlj8q25FHZ
Jn+Hah/ydVh+WbXj4P8AIy+eDw==
          "]], 
         LineBox[CompressedData["
1:eJxFzyEMglAURuE7IxkrzibZjNqwSia5aRWjmslQteqMNLeXMVg0WzWb7b57
g+ff3thXzi79+SpbdESk659+L+fNLQ5kIrbXOHgei+RvkbBJ39sQ98rPzEU4
zqv2O8BDGx5ZEE99rUlx5iJfxJbL8dKG14kG8c4OxHZeiWvNVfiw1+FToUFs
v9tgO8/hq+Za/Ljr8A8fIUUm
          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 180], 0.005555555555555556]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxdnHdYlFfTxpeysMACGns3aqJRk2gSNdZRY4maWGOvsUSDvcWeaOy9K5YY
uxGV3mE5Q0dsCCooggIqCiq9g3zrnpnD9b38k+tchMfnOb9TZ+57Pp25ePQc
c41GE2mp0Xz872+mn1qooZ/0tXVdB/9a056yP6yo3ZSaduKFJb1tx9e0R/s3
35o9qqZ957bx56ea9o9pHx9Y0/74tP39a9p9bD8+saZtetz3Ne3vvv34U9N2
HWx84Fc17S9ML1jTvmh8vcTWNe0Wxsf5N69pnzxh/GlU065remBN+8DHF3Ss
aZtez7amve3j47Q1bflT0y5u9/GFHFX77aiPX1TTNnVHWk3b9PjEmrap/27X
tMM/9ldYTTvgY//417RNr+9a0zZ9/4Watul7T9S0Td+3v6Zt6p6tNe11pg5x
RK+bfv0uTOvaZ+nHxy1xxNh9+wrCB67oM9c0XhyxbcOBhQN/Duwjx4cjTji1
tnP/EcV95HhwRNhasmSGvgNI/o64tcvqNpOzxoPk7YiPBv/0PP7VBjDh/dYR
f80csmV2xQmQPI2/X1TvzOjEGyD5OWL1gMBPFlr5QD3TBzvi4deeszxvu4Pk
44gn/3348onbfyC/whGztzbYvj/FByQPB9zzuNMWp90BIHk44ISd2h3Fd9xB
8nDAPn6Dfy087AeShwMWtNfs0DYNAsnDASMdKhxe3vcCycMBNfnTejg9CQTJ
wwEz2r9rluERAJKHA+6PGI3tknxB8nDA1F0/xLbqGQyShwMeGrwr81hPf5A8
HPB45fYRuxsEguThgNuKti3yWBQEkocDXqr6xfa8uz9IHg642XVBI7+fg0Hy
cECPBo5Hb2oCQfIwft/SeN0kuyCQPBywIqt82cbBwcTDAXfHnhwYnRNAPBzQ
Yc/STccnGIiHA7Z92rbVJ38HEg8H7Lpk/WHXU8HEwwEbXgvoe3VWMPFwwFVf
p+s3tQkiHg64cUGTTzfWCyEeDhg7cvvXRRsCiYc9PthmX1RvVgjxsMcnDUdd
mzg+iHjY49aJM1d59jIQD3ss/qln7eTPDMTD+PfdtmlsXIOIhz32DRq38Ifr
IcTDHsduylzsXBhIPOzxwgzNsl6VIcTDHi8/OTlh6Z4g4mGPnTY2cVnbMIR4
2GObz9blTnYwEA97LD/X+ZeIyGDiYY9TOs1s/3BbCPEwPn/1t3kT3gYRD3t0
7RIZ2qy3IB72GO38ckvnUuZhj306uH76qpYgHvYYFn7/RnJoMPGwxyh97Wa7
JoYQD3v89JB/7Q1JBuJhjzkFXcLO7zMQD3ssbV7esX50CPGwx1be/su6f2Ig
HvZo+abb0AtDBfGwx1cHm6X3sTAQDz0eiwvUu00VxEOPx3fW110ZbyAeemy5
6+Gnq5sJ4qHHVM2R9W6vmIceu5uN3ZjvHUI89Dhqdo8mC3cwDz3+5j98RIcf
Q4iHHp8GLjrbv6kgHnosebuo7u+lBuKhx7n6JzF1dwriYfz/92bqlyUwDz3m
OK17VxkjiIceX0/NqL733EA89DjVbddA7wRBPPR4oXs37/VtQoiHHpvkJxyd
5SGIhx7N59i5ZB4IIR56PBPWt9b4JYJ46PFZgv7NtCaCeOjRZtej+h7NBfHQ
o9fek4vdXAXx0GP8NQ/nT+8zDz120pqfcmqGxEOPm5Pq9p9+mOeHHkfsTA3x
H4fEww7jwq/mzF7M88MO024fCVuzEcG0P6fZ4SOnfoFPnUKIhx0+1HattfIE
Eg87tJ9xsU/QFuZhh7OO62DzOQTT5/rboWvOE/uh/szDDhcFD6n8cAqJhx3e
jB+zN0MriIcdZouhc3/ci8TDDtt3zug1c4YgHnboGVR//Y3VSDzscGRuwqSg
MEE87PDFG6uc7DlIPOzw/ZpHFnNrI/Gww6ntAme+mYDEww6tuuc869obiYcd
1stv1azhaCQednin8Gaf0bOReNhhdf4YL78xSDzs0Lja/DFrKxIPO9Sd6Pxl
8iQkHnaoCX/nnXqWedjhg//sxx2ai8TDDk/EdZraz4952GLt20nb66xF4mGL
fvdr/d04lnnY4usmugm79yHxsEWLgpsWLo+Zhy1WBh5ZMfciEg9bTGg0afPM
TOZhizaatjdTgpF42OLV71rEReQxD1v86Uj7m4cTkXjY4mWz2fVHlTMPW3zw
pmDLm3wkHrbYoq3378PMQ4mHLQ6KeDY8zTGUeNhiwCSrvybqQomHLS66rFn8
z9ehxMMWP7fffOJ7fSjxsMW32i5NgseEEg9b/O6zfZOaO4QSD1tc2Kjbvh3r
QomHLdrqbAP61w4lHrY45LCornMxlHjY4rBfPmTVqhdKPGxx2uHN6f3uhBIP
W3SGw86PmoYSD1v0HOwedKowlHjYoFO3d4FNvwwlHjbYrdmnQXa1w4iHDS5p
fH78j8NCiYcNnmjyYqFz8zDiYYOXA7e8yVkfSjxsMObugE0PGoQRDxtcNaR6
Q8PwUOJhg9177phxqyKUeNhg0/OHRrZqEkY8bPD77rMG+SWEEg8bvP4mzfH5
ijDiYYPNG+uaWfgyDxvcGdesoLl/GPGwwTsvv9WMCAgFeR63wQNh8+7euBdG
PGzQo37jppVvmYcNukBa+2/8woiHDQ79bHTvPSPDiIcNrs5uujx0bRjxML5/
72WjrSLDiIcN/nZyanmzAWHEwwbbju/XeWbLcOJhgysXBHy9E8KIhw22/r3v
ruRe4cTDBkXyTcsWm8OIhw7T7X0b2TYIJx46nHPn/CxRxTx02NrZw/FKYhjx
0KGZ/29/uywJJx46PGoYmeVjfD/JQ4cF/04OvfhPOPHQ4edxS4Z3sw0nHjpM
G7mtR+XacOKhw8etk1IW7gwnHjockNchMGlAOPHQ4aYetzoteB9OPHTYtmhE
417jw4mHDm8cNDxpVBROPHRY99Mj52fFhBMPHc5sHFvvWWA48dChx7qsf3b9
EEE8dGhYkLd6lfH3kocOneeOutd6QgTx0KHbveqoT7+MIB46XPQ6uf7MJhHE
Q4cHMgef9LweQTx0mHfxTdHwthHEQ4cfHuce+uVaBPHQYbyDc7t6vhHEQ4dd
Gn3itn5+BPGwxu1tvm1av2kk8bDGVVOnNZruE0E8rFEbO2r96+cRxMMaA/6O
8Hk1JZJ4WKOTfmQj6wcRxMMa4/7Qv1s2PZJ4WONev/nDrmyMJB7WOHxwzPse
DSKJhzUaT08t/WIjiYc19lh+f/iQy5HEw/h+RwOXwvxI4mGNK5fsrSNaRxEP
a+z3TSL6JkUSD2t03u9o5RESSTys8evXscfyFkcRD2scMqJ8jnejKOJhjbVm
v19m4RBFPKwxae4/q955RxEPa/y2a8LMzb9HEQ9r7B36uHGTsVHEwxonHXtb
6VcYRTys8cZ91wMXoqKIhzVabT3++7pTUcTDGq8sy54f2CGaeFijW/DRizHG
tuRhhV20XnUeZUYRDyvcXz+gRcgv0cTDCtcF5Z022xNNPKxwW8fkjLQfoomH
FZ74S/wRsDyaeFhh985Bf85PiCYeVvh07YasCS7RxMMKL3kdWzbhcDTxsMI+
8ROHTcyJJh7G31/PaN3DMoZ4WOE0u5Btb8KiiYcVLr3xhcOi9GjiYYXBO9/9
ktg+hnhY4YTQ4X+sqIwmHlZoA62tTsZEEw8r/P2bN11QH0M8rHD95M/OOraM
IR5WGHvFN/tOcDTxsEIz4wEgzC+aeBjb5f3aL9bGEA9j//z5bNTGoGjiYYUN
Vnd32zcxmnhYofeSM4dHnIsmHsb/f+65YfdPMg8rHODVpvimlnlocf6lo5ea
1YomHloca3t+wJlvmYcWr5y8en7wmSjiocXaBecGFsyLIh5aLGlo9vXbXVHE
Q4vnzP+rn1DJ80OLx0YmnV3ny/NDi4Pcdve4E8bzQ4urZ848U/EVzw8tWjyf
njbSkueHFjfNmReflhlBPLR4sOrWiBujI4iHFl3yhrsdGhdBPLR4bemCH569
4fVKi46LNnZ0OcbrlRb9Hr6Ys2RrOPHQYqjThsR9Wbx/aLHu7NnhYzXhxEOL
3xt+CZk4g/cPLT6z2rt2zXTeP7S40Om/FSNf8X6uxWWT7na5FsD7uRaN140M
3yW8n2vx3oXDG2c15v1ci333vMwsKeTzlSVeu/Pvlro7+XxliRNjP382aAmf
ryxxS9GwQUl6Pl9ZSp6+gnhY4ojMirx5EwXxsMSZdt8l9pwRQjwsMXDkisj4
R3zetcRPoh07dMoJJh6WuD3gYsSxSSHEwxKPrvqta//wIOJhib2cFnd9M4Pv
H5Z4q8vKge5OfD+3xODeA2+N3hVEPCxx4AGnARPvBREPS/zpUN/EhicDiIcl
5tkErtqwg++DlqiN2uCc3zWAeFji3byshDcr+X5uiQerffq1axZIPCxx22i3
dkf+9SMeltj490ahVX0DiIcljvOeazZmvD/I+JYlJu9M0mTc8SUelnhy+ouv
PXb5Ew9LXPs0dEpili/xsMCDewaU/9Dal3hY4KAOJ8Ni//EjHhY4fF3vspnv
fIiHBQ47WKvrN5N8iIcF3hs8A1xv+BIPCxxaJ+XwjO99iIcFVre5eGH3X97E
wwKDtiWErgzxIR4WaPhr8qlOUd7EwwIn2rRumnHVC0zdt98CvWLCYo76ehMP
CywxC283dY038bDAaw9GJxxy9CIeFrh7vS528AEvOu8an/eV+evBjbyJhwU+
s+97syTJk3hYYOPOcfF//eFJPCxwsVtSYs4kLzA9rrfx+y5tWNY8y5N4WOCe
TfoRbe57EA8L3LDX3b+ymyfxsMCmA1Y2y4/wpPlhgeenJY//8YkH8TA+76vv
Bw/o7kE8LLBgX/KBbe88iIc5dvglqX7HRp7Ew9j2ygq7WsuD7ufmeGtLZffe
t9yJhzl6Tnsf2v6oB/Ewx9X41/35WzyIhzlO+A4NSevd6X5ujpsn1+733Tx3
4mGO20YFug3q50E8zDH/8Zg1EY09iIc5lnnPGG6pcyce5vhbg18r2lm6Ew9z
/GzhiGOxlh7Ewxyn1vlt+MrX7sTDHK9VNDn4yXA34mGOVi/P7NvWyY14mOOB
9D9757x3Jx7mmPBZ7fGGanfiYY4Nt+T+/fu/rsTDHK90C/+k7heuxMMc/2s/
+v1FPfMwx+5WzVNWjvUgHsbnD2t9oWDcDeJhjq1Oby04/dqFeJjjjWcjxp3Y
5EY8zHFYXoPJhnXMwwz74aT8Z03ciYcZDvtt+ZFeI28QDzP84N47Y+LnbsTD
DE9W6Np2euBOPMzw7N1v9Nmd3YmHGeaMbfs4poUr8TDDS912ZAU+ciUeZpgx
5uydDcvciYcZVrx7nPJ6sDvxMMMJ0fqfIr1ciYcZDshv+e3lcFfiYYZmB/+J
aG/8/yUPM3zwaOfMJU7Mwww/35ww7GUP5mGG2T/fdR4V70o8jN/7IGDvoF7M
www3P+ySWOzMPMxwTFXgvdORbsTDDO83sfk5wsKNeJhh8YmkOj8PcSceZjhl
cvWtoU/ciYcZzk8uPLexkzvxMMNT/V+Puf+jG/EwwzO29XwHLnAnHmY4MqOt
Q8GXzEOD0Qn2qQ02Mw8Nni2P+Nz1ohvx0Jjin+jK80OD03s4fedwmueHBj8Z
c9XpwwPmocEFM5IP5Vrx/NCg35blf7Uzjn/JQ4NdbNcv6d7Mk3hosG5Pjzo9
a/P80GD5l7cOx//M80ODhwxPTlwQHsRDg4Ny1ueO+9eTeGgwf4uD22Xj90ge
GqzX4dctGTHuxEODMeNsU95e9iQeGsydanvTPpvXKw36xMfGO3zjQTw0+OfS
q2NdXD2IhwZHRy5NSz3qRTw0qMnyXdbnjifx0ODS01dTclbz/NDgJjiy103n
RTw0uPNeu7Ue9t7EQ4O6zn/33bLSk3hoMOWA2dmCDbw+VYuK+OiCWcO9IcnU
39Xiyegtu/MjOH5eLTrVdX6818uT+rNadLk77Yy2Lq/31SIAb63pctUbTPmW
rdWiVt1lWps/eD2vFgPM/JbaVHtRf1SL092H1Ulq6kPfXy1GTTk0pt9Yb5D5
o2pxp/+UwNp9ven7qkV9+yVfF//qQ99j/H3THSun1+J8wQex9WWFb98Ab9rv
PojPWhgaD3Pl/e2DaJz+Y2r+Vd7PPojp3VcGbRzE+9cHke92bWRTR186P3wQ
X5rfeLa/gy/x/iAubW38W+ADHzoffBD9XGrPaf63L/E0/n106r3V531p//8g
dh/pOWT2FF/i9UEYwOnloGpf2t8/iK6JXa2d7f2IxwdR62ZIYV4K799V4mP8
pnIj5zeqRNCis/0nLvEjHlXCIyXZ232aH/GoEj+GTDl3tdqPeFSJRxlLEg9G
+RGPKjF534Au11/5EY8qEbqmTv34pf7Eo0p8+smpDXF1/YlHldh+aeAXSzb4
E48qEWd+uWO/2/7Ew/j8KWcLo+b5Ew/j833sCzo0DSAelaLB/lU+hip/4lEp
jMvdwIx0f+JRKdYPXzNm8H8BxKNSpLq1OhZdJ4B4VIpekx+XbHUOIB6V4v2F
Pzu6ZQcQj0ph0WRHj1XDA4hHpXD+c//DQ3MDiUeleJexOL3hbT6PGZ93df7y
gTacHzH+/z4ZQzffCSQeleKn28v9PEICiEelCLnWLvWnz4KIR4V4F3Kgvvfi
QOJRIQLCXV6k7AskHhVi8u45sT+cCCIeFeLzstYfln4RSDwqhCFwc2H90iDi
USFW3N7a8dTTQOJRIboEvyksGxpEPCrEPG3btb5tOP9TIX5u0DYm5nwg8agQ
NqeHYfBNzu9UiC+3H46rrgwkHhWiz+8+L78bGUw8ykXobGGW+mUw8SgXV7aO
3TdmIefLysXeHO/uW7sYiEe52P3fyRe7Pg8iHuWiY3BYh8qhBuJRLpwvLDpX
Esfn6XJh/dW8G2HOwcSjXIw1HliqngcTj3KxdnmzkkOpQcSjXLiMWJDe6jDn
R8rFMu3O+T8HBxGPcnF6yKPYmO0G4lEuCleEtLg3MJh4lAkfMcN9ZWEw8SgT
H+MNBx0MxKNM/HbgQMMzs4OJR5k49lUSTD/C+Yoy4ZJ94HFaz2DiUSYSRzUK
yz/B+YgyMWvW4e+SdwYTjzKxBWxT08BAPMpEg9FznCqN/57kUSYe7n85dV4S
8ygTsdX1htiv43xOmXDc5nXN6irzKBWbTqQ8vfqPgXiUit19zKzKwoKJR6lo
M901znsV8ygVO8wXZYyuayAepWLcqE1Ln33PPEqFed+Oqf0XGIhHqfACXeHX
WgPxKBVf7E0e2/yigXiUivzIwpSpVZy/KhVPUpvd6uvOPEpFbt+EiCOfGYhH
qbDetzj+zn7mUSpadfjwz5j5BuJRIhqM6z7ccybn/0qE+TK/4sUeBjC9XliJ
mHx7WFl5XwPxKBF72vmvLnnKPEqEm/UQn2pj/0oeJcImvO6fvV4xjxLx1G9/
l0mzDMSjRJSnN9hcEcs8SkRm7zsH3l9kHiUiyqWF1exjBjB1X/MSEX3iSdWf
ecyjRBzUrmjQfRbn04qFw5XN80+3DSEexeL+ke+dyn42gAnH7WLhs0Pfc2s3
vp8Wi9b29kM+n8s8isWIM98kLHDkfGSxWHOtg6HE0wDrTR1YLPwiJ7q28Gce
xaJdnfXHwxqHEI9i4VHQpn/+aAPxKBbDclulu60JgfamDy4WGQFzYiY6Mg/j
3xsvOMedOR9VLJx3Dbq6txHzKBI34gIadJ0SQvt5kWh/an2T7/5iHkXiRR23
BkfuMI8i8U/AvCsRLfg+XSQCrlzYNKwF8ygSyWVOKWc8Q8D0uUuKBL44t7Cz
C8+PIlGr/pSSWZmcjysSHQvqn7vuHkw8ioTV48zAWwdDiEeR+GblvX9FV+ZR
JBbPGJWR/oB5FAofHPvFDxrmUSjWejncqLRgHoViYhPnyEVXmUehqOPvXffy
No4PFIrgiHquUx8xj0KR1LnPOqfjwcSjUMxt3fDerBUhxMPYPnrkn/JWPD8K
xey1+lnhQcyjUMx/Py1iYpKBeBSKVqsut11twzwKxaGBZ4sqxjOPQpHScnH4
KnderwqEz7LwGz84MY8C4dreYq57TDDxKBDlP6ZsOF6H4x0FIuCly8CT3/L8
KBBrH1lst9rBPArEV3v33P3d1UA8jO1ND8tdHXl+FAh4uDw1sJTnR4HY0Dbb
0PIx8ygQ3ZPOxTUo5flRIPq4nKq7IC+YeBSIXLPE7atdmUe+mJSxs3oI8HqV
L8Thomm5an7ki5E2laMv7eH1Kl+cvhad5lrNPPKFxtpreKoPr1f5Qn/zx4vV
6cwjXyRuOTHm3SWeH/ni/sjlcY81zCNfJHS413H4XOaRL4IGlDZaCswjX3S0
G9pySEPmkS/iXYJbHNnI61W+OJnfKWRqKvPIExXTfv32m+MG4pEn/Hq6zLj+
mHnkicc/b7Q6tobnR564/S45+omOeeSJPZ5zo1w6Mw/j712f7eozhnnkCR2W
Z/VI4/mRJ1Ytv3L57HHmkScuGtp1/FfNjzyh37TiQ61LzCNPjLxVuK9+OPPI
E3+Et67b04l55IpRy5Kfh7VhHrliQ+cNqzLfBxOPXBHf+m0vm+vMI1eYb6t/
6NhC5pEr2iQHTxjdjOdHrrj0a6c6GV8yj1xh9le7JtPb8fzIFcNtfS802sX7
ea4IGZlVb+s65pErnJ9e1/1QxTxyRftxYbro07yf54q84KYrdw8KIx654qJ1
Zvh/rjeo/3PU72V/56i/l/2bo54v+zNH/fuy/3LU+8n+ylHvL/vnvfo+2R/v
/+f736v+kd/7XvWf/L73qn/l97xX/S/H0zvFR54/3il+cry8U3zlfvZO8Zfj
4Z0aH/L88E6NH8n7rRpf8nzwVo0/yfOtGp9y/3+rxq/k9VaNb7m/v1XjX/J4
q+aH5JGt5o/kka3ml+SRreaf5JGt5qfkka3mr+SRrea35JGl5r/kkfU/60OW
Wj8kjyy1vkgeWWr9kTyy1PokebxR65fk8Uatb5LHG7X+SR5v1PooebxR66fk
8Uatr5LHa7X+Sh6v1fosebxW67fk8Vqt75LHa7X+Sx6v1f4gebxW+4fkkan2
F8kjU+0/kkem2p8kj0y1f0kemWp/kzwy1f4nebxS+6Pk8ep/9s9Xan+VPF6p
/VfyeKX2Z8njldq/JY+Xan+X6+tLtf9LHi/V+UCuny/V+UHyeKnOF5LHS3X+
kDxeqPOJ5PFCnV8kjxfqfCN5vFDnH8njhTofyfXrhTo/SR4v1PlK8shQ5y/J
I0OdzySPDHV+kzwy1PlO8shQ5z/JI0OdDyWPdHV+lDzS/+d8ma7On5JHujqf
Sh7p6vwqeaSr863kkabOv5JHmjofSx5p6vwseaSp87XkkabO33K/SlPnc8nj
uTq/Sx7P1fle8niuzv9yv3mu7geSx3N1f5A8nqv7heTxXN0/ZP8/U/eTqab+
fqbuL3am/n2m7jcyPpiq7j8yXpeq7kcyfpaq7k9y/UhR9yu5XqSo+1dL0/en
qPtZnOl7n6r7m/y+p+p+Z+qedk/V/U+Op2R1P9xhGj/J6v4ox0uyul8+N3X/
E3X/lOPhibqf9jXxf6Lur5L3Y3W/dTbxfazuv5LnY3U/LjW9YJK6P0teSep+
PdLEJ0ndvyWPJHU/dzfxSFT3dzn+E9X9XicviOr+L8f3IxUfmGfi8UjFD+T4
faTiC2ji8VDFH+T4fKjiE5LHQxW/kDweqPiG5PFAxT8kjwcqPiJ5JKj4ieSR
oOIrkkeCir9IHvEqPiN5xKv4jeQRr+I7ksd9Ff+RPO6r+JDkcV/FjySPOBVf
kjziVPxJ8ohT8SnJI07Fr2aY+v+eim/J/r6r4l+1TP17V8XHZH/eUfEz2X+3
VXxN9tdtFX/baOqfWyo+J/sjVsXv5PfHqvjeWdP33lTxP/l9MSo+KL8nRsUP
5XiKVvHFWqbxE63ij3K8RKn4pBwfkSp+KcdDpIpvbjTxj1DxT8k7XMVHO5n4
hqv4qeQZpuKruSZ+oSr+KnmFqvjsWVMHoorfUrhdxXfR1P8hKv4r+9ug4sMt
Tf0brOLHsj8DVXxZ9l+Aij/L/vJX8WlpUPBT8WvZHz4qvi2/31vFv/uavtdL
xcfl93mo+Ln8HncVX5fv76ri731N73tdxefl+11V8Xv5PldUfF/++xdV/F8a
Us6p/IB8/hmVP9hoet4JlV+Qf39E5R+kYWSfyk/I329R+QtpGFmh8huU/9Bw
/oN+D5wfob8Hzp/Q84HzK/TvA+df6P2A8zP0/sD5G/o+4PwOfT9w/of6Bzg/
RP0HnD+i/gXOL1H/A+efiA9wfuq55Aecv5Lj2Qs4v0X8gfNfND6A82M0foDz
ZzS+gPNrNP6A8280PoHzc3J9CAbO39H4Bs7vyceFAOf/aH4A5wfl+obA+UOa
X8D5Rbl+hgLnH2l+Aucn5focDpy/pPkNnN+U638EcP6T1gfg/GiEXD+A86e0
vgDnV/Vy/QHOv9L6BJyfpfULOH9bKNc34PyuXO9vAud/e8n1ETg/TOsncP54
i1xfgfPLtP4C55/l8nwbOD9N6zdw/lrun3eB89u0/gPnv+X+fA84P077B3D+
XJ7H4oDz67T/AOff5XkvDjg/T/sXcP5enifvA+f3af8Dzv/L82o8sD6A9k9g
/YA8D8cD6wto/wXWH8jzdgKwPoH2b2D9Au3vwPqGtXL/B9Y/yO57AKyPkOfZ
h8D6CTpfAOsr5HB7CKy/oPMJsD5DnscfAes36HwDrO+Q5/1EYP0HnY+A9SHy
PGtsk36EzlfA+hLJIwlYf0LnM2B9iuSRBKxfofMdsL5F8ngMrH+h8yGwPkby
eAKsn6HzJbC+RvJ4Aqy/ofMpsD5H8kgG1u/Q+RZY30PnX2D9j+TxFFgfJHk8
BdYPSR4pwPoiySMFWH8keaQA65Mkj1Rg/ZLkkQqsb5I8UoH1T5LHM2B9lOTx
DFg/RfcLYH0V3T+A9Vfy/v4cWJ9F9xdg/Za8bz4H1nfR/QdY/0X3I2B9GN2f
gPVj8r6bBqwvo/sXsP5M3kfSgPVpdH8D1q/J+0sasL6N7n/A+je6HwLr46T+
IB1YP0f3S2B9ndRHpAPr7+h+CqzPk6+XDqzfo/stsL5P6hkygPV/dD8G1gdK
vUUGsH6Q7tfA+kI5fTKA9Yd0PwfWJ0oeL4D1i3S/B9Y30v0fWP9I8QFgfSTF
D4D1kxRfANZXUvwBWH9J8Qlgfabk8RJYv0nxDWB9p+TxElj/SfERYH2ovH++
AtaPUnwFWF9K8Rdg/ank8QpYn0rxG2D9quTxCljfSvEfYP2r5JEJrI+l+BGw
flbyyATW11L8CVh/K3lkAutzKX4FrN+l+BawvpfiX8D6X4qPAeuDKX4GrB+m
+Bqwvpjib8D6Y4rPAeuTKX4HrF+m+B6wvpnif8D6Z4oPAuujKX4IrJ+WPLKA
9dUUfwTWX1N8ElifLXlkAeu3Kb4JrO+WPLKA9d8UHwXWh0se2cD6cYqvAuvL
JY9sYP05xWeB9emSRzawfp3iu8D6dor/AuvfKT4MrI+n+DGwfp7iy8D6eoo/
A+vvKT4NrM+n+DWwfp/i28D6fop/A+v/KT4O7A+g+Dmwf4Di68D+AsnjPbD/
gOLzwP4Eit8D+xckj/fA/gaK/wP7HySP98D+CMofAPsnJI8cYH8F5R+A/ReS
Rw6wP4PyF8D+DckjB9jfQfkPYP8H5UeA/SGSTy6wf4TyK8D+Esq/APtPKD8D
7E+R/HKB/SuU3wH2t1D+B9j/QvkhYH+M5JsL7J+h/BKwv4byT8D+G8pPAftz
JP88YP8O5beA/T2U/wL2/1B+DNgfRPkzYP+Q7N88YH8R5d+A/UeUnwP2J1H+
Dti/RPk9YH8T5f+A/U+UHwT2R1H+ENg/RflFYH8V5R+B/VeUnwT2Z1H+Eti/
Jc83+cD+Lsp/Avu/KD8K7A+j/Cmwf4zyq8D+Msq/AvvPKD8L7E+j/C2wf43y
u8D+Nsr/AvvfKD8M7I+j/DGwf47yy8D+Oso/A/vvKD8N7M+j/DWwf4/y28D+
Psp/A/v/KD8O7A+k/Dmwf5Dy68D+Qsq/A/sPKT8P7E+k/D2wf5Hy+8D+Rsmj
ENj/SPoAYH8k6QeA/ZOkLwD2V5L+ANh/SfoEYH8m6ReA/ZukbwD2d5L+Adj/
SfoIYH8o6SeA/aOkrwD2l5L+Ath/SvoMYH8q6TeA/auk7wD2t5L+A9j/SvoQ
YH8s6UeA/bOkLwH215L+BNh/S/oUYH8u6VeA/bukbwH295L+Bdj/K3kUA/uD
ST8D7B8mfQ2wv5j0N8D+Y9LnAPuTSb8D7F8mfQ+wv5n0P8D+Z9IHAfujST8E
7J8mfRGwv5r0R8D+a8mjBNifTfolYP826ZuA/d2kfwL2f5M+CtgfLnmUAPvH
SV8F7C8n/RWw/5z0WcD+dMmjFNi/TvouYH876b+A/e+kDwP2x0sepcD+edKX
AfvrSX8G7L8nfRqwP1/yKAX275O+DdjfT/o3YP8/6eOA6wNIHmXA9QNIXwdc
X4D0d8D1B0ifB1yfQPIoA65fQPo+4PoGpP8Drn9A+kDg+giSRxlw/QTJowy4
vgLpD4HrL5A+Ebg+A+kXges3kL4RuL4D6R+B6z+QPhK4PgTpJ4HrR5C+Eri+
BOkvgetPkD4TuD4F6TeB61eQvhO4vgXpP4HrX5A+FLg+BulHgetnSB4VwPU1
SH8KXH+D9KnA9TlIvwoXqH6H5FEBXN+D9K/A9T9IHwtcH4T0s8D1QySPCuD6
IpJHBXD9EdLnAtcnIf0ucP0S0vcC1zch/S9w/RPSBwPXRyH9MHD9FNIXA9dX
If0xcP0V0icD12ch/TJw/RbSNwPXdyH9M3D9F9JHA9eHIf00cP0Y0lcD15eR
PKqA68+QPhu4Pg3pt4Hr15C+G7i+jeRRBVz/hvThwPVxSD8OXD+H9OXA9XUk
jyr4//V3qoDr85B+Hbh+D+nbgev7kP4duP4P6eOB6wORfh64fhDp64HrC5H+
Hrj+EOnzgesTkX4fuH4R6fuB6xuR/h+4/hH5A4DrI5F/ALh+EvkLgOsrkf9A
5RHIn6Da5F9QbfI3qDb5H1Rb8qhpk39CtclfodqSR01b8qhpSx41bfJ3qPYx
T/3S66r9HP4PAO22Kg==
          "]], 
         LineBox[CompressedData["
1:eJxFzyEMglAURuE7IxkrzibZjNqwSia5aRWjmslQteqMNLeXMVg0WzWb7b57
g+ff3thXzi79+SpbdESk659+L+fNLQ5kIrbXOHgei+RvkbBJ39sQ98rPzEU4
zqv2O8BDGx5ZEE99rUlx5iJfxJbL8dKG14kG8c4OxHZeiWvNVfiw1+FToUFs
v9tgO8/hq+Za/Ljr8A8fIUUm
          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(8\\)]\\)\"", 
       TraditionalForm], PlotRange -> {{-4.1, 2.1}, {-0.01, 0.5}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 
        Scaled[0.02]}, {0, 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T5.1\"", "\"T17.2\"", "\"T33.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091264714520893`*^9, 3.9101545008181863`*^9, 3.910155616253199*^9, {
   3.9101562517976747`*^9, 3.9101562871700735`*^9}, 3.910162253949086*^9, {
   3.910168716292123*^9, 3.9101687292935357`*^9}, {3.9101687617626452`*^9, 
   3.9101687658955555`*^9}},
 CellLabel->"Out[24]=",ExpressionUUID->"ed351f82-ae45-4a0c-a0c3-0e82371407f4"]
}, Open  ]],

Cell["\<\
We observe convergence of the density of states with increasing size of the \
supercell.\
\>", "Text",
 CellChangeTimes->{{3.909125877711278*^9, 3.909126045253215*^9}, {
  3.9101545181845226`*^9, 
  3.9101545262977867`*^9}},ExpressionUUID->"d506a133-49ba-43d8-863f-\
f420b1ad99c7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Haldane model on the {8,3} lattice", "Section",
 CellChangeTimes->{{3.9091097560137053`*^9, 3.9091097636740923`*^9}, {
  3.909109820746976*^9, 3.909109821007987*^9}, {3.9101530821292405`*^9, 
  3.9101530911518974`*^9}, {3.910161201243699*^9, 3.9101612014819603`*^9}, {
  3.910165347636364*^9, 3.9101653621092367`*^9}, {3.9101654348830037`*^9, 
  3.910165443877036*^9}, {3.910171891441964*^9, 
  3.9101718958277707`*^9}},ExpressionUUID->"e56a93af-a87f-4a35-968a-\
8467cfa0ee48"],

Cell[CellGroupData[{

Cell["Import cells", "Subsection",
 CellChangeTimes->{{3.909109766864945*^9, 3.909109771535059*^9}, {
  3.909109823230064*^9, 
  3.9091098236720653`*^9}},ExpressionUUID->"ae46e953-10ad-4797-b4e0-\
8260e3aee7ea"],

Cell["\<\
We first import the cell, model, and supercell model graphs as produced by \
the HyperCells package (see \
https://github.com/patrick-lenggenhager/HyperCells for the package \
repository):\
\>", "Text",
 CellChangeTimes->{{3.90910977524686*^9, 3.9091097920317583`*^9}, {
  3.9091099483552275`*^9, 
  3.909109968542066*^9}},ExpressionUUID->"38803b53-6ccd-4824-bdcf-\
cc8ba9caacf0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcell", "=", 
   RowBox[{"ImportCellGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<(2,3,8)_T2.1_3.hcc\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9090560618564167`*^9, 3.9090560733680687`*^9}, {
  3.9090561514000225`*^9, 3.9090561514836597`*^9}, {3.9091128212745233`*^9, 
  3.909112832496519*^9}, {3.910161215877681*^9, 3.910161217541376*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"5d693b09-52f9-407c-a71d-859fbdd17a3e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcmodel", "=", 
   RowBox[{"ImportModelGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<{8,3}-tess-NNN_T2.1_3.hcm\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.909055936914714*^9, 3.909055963188888*^9}, {
  3.9090560238348665`*^9, 3.909056040271286*^9}, {3.909112837065897*^9, 
  3.909112838796729*^9}, {3.9091137679617558`*^9, 3.909113768077687*^9}, {
  3.9101612202907867`*^9, 3.9101612228731327`*^9}, {3.910165372517359*^9, 
  3.9101653740399685`*^9}, {3.9101719178394775`*^9, 3.9101719362323914`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"773c3d7a-414b-4199-bc38-515ca22083bf"],

Cell["\<\
We consider the following sequence of supercells, defined in terms of \
quotients given in \
https://www.math.auckland.ac.nz/~conder/TriangleGroupQuotients101.txt by M. \
Conder:\
\>", "Text",
 CellChangeTimes->{{3.9091138575774813`*^9, 
  3.909113909312521*^9}},ExpressionUUID->"7ee17594-1123-4dbf-a2e6-\
d64e55f9ad83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<T5.1\>\"", ",", "\"\<T17.2\>\"", ",", "\"\<T33.1\>\""}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
  3.910161235495674*^9, 3.9101612492366943`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"59d0bdaa-2ac5-4f47-ac9a-fccf670d2aa1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{8,3}-tess-NNN_T2.1_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
   3.9091142248348513`*^9, 3.909114238346472*^9}, {3.910161254190941*^9, 
   3.9101612556785207`*^9}, {3.9101654104848375`*^9, 3.910165411576088*^9}, 
   3.9101719465139456`*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"f97ddff2-7a7e-4567-b86b-63311369f1ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the primitive cell T2.1", "Subsection",
 CellChangeTimes->{{3.9091098104889455`*^9, 3.90910982999617*^9}, 
   3.9101612604916887`*^9},ExpressionUUID->"00eb273d-872b-49a7-be78-\
e075a282286c"],

Cell["\<\
We define the model on the primitive cell given by the quotient group T2.1. \
The primitive cell (Wigner-Seitz unit cell) forms an octagon with a single \
site at its center and nearest neighbors in adjacent copies of the cell:\
\>", "Text",
 CellChangeTimes->{{3.909109834065158*^9, 3.909109920885654*^9}, {
   3.909109996816284*^9, 3.9091100631664762`*^9}, {3.9091138866924057`*^9, 
   3.909113887462228*^9}, 
   3.910161267524358*^9},ExpressionUUID->"bd1b0af4-f1f2-45a3-9551-\
5f8d9ffb5691"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VisualizeModelGraph", "[", 
  RowBox[{"pcmodel", ",", "\[IndentingNewLine]", 
   RowBox[{"Elements", "\[Rule]", 
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ShowCellGraphFlattened", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ShowCellBoundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ShowEdgeIdentification", "\[Rule]", "True"}], "}"}]}]}], 
     "\[IndentingNewLine]", "|>"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"CellGraph", "\[Rule]", "pcell"}], ",", "\[IndentingNewLine]", 
   RowBox[{"NumberOfGenerations", "\[Rule]", "4"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9090560452383413`*^9, 3.9090560491912336`*^9}, {
  3.909056084328685*^9, 3.9090561117988863`*^9}, {3.9101612828124905`*^9, 
  3.9101612870015707`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"2ee61717-181c-42d9-821c-82fd98155de3"],

Cell[BoxData[
 GraphicsBox[{{InsetBox[
     FormBox[
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJzs3cty68q25vcTthtu+hX8Fu666W45/ABV4eMKd8oRpxzh8Fv5dbglTUqc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         "], {{0, 300.}, {300., 0}}, {0, 255},
         ColorFunction->RGBColor,
         ImageResolution->288.],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
         Automatic],
        Selectable->False],
       DefaultBaseStyle->"ImageGraphics",
       ImageSize->300,
       ImageSizeRaw->{300., 300.},
       PlotRange->{{0, 300.}, {0, 300.}}],
      TraditionalForm], Scaled[{0.5, 0.5}], Scaled[{0.5, 0.5}], Scaled[1]], 
    CircleBox[{0, 0}]}, {
    {RGBColor[
      NCache[
       Rational[2, 3], 0.6666666666666666], 0, 0], AbsoluteThickness[2], 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAUJYdAADp5j8U1uileNSzP8yvYTjJ
yOY/jPfzdde3tD/Qbq7T5qjmP3zvnqAqnrU/JoF551mJ5j9cbJxRaoe2PyLP
UIYjauY/tGYtm45ztz9mJtG/REvmPyggZnaPYrg/Vv6coL4s5j9Y/XPDZFS5
P2VWUzKSDuY/3DjkSQZJuj+lroZ7wPDlPyRs67hrQLs/1hq0f0rT5T907K2n
jDq8P1VwOj8xtuU/NPmIlWA3vT8lj1G3dZnlPxS5XOreNr4/bMYB4hh95T/c
A9f2/ji/P6JUG7YbYeU/2Hpf+tsewD/PAy4nf0XlP/akoIOAosA/BuKAJUQq
5T9avZ6daCfBP4AWCp5rD+U/MNHJw4+twT+O02Z69vTkPzaOuWbxNMI/qmXT
oOXa5D+i8VTsiL3CP/NfI/Q5weQ/CFT6r1FHwz9Q5rlT9KfkP9DQpwJH0sM/
gRWCmxWP5D8mCCQrZF7EP2SJ56OeduQ/rDknZqTrxD+jAc9BkF7kP8K2hOYC
esU/GSWPRutG5D/SqlTVegnGPyJk6X+wL+Q/dDgeUgeaxj8i+gK44BjkP57p
AXOjK8c/Zw5etXwC5D/MceRESr7HP8L00jqF7OM/asCZy/ZRyD/0jYkH+9bj
PyxiEAKk5sg/O8jy1t7B4z/IL33aTHzJPzZAwmAxreM/rEiHPuwSyj9MAuhY
85jjPxZYdA99qso/2myKbyWF4z8aI1Um+kLLP1AzAFHIceM/Hl4yVF7cyz+F
gsql3F7jPybIOWKkdsw/WkaPEmNM4z+aiusRxxHNP/WQEzhcOuM/t9tHHcGt
zT+7IzazyCjjP2ni/DaNSs4/MxrqHKkX4z+12ZQKJujOPxO3MQr+BuM/ZXKk
PIaGzz+rCEtp
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVUH0s1HEcFpdTXacXlC2TaadLauUcOVZi87JW465GSfIWapKJY1IjdjqX
htGxRcNWUm3YrTQ9zGb0ojv3hvP2+1JyXOY9Y/Trj2efPXs+z+f57HGKuRsW
b25mZsal8X/WRtfpqEUK8l2iheXJYXQn9AS7z1PQLwpfepQMQ1RrPG8xR6Gg
e2kh4cww7O7t14aaKPhuM6qKJwxILttkO85SeNARwm2UGWD+3H49eYZC4lXx
ZKenARxpfo0HzVmrjDkdNYQ0sDZzab7AqeLNSofA+sy3CaT9c+KxWgZ/CBGR
PIOMvr9hfdPReXwQx1anA4V0PsM7ozrkySAS1aaQSvq/bKujZrm8QfDqJcqI
JQpVMwe8OkYHIOYrOqpWKbiGJrjZFA3gpx9nK2KdQlOgvDfHfQDhN3xvV25R
UHDylzdG9Cg/YjcexiCQ+HLllRI9ouLzeMU7CMSSxupL7nr0yVkCf2uCCymc
CZdRHUxJa52ZtgSnC+tEzkU6pEcFl3EPEVy5taIO4OmgULSlhzsT9OS98i8Z
06Ik9qsLw5Wg3Wrs8XapFpEun5KOuxNoBv0yG/laGIZki0oBQVwB+fuIaDCg
2509H0Dw7LLzL+lTDVrz+t7KLhIwk1/Y93lrIGGeFDSEE/gR1p2QKTWGXa5/
8YwlOHzwRKtFuRpGQfhWQAqBYuZd98Y5NQRhS1nfsmjdaW+G159+PEwf0X4v
IHBTlZZ+rO5H057qxqBSgn6TrTEvuB/swjKpTw2BjYEZVLmqQpTO2up1E4HQ
Ifj+WoMKFdln38ja6H0HW68mkQpp13w2pnvoPiyNwmYLFUpN7Nx2PYGyJbWI
3aLERGrze+YUQW9XXEVXjBLRQntWzwpByoccD80+JX4rTu3ctJwAO63ep7Dw
B/4BC3Z8jg==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVjn0s1HEAxi8uVEJFZcvMNC8rNXOOvOwpbuOsFY5G6c1bUlOaiJnZ6W7O
ORqWUF6GTZKKpqh0pplKunNv3Hn7fVnmkLxeIrr+ePbs88fzYhd9KzTOgEaj
Oev13yd3hS2uTA6j70qtklqiYLfMqXEvHMZifC/bbYFCf8/yYvyJYWRXa/0M
5ynwtmml+RMa+CXvU4TMUfgkDnJuFGnwsHjTzHaWQvP5e5NdHhq4PLJeT5yh
EKKjzyspNYKFOVXuemY6ljNmhWo8/mi6maVn1/SxajpTDWYn0zJAn/e1uGpr
Pz4EbhRDI9L3s7xSK4LyhsDRTQdw9PvtJk60LMYQHsjmgkr1/wZnDniKRwcR
VZcriVymkBAS72IpGEQNs01crqMwFVD2OdNtEGZ+DluR6xQWHHJWNkZUyL7s
e6N0i0KXr3NZaa4K7w/vHw+lE7zKbaw466YCP47LyN9BkJPkMOE4qsRqmam3
vzlBAr82zF6ghFXiWleaFUHetVUZi6HEk0vsYudDBH+5Df6FYwqMtnWkRNgT
/DIZu79dqEBbzFdH+hECI/WptEamAjzHd9ePuhGU8MjvbCKHgUa0JPEmEIfb
/xAWyEFT7c5YYBG4J1Za93vJMcztfy46Q5BETG8GTcnw0vi4d30EwemDx14b
lshAd7r4xSOGgMw092yclMHSJ2KLlUTAttuT6vlzALGhy+l96QTh0qKi9ooB
NKSMKL7xCP7MWWm57AHILSoaA4sIvDTGgaU6KTz5xUKfKoIMG/bdtXopBEpz
k6dNBDobK8+mMCnEGXgm6iA4Z6TltBhKUXnBZ2O6l2Cp9bbArFWCzjmzrA8q
Am137MPuaAnMk1teGE8RFLzNdJfvlSCfY23au0oQfKfOh8//Dss3rjs3jSbw
D5lJVec=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAmNXopXjUs78mlh0AAOnmvwz383XX
t7S/oq9hOMnI5r/87p6gKp61v6ZurtPmqOa/4GucUWqHtr/+gHnnWYnmvzhm
LZuOc7e/+M5QhiNq5r+kH2Z2j2K4vzwm0b9ES+a/1Pxzw2RUub8t/pygvizm
v1g45EkGSbq/PVZTMpIO5r+ca+u4a0C7v3yuhnvA8OW/7Outp4w6vL+uGrR/
StPlv6z4iJVgN72/LnA6PzG25b+MuFzq3ja+v/6OUbd1meW/VAPX9v44v79F
xgHiGH3lv456X/rbHsC/fFQbthth5b+upKCDgKLAv6kDLid/ReW/EL2enWgn
wb/g4YAlRCrlv+LQycOPrcG/WhYKnmsP5b/ojblm8TTCv2jTZnr29OS/VPFU
7Ii9wr+EZdOg5drkv7hT+q9RR8O/zV8j9DnB5L9+0KcCR9LDvyrmuVP0p+S/
1gckK2RexL9cFYKbFY/kv1o5J2ak68S/P4nno5525L9stoTmAnrFv34Bz0GQ
XuS/fqpU1XoJxr/0JI9G60bkvx44HlIHmsa//mPpf7Av5L9H6QFzoyvHv/z5
ArjgGOS/cnHkREq+x79CDl61fALkvw/Amcv2Uci/nfTSOoXs47/OYRACpObI
v86NiQf71uO/Zy992kx8yb8WyPLW3sHjv0xIhz7sEsq/EkDCYDGt47+zV3QP
farKvygC6FjzmOO/tiJVJvpCy7+0bIpvJYXjv7ddMlRe3Mu/KjMAUchx47+9
xzlipHbMv2CCyqXcXuO/MIrrEccRzb80Ro8SY0zjv03bRx3Brc2/z5ATOFw6
47/64fw2jUrOv5QjNrPIKOO/RdmUCibozr8NGuocqRfjv/VxpDyGhs+/7LYx
Cv4G47/yeHmJ
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAJNbopXjUs79Elh0AAOnmP5z383XX
t7S/wK9hOMnI5j+M756gKp61v8RurtPmqOY/cGycUWqHtr8cgXnnWYnmP8xm
LZuOc7e/Fs9QhiNq5j88IGZ2j2K4v1om0b9ES+Y/cP1zw2RUub9K/pygvizm
P/A45EkGSbq/W1ZTMpIO5j88bOu4a0C7v5quhnvA8OU/kOytp4w6vL/MGrR/
StPlP1D5iJVgN72/S3A6PzG25T80uVzq3ja+vxyPUbd1meU//APX9v44v79i
xgHiGH3lP+Z6X/rbHsC/mVQbthth5T8IpaCDgKLAv8UDLid/ReU/ar2enWgn
wb/94YAlRCrlPz7RycOPrcG/dxYKnmsP5T9Gjrlm8TTCv4XTZnr29OQ/tPFU
7Ii9wr+hZdOg5drkPxpU+q9RR8O/6l8j9DnB5D/i0KcCR9LDv0fmuVP0p+Q/
PAgkK2RexL95FYKbFY/kP8I5J2ak68S/XInno5525D/WtoTmAnrFv5wBz0GQ
XuQ/6KpU1XoJxr8RJY9G60bkP4s4HlIHmsa/GmTpf7Av5D+16QFzoyvHvxr6
ArjgGOQ/4nHkREq+x79gDl61fALkP4HAmcv2Uci/vPTSOoXs4z9DYhACpObI
v+yNiQf71uM/4C992kx8yb80yPLW3sHjP8RIhz7sEsq/MEDCYDGt4z8uWHQP
farKv0YC6FjzmOM/MiNVJvpCy7/UbIpvJYXjPzZeMlRe3Mu/SjMAUchx4z9A
yDlipHbMv3+CyqXcXuM/sorrEccRzb9URo8SY0zjP9LbRx3Brc2/75ATOFw6
4z+D4vw2jUrOv7YjNrPIKOM/0NmUCibozr8uGuocqRfjP4BypDyGhs+/Drcx
Cv4G4z9s02Ib
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA6gtU8vXk3D/KYKPW4fPhvyf0U6E1
j9w/8GbISTPx4b/UxvTyZjncP36g6kID7+G/iwHq0Yzj2z9AcRPVUe3hv8rA
Simqjds/k5P+Dh/s4b+0WnjkwTfbPyqYGftq6+G/V/cE79bh2j9Oi4OfNevh
vzwnmjTsi9o/mr8M/n7r4b84ed+gBDbaPzS+NhRH7OG/RBBhHyPg2T+AXDTb
je3hv0s6dptKitk/UPfpR1Pv4b/ACCgAfjTZP47T7UqX8eG/3usXOMDe2D9a
pIjQWfThv25RZi0Uidg/nDa2wJr34b/uR5nJfDPYPwpCJv9Z++G/+CaD9fzd
1z98Xz1rl//hv8g9KZmXiNc/uSQW4FIE4r+3iKqbTzPXP4JlgjSMCeK/im4m
4yfe1j/zmQw7Qw/iv3CGo1QjidY/Emr5wXcV4r+SZ/bTRDTWP5heSZMpHOK/
A4OoQ4/f1T/atrp0WCPiv/cI34QFi9U/smPLJwQr4r8M2kF3qjbVP4Anu2ks
M+K/nIXi+IDi1D/+2o3z0Dviv8dVI+aLjtQ//NYNevFE4r88ap4ZzjrUP9iC
zq2NTuK/duIMbErn0z+rBy87pVjiv1QYLrQDlNM//iddyjdj4r/p667G/EDT
Pw48WP9EbuK/UCERdjju0j9eUvR5zHniv13RkpK5m9I/onTd1c2F4r8B7hXq
gknSP84Qm6pIkuK/QNsHSJf30T8yhpOLPJ/iv4AdSXX5pdE/g9YPCKms4r/+
HRU4rFTRP7p6P6uNuuK/XAbqU7ID0T+YWzz86cjiv/qzcIkOs9A/uO0Ofr3X
4r/yw2SWw2LQPwhxsq8H5+K/lrh8NdQS0D+GUxkMyPbiv11ypDyGhs8/Drcx
Cv4G47/+j2va
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAtGCj1uHz4b/HC1Ty9eTcP9xmyEkz
8eG/BPRToTWP3D9qoOpCA+/hv7HG9PJmOdw/LnET1VHt4b9pAerRjOPbP4KT
/g4f7OG/p8BKKaqN2z8bmBn7auvhv5JaeOTBN9s/QIuDnzXr4b809wTv1uHa
P42/DP5+6+G/GieaNOyL2j8ovjYUR+zhvxZ536AENto/dlw0243t4b8iEGEf
I+DZP0j36UdT7+G/KTp2m0qK2T+G0+1Kl/Hhv54IKAB+NNk/VKSI0Fn04b+9
6xc4wN7YP5k2tsCa9+G/TVFmLRSJ2D8GQib/Wfvhv85Hmcl8M9g/el89a5f/
4b/YJoP1/N3XP7gkFuBSBOK/qT0pmZeI1z+EZYI0jAniv5mIqptPM9c/9pkM
O0MP4r9rbibjJ97WPxVq+cF3FeK/UoajVCOJ1j+eXkmTKRziv3Rn9tNENNY/
4La6dFgj4r/mgqhDj9/VP7pjyycEK+K/2gjfhAWL1T+KJ7tpLDPiv/HZQXeq
NtU/CtuN89A74r+CheL4gOLUPwjXDXrxROK/rVUj5ouO1D/mgs6tjU7ivyNq
nhnOOtQ/ugcvO6VY4r9e4gxsSufTPxAoXco3Y+K/PBgutAOU0z8gPFj/RG7i
v9Lrrsb8QNM/clL0ecx54r87IRF2OO7SP7h03dXNheK/SdGSkrmb0j/mEJuq
SJLiv+7tFeqCSdI/SoaTizyf4r8u2wdIl/fRP5zWDwiprOK/bx1Jdfml0T/U
ej+rjbriv+4dFTisVNE/s1s8/OnI4r9OBupTsgPRP9XtDn691+K/7LNwiQ6z
0D8ncbKvB+fiv+bDZJbDYtA/plMZDMj24r+LuHw11BLQPy63MQr+BuO/SnKk
PIaGzz+RZWhn
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAATpYdAADp5j8I1uileNSzv8qvYTjJ
yOY/gPfzdde3tL/Obq7T5qjmP2zvnqAqnrW/JIF551mJ5j9QbJxRaoe2vx/P
UIYjauY/qGYtm45zt79jJtG/REvmPxggZnaPYri/Uv6coL4s5j9I/XPDZFS5
v2JWUzKSDuY/zDjkSQZJur+iroZ7wPDlPxRs67hrQLu/0xq0f0rT5T9k7K2n
jDq8v1JwOj8xtuU/IPmIlWA3vb8ij1G3dZnlPwS5XOreNr6/acYB4hh95T/Q
A9f2/ji/v59UG7YbYeU/znpf+tsewL/MAy4nf0XlP+ykoIOAosC/AuKAJUQq
5T9SvZ6daCfBv30WCp5rD+U/JtHJw4+twb+K02Z69vTkPyqOuWbxNMK/pmXT
oOXa5D+a8VTsiL3Cv+9fI/Q5weQ//lP6r1FHw79M5rlT9KfkP8bQpwJH0sO/
fRWCmxWP5D8eCCQrZF7Ev2CJ56OeduQ/pDknZqTrxL+fAc9BkF7kP7a2hOYC
esW/FCWPRutG5D/JqlTVegnGvx5k6X+wL+Q/aDgeUgeaxr8d+gK44BjkP5Xp
AXOjK8e/Yw5etXwC5D/CceRESr7Hv7300jqF7OM/YMCZy/ZRyL/ujYkH+9bj
PyFiEAKk5si/Nsjy1t7B4z+9L33aTHzJvzFAwmAxreM/oUiHPuwSyr9HAuhY
85jjPwxYdA99qsq/1WyKbyWF4z8OI1Um+kLLv0szAFHIceM/EV4yVF7cy7+A
gsql3F7jPxrIOWKkdsy/VEaPEmNM4z+MiusRxxHNv++QEzhcOuM/q9tHHcGt
zb+0IzazyCjjP13i/DaNSs6/LRrqHKkX4z+p2ZQKJujOvw23MQr+BuM/W3Kk
PIaGz79vKV5Z
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVxXss1AEAB/BzNskfRKPLq9p5FGHUdKxFJiJ/OK6mzc77Vpg3KzGmPIuz
xpZHt1vOxHbYvE7h6xA/500ozOT38LpacrtJZtUfn30uRSeHxLFZLNaVf/7/
vdqKxdphkLK43fjkcwcS26J44wQDjfYgc7mnE2lJrQvMewbqHxKpg6QLqvyn
Ww9LGXxJqOfHF3eDmA4u4sYz4Imc6irSe2BoNwffewzaL4iyxNEKsE7qpQNX
GVDH6cOxgl6YPAh1e23IIINHBegFfICgtejZ4E8aIwl7igTvjyg278wLXKBh
qZY3vfLsg36Kp5drN42Nw5LqyBv9WKng92TW0JhVhO+uuw+AO6qzycmlUaW7
rD3hAeECi26LKBqK7IijVetBvNR1ts+7Q2NFJn2e/24QI9/ybX0daPj0S94+
slfC28xAkmBEgzM3PiyWKxG8IMrWaihYV/SK9q8PISluQUqvUKjcF6hL+ofQ
G8HVeCgpaEOP2vj+w+AwvaGaJgpDs01s//lhBJkW1JmKKVjq2zjGCkfgVrrV
IMmiIPOwF8n2RpCuM3O7UkhB0f2CYWd/wq6N2G/Pj8Jki2Ax+/QotDE7ee0u
FJJ51iGnakdx+Jut2OBQqN3RSW9wHIOXobArh01BlUr5Bg6MoV4z71moJhE/
WDOh5ROYLS899WeJhFP0GbaMIXCe+LW0riRBuOSuBOWMw8x7KNJVTkJ+t/iW
2kQFZ/Z22MEbEpywDKPcFhUGEsuSbQtJWHHv2x35TMD9GotPpJK4KHQTCNcm
kFSgalwTkrAnPKJlWZPw9RObxASRqCvbMx4znsJm5VleuCeJvlV/K6V8Cs1c
9w7iMonEzWP38sBp2JjvWjafI6H4WmVgtz0NvR5XgxM9Eo/TZDeLimbwFwDX
dvM=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVjn0s1HEAxq8ISYeismVmmkuvqzsveekRFmeLeWk7VIpoyZQSMZN5udE5
NiyOFg1boWw0iVWMmd64c+7O3Xn7fRnzlnAcc3P9+uPZs88fz4t9zMPQuL0M
BsOJ1n8fuF0np9YpzBwIX9uYGcNK/ACXvUrBXhP2xrlkDJm1Cz4GKxQG+zVr
8ZfGcDn5sCxkmQJ/z4KkaFqN0rJdpt0Shb7uQKdGoRqnKm12EhYptEQ+m+lx
VeOaILfGmeZQreGKnFKh8pvZbhbNrqwqzpJABfZXFyt/Os9On6w1dFHh+Q2O
Wkj3w+KOncOUEsHaef8wev+qe2p14AslhNLlwAr6X5fJSUYWRwlefYE4QkNB
tXjUrXtiFK9c2rurtBQSQuLPWhWOwtTHUR+xQ2HeX/Q9kz2KzGivBxV6ChrH
3A3duAIdJ45MhRoS9Hk5iSoKFMiJy+EU7SdoK2isDmYrsCYy8/A1J+AnOU6z
JuSwTNjuSbMmSOTXhTsUylF5i1vmdJyg+N6m1I8jh7K9M4XnQMDIfetbMilD
a+xPluFpgnWTybx9AhmyWV33z7AJTFVX0hpdZNhVCdfFHgSifLKVTUagkx/M
WPWj/1x3mBUUj2A0Z/C9MIjAPeG1zaD7CJqMz3s08AieELPEwDkp9KybP1xj
CUKOnftoUC4F05On90simF380K/zliI6VJP+K50gyN4y1e3PMOpSxmW/8wki
JaWln6uHMWRR3RhQSqBftl7I4Q7jIr9M4FlD4K02DqjQSpAnNzd510yQZct9
ut0gQWcGmoSdBDpba7fmcAkqozx18wMEUUYLYa0GEnQsM7O+KAi22h4VMtvE
ME1ubTGeI/jbe/dlb4wY/DAbs4FNgvKOTOeRQ2IwP10w3TWaRtTjek8+fwj/
AOc6V7g=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVjn0s1HEAxm+Rl7qQXGiZGjuuVGvO67GSW9y1lbg2elF5nWqS5C1T8zZv
l+ZaN26Lhk0X2jBJs4c005vu3AvucH5fljlv854YnT+ePXv+eD7PczzqYWjs
HhqNxjJo15n7BUurkyMIuVOjppYpxC+HvfUoG8HTuD6e+yIF296VpTifEdCr
9ReMFigM0PTy0gkt5EmHVFfnKDC6+CypUAuWaNvCcZaC0fX0yW4vLb6K7Tfv
zVCQrhkvqCkNZopzqzwMWcSsZM+WaOAL+nb2bk7XVRt7ajDU6WkTZOjXWN51
dBofhutNtlZo4Df5pEr4xcP4tzYdFGbYdzVzpWWzh+GnmOOLDf8uzdh6d40N
gV5bKItYoaALiTtlUzSEUM+2rsp1CtFBFd+y3IfwJYC5E7FJIZmZu7o1Ogjv
2/73xTsUgvxZFeLCQaQ7Hx4PNSbgFEolV9wHwY3NYZeaE1gnMidcxtRor6Bz
Ai0JtvJrBE5FamgSNrrTGATO8WsKLluNmEieiHWUQJJTH1imU6G+rSMl3IlA
ZKbL21uiQl70DxfjkwRNwwFpUk8VBC6fE9zcCQLzyd/nRAmVRrgs4xA8vub0
p+SFEkr1gcxFLsF8whv7fl8lWnP6G4WXCdwI/QF/SoEi0zOcunACK7vTrUav
FBh3ufXdK5pAOtPUu3VegSVO+A43kcDu+MFU7/kBcENXMn5mEJyQl5d/kgyg
NGVU9SufQDHH0OfwBtBhJZEGlxMc0ZoGi9flOFYgKvGrIoh04D3ZqJMjWW1p
9q6BgDgwvBsEcjRknnsv7CC4aKIPazaSo/SG39Z0H4G+JanIokWGxjmL7M5B
gqmemNc9UTLQHjV/MJ0ieNme5aG0luFZmD29b83AT671Kyj4DfOPZ/dtm0zg
P/rCe18=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAABNfopXjUsz/Hlh0AAOnmP2j483XX
t7Q/PrBhOMnI5j9E8J6gKp61PzpvrtPmqOY/FG2cUWqHtj+MgXnnWYnmP1hn
LZuOc7c/gc9QhiNq5j+0IGZ2j2K4P74m0b9ES+Y/1P1zw2RUuT+o/pygvizm
P0Q55EkGSbo/slZTMpIO5j+AbOu4a0C7P+yuhnvA8OU/xOytp4w6vD8XG7R/
StPlP2z5iJVgN70/kHA6PzG25T9EuVzq3ja+P1qPUbd1meU//APX9v44vz+a
xgHiGH3lP956X/rbHsA/ylQbthth5T/4pKCDgKLAP/ADLid/ReU/WL2enWgn
wT8h4oAlRCrlPyTRycOPrcE/lhYKnmsP5T8kjrlm8TTCP53TZnr29OQ/jvFU
7Ii9wj+yZdOg5drkP+pT+q9RR8M/9F8j9DnB5D+w0KcCR9LDP0zmuVP0p+Q/
AAgkK2RexD93FYKbFY/kP4Y5J2ak68Q/VInno5525D+UtoTmAnrFP4wBz0GQ
XuQ/oKpU1XoJxj/7JI9G60bkPz44HlIHmsY//mPpf7Av5D9m6QFzoyvHP/f5
ArjgGOQ/knHkREq+xz82Dl61fALkPy/Amcv2Ucg/ivTSOoXs4z/uYRACpObI
P7aNiQf71uM/hy992kx8yT/2x/LW3sHjP2xIhz7sEso/6z/CYDGt4z/UV3QP
farKP/wB6FjzmOM/1SJVJvpCyz+CbIpvJYXjP9ddMlRe3Ms/8jIAUchx4z/g
xzlipHbMPyGCyqXcXuM/U4rrEccRzT/vRY8SY0zjP3PbRx3Brc0/hJATOFw6
4z8l4vw2jUrOP0IjNrPIKOM/ctmUCibozj+0GeocqRfjPyRypDyGhs8/jrYx
Cv4G4z+eT1MC
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAdNXopXjUsz+2lR0AAOnmv/T283XX
t7Q/NK9hOMnI5r/s7p6gKp61PzxurtPmqOa/0GucUWqHtj+VgHnnWYnmvzhm
LZuOc7c/k85QhiNq5r+oH2Z2j2K4P9ol0b9ES+a/4Pxzw2RUuT/O/Zygvizm
v2g45EkGSbo/4FVTMpIO5r+4a+u4a0C7PyKuhnvA8OW/DOytp4w6vD9WGrR/
StPlv8z4iJVgN70/2G86PzG25b+8uFzq3ja+P6uOUbd1meW/fAPX9v44vz/0
xQHiGH3lv6h6X/rbHsA/LlQbthth5b/KpKCDgKLAP14DLid/ReW/Lr2enWgn
wT+Y4YAlRCrlvwLRycOPrcE/FRYKnmsP5b8Kjrlm8TTCPybTZnr29OS/ePFU
7Ii9wj9EZdOg5drkv9xT+q9RR8M/kF8j9DnB5L+k0KcCR9LDP+/luVP0p+S/
+gckK2RexD8kFYKbFY/kv4I5J2ak68Q/Conno5525L+UtoTmAnrFP0sBz0GQ
XuS/pKpU1XoJxj/DJI9G60bkv0Y4HlIHmsY/z2Ppf7Av5L9u6QFzoyvHP9H5
ArjgGOS/m3HkREq+xz8ZDl61fALkvzjAmcv2Ucg/dvTSOoXs47/2YRACpObI
P6qNiQf71uO/jy992kx8yT/0x/LW3sHjv3JIhz7sEso/8j/CYDGt47/aV3QP
farKPwoC6FjzmOO/2yJVJvpCyz+abIpvJYXjv9tdMlRe3Ms/EjMAUchx47/i
xzlipHbMP0qCyqXcXuO/UorrEccRzT8gRo8SY0zjv27bRx3Brc0/vpATOFw6
478c4vw2jUrOP4UjNrPIKOO/ZNmUCibozj8AGuocqRfjvxJypDyGhs8/4rYx
Cv4G479afmTV
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAASgxU8vXk3L8oYaPW4fPhP4P0U6E1
j9y/SmfISTPx4T8sx/TyZjncv9Cg6kID7+E/3wHq0Yzj27+OcRPVUe3hPxnB
Simqjdu/3JP+Dh/s4T//WnjkwTfbv26YGftq6+E/nPcE79bh2r+Mi4OfNevh
P30nmjTsi9q/0r8M/n7r4T9zed+gBDbav2a+NhRH7OE/ehBhHyPg2b+tXDTb
je3hP3w6dptKitm/ePfpR1Pv4T/sCCgAfjTZv7HT7UqX8eE/BewXOMDe2L94
pIjQWfThP49RZi0Uidi/tja2wJr34T8JSJnJfDPYvx5CJv9Z++E/DSeD9fzd
17+KXz1rl//hP9g9KZmXiNe/wiQW4FIE4j/BiKqbTzPXv4dlgjSMCeI/jG4m
4yfe1r/ymQw7Qw/iP2yGo1Qjida/DGr5wXcV4j+IZ/bTRDTWv45eSZMpHOI/
84KoQ4/f1b/Ktrp0WCPiP+AI34QFi9W/nmPLJwQr4j/v2UF3qjbVv2gnu2ks
M+I/d4Xi+IDi1L/g2o3z0DviP5xVI+aLjtS/2dYNevFE4j8Kap4ZzjrUv7CC
zq2NTuI/POIMbErn079+By87pVjiPxIYLrQDlNO/zyddyjdj4j+g667G/EDT
v9o7WP9EbuI/ACERdjju0r8mUvR5zHniPwXRkpK5m9K/ZXTd1c2F4j+i7RXq
gknSv4wQm6pIkuI/2toHSJf30b/shZOLPJ/iPxIdSXX5pdG/N9YPCKms4j+H
HRU4rFTRv2p6P6uNuuI/3gXqU7ID0b9EWzz86cjiP3OzcIkOs9C/YO0Ofr3X
4j9iw2SWw2LQv6xwsq8H5+I//rd8NdQS0L8lUxkMyPbiPxxxpDyGhs+/qbYx
Cv4G4z8XQmoo
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAQGCj1uHz4T8OC1Ty9eTcv2lmyEkz
8eE/TvNToTWP3L/5n+pCA+/hP/7F9PJmOdy/vnAT1VHt4T+5AOrRjOPbvxWT
/g4f7OE/+r9KKaqN27+vlxn7auvhP+hZeOTBN9u/1oqDnzXr4T+O9gTv1uHa
vyS/DP5+6+E/diaaNOyL2r/CvTYUR+zhP3V436AENtq/EFw0243t4T+FD2Ef
I+DZv+L26UdT7+E/jzl2m0qK2b8j0+1Kl/HhPwgIKAB+NNm/8qOI0Fn04T8q
6xc4wN7Yvzg2tsCa9+E/vlBmLRSJ2L+oQSb/WfvhP0FHmcl8M9i/HF89a5f/
4T9PJoP1/N3Xv1okFuBSBOI/JD0pmZeI178mZYI0jAniPxeIqptPM9e/mZkM
O0MP4j/tbSbjJ97Wv7pp+cF3FeI/1oWjVCOJ1r9CXkmTKRziP/1m9tNENNa/
hra6dFgj4j9ygqhDj9/Vv2JjyycEK+I/agjfhAWL1b8yJ7tpLDPiP4TZQXeq
NtW/sdqN89A74j8YheL4gOLUv7DWDXrxROI/R1Uj5ouO1L+Ogs6tjU7iP8Bp
nhnOOtS/YwcvO6VY4j/+4QxsSufTv7gnXco3Y+I/4BcutAOU07/KO1j/RG7i
P3rrrsb8QNO/G1L0ecx54j/mIBF2OO7Sv2F03dXNheI/99CSkrmb0r+OEJuq
SJLiP5/tFeqCSdK/84WTizyf4j/k2gdIl/fRv0bWDwiprOI/Jx1Jdfml0b9+
ej+rjbriP6gdFTisVNG/XFs8/OnI4j8MBupTsgPRv37tDn691+I/rrNwiQ6z
0L/QcLKvB+fiP6rDZJbDYtC/TlMZDMj24j9SuHw11BLQv9e2MQr+BuM/4HGk
PIaGz78AHmq/
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAASpYdAADp5r+Q1uileNSzP8SvYTjJ
yOa/APjzdde3tD/Gbq7T5qjmv+TvnqAqnrU/HIF551mJ5r/AbJxRaoe2PxXP
UIYjaua/FGctm45ztz9WJtG/REvmv3QgZnaPYrg/Rf6coL4s5r+g/XPDZFS5
P1RWUzKSDua/IDnkSQZJuj+RroZ7wPDlv2Bs67hrQLs/wBq0f0rT5b+o7K2n
jDq8Pz5wOj8xtuW/XPmIlWA3vT8Mj1G3dZnlvzy5XOreNr4/UMYB4hh95b/4
A9f2/ji/P4VUG7YbYeW/4Hpf+tsewD+wAy4nf0Xlv/ykoIOAosA/5OGAJUQq
5b9gvZ6daCfBP10WCp5rD+W/MNHJw4+twT9o02Z69vTkvzCOuWbxNMI/gmXT
oOXa5L+c8VTsiL3CP8pfI/Q5weS//FP6r1FHwz8k5rlT9Kfkv8LQpwJH0sM/
VBWCmxWP5L8WCCQrZF7EPzWJ56OeduS/mjknZqTrxD9yAc9BkF7kv6y2hOYC
esU/5CSPRutG5L+5qlTVegnGP+xj6X+wL+S/WjgeUgeaxj/q+QK44Bjkv4Hp
AXOjK8c/LQ5etXwC5L+sceRESr7HP4b00jqF7OO/RsCZy/ZRyD+1jYkH+9bj
vwRiEAKk5sg/+sfy1t7B47+gL33aTHzJP/M/wmAxreO/gkiHPuwSyj8GAuhY
85jjv+lXdA99qso/kmyKbyWF47/qIlUm+kLLPwYzAFHIceO/6l0yVF7cyz84
gsql3F7jv/LHOWKkdsw/CkaPEmNM479jiusRxxHNP6OQEzhcOuO/gdtHHcGt
zT9mIzazyCjjvy/i/DaNSs4/3BnqHKkX47962ZQKJujOP7q2MQr+BuO/K3Kk
PIaGzz/HjWNG
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwtknks1nEcxzF5xLOiBxMLj1pzjGXkSr1RKemJ2uMPosPVQhNWEumgFKYc
maYpc0RNrpCjdWwo2+OmmOd5ft+PI3lolHOWpa0/Xnv9+9p7b2FQ1KlQFSUl
JfMN/vnzueIh9pthXFP8a3F8FCTIW9ZaYujUCNbwFEqRPujWkLTCsMnWKTM7
UIqUFCt1yzWGRIE0vveJFCKzPqa7ztA9feeL6pAUEtMCeygTSnlZ8ZbbZMgP
m1wpUyWYmJXcO3RChuYaVQOROiHqW87siTQZ1CROaTZ8gn/P1Vee7TIsdLc6
irUIH7xfvLNVkUP54ltBvQ5hIb5DyD8gR76Fl7p4O4FVtQ32xstxbTRVxcaI
MD3FfU2ul6Os98qs105CqEblbuG8HDJ37boSM8JIYfo5sR6HhEovl33WhHDT
vf18Ow4z9vzorXaEyjDziKaTHPJ19jgKnQmTXHS5XxQHj5W0uMuuhOLjIs3Z
DA4rt74L/ngQivpsdGJfcnCt5s23iwgS6+6Dig4OW0JK5yVigvuglqHvBIfJ
gZhl7QCCl56JYbUKQ5a+4Vh2MCHALaxtzZjBucI91yeCMN+eWeCwn2FpLvXH
sViCr98D42B/hobh5A+3Ewiu/Iz+G3EMxec7FxeSCUdidZ1TcxlGbRUhJRkE
7fc/B5NqGJ4cjpl6+JjgPWxlEdLF8Dpuyq+xkBB006HZXsEQ7jKQZVBOeHP6
4+YlHqHHrflCUw2hdsfA06JdBAsTo9qclo2+R5JlRzfCDD/Zo6KNEFkV9Kwl
kDCXFbm62k1QainSN79OWD16tvDuCKHNc2HqVh4hpYDxjk8QnvoJ8z7VEsbv
JfJEcxt/OONdNtu1sVtI66X7a4Q6H7XnygqCTqONxrraGAz++y8lXlBc
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwdjAtIUwEYhS9qRCkiWqKVslC0lag5fDBfcz4IFV9QmjOnkuhqpeYSnaJD
zAcJleFbdE6d5kKny+UjO1YgaRNFZk2yhhi7d8OZJkFlWLd+OPx8fIdzNqcg
JdeCIAgmnX9f2exCEEYDhGvUQKlWBc12XYr+jwFRc7FfWAEqZESM1JOOJLwE
gkJh+zhcG8LCnbxJrHSl7rgfjkFkH2RfFE2CKlce8K+PoYNl7trLIDHJavRh
aJRY/W0lbheRGFoVncr3V+K2uSIyv5EEcUfdKOKMQqkYbrrWT+JhvNMtP+cR
1COUKHtB4tJ87LLt96dwTIpwn9aS4Ng59thqFdjfcmlhmEnMvZ6aDlAPg+3e
ua04QsFO/+Hb/c4n4Mo2Z3muFHxtso471AzBVlrR4xNIodC2XL1SMIgrH3ke
nkm0F5d0L2TKweGtGSIEFM71KXkWyQPo4QyKqqopTM7XlFXF9EPT9jNH30lz
ceDd6PA+WLKyorIn6L731mxasAxhpRvDVsv0flLus1l2L+qj9Z4LFIVdZpyi
NFSKN29j40csjFCqK5dO13VjiS8aUp0xwndzJ8iyows2Yg+NLsAIQhRJjqo6
kFghi3FJNoIxLz92XtuGA7lMLrlJ+yazquygBTWHPLFFLe0Zog05sxmuAZJE
mdQIyd4BbyrzMRRd4Sr+jBG7VIN5suMRVq3j/Njv6b6pISN95gFC1tfSLu4Z
IS0ZZgcnNuLHQut4lI0Jkrq6QLe9enw6urxY7GkCJ2FCx+i9h5POXK+XXBOk
ldZ5XH41Wtcjst0yTZi7sbxxIbUS/SWKfVkZze82xSk2pfAXmoQhzfRe9/NF
h89FuFrz6/JXpQnE7ivDifY8CHWCwBkNzQm1Ei4/FUxtensPRfP/04X8BYVM
acg=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwdzX0s1AEYB/CbWPOSiWZK2hVj0lLe56Wv9xkt3NaYkzvGMBrmR3dc3JCX
dVsrkbc4F4cjjovyVtp6cXbtbN7Lcpb8fnd1pJc/itSvnu27Z5999+w5mZLD
SjNgMBjOdP7tvQWqkzevQES9HYOh3YRmKnLD3UuBRH0Va+3PJlSZmbnZjUP4
GNRfTVqTIO7HbTnsD0JccwE2Z0ncFch3OamD0Fv6WOaFkcj2ELkyVXKYeOhb
dhJJpM4RxzI85fD/bVjUSJAQ5o+IiMABqPWCkAwRCZtLNlfdjvbDuE9250oH
Cc3rSLX5jz68fRbA4E/QPmzdZj7fC25MkMPYPAnui9ExrxEZPDbs6pl6ElOa
pa83m3tAODR/7jWiQB3imlhVdIOQrE+yT1BgWhSPzOZ0wUcsaHP1pvviwlZl
khT8d2xHpxgKmg452yC2Ewnshc2gTAoZ0xX80vAODAZ2EaVltAu8C8LwAIsN
P1PWminMun6YjPeTwMidG5o8TMGClfZo0rcdPrxVmaGagtglqpcXIEZR2JqT
kqLwZbTkjW1VKx5OR17sN9BCuLHlc6CpBQMcoltxXItz10LIAUUTSL6jatlL
i0Cl1Pj0fANOCSThdrFaMOr0Cv5uPV5JJVJhlhZMe2JV6lyHiH12kUGlFtzv
u+zRpFqseAqjJWItpj7V6J803UZSCxSccfrfdk1iwvgtXDeNcvNdpPtima9f
tAia5YX48zt0L6rytt+pRq3y3lComQ4a1vAys/0Gcg+qZ/KddGCUm6YHc8rQ
bhN85mkw7Xz1qktcCWxXgpLtk3QQzq0Xscx4YBb2fpPwaXc+nrF6n4eeLF22
fx3tveebRxrT8bL81+VtOX2fWikM5sRhdinTe1xF+/90T1TOJTS2UTr8BQYu
RxE=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwtzX8s1HEcx3HMnLgt4kwUTk1+pKUkST9OZYmT2rV2pSiSDcmPEkp+hMLk
V7amKUsizI9WccqrX1it/CZad/f9vPXjYtcoP7Msbf3x3OPPp/Bk5MFTWhoa
GnaL/bNTX/Jz6vMnNAXeHWS/GBr0gvS8hHL0GRXPGEwzqDZsyS04JkfCgOhx
0iyDv5E8vuemHLFXHHUd5hlqRlPfaA/K4W7bywQLDEm8/HiHZQrIrEtcdmgS
pteUZ+z2VSA95OtshTZBNFSo9s1SoKJB20ysS7DtPl/t1a7AxLstWU58Qvb+
+882aimh6HrqKjEgtMR3CPnblRgNbTJ6ZEyoqGsb6IlXItneW1eynFCt4j6k
PVIi8FOmlpMFYZVerY1wQomcnnNq71WEptLsQIkJh9cehg/LbQme1pv6+M4c
Amu93beuI2SG2IU1H+DQ7cKPWupMABdVKY3kkGi83lXoRkjwEeurczjYzmbF
nd1JiOt1Mo55wGEo+ZvRH09C2bquXWMdHKzqeRPtYoLxgIH5oS8c1EH3Jt5L
CCtMrMzrtRhe9UfPGPoTHEQhbfOWDGdMzUcKghZ/7bklm7cxCKo8ivzCCNbS
a5ZBRxi6xzO/74sh6PNz+i7FMeQNpz1PSSQYxAjcMosYEk+8nZpMIwy3/hhI
amBo3DgWXJ5DEAw72gd3MkTsiVZdv0GwubxZ5jLGkBKnkj4pJVw4+mLJNI/g
7t6fb1ZJiF3Zf6tsNeGOSHa6uYFgkfd+xlVE+G1p0VjYQlhbd/J2yzGCjJ/m
WdVGaJWVmdolEJ7lh8/NdRFSvSZVycWEV3sDStM/Eg5LhcUvGwniEsbz+UII
OL6/Qt1JqMm4yBOPE8L9dO5ojhFCg59GXJ0n9Dx20lvQGcHQf/8Crth1vg==

       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwdj3ks1nEcgHknr3i3yLFk0Usrx7TeHLnq0ytZcmZvW4oSko0mhFHpeHNm
ovROacpCjplrKORDGx3LfRTr9f6+H5EyjdxTlvrj2bPnz0cYFOl7gaekpGS2
wT8na0h+LX79gsWBz4fZPIMI9WB1N6Ec27Rly5pLDEr322fdD5Bj2JC4IWmF
gVBbntD3SI5BdyzVLNYYxP64/V5lWI4Wpv1Md52BBz8nwWLrGFYY59uCMsG7
PUUpLl5jGBc6uVKiQqD/+cGMV8YY5tWobPdUI9jUG1fh1jmGXz/aZ4gEBBHe
L15b8RQ42NNiJ9EkKEx4KxQcUiAX9lK7Xocgu6pjqC9BgfHm7moSfYLHU9wn
ab0CT31J5YkMCfTUK3cL5xSY0hc7425CUFdwN1Cix2Grs1ZdkSmBi7HNgMCa
Q/9KdyfHvQSpoWbhr05w2G0riNpiTdDORZX6RXKYqLPPTuhAkOThqTGTyaHp
Skb85cMb3S/SiSnncPTmN+0/rgTle3uOTL/l0KSaP9fpSWA0pGlwcoLDueDi
uS4JgZneToNqHsN3g9HLWv4EjuLQjjUjhle2GYzfDybo7czKP3CQoWGZc65P
OIGNX7pR8GmGo7Op34/HEAgFmQPX4xk+HpG23bpKYBqj65CayzDt/IfFBSnB
fOvPoaQahm1W0yFFmQSiEUvzkG6GSUejp+493Pi9caDJdpphbvyUX2MBQd6Z
9s1LfEIfp8Gc7aUEsh2DTwp3ETaImy6+qiEQZ3ct24kJNXca1j5oJvCtCnra
HEA4IJC6lnUQTDYVbjNLJPyUE7G62kNQ4bYwdVNGyB07V5A8SiD1E8re1BKG
5zO+xwRB5lnvkpluwo8p1/ieswT5PqrPlKcJ00NaLqWtEfAaRerrquP4u+G/
4S9nJWAR
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAPNbopXjUsz9Blh0AAOnmvxzBSuQz
NrM/Vu2HUt//5r8IamlwbJmyP99BrojnFue/rJ1X7iT+sT+aiT4/GC7nv8x8
sPtfZLE/6BI4EnFF57+kNIwvIMywPwY07ZzxXOe/mNN0Gmg1sD83/QR6mXTn
v/Bztox0QK8/y+18Q2iM57+IThhtMhmuPwasqpJdpOe/UMhKzw71rD/Xvz0A
ebznv0gSFp8O1Ks/XlBBJLrU57/QxLm6NraqPzPkHZYg7ee/KOHX8oubqT9y
JJvsqwXov0gOYAoThKg/c6LhvVse6L+QEHu20G+nPzegfJ8vN+i/UHx2nsle
pj9421smJ1DovzilsFsCUaU/WlvV5kFp6L/QyIR5f0akP7JAp3R/gui/0HU3
dUU/oz/XmPli35vovzgw471YO6I/BjNgRGG16L+AUmW0vTqhPzp43KoEz+i/
CCxLq3g9oD99Rd8nyejov9C6fs0bh54/sMhKTK4C6b9Q5e44A5qcP7JfdKiz
HOm/EHhD56+zmj/qeSbM2DbpvyDKpgkq1Jg/JnyiRh1R6b/gle2zefuWP8um
oqaAa+m/8CN03KYplT9M/lt6AobpvzD1+1u5XpM/3jWAT6Kg6b+Q7IntuJqR
P2ScP7Nfu+m/IPGJXFq7jz+DC0syOtbpv4B9qjo7T4w/59jVWDHx6b8Ajoc3
I/GIP5rJl7JEDOq/gFS12CChhT94B8/Kcyfqv8CEC2dCX4I/qRhCLL5C6r+A
ds/cK1d+PyPZQWEjXuq/wNbhelIMeD8pdqvzonnqvwCpt8oT3nE/smvqbDyV
6r+AA8LmFJlnP8+D+lXvsOq/AHSGgEJfVz/a12k3u8zqvwAAAAAAAMQ8kNNa
mZ/o6r8Xple5
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAwJUdAADp5r8w1uileNSzP9Tsh1Lf
/+a/GMFK5DM2sz9cQa6I5xbnvwhqaXBsmbI/GIk+Pxgu57+0nVfuJP6xP2US
OBJxRee/2Hyw+19ksT+CM+2c8Vznv7A0jC8gzLA/svwEepl057+o03QaaDWw
P0btfENojOe/CHS2jHRArz+Aq6qSXaTnv7BOGG0yGa4/Ub89AHm85794yErP
DvWsP9ZPQSS61Oe/eBIWnw7Uqz+s4x2WIO3nvwjFubo2tqo/6iOb7KsF6L9Y
4dfyi5upP+qh4b1bHui/gA5gChOEqD+tn3yfLzfov8AQe7bQb6c/7tpbJidQ
6L+QfHaeyV6mP89a1eZBaei/gKWwWwJRpT8mQKd0f4LovxDJhHl/RqQ/Spj5
Yt+b6L8Qdjd1RT+jP3kyYERhtei/gDDjvVg7oj+rd9yqBM/ov8BSZbS9OqE/
7kTfJ8no6L9ILEureD2gPyDISkyuAum/ULt+zRuHnj8iX3Sosxzpv9Dl7jgD
mpw/WXkmzNg26b+QeEPnr7OaP5R7okYdUem/oMqmCSrUmD84pqKmgGvpv2CW
7bN5+5Y/uP1begKG6b9wJHTcpimVP0o1gE+ioOm/sPX7W7lekz/Omz+zX7vp
v/Dsie24mpE/7ApLMjrW6b8A8olcWruPP0/Y1Vgx8em/IH6qOjtPjD8CyZey
RAzqv6COhzcj8Yg/3gbPynMn6r8gVbXYIKGFPw4YQiy+Quq/IIULZ0Jfgj+I
2EFhI17qv4B3z9wrV34/jHWr86J56r+A1+F6Ugx4PxVr6mw8leq/wKm3yhPe
cT8xg/pV77Dqv4AEwuYUmWc/OtdpN7vM6r8Ac4aAQl9XP/DSWpmf6Oq/AAAA
AAAAxDyKDVec
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwlkWss1XEYgHVmjjiWcpmYy1EztCyRW+oNZe6Xdmo7ShekmpqwMhUphSS5
pQuJkVKaS3OvvaphtSGXU5Rzzv/3oo4OjXLNsrQ+PHs+Ph8eYVj03mM8FRUV
qxX+ue9I2Uf2i8G4pujn7OgwTugUzGvPMejWCNfwFkoxX+LWkLTAgG/nnJUb
KsWbVzerb1pikKgjTei9J8X9ln1Mb5lBz/cr71Q/SlFiXugAqwjK+DkJm9bJ
sCTy60KFKoGxZXnq7gAZttWqGvqrE0QN5k0GZMhQq8s5w1ZAIPpw7pl3hwyX
el46ibQJmgIfv7LjyVH9ZJNOvS6BMqFTKNgpx2JrX3XReoLB6nZJb4IcE4fT
eLYmBHIF9ymlXo5VvWcnfTcQiDWeWwin5Ujua1+UWxL0F984ItLnMPm5r+t2
G4Iw8239AnsOpxwEMWvsCcojraKagzks0t3iJHQhkHIxT8TRHPosZMSf2UVw
389fczKTw9/J33T+eBLc6bPVjXvKoUcNf7rDn+CtTY+HspND7YhH010iAgeJ
ttG+MQ4VA7Hzaw8SgL6ZUQ2PYa6B0UhuOEGQW2T7kilD10r3/KAogtGOrELH
HQznptLGfeIIvMTXTcNDGDYMpbRdvkCwVZDZnxjPsOzo+9mZFAKnOD2XtHyG
X+yUEeWZBDz8IUmqZXh3T6zi1u2V3tBm64huhlXxCnFjMUHwJccWByXDE64D
OYZPVv4ceL16jk/Y7dZyvLmWoNR4oKh0I6GFmUldXiuBT3bXvJMboUKQ4lnZ
ThBSHfawNZRwIufU4mIPwURLqYHVecIZr8PF1z4T1HrPKJILCJMKGd9vjCBd
LCx4U0coS73I958iyD4UWDHZTVgY8fJ0+hLBgyC1klVKQq1GW41ltRFQ/W/8
C8+uZHU=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwtkX1MzHEcx+vWejycHkRZuUKq1UpXevAQWuQUcjY10bqe5mEoevDQIkRa
15MstdIkFaKa6IF32qoxuaUnT9f9vh96crJKXNbE2fzx3uuP9+uf997CiKPB
UTwtLS17Tf4xIfxWP/vOYGMkmfrx+SNkJgVqwU+GOQOpYYBQAVHfxoaUGQbn
1V5ZuWEKOFxw0necZSg2ViR3FyowYfeGmc0xDI2df6HTr8BhmyKPDdqEWt2c
ZEfjQYiih2cqdAg2duWX/IIGEVyrYxGoT4gdyBsPyhhE8SuvDFc+IUCecDeg
YxCX5C2eEgHhdtCdp248JbJjn5g8MiXIkzqF/PVK2DqI9SVLCPU17X3dyUr8
+ZDOc7Ui1I1wA2mPlHDoPjkutiWsMLi/UjipxP5NC+vLVxHcS66GSxZxUN8T
r/VxJrQK3Xv4Ig6RHvzjC0SEuSj7Q427OPBNXTyF3gQRd7wy5CiHBnVG4jFf
wldxoNF4psZPHTH57U8Y7nY1ja/mUPlAb7IjkDDPWb5Z1ckhTnp7sktCONsr
sNwzxMGvN069cB/hvNkyy4c8BpW55adcKUHmG90+a82QXbkpf+chwrKOrKI1
6xi2TKSPbYsnpO69Yi0NZeC9S2s9d5oQY5TZczaR4Uv4yx/TaYSDcWbe6fkM
Vm6qyPJMgsuzb30ptQz9fnGjsmua/q2TQ+RrhuGE0ZDHJYSklDVNHiqGEp/e
HItKQmfoc4Ofeprdvk0xjbWEtqW9xWXLCbutrerymjX/yLrUnhsJAn6af1U7
4URNRGlzGGF+zuFfv+QEnaayxfanCMZbD5RcfE/o2Do9mlpAuH6D6W0fIhTu
FRa01RGmLp7RC5wglIbtqBh/TaiWthy5PEuo2qF7U1tFMG9wNZzT/YR5//kX
gyxykQ==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8408964152537111, -0.34831069974900514}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwdjAss1AEAxv+T1oqsYSalaYxJi7zODn3eLSqP1piTwxKGMEd3unHzVree
I4c4F+c6xnGRR6LNypnG5jwaC8vu//9fnShtytDVt3379u337TudlBWVbEAQ
hKPe/zKixpogaA3M56hWrlqJW7qKqOV9DbZGQ9fcPJVY9++sJC1IrKWlZWeI
eiCvugDLcyQqn0ev2+11Y9vUyzQnmEQLX7HDvtkNC3ddw2YcCYG70NlmUoGL
u4YFIg4JzgzHKtVDgUUdPzBVSEKW2yfk+HXBokP+5EYLCa+rlpmuxztBjfgS
vDcktj+ETpn86sDtCH+7QTUJwtSiyUTdjqA16xobHQnu2MCgZ58cpXb139oP
Uphemf9xv/4lyiSrw6xTFLaPJhwxK5Xhkpjf5Myg4HXsbt90VhvuLbLsHSIo
EPz8RlW8FJmsWY1/GoWNFgXLILIVY35tnKJiCoLxUl5RSAu0tb+TluspcPMY
ecF4ASu3hKDEXv3e+ctwjLcEV7hLcsMpCi5Rya+Gmc14FLzsoKIo9DuFtXN9
xRgbD73caUDDZbDw44mKRrxnc2TKkzQUa+teB+oasMezn1zwpJF9J5DsUtaB
yZeEWEfSEKikh8+oa7EilUgF6TT8qnVK3k4NEvdYBQblNBJsOUtSx2pseQjC
JWIa4q0d1kD8U/AaoGQP0dj4WqXrr3uMWqMwV+YcDZuNqrjYoYfYXZiNOb+p
/+PLmd7hQihUz3qCjLVYEVYwbDcr8eDQ1ESugxYJ13oXbJrLMGIZcPZtgBbi
EqOUAHYxmJ/8E23jtRjlTC05RRcC+e0/JTwtBOrVgihjLibStRk+1VoQba8n
zD7nQFPy5/p3hZ7vv9OYi1KwOZ/GGJrU8/RyQQA7GrKZWFETpe//JfP5Cx4n
Sc0=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8408964152537161, 0.34831069974900736}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVzH0s1AEYB/DbpVoxM6RLaVfs0JvFOCN598dpc6xGTg5LiCbrxCEu5KVu
60XknLlzceTEcZH3b/WHxdhZO2FZkna/310dyVpELz/P9t2zz77PniNJmVHJ
dBqN5kple1vMkM25Og321TjQaAY9vr/mfPHw0sDFVB618E+P+atp1zMk3Xge
2FFB2BGoaIhedvrbhSuVZ/0Zpwi031Jv8i93odva2zorlOo9xW7MCTUmPUz1
q3EECnQC+1RPNba2zPIkAgJ92b1iQUAnxKaC4FQxAS6Xcc39QAdGVW2PLjUR
sBrnaC1/tqMKfjThEAGmrZ3MUqfCfm6g04COQO1o/4BXbxuMSw41TBOB9c8z
P+5Jn4HlJP2m2knCxSphr01pK1iKxWHeYRIJ1vm9U5kt0MsKZG5sqi+82TAW
r4TTBx7LmUuC2aLm0SObYcab1gemkWgdLxUWhTXhYkCLoKiYhDyHnR3q/xQF
tRtJC1ISVu5LwzG+CrS6J4Qk9pDgnk9+MezTiLmc+TYzLYmpk+GqXD857EMX
nMdIqh8pnDxY3gDOW865DroBU+Sy9466enD4glbNIQMe5AcTnZo6FAlZE7Ne
lCeVe47patGXrwhziDQgQGLSCDdrEKtUKEXpBiQ4C+aVrtWY+8PLo5dR9+ub
vP74KqR6iiIUcgM+rVSa+uoe4qvUX8MfNED+qzIudvA+dpuHu/u8p1zS5uMb
IUbq7HTM6VXq/+NytuNqBRhjT7pDLIyQx/bMMhvvYG2XdvyGM+W75ilB/GIc
ZQSdGAky4tVt7fzx6ELUzQYmOsZTXlzMi7LIRX22ak0hNEKkeTlu8zELjunG
jDPVlBlv9LaSFPiV/L6wojaCJi0TBfGjETqTxh6coLw9InJo412sREYa8R8D
0W5M
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.3483106997490042, -0.8408964152537092}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwtkH0s1HEcxzE5D9eiw8SmrlqFHlxJpLy5SkOX1GkxIk+1aCklelBcpXST
p6zGxJJUa1GTOHqwYVkec6S5u9/3owcPUyk6sqxr64/3Xntvr79ewsiju2MM
9PT0HHT7Rz8z6Y/JjwPYH3Gnl/1k8DKNMvUVqpAqKNCa/2LIXOuelRumwkql
97PUKQYLgSql65buX1xl7DTDcGIk/Y1hrwq/l3czq1mGfbycFKf5alxYXOgK
fcLg8rLLW3eqERj7earckOD9Pm9sZ6YayVWGthJjgkdn0kPfZjVa37pniviE
yoB7DesMNHjRUe8mNSf8SGkR8j016D70XFBtSfj2uEnZlaJBgqO/sXQBwWiY
65NVa7B3IMNAZE/INn20TDiuwbWuk2P+Swja4msRUmsOb8QWT8tWELIWr3/H
d+Fw5JH/Jo/VhL5Yh7jaQA6fXfnH5rkQbNixiuCjHG5aOrsJNxIGdkjMxuQc
JFOZpxK8CKxbZJn4gMOctC+CPz4EyzUdW0ZbOARV8sabJYTrSnO7oE8cHKPv
jrdJCbetF9lVGjCYKI9rLUIJNd6xTTMLGRQ2doO5UYQ9LVmFGzYzxN8X5++K
IzQEX10YFcLgPJ4x7JdIeMyXvzt3ikHbL3uVdoZQn2i1MSOfYeRA6+SEjCB/
+VWZWsXg5DIaXSYndPavcoxuZ/i27fjQ9RuE4fMb6lxHGfjJQ8E1xQRx6GuT
Xzydt6knx7aC4GPfU1S6lOAprjtYW6Xrld2mdfMmlCyyf5KnIPArI28rwgiH
58p87jcRyhWlNg6nCUm58dPTHYQEv4mhCwWEy77hxZc+ECQhwoLGJwTbIsbb
8YkQGh5QPtZOSM84y5N81/mBRiX6o4TtMfVHrszo+taITGeNBtH4n38B5CVL
ow==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.34831069974900597, 0.8408964152537142}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwlkH0s1HEcgDFzXm5LoUTh1ORlmYt0RJ+oLHmtTutEhNSmlghdSYUoGfOS
1ZiypOtFoSlv9cHmLCvy/rLu7vf9SCnTUl6nLK0/nj17/n0EEWcOHNdQU1Oz
WeafJXrinzOfPkJz+P0B9ouhq26krrdAAcMGRXP6swxjt7jk5Icq4HK/x8uU
eYa0SiHtvqOAxPTN2naLDIXfUt9qDijA3bqHGS0xVOflSe1WKaHRstgZ1AnP
byrP2O2vhPToz/MVmoStgwWT/llKKK/WNPHTJpR1JT7xlivh+zuXLCGfUCfg
4WtHDRWMdDWJxPqEImm7gL9DBZ9O1hnUGhJaPm/r75aq4Lytj7Z4LaHVODeY
VquCQx8zNYRmhCU6lVaCKRWkdidM+mwgPFd6M1y8moM6z5Uvyq0J1S239vKd
ODhY6eO23Z7QM9ompn4/B63O/LMrnAil3FmZ5AwHpwwdRAJXQidfP73JbA7W
zGclxe4kdOgRGsY/5kB+5YvBHy/CYPuuXRPtHPCreFNyP8J3ffqmQWMcDEY+
mHovJuw1sjCt0mDwtC9ubmUIIe2Mbls0ZxBkbDqaH0mYIM8p3ubO4LfMszAw
hnDo8A3zyGAGtT8yv+6LJ2zRy+69lMQgbjit+epFQnmckWtmIYOQYx0z02mE
OW++96dUM8h3nIgqzybsGNpsG9XJwHdP3HjuLcKRlG0NzhMMwpLGJa9KCe2O
tOjM8giM3fryTGSE1uv7Sso2EiR7NJyoryb8kPt+TuRB0GNuVlPQSKh8FnG3
MZQgn5/m9aiNMLahzNjmwnLnnVpY6Fr+4z09fqWI4PbesNJrI4TaEkFRaw2B
RTHj+Y4R6h8NqJjsJEjJSOb5/SBcF6h1T32CQBTVdPr6ImHqS6HuktYoyP4b
/wKiV14o
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.34831069974900514, -0.8408964152537111}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAARNXopXjUs7/GlR0AAOnmPxTASuQz
NrO/5uyHUt//5j/4aGlwbJmyv3hBrojnFuc/lJxX7iT+sb8+iT4/GC7nP6R7
sPtfZLG/lhI4EnFF5z9wM4wvIMywv74z7ZzxXOc/WNJ0Gmg1sL/5/AR6mXTn
P1hxtox0QK+/l+18Q2iM5z/gSxhtMhmuv9yrqpJdpOc/iMVKzw71rL+4vz0A
ebznP4APFp8O1Ku/SFBBJLrU5z/wwbm6NraqvyjkHZYg7ec/MN7X8oubqb9y
JJvsqwXoP1ALYAoThKi/faLhvVse6D+IDXu20G+nv0ugfJ8vN+g/SHl2nsle
pr+W21smJ1DoPyiisFsCUaW/g1vV5kFp6D/AxYR5f0akv+VAp3R/gug/uHI3
dUU/o78Umfli35voPxgt471YO6K/TjNgRGG16D9gT2W0vTqhv4x43KoEz+g/
6ChLq3g9oL/ZRd8nyejoP6C0fs0bh56/F8lKTK4C6T8w3+44A5qcvyRgdKiz
HOk/4HFD56+zmr9meibM2DbpPwDEpgkq1Ji/rHyiRh1R6T/Aj+2zefuWv1yn
oqaAa+k/AB503KYplb/o/lt6AobpP3Dv+1u5XpO/hDaAT6Kg6T+w5ontuJqR
vxSdP7Nfu+k/4OWJXFq7j789DEsyOtbpP4Byqjo7T4y/q9nVWDHx6T9Ag4c3
I/GIv2jKl7JEDOo/AEq12CChhb9RCM/KcyfqP6B6C2dCX4K/jRlCLL5C6j9A
Y8/cK1d+vxLaQWEjXuo/wMPhelIMeL8hd6vzonnqPwCXt8oT3nG/tmzqbDyV
6j8A4sHmFJlnv9yE+lXvsOo/ADOGgEJfV7/x2Gk3u8zqPwAAAAAAAOk8stRa
mZ/o6j+0nle4
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.348310699749006, 0.8408964152537124}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAACJYdAADp5j8w1+ileNSzvxvth1Lf
/+Y/FMJK5DM2s7+gQa6I5xbnPwBraXBsmbK/Wok+Pxgu5z+snlfuJP6xv6YS
OBJxRec/zH2w+19ksb/AM+2c8VznP6w1jC8gzLC/7/wEepl05z+g1HQaaDWw
v4DtfENojOc/AHa2jHRAr7+5q6qSXaTnP5BQGG0yGa6/hr89AHm85z9YykrP
DvWsvwpQQSS61Oc/YBQWnw7Uq7/e4x2WIO3nP9jGubo2tqq/GiSb7KsF6D84
49fyi5upvxii4b1bHug/WBBgChOEqL/an3yfLzfoP5gSe7bQb6e/GdtbJidQ
6D9gfnaeyV6mv/ha1eZBaeg/UKewWwJRpb9NQKd0f4LoP+DKhHl/RqS/cJj5
Yt+b6D/gdzd1RT+jv5wyYERhteg/QDLjvVg7or/Md9yqBM/oP4BUZbS9OqG/
DUXfJ8no6D/4LUureD2gvz7ISkyuAuk/wL5+zRuHnr8+X3SosxzpP0Dp7jgD
mpy/cnkmzNg26T/we0Pnr7Oav6x7okYdUek/4M2mCSrUmL9OpqKmgGvpP6CZ
7bN5+5a/zf1begKG6T+wJ3TcpimVv101gE+ioOk/4Pj7W7lek7/fmz+zX7vp
PyDwie24mpG//ApLMjrW6T8g+IlcWruPv1zY1Vgx8ek/QISqOjtPjL8NyZey
RAzqP8CUhzcj8Yi/6AbPynMn6j8AW7XYIKGFvxYYQiy+Quo/IIsLZ0Jfgr+O
2EFhI17qPwCDz9wrV36/kXWr86J56j/A4uF6Ugx4vxhr6mw8leo/wLS3yhPe
cb8yg/pV77DqPwAawuYUmWe/OtdpN7vM6j8AnoaAQl9Xv+7SWpmf6Oo/AAAA
AACA6bzCFliX
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8408964152537173, -0.34831069974900586}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAYmCj1uHz4b9KC1Ty9eTcP4ITlvcQ
9uG/PwpjCkkh3T8w1UG2fvjhv4kyOY6SXd0/LoQtCCv74b8PE9150ZndP/wn
0uEV/uG/ceqCyQTW3T+CIps2PwHiv1UHkXkrEt4/Umbm+KYE4r/fJ6SGRE7e
P3qxBBpNCOK/PdiT7U6K3j/MzDmKMQzivzbQdqtJxt4/wM+8OFQQ4r+rT6e9
MwLfP9RouBO1FOK/7XnHIQw+3z9wKksIVBniv+ivxdXRed8/VtyHAjEe4r//
6ODXg7XfP4rRde1LI+K/iAqtJiHx3z/IQhGzpCjiv/Oei2BUFuA/bK1LPDsu
4r+JIjXTDDTgP+Q2DHEPNOK/02Ypa7lR4D+WFDA4ITrivxPhcahZb+A/SviK
d3BA4r/XTE0L7YzgPwKB5xP9RuK/3NIxFHOq4D9SsAfxxk3ivw4vz0Prx+A/
JmSl8c1U4r+J1RAbVeXgPwTVcvcRXOK/mRYgG7AC4T+3GBvjkmPiv7BBZsX7
H+E/ZqlClFBr4r9Mx46bNz3hPyrxh+lKc+K/tlmJH2Na4T/x2YPAgXviv6gM
jNN9d+E/5GHK9fSD4r+1cxU6h5ThPyQ062SkjOK/hb/u1X6x4T/oRXLoj5Xi
v8nZLSpkzuE/BXjoWbee4r/ifze6NuvhP8g81JEaqOK/OlzBCfYH4j82Qrpn
ubHivz4e1JyhJOI/mCAespO74r/ukM33OEHiP2ENg0apxeK/BLBin7td4j9s
kmz5+c/iv527oRgpeuI/fElfnoXa4r9oSvTogJbiPw+c4QdM5eK/RFohlsKy
4j94h3wHTfDiv1NfT6btzuI/PGW8bYj74r9mUQagAeviP7e3MQr+BuO/0rcx
Cv4G4z/bI1+e
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8408964152536423, 0.34831069974896695}], {}}}}, {}}, {
    {Arrowheads[{{Small, 0.5}}], 
     {RGBColor[0, 0, 1], ArrowBox[LineBox[CompressedData["
1:eJwtiglIkwEAhX9NSRaK5ipx4ZXlmUWKRy3eNDNNk8zssAkmk8ZQMoMUmzUP
aGjk8sC8HQyx1KTUYd73lpu6+7CMZUpWhlpmRtla4IPHx8d7rik3L6SaEwTh
Zep/dueQ7tX/0IPYTjBZFBEsNDlZGx379C7Yc1xJcZYetLw4Sr6wGKtBYX1V
IXq4sJq+dyrKwfSZnUj5o4NB5C2skdVgKde78uOgDrwWn9kMFh9U+ZbGs1AH
wr6r7tWKAMET1n4eUTpweDmnnLKbQRwyC/tgY/qLiwzlO1ohs2UJk9RaJC8m
5NmXtmP92JhvZa0W3NEFsvjxC1wxZobzGFo0pgpZBL0D5NXB6qjDWkQGDvS2
eXRhWaqbHN3QIJtdsDW5LgTv51S6cUgDVUmha/xoN8gDPMetYg0EpNN7Qst6
QHSspfZf1iBgJ32khNGH1l0N8zR3DWyZ+TbHgwbAtDjgyl1To7FCll5nOYS+
s/PtZYNqOC2sFESsDqEx3ZHCeKQGKUYvrHgzDF28YflXkhqRgvVbXNEIqN1O
bQl+arBb3znt7xwFtbX8fZZRhWfnMw7G8sdAd1FZX5er8Hxt/AulZBzSTFqH
nUCF6pcRmvzcCdAsrOOKslT4NtlyhpMmgkxxgiGJVqFobiffji4GQam9oXYx
7fHToQExr2FhFCubN5ToGZh9sEidhHuAp3PElBKKkOwZNz8J0oRL/W0CJZ6o
mbc/OUtBzzdzM7CVIFl8lQbunoJnwtHeuQQlwkkSfyvLaegyNzeajijhdufS
38TNaWxm8mlUkhKrlVl5vsszYNgHmtUvKmDDuWp1MkOGi3YFDdJhBZI5Dvcb
P8vw1movR1yvQGFVyjmkyvEwkWpZylbAn/jt6GCQo3yfeYnXNQX42/wH/eFC
Sw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMBcCjylb0j9QFwKPKVvSvyhaPAWS
fNI/5f/6Ghjg0b98CBaAyJ7SPzmZYk0/ZdG//BCDn8zB0j8XgBh/oOrQvwwT
NgGe5dI/yH9ZCD1w0L+kcqFAPArTP2qXd4Es7M+/hHL49qYv0z+gdVb+WvjO
v9hUMLvdVdM/xgnLMwgFzr8QggEi4HzTP5AD7cw2Es2/ILbova2k0z8m1Whz
6R/Mv9wzKB9GzdM/Yjl4zyIuy7/A/sjTqPbTP1C+2oflPMq/wBqcZ9Ug1D+Q
U85BNEzJv5DSO2TLS9Q/Kt0HoRFcyL8EBA1RinfUP57Kq0eAbMe/lHJAsxGk
1D9KskbWgn3GvyQg1A1h0dQ/XvHF6xuPxb8MrJThd//UP2JQcCVOocS/CLge
rVUu1T86rN4eHLTDv6RT4Oz5XdU/DKT0cYjHwr9wbRobZI7VP9RL2baV28G/
jErir5O/1T/q4++DRvDAv0AEIyGI8dU/dpXQbZ0FwL+IC5/iQCTWP8Bngg46
N76/3LLxZb1X1j/0BlzCj2S8v/S9kBr9i9Y/bApFFUGTur90981t/8DWP6yP
hCFTw7i/zMzYysP21j9YfIP9yvS2v/jvv5pJLdc/MDa+u60ntb88/3JEkGTX
P5BltmoAXLO/3DLELJec1z+Iw+QUyJGxv7wQarZd1dc/cOVVgROSr7/oJQFC
4w7YP8DIiuCUA6y/KMYNLidJ2D/QkHpDHniovyjR/dYohNg/UBO1nbnvpL/Y
fSqX57/YPwCsK9pwaqG/XCvaxmL82D8AySq2m9Cbv+Q3QryZOdk/YGum87TS
lL9w3YjLi3fZPwCEURuCtou/LBTHRji22T+AGtdLTql7v7R6Cn6e9dk/AAAA
AAAA3rwf+Vn6
        "]]], 
      ArrowBox[LineBox[{{0.4056164008015161, 0.}, {0.6605975298376587, 
        5.664226070673724*^-16}}]], ArrowBox[LineBox[CompressedData["
1:eJwtxQss1AEAx/Hzmts1lkdlmFeZZ2plHnXth3RNZMmUxCY7YzfWRYsJHdoy
WidOyLuZac5U+E85HIe7OJz7/++laZcoScOStEiP9d2++zgnXb+YbEij0Tz+
/NfqA4Z8j6tK1P3Xi/bT1kY/A0Ec06Q8V4m8mqTzSJ6Bnr6fJ2tQIpZnc6dp
WYF4i6JG+ZASprwr9FNcBdKs/AwaFpWYr8oq8F6ZBi2zOYjJIGF569KvuK0p
6DO2NluPkPBlTBynm0zBO+Zo31wMiW2jL3I/y0mwCw1c9LkkSlSpmZ8c5eAS
S/0dLSTGArOnXXwm4O3r7siaJCEcmL23yBwHfVdGtm2S+BA9Fewb8RrGdnUp
KicK+XOmzRbxMlDKk+yJcArL4+1neWlShBqbRZVkUbj/gqUuzBuDIiOoy6KF
wpP10c92/FEkOlFm12YoNFzgukY2jyBUKHiXtUvhpvCtg323BMxeh44YHxWY
LRs3iqXD0EbrV34kqGAYoSMq3wyhKd3Wjv1ABcuF1SLWmhiic/OdFYMqPKpU
pNebiJFmfNC5eF2F7ZRC8xP+A3i2p3E+6JAa9qbxw3y2CMZd68n9l9UQMM7s
C654BZuBMtudUjVG+HedoyW9EHyfTN8Vq5GaW7QzvkFgRa4dl2yqEeA30Nfh
1gObtcHHYYc1qE4mOLT4LsTuZoSWsTXIlixYyx4+x8axEe+qOg2CFmMKrMo7
odjLIRJUGnBlJXqBkRDbrgYh7821SCzLOe2Q3YaAMTMftzAt1ix76l+utoA5
s6N2v6sFt91rlstpxlKeZ9XHQS3EUk+iVlELttfsWNK2FjRO69dupQAr/iGi
mkAdxLwou0KiFNlzxROlWTrwrDThkU9vw9daygogdKD9q0nUncPIb/imw29i
r0W3
        "]]], 
      ArrowBox[LineBox[{{0.2868141075672326, 0.28681410756723275`}, {
        0.4671129929832897, 0.4671129929832898}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAyLw8egp+nvXZvwAQ10tO
qXs/vBPHRji22b8Af1EbgraLPwTdiMuLd9m/AGmm87TSlD94N0K8mTnZv6DG
Krab0Js/9CraxmL82L/QqivacGqhP3h9Kpfnv9i/MBK1nbnvpD/M0P3WKITY
v6CPekMeeKg/zMUNLidJ2L+gx4rglAOsP5QlAULjDti/UORVgROSrz9oEGq2
XdXXv/jC5BTIkbE/jDLELJec178QZbZqAFyzP/T+ckSQZNe/qDW+u60ntT+0
77+aSS3Xv9B7g/3K9LY/iMzYysP21r8gj4QhU8O4PzD3zW3/wNa/5AlFFUGT
uj+4vZAa/YvWv2gGXMKPZLw/qLLxZb1X1r88Z4IOOje+P1QLn+JAJNa/MpXQ
bZ0FwD8QBCMhiPHVv6jj74NG8MA/ZErir5O/1b+QS9m2ldvBP0htGhtkjtW/
yqP0cYjHwj+AU+Ds+V3Vv/qr3h4ctMM/6LcerVUu1b8gUHAlTqHEP+yrlOF3
/9S/HvHF6xuPxT8IINQNYdHUvwayRtaCfcY/fHJAsxGk1L9ayqtHgGzHP/AD
DVGKd9S/6NwHoRFcyD+E0jtky0vUv0xTzkE0TMk/tBqcZ9Ug1L8MvtqH5TzK
P7j+yNOo9tO/IDl4zyIuyz/gMygfRs3Tv+LUaHPpH8w/JLbova2k079MA+3M
NhLNPxSCASLgfNO/gAnLMwgFzj/gVDC73VXTv1Z1Vv5a+M4/lHL49qYv078k
l3eBLOzPP7hyoUA8CtO/pH9ZCD1w0D8gEzYBnuXSv/J/GH+g6tA/EBGDn8zB
0r8UmWJNP2XRP5gIFoDIntK/wP/6Ghjg0T9IWjwFknzSvykXAo8pW9I/UBcC
jylb0r/epln8
        "]]], 
      ArrowBox[LineBox[{{0.28681410756722675`, -0.2868141075672285}, {
        0.46711299298329145`, -0.467112992983291}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAoDy0egp+nvXZP4AT10tO
qXu/NBTHRji22T8AgVEbgraLv3jdiMuLd9k/IGqm87TSlL/sN0K8mTnZP+DH
Krab0Ju/ZCvaxmL82D+AqyvacGqhv+R9Kpfnv9g/8BK1nbnvpL840f3WKITY
P4CQekMeeKi/NMYNLidJ2D+QyIrglAOsv/wlAULjDtg/UOVVgROSr7/MEGq2
XdXXP4jD5BTIkbG/9DLELJec1z+gZbZqAFyzv1T/ckSQZNc/SDa+u60ntb8Q
8L+aSS3XP3h8g/3K9La/6MzYysP21j/Qj4QhU8O4v4z3zW3/wNY/oApFFUGT
ur8UvpAa/YvWPzQHXMKPZLy/ALPxZb1X1j8MaIIOOje+v6wLn+JAJNY/opXQ
bZ0FwL9oBCMhiPHVPx7k74NG8MC/uErir5O/1T8MTNm2ldvBv5xtGhtkjtU/
SKT0cYjHwr/UU+Ds+V3VP36s3h4ctMO/OLgerVUu1T+sUHAlTqHEvzyslOF3
/9Q/sPHF6xuPxb9cINQNYdHUP5yyRtaCfca/zHJAsxGk1D/2yqtHgGzHvzwE
DVGKd9Q/jN0HoRFcyL/Q0jtky0vUP/RTzkE0TMm//BqcZ9Ug1D+8vtqH5TzK
vwD/yNOo9tM/1Dl4zyIuy78gNCgfRs3TP5zVaHPpH8y/bLbova2k0z8MBO3M
NhLNv1yCASLgfNM/RgrLMwgFzr8kVTC73VXTPyR2Vv5a+M6/1HL49qYv0z/0
l3eBLOzPv/hyoUA8CtM/EYBZCD1w0L9gEzYBnuXSP2GAGH+g6tC/VBGDn8zB
0j+HmWJNP2XRv9gIFoDIntI/NgD7Ghjg0b+MWjwFknzSP6MXAo8pW9K/kBcC
jylb0j+PaVnt
        "]]], 
      ArrowBox[LineBox[{{6.99702747969524*^-17, 
        0.405616400801516}, {-4.834719367710373*^-16, 0.660597529837657}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwtigss1AEAxk8Y0xid6kbzinkktTSPuhYqTWQkJbGV3ZWJurR2N3mf1Q3L
5THhPG4zu4ZZHv+U4zvv6xzOvSl2iaXSsC5peXS1vu3bb799n3PSvUv0XSQS
ydPQv8zev6vE87octP8kk37bUXRTiIunmpZmynGrKuniafoUBOb7csV1coTk
UnIavsjgZMOul/bLoc+5Zn6KIYM32c+oblGOvkpmnvfyJETp/CCqhQKrD69s
x29MgJe+sd50RAGKxZivuekEli8f7ZmNVWDO+JvUb884XPONXHSZCtxVJT/4
7CiFN7HU29qoQEsga9LFZwxLvh6OoeMKPO+bebJIlUC0LVYI1hVQx0wEH494
C6Ed77bKSYnUWTO+TYIYxfKTtLFwJd5Lms/npo5i09gyupCpxOP2UHV+1ggK
0oM6bBqVqF4b/mpfMgxbJ6XlzSkleFEMt0j+EPTN5R+YO0owWuYcDnQOYvWV
Q2usjwrURv19zugAODG65V+JKphETBMV7/oRlWZnT3uqAmVhhR26KkLyhfm2
MqjQUCFLqzUVgWJy0JmzpoJ1cr7VCf8+xO2unw9yVSPALGGghCaEoH2N3ntV
jU6Lc3uDy96gu5drt1Wkhq6kwDlmsBsBP8fTdkRqcDPZWxI9gWKpVjK4rkac
X19Pq3sXOldQHXZYAxGdSCEldEC/nX6WS9NAMLhgK372EtxjQ96VPA0aFmPz
yKVtSLZOIRJVGujEhbpy4xaUuxmFfLTSQsfNOOPAEkA6bOnjHqbFDXJX7euV
RkhlW2qPAi1ILYdmGCl8sLK8Kj/B8Bd7ETWyGmx4zYwkbRr2O03fO+XlYPmH
CKsCpxHEjrbPJ4pgMssZK2JOg0TRhEe+eAQheTQ0gDD4v8iF1AyL7Lof0/gD
nw9wxg==
        "]]], 
      ArrowBox[LineBox[{{-6.92670381065753*^-16, -0.4056164008015093}, {
        1.0222443204062975`*^-15, -0.660597529837658}}]], 
      ArrowBox[LineBox[{{-0.28681410756723114`, -0.2868141075672295}, \
{-0.4671129929832925, -0.46711299298329434`}}]], 
      ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAlBcCjylb0r+WFwKPKVvSP4xaPAWS
fNK/KgD7Ghjg0T/YCBaAyJ7Sv3uZYk0/ZdE/VBGDn8zB0r9WgBh/oOrQP2AT
NgGe5dK/BoBZCD1w0D/0cqFAPArTv+CXd4Es7M8/1HL49qYv078Qdlb+WvjO
PyBVMLvdVdO/MgrLMwgFzj9YggEi4HzTv/gD7cw2Es0/YLbova2k07+I1Whz
6R/MPyA0KB9GzdO/wjl4zyIuyz/8/sjTqPbTv6y+2oflPMo/+BqcZ9Ug1L/k
U85BNEzJP8TSO2TLS9S/fN0HoRFcyD84BA1RinfUv+jKq0eAbMc/wHJAsxGk
1L+OskbWgn3GP1Ag1A1h0dS/nvHF6xuPxT80rJThd//Uv5xQcCVOocQ/MLge
rVUu1b9urN4eHLTDP8hT4Oz5XdW/PKT0cYjHwj+MbRobZI7Vv/xL2baV28E/
rErir5O/1b8Q5O+DRvDAP1wEIyGI8dW/lpXQbZ0FwD+cC5/iQCTWv/Rngg46
N74/9LLxZb1X1r8cB1zCj2S8PwC+kBr9i9a/iApFFUGTuj+A981t/8DWv7yP
hCFTw7g/2MzYysP21r9gfIP9yvS2PwDwv5pJLde/MDa+u60ntT9E/3JEkGTX
v4hltmoAXLM/4DLELJec179ww+QUyJGxP7gQarZd1de/MOVVgROSrz/kJQFC
4w7Yv2DIiuCUA6w/IMYNLidJ2L9gkHpDHnioPyDR/dYohNi/0BK1nbnvpD/Q
fSqX57/Yv3CrK9pwaqE/TCvaxmL82L+gxyq2m9CbP9Q3QryZOdm/4Gmm87TS
lD9g3YjLi3fZv8CAURuCtos/HBTHRji22b8AE9dLTql7P5x6Cn6e9dm/AAAA
AAAAsLyuDlwJ
        "]]], 
      ArrowBox[LineBox[{{-0.28681410756723236`, 
        0.2868141075672325}, {-0.46711299298329184`, 0.46711299298329}}]], 
      ArrowBox[LineBox[{{-0.4056164008015143, 
        7.166803835241803*^-16}, {-0.6605975298376634, \
-1.6921517786986418`*^-15}}]], ArrowBox[LineBox[CompressedData["
1:eJwtknssFAAAh8+rLqV1qAzjKPPsspJXVx3pIjKSHuKP7Dwy1qUaEzmPLWPr
xJnJ89rNNKQ8bsrjd553cTj3RKOLs67SsCSt0NX6bd++ff//7GJvX4rTJxAI
zjr+mpNh/LDm+zQI/yaimpsL6d58XZNUwaHPH+DabMFoUdo0WNnhVrn8Iki8
/LsrfKZBu1X/rV3KQaDrzHDs7ykQhC78SkklRFku5R+h60bXGWYSF9aTm0qn
/CmwTDuqXy/zYDFsQnEMmsIKO+OsTXoD1A56/gt7dS0sVHMMmtC+L4kfo1BB
oInMMStpgfzYoFt5lQruAxpz0ZNX8N5ODShmqBAYx08iRLdhbRlPg46ooD3R
29Xs2AGxeGpkYF0Ji8y8zZE1Pu79GEvZFijBZOfbRQx0YqOn2HKzSAmq8bn9
fqVvoGldjeu5qsTgjuh+NqMbxbtr52mHlahLyN3r69WLEMNDdgWrCsSXSVKq
jQSoujDfUgoF5haW8+grAuSnWFoxHisgDp7ml73rQ2eEeulnjAJE3tqdAmE/
yJ02zZEUBXyb5mys2wdAbuJ8SNuWgxHGdAjlDoJGlpvcnJQjfnXoixV7CC9T
aW0knhyXW+nK3KxhOBmahBemyfFipPE8K1mITulJxmiwHKdnd3JJ0SJoLKsS
FGQ5nkWM+3mEvIV2SyRrWJchsXfm0SJ1BHs8nGzpYzJk+qRP2FNGEcbX9jTz
ZKApEu9+shWDlqtnr86UodXgq9jTdAzESPeu2UgZtLtGjxONxtGdurFef1SG
wftXtqI2xqFO5dKoxjJwytNy3JYmEGDmqVezKMX77OvEU0wJvEl5teI+KSgs
i+y6zxJ0Ew+wRDVShFfEXjwTNwlmFNWoJFOq+9svSwv1JNIP6rOdb0iR/N9/
AM4WbSI=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQvaOKq27e15v2DFAw5dX/OzlmN+0b9m55FezdaC9g
+m1hbMUNe4ccX1ajlIn2L5pecpTsvm7v4HlavMh6ln3MqWsem/9fs3cw7b6y
cOpC+z9n106Wc71mn7DJ5Ol+yWX2IYbOYju7r9o/cAqY+H/lKvszi51+tF6+
Yv9gftF3H7f19jpKijEdMlfsJ9y4xuD1faP9Dj/++MNpl+0fsH0xSgjcYm/z
4LWE1aZL9g7rpS7HbdxmH6JhNuf9v4v2Fy5N77AW32kvspHh2zOfi/YNGzUe
vm7abR/x6bGu8pwL9hN8NAJTv+y1v2D7qNvv5nn7D6vvzTxnesA+QNir9E3N
OfsP3i2pLiUH7TvctrGqKZ+1Z7iuuaBv6yH7CIVGecYzp+0fqCtcWv7zsP2F
dX0zm8tP2Vd8rS7vcjhqfyDE2H6z6kn7jJu6DIZdx+wfdEtdmHrtuL1ED4TW
gIozhELUGUD1cayHmLMAau4MqD07rkHsPQB1xwaYu6DuXAF19w+oPwSg/iqB
+vPDBoi/DaDhEAANlwJoOB1YBwm3GGg4JkDD9Qo0nAWg4e4BjYcH8yDx8gQW
T46QeMuBxmPCRki8SpyDxLOCCSTeS6Dp4IAbJF0wNEPSSUMWJN1oQNNRw05I
uloDTWeQVPdozwVoOgQAsgdCEw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQPV2cqV8z+pL9AiitzmbFplx00V4nzK71jOkle4el
72sudFyw/8JTqh0mdMk+2sfgerbdeXufhcoyxz9ctD/Dd3T6uqyz9lPm1LyU
v3jRXrvNx7Bw2mn7GP1U2cTNF+1VPi6evfvgSfueG0WW3dOB8kpbLkx9c9z+
h8HLbfNqL9p/3+93hl38mL3I7e1sc1Iv2h+q5e6RdDxi/2BaxcRm/4v227xV
+S9nHbL3qMrdHmp90T6gITzMZsoB+yu+9ReENC/ae30rPb6raq/9DF4bnd0S
F+3Lmt1Ka87stN/Rd1XQn+uivZTe931nZbfZG3gqHDj394J9n4zH+n15m+xV
3CblWn2+YB+QarV0X91a+xlGTh6TXl2w7/IvyK2XX2a/Zdqz0muPL9gzRJ9a
ub9+rn2K4VVh9vsX7Od6HXj9v77Xfk0Fk7nKnQv2YenPjZbmndpjYsf4Rvf2
BftzvmD5/Sug8jNjwPr3w/T7B4DN3w8zXzYNbP9+mP3fIO7brwB1XzXE/ft1
oO6/A/Hf/i1Q/22A+H//FKj/myDhs/8CNHxeQ8Jvvws0/L5Awnf/DWj4ah0A
h/9+AWj4x0HiZ/8XaPxEQuJvfws0/uIg8bvfBxq/vyHxv78DGv99kPSx3wGa
PqIh6Wf/C2j6sYOkr/0a0PS1CZLu9k+Bpj8AzWxF4w==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJw1km9Ik1EUxt8ia/SlQZIlUa9JNT8IatuIXDxDTcZcov35ZiXRog+jRAxH
RbxawXAiSkgZUhtFUVlzzkQROa/ZH9Ncc1vTgcQqCtJBEf5ZX1p1D124HLjc
e89znueXc/LcIftqSZLy/u5/9f/qv7D+8u2lOJSR/vnDFU3UPp+ecxjjMDsO
ZhSd6qBMw7L3mHMWqmUyq774FiWbv2kahmcgGdxRb6eXaidilkA6BrlP/4W2
3CdN8Mn1bQdiUEqqOtIPH1FNYemmIfd7KHfqV2zlPoreLUldi0RRNxuTrCt+
Mu3IqXFtjcKzdrGotrqfxis3nBg7HYHWlx057h+gqsTC5n19YbSHb7iKs4bo
jM7Y/f33NAr8uo8LzcOk80vLX23TMNt01fbFEar7+Tk/tzsE9fGHrqBBpdT+
T+7K+DuoFVftZQ2jpGy0nk9eCiIUy/O0PXtO4+UDGbtyp9C7Ww4/+DVGN+Wm
7aveTsKydLGxxfyStL62riuNEyiI50uFLa9Ic3QPAjvfIOHODnXGXpPcKirU
I+KcnHwP6lPxjlz8Dyz8L6W4D5zcl7QzQgf2si7S2oRODLJu0vSIOWDhuSjE
c2INz0297APK2BfSRoRP0LFvpLCPuMe+krxO+IxM9p1+cA7o4VxI8YicoOfc
SCkVOSIxJXIlOSByholzJ8koOMAL5oIUq+AESb3ghqSzgiM4mCtSRgVnaGXu
iCmcM/0Bve5QfA==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtkl1I01EYxuegCbm+LLJgoqaRI02NxFpzZxWI1cwRtKK8qViQMVvCYMjW
BKkGrSKxDWpJEoZBZVQoS9qzwhrV3zpnOZMsvCgia9AkyCvp43/ei8N7cXg/
nt/zlBw5udep1Wg0xn/vf+0p0F4yHkohIisrdljOKLUprNOZdKXtgn3Te9Y7
8lPY0f/Tx4OcWftKDcmswFFb9fsTlrcsFPXNFAmBicXPI/dax5i9yll4+KHA
5rO2mlPh16xzsn3L+YhA7ezNayNPX7Js9cxQr1+gfs0jfiWTZPqpYV3UKaBP
7FFyC16w8bD3clezwAd/Xmj1tlFm7XAN79sqwHevXfKu9RlTmgI83yjQ1rnf
Ye5JsNAic8XIKoFzvz3Jxx1P2P2L6WXNCwViXQ0enxJj5TuLE2/mOY5vmIuP
FQ4xQ0O3y/SL45OhcTDe9oCFNm5v7P7OkXPM1B8/fZfdCX/1THzmqLe7XYGi
W6ylJr08d5rD2/LqNgLX2Q2vtq7sI0emKfHjT+ACK7fkZCqnOIKz6ZWGacUc
pX/7LvUfB6g/dlDtxwDNdzSr8xGk/SVOdT9W0H1ueR/K6P65SvV+DJA+m9SH
IOk3SP0YJT51kg82Eb+rkh8U4tsn+UJD/Meh8scX8kcn/YGb/JvPqv7BSv4u
kP7CS/73Sv9RQfmokvnAJOXHKPODpZSvPJkv+Ch/fqp/AddZViI=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQPaWKq27e15v7GcDghE3Jq/93csyA/D1bXgV7N+7/
YvJtYWzFjf0O2b6sRikT959peslRsvv6/gPup8WLrGftdzl1zWPz/2v7G0y6
ryycunD/m7NrJ8u5Xtu/YKPJ0/2Sy/Y7GDqL7ey+uv+BY8DE/ytX7d+z2OlH
6+Ur+x/MK/ru47Z+v4KSYkyHzJX9AjeuMXh937h/gx9//OG0y/sd2L4YJQRu
2W/x4LWE1aZL+zesk7oct3Hb/gANsznv/13cb3Bpeoe1+M79IhsZvj3zubj/
wAaNh6+bdu+P+PRYV3nOhf0PvDUCU7/s3X/B9lG3383z+ztW35t5zvTA/ghh
r9I3Nef2T/BuSXUpObh/hts2VjXls/s7rmku6Nt6aH+BQqM845nT+zPUFS4t
/3l4/4t1fTOby0/t//GlurzL4ej+FyHG9ptVT+5/cEOXwbDr2P4f3VIXpl47
vn8ClA64CREvgKpL+ArRVwA15wLU3A/yEHs+QO1VgLrjA9RdF4Qg7nwBdXcA
1B8TfCD+koD6s2AjxN8XNkDC4QI0XHig4RSwHhJub+5DwvECNFxToOG8ARru
FxQh8cCwABIvBdB4YnCGxNsHA0g8NmyCxOscaDw3mELi/ctJaDrwhKSLGlg6
yYGkmyXQdMSwH5KuZGDpDJLu9jhA0yEAw/duVA==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQXS/O1K8ZfWl/ApQWZLNiUy66uP9DqF3rGdNL+/WX
vq+50HFh/xaeUu0woUv77XwMrmfbnd/Ps1BZ5viHi/u38R2dvi7r7P6QOTUv
5S9e3C/d5mNYOO30fgX9VNnEzRf3y3xcPHv3wZP7A24UWXZPv7hfQ2nLhalv
ju8/YvBy27zai/t/7/c7wy5+bP+dW9vZ5qRe3H+2lrtH0vHI/hXTKiY2+1/c
f8Jblf9y1qH9IlW520OtL+7PaggPs5lyYP8c3/oLQpoX93d8Kz2+q2rv/gxe
G53dEhf3H2h2K605s3N/R99VQX+ui/tL9b7vOyu7bT+Dp8KBc38v7P8p47F+
X96m/V9cJ+Vafb6w3z7Naum+urX7M4ycPCa9urC/N6Agt15+2f6Gac9Krz2+
sN8o9tTK/fVz95sYXhVmv39h/zH/A6//1/fur6hgMle5c2F/w/ckgU+77+1h
sWN8o3v7wv7f7mB5+xKofEYkWL89TP8iP7D59jDzo1LA9tunQO3/Iw12n/0H
qPsadcHut//jAXH/mSaw/+xboP7r/wr2v30C1P8f6sHhYw8LHz9I+NnzQMMv
GBK+9kug4dsACX/7G9DwX6sIjh/7PdD4mfMBHH/2PtD4W9IKjl97CWj8WkLi
3z4AGv9HvcHpw54Fmj4+LgGnH/sV0PRzmRWcvuyfQNOXEyTd2YdA0x8AMnZb
iw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlkmtIk1EYx0/BYvQlKUgTyS27zA/CvEwirefNcphbMsugD1ov0cJACGTh
qIipC4YLSUrCGLYRlN3cXjVxmDwzu+Bt7da7DaSWXSgNGjF1fWnV8x44PHA4
5zz/5///Kc9cOGZczxgr/Lf/V2n5nlde2ni1fyWObGJk6biuHfKWMgst5XHk
Wo7KSs72gKNs1dVkjiE7MpvdWnEHTB3f5abxKHIae8TV64LktFgznBGRHyr7
gtvuw635pze3V4voqzL0ZB4+gm/qQ1u99neYuNu6pte6ofleVfpaOILOmMhq
1wSYUyobbXkRTGxIlfD1I9BYt+n01LkwGty54VPCKCQ+LOfsGwphInTbVpHt
BaYqd/z8E8Qbgurjcsc4vPSw1a/6IHr0qnpjagLkvz4VFTgCyJ687/NrfKDe
v2ivi79Fud5qPGyahLHNtRd/XPFjVrTQ2f3sBaSrR2W7C+YxvUcRevB7CgL5
7fnr5mbRtnK5rYt7Bdxgd19n2wya40WsuOs11DSUwvCuaVRfzw30im+At1PF
nBN0Dr4Y3UOFm95BIEX/4ICC/gVO6oMxLfWFkyLpwIEtpAt4HelExQHSDfxj
mgOt0lxg0dGcyAk0N/Ae8gEtki/gC5JP2Jwg38AwSD7iZ8lXSMrIZ2zYQb6D
J0o5YFLKBRT9lBOaiyk34A5SjrjTT7kCEyhntM5Q7uAsJQ4wq5O4AE5LnOBe
DXEDlvPEEY5JXAHzEme4IHEHEoeLlX8Bo1hTuQ==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQrSPO1K8ZfcneH0Lv3xNq13rG9JL9A1YrNuWii/s7
eEq1w4Qu2f9Z8r7mQseF/U8WKMsc/3DR/oa3wfVsu/P7TebUvJS/eNHel+/o
9HVZZ/cz6KfKJm6+aL++1cewcNrp/QY3iiy7pwP5HxbP3n3w5P4lBi+3zau9
aL9DccuFqW+O7z9wazvbnNSL9t37/c6wix/bP2VaxcRm/4v2EbXcPZKOR/Yz
VOVuD7W+aB/srcp/OevQ/h7f+gtCmhftP9aHh9lMObA/hNdGZ7fERftJX0uP
76rau7+i76qgP9dF+9NNbqU1Z3bu/+KhcODc3wv2Vbrf952V3bb/heukXKvP
F+x/SXus35e3aX+KkZPHpFcX7E1SrJbuq1u7v2Has9Jrjy/Y1/kV5NbLL9tv
YXhVmP3+BXvxyFMr99fP3V9TwWSucueCvYv7gdf/63v389gxvtG9fcH+x4YN
M///emTTApVfGgCWt3eA6j8eC9ZvPwFq/rUAsPn2FVD7e9LA9tuzuEHcpyYL
dp+9iCfE/Yv1wO63nwP138dmsP/sG6D+3/sN7H/7PdDwaWkAh4+9BTT8nkPC
z/4MNHxfQMLXnuE2JPylD4DD3/4FNH68lMDxY18DjT+rj+D4s/eBxq91Gzh+
7Tug8X8HEv/2Dgsh6SPVB5w+7N9A04/TUnD6sdcIg6QvFTZw+rKfA01/E6E0
AMbgR5I=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwthwssFAAAhs/NaCav2FHpwSYcOmqNmL+SNetxGNfjRiKiPOaVx6xhnHRr
ZpHbIa+TR5doQuXCOe/oHM4dJ8cdy0qOo1Gx1Pq2b9++o8ExvqFEAoFgs+vf
skjEPBu6COz/5ZOLS+ImRZA1G/pRe0ZhTbHQivMfg0Pf2RUlZRQiihbTcmIM
lezR4JVSIWjv9GWZtHHYnbvHidcVws2EUcyUjoObtuqyvDkC9o5fgEvgBNYt
1d4/p4fxQeZUk6OcQOTjJrIp/yOeRfepYiPFYAkYl71fDIG/LqpSb4ghK9k5
xC0ahJvI/+CejElwwrOXT+YMIJXTVlu/VwLNYtJXdUo/koXrueJiCexoa/Zr
MX2wzeKpGWQpBEvnG50jenHFtk63tV2KAg8FVRjagykq/fst6hTs/LeGu0IF
0NxqqM5UTOFIbMeISUQ3lLfnnIxTphFUeVw6HsOHnjsv19BAhkuEdpp2ahfq
T/XmJ9bK0K+h9eRNTica9UKtXM/NwIBjn/TJsQNPicakgJkZsHwdOy7SebhR
wTwmTvkM+VWL2RXmewxqq/QrSLOQcFxSh7rfQi99J62tZRbhbbSNZWIbJF3m
D5lkOVRlqffDvFrgnmfQSE+Tg0LyVHoUNSNCYvV7YFgO56H4hYJvr6HOkXLH
Ds9B0hMiv+PVhE1CyHZi3BzO6NhuFNJfoUpn0rKhZw6q7CAK6wQXNl9O+6SY
zUM4b966ur8OESWlTeNR86DMPvLiGT4H4xolksefR/qPQAsT0yokG9+sopgq
oBJsbxg5lGPCeymBHK1A56KjoqyGDW2NX1v1AgXSw18mDBgVYqfE8wL3gBKd
dHVTtWse2NfNouzid38x4644PwsqxoMk6yEl0vXHwog+CcjcR40utVwA4R/l
bn8A34ZK7A==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAxm8duTBro7xfmojJS0gIKSrl0EJ56Y8borydl0pZa9JmRtEM
u5WdRFKd145u1TxexnDl/bjv73fXNJGXu0V1oVm6Ws/27LNnz/PPszeOd+7S
NgaDYa/xXwbyTecc5xRI/M8svdTu4hoFvv8KSRI4KRB0Zy2ayVWgMzTALThH
Dkq58LnSSgHrXRM3vEEjIcq9IGhWjnovn/Ss7TTYSflhZg1yrCSqwjY4FPyu
sf0NeHJwbMO40jKCsvNzgbaecpRK7n/Rl8mQJXL3TGDKwXaOd6u3kCFBj/40
OErDxHOm8hl3GlanWWtRj2n4enokG9dN4areUTPDLBq15nm6m/NSPMg7SW+c
oLGcVkxi7aXQWrR4bWBBQ+lR4+ubMgnOuyXj8B8UKltCa+qFExDzfkYMDFNg
yRyzBapxTM7w23gvKTykG20cnMZhFe8ad6aIwlQS7RSePgZRplV+dAqFg1I7
lmXTKDjaIktBKIXxjNSLbHoEdSV2jqbuFCRNrse40cNYqXhUITHX/N4R3Ks/
/R6Xt7TsO7Qp8PoSlS4REhxQO9eTVYKhfWNDZHQQ69dFYo8Zgnn+7wyjkAGU
l66ufxglKJwwV6sG+nHLhaWs7iUQdlRlZAf2oe7VFLNRTPBtv2SrFb0QMtUC
dTPBsiSyu8O7B6LkVlbuc4Irwo/SkvYutOgY3PR+SmBYZYgSbifuLXUaHa4l
6Mg0ZtKRb2EybafiaTLnKw8WwWK0NHEZc5p9j/Uen3T/dsjyHLwqXxCksqq7
Fg+1QXx8K/1uq6ZXbtqEX2iCv6NWovANQcHZTVVpQAPce3aP7OwnGK6Ojel0
eYKVnKFTLRMEJmybARs/PsR6aTFFswR81+YFnSOFKM/VvS1QEzD+ifb5A4GL
b9g=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAfhcCjylb0r9gFwKPKVvSv6wrm5xy
19K/pLQRVE/F0b8WMCIGclXTv/rGQe/kMNG/wjAGiyPV079umtFi753Qv0a6
D9yCVtS//EFrpHMM0L80FYabi9nUv0x88Tnt+M6/lP5UXTle1b+YI/NQ+tvN
v7jcMqeH5NW/FI2xKxjCzL+cbsfwcWzWv0TEhk1Qq8u/xPTSo/P11r+MnP4e
rJfKv0LSVRwIgde/VGiF7TSHyb+ApLioqg3Yv7yaF+vzeci/htD0idab2L/k
VfIt8m/HvzaEvfOGK9m/gOlEsDhpxr9gKqkMt7zZv1hD40/QZcW/7E9b7mFP
2r/wVPnNwWXEvxj5rqWC49q/5HC/zhVpw7/+ZOEyFHnbvyyiL9nUb8K/Kj69
iREQ3L8gALxWB3rBv8w2xpF1qNy/oAEGk7WHwL/ODmUmO0Ldv9CjLXfPMb+/
ugIUF13d3b9QUjG/S1u9v4ChiyfWed6/oFci3++Lu7/wB/APoRffv7CkOXrL
w7m/OID+fLi2379AuFb17QK4v+/BHYiLK+C/2J96dmZJtr9WjxCwW3zgvxgX
ReRDl7S/g9gm/MnN4L8gy3PllOyyvw2I2azTH+G/0MVj4GdJsb8TAWP9dXLh
v2AKKvWVW6+/wArXI67F4b8AhmAwmDOsv0boOlF5GeK/8OIdt/Eaqb+HnJ2x
1G3iv3Dfikm9Eaa/plgwbL3C4r/Q9l4iFRijv5gUX6MwGOO/UMX99RIuoL/4
UOl0K27jv6DnMeOfp5q/KgH7+arE47+gaa10yRKVvyGdRUesG+S/QF7zsaU7
j7/AWRltLHPkv4DpgWrWkYS/GId+dyjL5L8AFdNmAlF0v6gTT26dI+W/AAAA
AAAA2rw9MHGU
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtin0s1HEAh28dOS+zFstwXloRMzLkrdNH0avXvJS3thsXDee8VOSPJm3W
WKwXZsvOSyXpvIZumPM+nDjO4fv73TWGkrk1rUvajdT6bM+ePdvnaKIg4uYB
BoPhuM9fH640X3NeU8H0vwMN0wdKalWo+x2SInRRwfrBdiyTq0JWaIB7UK4S
7ZvrqxW2KhBTeZ6vhIZ/jEfRpRUlbvhwMrIP0thNLgyzaFCiMVkdthNMwfqO
tb+xQAl9+zCu4inB3WtrgfbeSgRLH38xWlxEXIeHN4+pxJJLkns9exHhhvTy
uIwG7bVU8Ya7AKPLrO2YGho63p6pZq/mwTOEhUk2jXTLAgPtZwUKCi7QO+dp
iPklJN5RAe06+4Mxm0a3Z62fX9ocAns3zCJ/ULjVGlpbL5KjVfAzamyKgnLB
OUeonsXcUmW74B2FTLrJzsllFrZJbolXiim0ptAukRkzEGfZFsamUTBWOLCs
mmUI1+2wEoZSKMtMT7CmpyEqdXA296DwpNntLDd2CtryF+VSSwos/aAho4VJ
3N7TcezSpYCR5E3XKCk4mpP1ZIug7vjMBJGNg5XbIfZcIhiu3M00DRlDQ9nW
r48yAr7cUqMeG8VzV9Zm9RDBs66qzJzAEfS+n2c2iQmWT0j32iRDGGZqhJqW
/ZZGD3T5DkKW2sbKf0vAE31SlHb2Y1LP+J7vawKTKhNJKbcPoo0+U6+XBCNZ
Zkw6ugecBQe1YL/53wQSdpAYsmYuY23///2YDSfDvxPaAiefikaCRlZ1/9dT
7VCe28t42EYQodbaRV5vBs9ZJ1nUTeB+VasuC2hAwuCR6UOjBEU18XF9rnVg
501cbJUTzNnYjdmdqcSqIT+ueIWA69myrnf6EXrzDe4LNQSMf+vh/AH3vkYQ

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAlHoKfp712b8AAAAAAIDJPMALbVqK
49m/IDev6Ac7iD/4d8pHsNPZv0AgJcglPpg/PMIWzxDG2b++oFtavjCiP0gt
BGasutm/ZVH87Y9DqD/AQv9ug7HZv43t/CVTV64/5IArOZaq2b/FCJ/A6TWy
P7iuYADlpdm/DSQfPG5AtT8g1yjtb6PZv4jvb78cS7g/lOq+FDej2b/pcRcD
21W7P7wHDnk6pdm/N5wTv45gvj+8arEIeqnZv3Ks3tWOtcA/uAP1nvWv2b/x
y1XBtjrCP7Cz1gOtuNm/8ifL/7G/wz+IMAjsn8PZv6O2nHBzRMU/oI/x+M3Q
2b9/0xv17cjGPwR3tLg24Nm/05j+cBRNyD809S+m2fHZv7Ik0crZ0Mk/dP8E
KbYF2r9RxWbsMFTLP/yVm5XLG9q/GglLwwzXzD+sjigtGTTav6GuMkFgWc4/
WAW0HZ5O2r+fcGxcHtvPP7xxIIJZa9q/FtUoCB2u0D8oYzJiSorav7hn2y5T
btE/3OCYsm+r2r93260lKy7SP8Bv9lTIztq/5Nctc57t0j9QvOoXU/Tav2+w
TqGmrNM/DOkctw4c27/CNqE9PWvUP5CARtv5Rdu/vm2L2Vsp1T94Cz8aE3Lb
v3IbgAr85tU/JEkI91ig278KODZqF6TWP2gL2+HJ0Nu/4zfglqdg1z92tDQ4
ZAPcv+UuYzOmHNg/kFblRCY43L9Sy43nDNjYPzp1HkAOb9y/DSZPYNWS2T8e
Z4JPGqjcv69m7U/5TNo/Ylg0hkjj3L9iOTxucgbbP9bs6OSWIN2/2xTTeDq/
2z9AgfdZA2Ddv3ROQzNLd9w/agtswYuh3b+l+k1nni7dPziYGeUt5d2/F5gZ
5S3l3T917Vrm
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAfBNPbp0j5T8AAAAAAADEPOqGfnco
y+Q/AAzTZgJRdL+UWRltLHPkP0DlgWrWkYS/9pxFR6wb5D/AWfOxpTuPv/4A
+/mqxOM/gGetdMkSlb/MUOl0K27jP4DlMeOfp5q/bhRfozAY4z9AxP31Ei6g
v3tYMGy9wuI/4PVeIhUYo79cnJ2x1G3iP3Deikm9Eaa/G+g6UXkZ4j/w4R23
8Rqpv5UK1yOuxeE/MIVgMJgzrL/oAGP9dXLhP4AJKvWVW6+/4YfZrNMf4T9o
xWPgZ0mxv1jYJvzJzeA/wMpz5ZTssr8pjxCwW3zgP7gWReRDl7S/xMEdiIsr
4D9wn3p2Zkm2v+R//ny4tt8/4LdW9e0CuL+aB/APoRffP0ikOXrLw7m/KKGL
J9Z53j9IVyLf74u7v2QCFBdd3d0/AFIxv0tbvb94DmUmO0LdP3CjLXfPMb+/
dDbGkXWo3D94AQaTtYfAv9Y9vYkRENw/9P+7Vgd6wb+mZOEyFHnbPwiiL9nU
b8K/wviupYLj2j/EcL/OFWnDv5hPW+5hT9o/zFT5zcFlxL8KKqkMt7zZPzBD
40/QZcW/4IO984Yr2T9g6USwOGnGvy7Q9InWm9g/wFXyLfJvx78opLioqg3Y
P5iaF+vzeci/6tFVHAiB1z84aIXtNIfJv2700qPz9dY/aJz+HqyXyr9Gbsfw
cWzWPyDEhk1Qq8u/YNwyp4fk1T/0jLErGMLMvzz+VF05XtU/dCPzUPrbzb/c
FIabi9nUPyR88Tnt+M6/7rkP3IJW1D/sQWukcwzQv2gwBosj1dM/YJrRYu+d
0L++LyIGclXTP+jGQe/kMNG/VCubnHLX0j+UtBFUT8XRvyQXAo8pW9I/UhcC
jylb0r/+rV6c
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAuHoKfp712T8AAAAAAABwvOQLbVqK
49k/mDWv6Ac7iL8YeMpHsNPZP4gfJcglPpi/XMIWzxDG2T9ooFtavjCiv2Qt
BGasutk/DlH87Y9DqL/cQv9ug7HZPz3t/CVTV66//IArOZaq2T+fCJ/A6TWy
v9CuYADlpdk/7CMfPG5Atb881yjtb6PZP2jvb78cS7i/rOq+FDej2T/KcRcD
21W7v9AHDnk6pdk/GpwTv45gvr/QarEIeqnZP2as3tWOtcC/zAP1nvWv2T/n
y1XBtjrCv8Cz1gOtuNk/5yfL/7G/w7+cMAjsn8PZP5y2nHBzRMW/sI/x+M3Q
2T930xv17cjGvxB3tLg24Nk/zpj+cBRNyL9E9S+m2fHZP64k0crZ0Mm/fP8E
KbYF2j9OxWbsMFTLvwSWm5XLG9o/GAlLwwzXzL+4jigtGTTaP6GuMkFgWc6/
XAW0HZ5O2j+icGxcHtvPv8RxIIJZa9o/GNUoCB2u0L8sYzJiSoraP7pn2y5T
btG/5OCYsm+r2j98260lKy7Sv8Rv9lTIzto/6Nctc57t0r9UvOoXU/TaP3Ow
TqGmrNO/EOkctw4c2z/GNqE9PWvUv5SARtv5Rds/xG2L2Vsp1b94Cz8aE3Lb
P3kbgAr85tW/JEkI91ig2z8SODZqF6TWv2QL2+HJ0Ns/7Dfglqdg179ytDQ4
ZAPcP/AuYzOmHNi/kFblRCY43D9ey43nDNjYvzh1HkAOb9w/GiZPYNWS2b8Y
Z4JPGqjcP7pm7U/5TNq/Xlg0hkjj3D9wOTxucgbbv9Ds6OSWIN0/6hTTeDq/
2786gfdZA2DdP4ROQzNLd9y/ZgtswYuh3T+2+k1nni7dvzSYGeUt5d0/KJgZ
5S3l3b/4UFpt
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAphNPbp0j5b8AAAAAAADevBSHfnco
y+S/gAfTZgJRdD+9WRltLHPkvwDjgWrWkYQ/IJ1FR6wb5L/AV/OxpTuPPygB
+/mqxOO/gGatdMkSlT/1UOl0K27jv8DkMeOfp5o/lhRfozAY47/ww/31Ei6g
P6NYMGy9wuK/kPVeIhUYoz+EnJ2x1G3ivzDeikm9EaY/ROg6UXkZ4r/Q4R23
8RqpP74K1yOuxeG/8IRgMJgzrD8RAWP9dXLhv1AJKvWVW68/CojZrNMf4b9g
xWPgZ0mxP4HYJvzJzeC/wMpz5ZTssj9TjxCwW3zgv7gWReRDl7Q/7cEdiIsr
4L+Qn3p2Zkm2PzaA/ny4tt+/ALhW9e0CuD/sB/APoRffv2ikOXrLw7k/fKGL
J9Z53r94VyLf74u7P7gCFBdd3d2/MFIxv0tbvT/MDmUmO0Ldv7CjLXfPMb8/
yjbGkXWo3L+UAQaTtYfAPyw+vYkRENy/HAC8Vgd6wT/+ZOEyFHnbvzCiL9nU
b8I/GPmupYLj2r/0cL/OFWnDP/BPW+5hT9q/AFX5zcFlxD9kKqkMt7zZv2xD
40/QZcU/PIS984Yr2b+Y6USwOGnGP4zQ9InWm9i/CFbyLfJvxz+IpLioqg3Y
v+iaF+vzecg/SNJVHAiB17+EaIXtNIfJP9D00qPz9da/wJz+HqyXyj+obsfw
cWzWv3zEhk1Qq8s/xtwyp4fk1b9UjbErGMLMP6L+VF05XtW/3CPzUPrbzT9C
FYabi9nUv5h88Tnt+M4/WLoP3IJW1L8mQmukcwzQP9QwBosj1dO/nprRYu+d
0D8qMCIGclXTvyjHQe/kMNE/wiubnHLX0r/WtBFUT8XRP5YXAo8pW9K/lhcC
jylb0j/pgV3q
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj3lI03EAxYebtlQkcCjqPKI0RTTx1rRnaZfmUR55EcMzvLaU0PwjlkGU
kkaoSMk8MtPSeTRtlHiiTGc6tTm/v98mhlkmjhBaaoxsUQ8eHz7w/nlHM/hX
s40YDIaboX/5L7UhknLTOyIdQYdfz+ahUw+gNitMrVwnEDo6y5xPN4BTNnOh
d4ngenNa6rBXKxLGreaPTBEwr+i1NeEd4HmwcrreEbhr9c7x18RYOXtQdK+P
oJbdNPrNrx97Qveg+lcE6mOOIUVhA5gV8xgbLwiSvvNHuFFSeKlctfznBNKb
1kw68T3atoY5AQZnNVqOVPOGITtkcTvYsE/tWlVWD4xCltfHLu8kIPLEscHg
cYwydSJdj8FPyA/6RiYgfbPM7JYSVA42CkoiJvHYi73dNEGQs2Sn08qm0Faz
s/dBQTDU8FvAiZaBVSqR+q8RPD2+MEMU0wjUnWwnOwTBkznbXglyCA5YboPG
FJiHoybMVbPQ1z2rk9tRqBJ7n+GlzKGj2tXDxpfCQ0FBugM9jzhjib0ohoK5
0pVtL1YYfjlVpORT6MqlPeOLFsDN9M6IrKRQQHc7u3suQrHW0M9/TYGoPEpE
2kVI+D8TZHMUsntjWtq7lhAxtGUd/4OC1L8lNDT/I/Sb3LcWXBqSwiqS5qaE
UHie3j9H44ad0FT/RYksM9haFtMwCvTPs25bhvkl9m5yMw06YK3+JU+FODP6
07SCxqpnpk87dwXpEt/ALKYaUfJHX81XVlCWtBHhEqiGiUssT/mEwOGWQ5gF
X43OHG3s/mUKjNyKWNsONdKCQoqKTWhEJPvev7iuhoqzVBY8QmNwe/NzvZMG
gphwn6hSNZzu7qYweRq0/orOFXlqEGlWMFbVogGnwWbDY0MDq//8A4ZOQy0=

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwth3ssFAAAh6/7A5m88jhFiU1xHkfWEm1FVtbaYSgdkmfyzCNzs8I8uyKL
MU7IWxJNXHL7hfOOzuHceR53tlSe5zbyWFp927dv3xm/SNdAIoFAMD70b//B
s4s7To0oMVxCkuJYENElFpL0J/HnhiRIkiQ/5OemIttTJ9w05vA9pc1VtjnY
ZDpebzgpgW/wu9gB9XzsEnZ36jlilC1ZiktritDvvBxLjhDjCmdfpm5ehlCN
exUUkhgimY+BJqkC9DuUMHbXIl7OPXNiq1XDi1nSPB6+CP1FvbaNE3XQ/X7J
JUFnEc5pvpTC8w0oUJw0bOxZQNNRE1k+7T1+EPz346IXkNnjLwp2asZShrBh
7PQCBIMxS3m/PsBLYLQ3MCyCQMtR4lDQAosc1SZaogi1pfTHQU6tGOzUy2SQ
RSCxPGQrRBbWnx4kslrnkVRpQx/q/oR6+XWVcu15ZN42mF9jfIZdOeMsP2EO
N1wtcZPGBp2ooe09OwtWhVn8N0sgWznQyNZ+Fswjcq8+ZnzB8wu9uXG1M9An
dHjI0zuxepmdpaY6A9M3FsLxyC5wAhasNBKmsR6FEc2Qbki2G6tSxFPYc9sZ
7gzkgEWlrd6nTiHAQUzlBvbA3KROqa1DiLzla00XQ3qhkMqWppOF2HPfNNuM
7MNd7lYWv1gAbpH2T2lCP9wqWbX1xwQIe5C2Yp0xABLPXVcheRK1zINTDQWD
eL3Fq5DK+AjgpN9yfjsEekTf+qMwPqxfNJNJXV9ROGNVkyGZAMtQ6vx7ehjR
B27eNj4TiErcsFnZHoGWZnoxQzgOZfvQyhglLszbVWZSPMaRWjTqt1bCRTVF
jmE4MQbVvqtrEsooDiwM5KLdx9DeouZG7RlFIbmYGT3JQ6I2MceYxkPY//4B
Y0xzHw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtin0s1HEAh60j52VmUcKRNsxNuCGOTikqJay8dF7+uFFn83ZiRWZ2yZoh
WhujdChJ5e2ErMyHjHnL23Xc9/e7a2co5FZaF5olrZ7ts2ef7TkcL7p0dY+O
jg57d3/9j5EeXo5hnkRLwPduXdY/VogUo9SYogWCXDuHYYfjlajPGj3bJiNY
q42N6eU8xrf+A5OmQwR1F7c1ZQGN2D6iK2x6QyDXbDuEX25B9qmdtNtSgu/M
mr6Vo+2oFTv7VLwgCLA/xEvz70R2i0Bn6SnBwFcRWMHdWJ510oieELAzLBh0
5FvErfaae+/+vGozlAp6UaBvctN3t69q+igv7exDSZKUmfOcgDUe2d/l+w6F
DK1E20pg6zS2I8UACl7NMpq7CWRd1emZgYMQcJhrNQMEUpm1VjM8hNyy9c33
UwQGVb/TzUOGob7R0e2lJvhiPz1KpkZwUOvWQNYJSgaFa5yIMfB3dNldehSi
DIIHjOfGsVj+sHzMmoK6xf2kIHoC1aVOLpaeFObTU+Js6UkE6nXYSEIpcOVO
TJuWKbRds8uPTqZAJdKu4WnTYCW4x58vovCIbnZwdp2BQl3ZLnpJgalwyZRo
ZtAn+hkxPEGhvC20rqFJhoieVYvwHxRWver8/JI/wHSF9dqERWM5tZjEsuWo
FJ+ht07TeGAtNtz+JIfY6ISVWQYNT65XkkX9LDjnmBv8WhomXHXFM8Ecso3o
+ZEpGvvcEjwaWAoUdnhyrzCUEI/d/WysUKAxainQkasEzzFMIL9PEHHd1t9E
pIRSqAnbukDBNzE/zKpRiXs+vLSMvTTy+Z53ghaUMN4vy/YFjc215cUKOxUa
QgM8grOUEN7aiGYIVJj9FZIocVWhwiilv7hOhaBKyyWXJRWE//0H3xFvZw==

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtiQssFAAAhq9boxl5xA6lxCYcOmqNrP5F1qzVYUjdSEToMK/szCqGS7dm
6jzmMa+TRxJNXOXmvOnQORzHyZ07jUoeh6FY1+rfvn379p8MifUJIxIIBBs1
f/1v/Hb6EWpMqeUCCDpj4UTvREizHiZbC5TgL6RFiXMzwLxpEm2XoO5bquZq
1xx8K/G40nBUCfOI14mDBnnYIPzaqe9RIPiro6KspgjdXkuJ5BgFmnr2Ng0c
yhFueLuKYqz+t4IsjIyrkBRAofO65qE399STp/8SASWlzePR8yifN2tbM60D
afG8N8NkHsLMYErhmQawtSYtG3vlMNey3cyjvcEiIXQvKV4OYW+o7J5nMxRM
ScPYCTmsBQkL7B9vQZuy+j04LAOF5KF0L2gBJUeviZYqw2pZyoNwz1YIOs2e
sMgyRHD9N5eJXGw92k/lts5ByHFJEXS/R6Pmqm4FSd03LOZWWB/hVsE6JWZ8
QaGPY8dVGg+PiYakwNlZ6HHskz87dqDwcJiVq9sshg5ovHjH5CP/XF9uUq0U
XoR2f82UTuxe4GXr60kRXHlaMh7bBdFduZMhYwbmcR0jRpHdWN1urE5XTMPO
b2e4M6wHA1TazzvUabDdFVRhWC8u2tZpt7VLwF+63OQc2QfTDJ4qiyyBtf+6
/XpsP+jCjWxx8RQOFpO+qxgDiOJwa+t1psCJyFw+yxyEk8jv2KG0SchK9o83
FHwCd0NUpdoUo7wn65rXKwHYMf2rcXQx6M+aycZdQ2iVOtUwlRPYsFR57c4M
4/m+b6BL0ARqU9dclrdH4GyUVcySjMPO7T4nQVuI6x90pen+46gsGg1ZKRVi
iKLBspwYg0P/pRUlZRRWFAuNeL8xTLfo+1J7R8EnF5fET4pQRCLm2NBEyP/v
PzmaSro=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAlBcCjylb0r+YFwKPKVvSP9a0EVRP
xdG/wCubnHLX0j8qx0Hv5DDRvyYwIgZyVdM/nprRYu+d0L/OMAaLI9XTPypC
a6RzDNC/UroP3IJW1D+ofPE57fjOvzgVhpuL2dQ/7CPzUPrbzb+U/lRdOV7V
P2yNsSsYwsy/uNwyp4fk1T+YxIZNUKvLv5hux/BxbNY/3Jz+HqyXyr+89NKj
8/XWP6hohe00h8m/MtJVHAiB1z8Imxfr83nIv26kuKiqDdg/LFbyLfJvx79w
0PSJ1pvYP8TpRLA4aca/HoS984Yr2T+YQ+NP0GXFv0YqqQy3vNk/MFX5zcFl
xL/MT1vuYU/aPyRxv84VacO/9viupYLj2j9koi/Z1G/Cv9Zk4TIUeds/UAC8
Vgd6wb/+Pb2JERDcP9ABBpO1h8C/nDbGkXWo3D8gpC13zzG/v5oOZSY7Qt0/
qFIxv0tbvb+CAhQXXd3dP/BXIt/vi7u/RKGLJ9Z53j/opDl6y8O5v7IH8A+h
F98/gLhW9e0CuL/4f/58uLbfPwigenZmSba/zcEdiIsr4D9IF0XkQ5e0vzKP
ELBbfOA/SMtz5ZTssr9e2Cb8yc3gP/DFY+BnSbG/54fZrNMf4T+ACir1lVuv
v+oAY/11cuE/EIZgMJgzrL+XCtcjrsXhP9DiHbfxGqm/Gug6UXkZ4j9g34pJ
vRGmv1qcnbHUbeI/sPZeIhUYo793WDBsvcLiPxDF/fUSLqC/aRRfozAY4z/g
5jHjn6eav8ZQ6XQrbuM/4GitdMkSlb/2APv5qsTjP0Bc87GlO4+/7ZxFR6wb
5D+A54Fq1pGEv4lZGW0sc+Q/ABHTZgJRdL/fhn53KMvkPwAAAAAAALC8bhNP
bp0j5T9fH19W
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAM5gZ5S3l3T8qmBnlLeXdv8H6TWee
Lt0/WgtswYuh3b+OTkMzS3fcPy6B91kDYN2/9RTTeDq/2z/A7OjkliDdv3o5
PG5yBts/Slg0hkjj3L/FZu1P+UzaPwRngk8aqNy/IyZPYNWS2T8idR5ADm/c
v2fLjecM2Ng/dlblRCY43L/5LmMzphzYP1a0NDhkA9y/9Dfglqdg1z9IC9vh
ydDbvxo4NmoXpNY/BEkI91ig27+CG4AK/ObVP1QLPxoTctu/zG2L2Vsp1T9s
gEbb+UXbv842oT09a9Q/5Ogctw4c2796sE6hpqzTPyy86hdT9Nq/7tctc57t
0j+Ub/ZUyM7av4LbrSUrLtI/sOCYsm+r2r/AZ9suU27RP/hiMmJKitq/HtUo
CB2u0D+QcSCCWWvav6xwbFwe288/JAW0HZ5O2r+srjJBYFnOP3iOKC0ZNNq/
IAlLwwzXzD/IlZuVyxvav1bFZuwwVMs/PP8EKbYF2r+0JNHK2dDJPwD1L6bZ
8dm/0pj+cBRNyD/IdrS4NuDZv3rTG/XtyMY/ZI/x+M3Q2b+dtpxwc0TFP0ww
COyfw9m/6ifL/7G/wz9ws9YDrbjZv+XLVcG2OsI/dAP1nvWv2b9jrN7VjrXA
P3xqsQh6qdm/EpwTv45gvj90Bw55OqXZv7pxFwPbVbs/TOq+FDej2b9Y72+/
HEu4P9zWKO1vo9m/2iMfPG5AtT9srmAA5aXZv4kIn8DpNbI/lIArOZaq2b8D
7fwlU1euP3BC/26Dsdm/x1D87Y9DqD/0LARmrLrZvxagW1q+MKI/6MEWzxDG
2b/cHiXIJT6YP6R3ykew09m/IDSv6Ac7iD9oC21aiuPZvwAAAAAAgMm8PHoK
fp712b8oIFo+
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMBcCjylb0j9QFwKPKVvSv3S0EVRP
xdE/fCubnHLX0r/MxkHv5DDRP+YvIgZyVdO/RJrRYu+d0D+SMAaLI9XTv9JB
a6RzDNA/FroP3IJW1L8AfPE57fjOPwIVhpuL2dS/SCPzUPrbzT9g/lRdOV7V
v8yMsSsYwsw/htwyp4fk1b8ExIZNUKvLP2hux/BxbNa/TJz+HqyXyj+Q9NKj
8/XWvxxohe00h8k/DNJVHAiB17+Emhfr83nIP0qkuKiqDdi/sFXyLfJvxz9K
0PSJ1pvYv0zpRLA4acY//oO984Yr2b8oQ+NP0GXFPyQqqQy3vNm/yFT5zcFl
xD+yT1vuYU/av7xwv84VacM/2viupYLj2r8Ioi/Z1G/CP7xk4TIUedu//P+7
Vgd6wT/sPb2JERDcv4ABBpO1h8A/iDbGkXWo3L+Qoy13zzG/P4oOZSY7Qt2/
GFIxv0tbvT90AhQXXd3dv3BXIt/vi7s/OKGLJ9Z53r9wpDl6y8O5P6YH8A+h
F9+/GLhW9e0CuD/uf/58uLbfv7CfenZmSbY/ycEdiIsr4L/wFkXkQ5e0Py2P
ELBbfOC/+Mpz5ZTssj9c2Cb8yc3gv6jFY+BnSbE/44fZrNMf4b8QCir1lVuv
P+oAY/11cuG/0IVgMJgzrD+XCtcjrsXhv7DiHbfxGqk/Gug6UXkZ4r8w34pJ
vRGmP1qcnbHUbeK/oPZeIhUYoz94WDBsvcLivxDF/fUSLqA/aRRfozAY479A
5zHjn6eaP8hQ6XQrbuO/QGmtdMkSlT/6APv5qsTjv4Bd87GlO48/8JxFR6wb
5L/A6IFq1pGEP41ZGW0sc+S/gBPTZgJRdD/ihn53KMvkvwAAAAAAANI8cxNP
bp0j5b+FHF2P
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAOZgZ5S3l3b8YmBnlLeXdP8b6TWee
Lt2/SgtswYuh3T+UTkMzS3fcvyKB91kDYN0/+hTTeDq/27+27OjkliDdP345
PG5yBtu/Qlg0hkjj3D/JZu1P+UzavwBngk8aqNw/JyZPYNWS2b8edR5ADm/c
P2nLjecM2Ni/dlblRCY43D/8LmMzphzYv1i0NDhkA9w/9jfglqdg179MC9vh
ydDbPxw4NmoXpNa/DEkI91ig2z+EG4AK/ObVv2ALPxoTcts/zm2L2Vsp1b98
gEbb+UXbP9A2oT09a9S/+Ogctw4c2z98sE6hpqzTv0C86hdT9No/7tctc57t
0r+sb/ZUyM7aP4LbrSUrLtK/zOCYsm+r2j/AZ9suU27RvxhjMmJKito/HNUo
CB2u0L+wcSCCWWvaP6pwbFwe28+/SAW0HZ5O2j+nrjJBYFnOv6SOKC0ZNNo/
HglLwwzXzL/0lZuVyxvaP1LFZuwwVMu/bP8EKbYF2j+wJNHK2dDJvzT1L6bZ
8dk/0Zj+cBRNyL/8drS4NuDZP3jTG/XtyMa/oI/x+M3Q2T+atpxwc0TFv4ww
COyfw9k/5ifL/7G/w7+ws9YDrbjZP+PLVcG2OsK/vAP1nvWv2T9irN7VjrXA
v8RqsQh6qdk/DpwTv45gvr/EBw55OqXZP79xFwPbVbu/oOq+FDej2T9X72+/
HEu4vzDXKO1vo9k/2iMfPG5Atb/IrmAA5aXZP4oIn8DpNbK/9IArOZaq2T8R
7fwlU1euv9RC/26Dsdk/2FD87Y9DqL9cLQRmrLrZPzqgW1q+MKK/UMIWzxDG
2T8YHyXIJT6YvxB4ykew09k/iDSv6Ac7iL/cC21aiuPZPwAAAAAAgMA8tHoK
fp712T+u1ltU
        "]]]}, 
     {RGBColor[1, 0, 0], ArrowBox[LineBox[CompressedData["
1:eJwdxX0s1HEAx/HzGJtxhj+4RERqaR7CXPgYaxaLQ90pj3lorHOplWI3TJSn
9MehsPM0YZ7ylHTiMHFRUWE385Dy/f1OmiFkztLDe3vtfTT6RlCcKoPBOPHX
vwsNAgRiSwLG/4bd7GAY9sSJwDM8VEPtkwB2V7UWZ3wIoqznPe/3pSGT01wa
eoVg3SyWV/77ASY9jthaJRJwUqqnKVEhCipYro4ZBA0rQVUeeiIcY6qFZYsI
4rnX9lgTJfDgzjiw6glClrW97+WWgeK4Xd6SEMjVk6I8PSrQe5CZwJwgyPJr
a2zbqcJ2XvW+4BuB0Pi9eex4DbjB7Ea9XQLDJGN7e3EtFrXEWps6FAxZ+zm6
/DrwZLJmIwsKF2/Ry5suDciD4GSqC4V3kznMaUYjnOQbBmYXKGT1/aKaRppQ
t5K4pxZDIezNcpAgtwUr612JNikUhBoyf4Pzz5EzEbyf/5iCScfDTVlmG+TM
IsfTdRQi3KyfJkW2o8MprVK3j0K3XrutkN2BZ5pzY6emKHyYl3Nog06k/2Aj
Z5XCjH5tfctqJ+wC1rLM1Wh4Hc7+MjbYha09fcttExoOoqQOdskLDOYXVGo4
0og+/nNuN74bUwv66YF+NGb5PjYq7Je4k2d1Th5DI/Xu9bgA7R6MhJreLhXS
8Pd1FizO9KBq1vJRUTGNfuNEq5aaV+B/ZjPfttJYiJQnd/ElWKfchc4yGkND
IbyNM73YMyP+c0s01saVw5HKXpDCUXWJkobmTeaoUvoa5Hu48YSRAmv8s4LB
zD7ouGocYtkpYJGQP9Xs3Q/1FBUfsa8CX3cKTCWqUkTwMgIvxSmQxotIJlIp
hKRc7JWhwEHuUl6x+wCU3PDq2HIF0ttZFd5lAygZln6UdCuQ0qpiotwewB/+
CETG
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwlj30s1HEcxw2ZeZozFhLztHXnIUTrIh8shU6WHZbZrfM0DxmZNBH5A5Np
3E5DGvNQLNOtWSrNh1axHSlPKd8vv9/d4ZxZhGweO+uP99577b299347JmZH
p+jq6OhwtTp2fr3NosciRev/DrYPenhevHl071f90JukcNFij8Rnz2PWhxCP
/CEKSY+aGrp753Gz2hnKZBT2zNMOnHfn0dFCmOzdQmFo8U47wgL+ERWt36+h
kFNkySsuW8BIjr1vYikF45adMyL5AtbJJEXLuRSWR6tOvzJkMNLJyNI4hcKg
x1LRgBuDRp6VwWNxFCpj1cXkOoOlHHWY5zUKvT3t2Ya5DOq5fs/wBArm/kuN
wXUMmtagauwcBRu+r6DiLYNis8N1Ey6F9v7pr7NzDIZ/7viyak9hJmw6y++I
wVjus4YMKwqCAv28JicW07aeNFaaUMisP3IzvcKinztnJ0yfwqdQb6Y8nUUf
vvBn5z6B2ydnfhlWs6gxzU3r2iYQcUknVSJj8ZsodCTiN4EA16dypykWJZoc
m+oVAocO2THvdlicnRAV5KgIjBi4RsacUqD0RJDu9gIBCRu+vx2owIk3xnJb
QoBUR3c3JirQYLV4mZ0lsJfS/DykXIGbHLu0iBkCo+oS37UuBZq+5sULpwj0
i883N4wpMN+lb/hogoBF7d7ZqxtaFkv6BFrOF+p6bVsqsYXe8PDX8sOoQnXr
BSWm3oviyrWcKa1vjUpQYvTdrs79SQIvBbUvdkuUOC4N6RifJlAo7ghqa1Ni
Hvej1WXtHh8Xx76wYSWuCqRrN+cIJPy9JdRolJjsoLHjaP+UbkyJK8xUKLV+
X5OuJFD1WJ/r4KPCgPRBnyT1cb9kUxajwsCskpWDNQIDcWAcUKDNPYPq+VsE
/gHesGU5
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwdznss1AEAB/DzjGac5A+OiGlqNBLq8syaFXkuj5Arj524i9XsaiZT6jxS
yyvsvGannUfe6Ty+ZxmXtIuwW7vI8nuU1o6IOauuvtt3333++x6+diMqTZfB
YBzV9t+KLcL5IkcCjP9ZHonzP5hY46k1N8FAb46PmKtGy4vBWrt8Crg3mg9x
REdtwmUCMofU2PrfD6D2O+TqxCMQkNe8QFaUQ9LAOu1RQMBtLarJz6wCgUy9
xKIKAurY9F2WohrxMYsnWG1aE8ZBguI6MCJ94jelBAoMszkBfg2Y+1OYwVQQ
4IZ2S7p/NWF/afMe/wsBjvU7+9S3LciIZkvMdrR/cqzc3UWtUBuJjDZMSDBs
9oSmWWKky+Udlg4kIm5Sqxvez1Hjzz92x5uEfFbIXGBIEKhct7C7SEI4tk22
T7aj+ytvVy+FBGdyNYpf3Il1dT/P+TaJJ4byMIvzL1CuiN4rfUyio/fhhryw
GypmpcdxMQna58iz7OQeDHjmN5qOkghl9rjmsXshNlRNu8yT4C4pIyiLPuR/
Z/sL10gIDrS2da71wSX8x317PQq0TdHn6fF+qHfNHbesKagqsnvZ1QMYLi1r
NPCgYOL8U7XDHcTMkvndyBAKQl6wsw77JTJLnM4pUyi4CDLTwo2HIE2wvVWb
R0E/xIu/vDiEpx8dH1VWURBY85w6W14h8QOb+aaLQitHmdufJcUy6ZvnJadQ
9joudv3kMGg7Iky1QmFkRjORrBnG+/IpfamGgjKHOaXBCBTfkqwUljRkvDP8
8cJRbJ0y2Mdyo6F/vXS+I2gMawKdYNEFGhPbZbZSXSAotiDyUhoNbtyVXAIA
h6gXnS2gkVuyUlLlK8NSTFJzaj2NnR5WQ1CdDLkTmJUO0tjs0rHWbMnwF5cN
bZU=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAxiXDItuJzEsKu9aR12gkPVgJeSmRsqKuGJpO1oy6zmphal4X
HWnMS7EMWw2VpdpKm04rL5Hv1/1ezntEuiwv6dr649lnn3+ePY+NWBIRr62l
pSXS5B8FcvMxxzEKk/90eqH6srGPQud6s72L/SgyOv0d019TeBivkBjJKPQK
7JDdSiG5XVne9HQUfsaRF1yrKbYKEtfslkdhGSedv1pEMTd2ua4LStwUWLuL
b1A0SU3sZdlK9LWWSCfSKKKrl3bF9ight91kYhBPYaq4s61Fn0GsU56fIpri
l+O49KUDA04wGeh0hKL7xKSMhDFIEX5KdgLF7+Y6iX4ag1tFXSrFHooz3uMV
fqUMeKM/84Yiikte7iG5HQyG39a/m7Gm2NA50Ds0wmBB9KA82ZRiX9BAisc6
AyN1WUWeIUVHps6VSlsWU7sFS4E6FEr5usPmABaLXpHDDasECHBlcpJYtBml
JTaqCebMBr/q57N4HHfoffB3gn4frYSSVhaZM6nm+VMECuH9Htt+Fh/6YjNT
VQRlOyRRz5ZY3NP11VYrCRL1hKFRlhzYdoMeC0LgyQWtqg9wsPsmm2CHCPIK
IpoqxByst1glBg8StCRUPfTP4XD4iX1MZD9B7lSW+2wjh05he/f6ZwKZeG9V
uYKDQlzSHqLxkeIV58MLHHSVxxy9NR4Qpe2iNuExnBEu6tF49NFrkzWePAbT
GxtW+wgCS+U14ad5iMv86z8OEBSGFj9azuJh5vDG9KBmT4K43re2lkdl2N3Z
UyMEdkKb9sBuHjttpq0Emj/Hl85GTk/ziLd4XpTEa/b86D+Xa6SC9cVXbucn
NX2FOqLtbio4S7Km1mYJ2kJLFlujVPBx8ZV7/SToPQmD/Zkq/AUxhVGL
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMpgZ5S3l3T8pmBnlLeXdvyN9riow
Kt4/R7vk1wPT3b9TEvvcWm/eP5S8Qi12wd2/jYqcmay03j8ljiM/hbDdvzQR
aP0j+t4/XxJUZDGg3b8M5nGkvz/fPzxffPB6kN2/ynwUKn6F3z+kER40YoHd
v3Wg9yhey98/9rCSfOdy3b8kzYsdrwjgP7wiChQLZd2/BC7mfL4r4D+FLolB
zVfdv9VW6H7cTuA/CxLoSC5L3b8Ir6RvCHLgP5gl0WouP92/bDvmmkGV4D+w
kL/kzTPdv305NEyHuOA/EA/+8Awp3b8QvNXO2NvgPwfGpcbrHt2/SUnVbTX/
4D8gKp2ZahXdv8Z5BHScIuE/QPWWmokM3b/tmP8rDUbhPxstEfdIBN2/TUYx
4IZp4T8mOlTZqPzcv/wX1toIjeE/6w5yaKn13L/iPQBmkrDhP+FfRchK79y/
2yWbyyLU4T+y63AZjencv6Mgb1W59+E/BtReeXDk3L91ByVNVRviP9EGQAL1
39y/ReJJ/PU+4j8duAvLGtzcv5aOUqyaYuI/Yux+5+HY3L+8Zp+mQobiP10T
HGhK1ty/lOl/NO2p4j+IsypaVNTcv4piNp+ZzeI//yW3x//S3L/okfsvR/Hi
PxBjkrdM0ty/UlUCMPUU4z9K31EtO9Lcv2NQe+iiOOM/IHlPKcvS3L9UlZii
T1zjPx53qaj809y/mk2Rp/p/4z+slkKlz9Xcv3FipUCjo+M/YCvCFUTY3L8u
JSG3SMfjP+lOlO1Z29y/XfdgVOrq4z9zIeocEd/cv4ny1GGHDuQ/tBq6kGnj
3L+ZjwQpHzLkP25rwDJj6Ny/v02S87BV5D+Ab3/p/e3cv9hYPws8eeQ/jzBA
mDn03L86dGNo
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAwbxsE09unSPlP4BcWwUD
0m6/ID8UXJc15T+AJt1Ag71+vyBhCN/WR+U/ICBkV5v+hr9yUKyZW1rlP4B5
odXmk46/wD4eLSVt5T/Q6VKgPg+Tv3ueGzkzgOU/oFZm+hvPlr8UEANchZPl
P6DkCUN4iZq/LVbWMhun5T8gBXBgQD6ev9ZQPFn0uuU/uEuwqrD2oL+q/4Jp
EM/lP7gZzSBky6K/5Yqh/G7j5T9IcBkxMZ2kv0ZTOqoP+OU/WBv8iA5spr/O
CJ0I8gzmP5hy5+TyN6i/SMjIrBUi5j8g0YgQ1QCqv3k/bip6N+Y/yL335qvG
q78l2PETH03mP7DF5FJuia2/l+lt+gNj5j/QBchOE0mvv9rwtG0oeeY/TLKH
8siCsL95z1P8i4/mP4w8JphwX7G/yBCUMy6m5j/sD7EtfDqyv6I1fp8OveY/
CN7YUOcTs7+WBtzKLNTmPxASpKet67O/b+w6P4jr5j+AHIXgysG0vyBP7oQg
A+c/dJNwsjqWtb/l+hEj9RrnP6Qn89z4aLa/souMnwUz5z8gbUcoATq3v8Te
EX9RS+c/xHdrZU8JuL9miiVF2GPnP5hKNm7f1ri/t1sddJl85z8MGm0lraK5
v5HaI42Ulec/MGDYdrRsur9d0zoQya7nPxjDWFfxNLu/4eY9fDbI5z9EzPvE
X/u7v+wf5U7c4ec/YHEQx/u/vL/XjscEuvvnP0htO27Bgr2/1+pdGc8V6D+E
aYvUrEO+v/44BQcbMOg/QPeMHboCv7/2eAFHnUroP+RXXnblv7+/UFeAUVVl
6D80iuGKlT3Av27lm51CgOg/tLEbnkOawL/uVl2hZJvoP66uARr79cC/iMS/
0bq26D8K2FZe
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj30s1HEAxiVvQ5qLGUledisnQnqRysvymrfsrmINXRhandQsEivDZN5u
MaQxL8VmsdV2xDzVFtpNTV7L93t+9/ud9yzKzea1a+uPZ5999vzzPHZiSVSi
tpaWlqMm/+hfbTnjPEOR9J/xPaqJvSMUwkevBa4CBdp6/ZwzPlA84W2SGIkC
p0sdvPM7Kbqe1tW0v1XgDk+Y4NZAEWuavO2woUBgXPZKVjmF++zdZnhPo93U
xkP8mGI520yQkz+NzU5p9lw6RVXD+tFY+TT67A3NjBIpPIaKD3UYMMhzKfId
ukrBc5nN7nNioMubD3K5RMFemc8h4QxK+cOpLt4UZh3NEoN0Bk3lUA2doMjw
mq31rWSwZ//OirEjRYGnR2hhF4O1Ty39SzYUFr1jXyanGBgKXtSkmlNEBo/d
PrnLgK+uqi0yppBn6tyvs1di55jpepAOxWr1rtO+ACX0zgq/t24RRAa4MQUp
SgyapCe3qQl2LMZ/GJQo0R3nPxjyi4A7r5Uk7VSiYCnNsmSBYIr/XG4/qsTE
SGxmmoqg0VYi6l5Xol7PR1s9TXBPnx8mOshiTmYktyIEfmzwlvoCiyM/c+aU
kwTS0qj2WjELuwPWySHjBLKk+pd+BSyC3ghihKMEpQu5HsttLHr4soHdbwR5
4lP1NUMsPoulslCNMxWbxwNXWewqLjt7aTxYpO2qNuMw/CDCUa7x6MiH841n
OMgz2lq3RjR9ZXVjxHUOoiq/lq9jBGVhFa82cjnoO300v6jZkyBu8Wlq4lAc
/mw5eorAlm8nCxrgwLNbtDbV/IlYjxcuLnKIsHpXnsIRZP0evVFoooLurffu
N+cJisp0HA+7q2AuyV3YXiboCJP+6RSpYOvqU+25RtB/zdvoXKYKfwGBYnpl

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAACA0jx1E09unSPlv8BhWwUD
0m4/KT8UXJc15b8gKd1Ag71+PyhhCN/WR+W/UCFkV5v+hj96UKyZW1rlv7B6
odXmk44/xj4eLSVt5b9o6lKgPg+TP4KeGzkzgOW/SFdm+hvPlj8aEANchZPl
vyjlCUN4iZo/M1bWMhun5b+4BXBgQD6eP9pQPFn0uuW/BEywqrD2oD+v/4Jp
EM/lvwQazSBky6I/6Yqh/G7j5b+ccBkxMZ2kP0hTOqoP+OW/nBv8iA5spj/S
CJ0I8gzmv+Ry5+TyN6g/SsjIrBUi5r9k0YgQ1QCqP3w/bip6N+a/FL735qvG
qz8n2PETH03mv/zF5FJuia0/mOlt+gNj5r8cBshOE0mvP9rwtG0oeea/crKH
8siCsD95z1P8i4/mv7I8JphwX7E/yBCUMy6m5r8WELEtfDqyP6I1fp8Ovea/
Lt7YUOcTsz+UBtzKLNTmvz4SpKet67M/buw6P4jr5r+qHIXgysG0Px5P7oQg
A+e/npNwsjqWtT/j+hEj9Rrnv8on89z4aLY/r4uMnwUz579GbUcoATq3P8Le
EX9RS+e/6ndrZU8JuD9iiiVF2GPnv8JKNm7f1rg/s1sddJl8578yGm0lraK5
P4zaI42Ulee/WmDYdrRsuj9Y0zoQya7nv0LDWFfxNLs/3OY9fDbI579uzPvE
X/u7P+Yf5U7c4ee/hnEQx/u/vD/QjscEuvvnv25tO27Bgr0/0OpdGc8V6L+u
aYvUrEO+P/c4BQcbMOi/aveMHboCvz/ueAFHnUrovxZYXnblv78/SFeAUVVl
6L9LiuGKlT3AP2blm51CgOi/ybEbnkOawD/kVl2hZJvov8euARr79cA/fsS/
0bq26L9j8Fan
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtznss1AEAB/AfaToZsbPKvBq2WpOzXViT752WnGko/lBKxN3ybktksl95
hLaiLK/inEfzSByd68L9GtHcwjVTiDt33CGrS57LTtfWd/vuu89/3yMxKRfi
jAmCOGbovxVnmmVXr0+C+B/+rMyG+2AKBDff9iAvFcwNwU7y4WkQRcsB02Ek
6nmVfHGLwd97rLXXC9DskpXi5/sNZFR08kVGMVp35BP75QbrG8MLXUvh4K45
Q4+dAXHgXmCJVTlc9P3OlzdnQJolR/PWqkCyvdWKolkQpvZi05EalG7Lf9Q6
KEDKxae8RmvxVaUS8oUKsFb652XCOkhNqE9JzkqQ2ukNaUkDik+wzZqSDB4L
emKV+BJZgv4BI7ES1EOTmT52E2wqt4TpxnMg2kuNBq1b4OB4q8js/ByoCKa7
q6IVv8NfEZKyOcPf9xVTjW2gfdQP56nmoKxU+awy21HQ1lid5KaCkuWd70Tv
wK7PEONmhgpEoZyzqeuA7wrXs7hfBZK13pwmE+Lsh9TYYQs1SH+/0cq6Tpxr
7UpxvGQwt3027k4XJlu05o8b1OAzSvZMBL0Bg1WvO/RLjWsjxfHL9iJkCuJH
e3zmQU6I/AQrIkTQa69kFsyDb8/r3RF3g3e8NDh0fB5OeTEW2/fFWLVLj2A7
LYA1OJTwLPAtOmix7oGJBp+mW4xbSlDDicxLEC+Aeu3C6PgswVp3gGWDiQZO
1p6Wbk/f4eTuNrkRogErULPsH9qDsIWjj6JeaED9ZO7Vm/dCV3Z7WbGkgZKW
Kwgd7EXtViIn3VMLQlZOY9/tQ9pS9lXXHC0ozvMcmYcU0RX7ZpZGteB72UXq
1FJoxoIzBuwWoRvOS/3CodDrm6vuurGIkM5ojxw+haoBqVwiWgTZZmT7Z53C
X9wpSuA=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAfBNPbp0j5T8AAAAAAIDEPMrTqssY
KuU/oAvFORoTfj+64QwsnTHlP5xK3opiC44/wQVB/Sk65T8s8As0LoKWPwjJ
+5i+Q+U/VHZ9v6v5nT/HF+dEWk7lP/iCFlfMtaI/bGmwMvxZ5T+m+18Zsmum
P3xtGICjZuU/GgGM+z4eqj/6OwQ3T3TlPzpCpRMrza0/BgiQTf6C5T/zeCNf
F7ywP09TI6avkuU/yQ0HUoGPsj/CoIYPYqPlP8aYgt+vYLQ/4qT6RBS15T/I
tQSwfy+2P/DxUO7Ex+U/RsYUms37tz8eHgagctvlP8DT/qR2xbk/rmFd2xvw
5T+SvXsLWIy7PwurfQ6/BeY/pH5VPk9QvT+GJpCUWhzmP3hXB+c5Eb8/dTfg
tewz5j/W1Cz1emfAP0bg/KdzTOY/+qh8tbBEwT/2ltuN7WXmPzsnBWYtIMI/
SYP8d1iA5j+fv9pZ4PnCPwgkkGSym+Y/mafYBrnRwz9gWJ4/+bfmPySK4gan
p8Q/bMou4yrV5j8JeyMZmnvFP+O3chdF8+Y/HRVKI4JNxj+qFfCSRRLnP12r
wTJPHcc/Fguu+iky5z82deh98erHP3bBYuLvUuc/ZJ5CZVm2yD9WhKLMlHTn
P/0iqnR3f8k/HS8QKxaX5z+oYHtkPEbKPwvkjl5xuuc/N0a+GpkKyz8XCXW3
o97nP9UKTKx+zMs/pYbAdaoD6D/XVvFd3ovMPyFETMmCKeg/t8eMpalIzT+B
3gbSKVDoP8u5KSvSAs4/apQqoJx36D8dQhfKSbrOP9hjdjTYn+g/FUP7kQJv
zz/OVGiA2cjoP6rD8GN3ENA/yOx4Zp3y6D/oZqNzAGjQP0bGV7ogHek/oNmP
0RW+0D/FKURd
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwdyXss1AEAB/CfaHKZ11hlXg2bZl7NZO1md9rkbpqIP0J5hFucR1s6GfqV
R1grV5Zn4oSJ7Bxx6fj+jNjcOBejvI477rhZXS2vJbr6bt9999n3bEJGeNIx
giDO6ftv63Jo+fXbX0H8zxQ9d1lqk/x4HkRCse0pTiYsdgQH6WcWQJRogxci
SJCcmgZxu95aiZXmVgkKXXIzAgMWQcTGp1/zLkfxgXz2pHwR5GFLZKlrBXY8
1ZesE5dAWDxk8y2rcPhn2Dl6dwkkLT2e86sWEUx/laJsGYSxvdh48jWS9+Xf
Gh0UIOXiixdkjehQKkUNIgUYW8NrUlETWo2oiTTnFVCahR3wm8HzZNLa0vSe
CnluyW1FomB4xEC8AsYTo6VBZhsOqvdEvGOrYAgrDEat2mHoeLeMdmUVZJSv
l6uiA18i3xH9lfr/aKh6vqUT38cOx4uUetcq6T99heB2ttSneSjBYPoXO1l3
QUUf876TrQRZKmft6rrgvJXsVz6sBMHcfpslFcHtU2biuJkKK0GBspqmbrh3
9GQ4RqlAcITLSfd7IGnXmD5r1tuHbzgb8h6WjDe60z9UoCbLU7T2vYgWpMgk
9DUQc72Bgq1e+Fs33sgpWQPDgTNwIO7DZfeK0LCZNVBFCWb7j8SYtuNdZzqt
gxgbS33J/gC+SaIXm6t3gLXZjHk/8lgxRanidcQJXby7Pvdjui/YvNlIDcrK
z9zjxUfYHO2TO1fVWGGrtUFhEpxfd3sa+0qNOJ3v8UPTAUxU3tMqNtVooBUK
wkYH8GCPy+L5aUBJq0yYeYMI38y/6VqgAcmuK5D6AAHVJ5Y2ZXr728XoVMDQ
VGj2iN0G4qRFmXMsClUBhaqe2xuguuN9ChooZI1A3t+7AV2nge3vbQp/AdP0
cQI=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwVxQss1AEAx/FLnHKqK29iclY7RMkmzTSiVTuPVF6b6DwrZXmPcJ1miZBM
UmQedzqJzDHCz/v9VpvHdnns/0gqj9risPLdPvse44e7BykwGAzuf7sXqbne
L+QQYOxWLGtenZQMapsQYLO7bXTVkjA3r2pWeJpAHE/2lM/KBKlkv809R+D3
CsvKXJgHk355fusFAssxiajcKAStRTn6uBCwTNH0HJKWIP12jeWWN4EBuZ9O
7V0RCu5pC0qDCZjtyZDbGUigaato7RpF4KxDuZrpcBWM9mU77wgJ0HEcP63m
GoRe44iqcwjUHVB2f5RVi5ni1EP8UgKSfOHXav86/C3bdFSXEiiTKtYkW9RD
cc3tZ1cvAe0e9YJheQNOGTCLI2YJPJncKYvpbkTrLd9ZvRUCHi0JLK+MT9Cp
TDwIJRL+STfsXN1a8OJ4dq7PURLmnsqUzWFAYD0nXT5Douqz2Z/4kDa4zG2J
I3kkhiseSmsc27GdN/vsRxAJ1gml4JOGHXBJ2Yr1EpAIw4z33EYHVI2zA2tf
kwgQTzEbxzvB9yo6v9FAYiltgSkWdyFswHzR5AuJ0XiOTkFCN+YbIrSc1knI
1K9whM49EGms5DgdoaBX2W7pqt8LNuvDJteSwnoUnbi61Iuwdv7CL3cKhkUO
Qd71feA9LhnKjaJQbySJik3uB9uCbar5koKff0Kg7cUBbC1m3nzQROG7U6vu
K5VBMPdHN5TKKKSp8N4nDQ0iJ7UtWrKXRprHqq8sfQiqjrx+IZdGSG9G+btL
w7gjY05w3WgkNHJNJxRGcDXXpPhNLI1Be62By00jaA6IsZp6S6PbQf5cIXwU
H6+HCqb7aAg6VwJi2WOoWI4LLlyj0RZcGskIHYNxj2eTof43xExnjWu0juEf
67dtdQ==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAkhcCjylb0r+YFwKPKVvSP/JzB1Gj
8NK/qAzNrNmT0j9WyA4c5IXTvwhJ8R0fzdI/EkXrWusa1L+QBjGp+QbTP+Ce
qXi4r9S/uHi5FGlB0z/ao5DgSkTVv7gGIyZtfNM/ENAh/qHY1b/YhXGiBbjT
P/7hGT29bNa/OHQUTjL00z+ubnEJnADXv6A05+zyMNQ/uHVdzz2U179YSjFC
R27UP/T0T/uhJ9i/CJamEC+s1D/we/j5x7rYv/CSZxqq6tQ/NL9EOK9N2b+g
lAEhuCnVPz4rYSNX4Nm/oAVv5Vhp1T9Ad7kov3LavzCmFyiMqdU/pDf5teYE
27/4y9CoUerVP0RwDDnNltu/MKLdJqkr1j+AJiAgcijcvyhq72CSbdY/5PKi
2dS53L/YvCUVDbDWP6ySRdT0St2/cMwOARnz1j8Ueft+0dvdv+imp+G1Ntc/
OGD7SGps3r/weFxz43rXP9DZv6G+/N6/cNEIcqG/1z+w3wf5zYzfv8Dl95jv
BNg/8rFr30sO4L9A1uSizUrYP1Lwu7ENVuC/gPP6STuR2D/4c7wrrJ3gv0AE
1kc42Ng/eFnYBSfl4L+Yi4JVxB/ZP4hYnvh9LOG/8A9+K99n2T9mC8G8sHPh
v5hit4GIsNk/GjYXC7+64b+g544PwPnZP5INnJyoAeK/iN7Wi4VD2j+sfm8q
bUjiv2Cr06zYjdo/+HTWbQyP4r+AIDwoudjaP34hOyCG1eK/wMg5syYk2z8+
QS372RvjvzgyaQIhcNs/lGNiuAdi47/AOdrJp7zbP4YwthEPqOO/oFYQvboJ
3D/SrirB7+3jvzjnAo9ZV9w/7onogKkz5L/QfR3yg6XcP8pXPws8eeS/UC5A
mDn03D/XM2ZZ
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAOZgZ5S3l3b8YmBnlLeXdPxkP7/Bo
Q96/3ByjPUiZ3T/jKCQd76Lev2IR2gYFT90/47/SJ7kD379rnx3laQbdP66U
eba/Zd+/p72UXHy/3D/+U4tW+8jfv/HlwtBBetw/Grj/PrIW4L96Rh+Evzbc
P9Fh8sV5SeC/onWul/r02z8m+Hpk0Hzgv2awngr4tNs/A7kXNLKw4L/pqua5
vHbbP7ars0Mb5eC/fvrmX0062z8cS/OXBxrhv2ggDpSu/9o/qveBK3NP4b88
PH/K5MbaP2QrYO9ZheG/xGy7U/SP2j/taTLLt7vhv+XlTVzhWto/j+aQnYjy
4b/0wXrsryfaP0faVzzIKeK/oJTw52P22T+wg/h0cmHiv2TFfA0Bx9k/pcrK
DIOZ4r9Lt8L2ipnZP26BX8H10eK/ecP1FwVu2T8qPdNIxgrjv+wLlr9yRNk/
QL8hUvBD479tKzAW1xzZP2DpeYVvfeO/qscfHjX32D/jNZKEP7fjvxsKVbOP
09g/5q396lvx478sBB2L6bHYP99WgU7AK+S/2gLtM0WS2D8QEWo/aGbkv8jV
MBWldNg/UuDiSE+h5L+bDRxvC1nYP8OYS/Fw3OS/IzV+Wno/2D+m6I+6yBfl
v6MImsjzJ9g/3rh+IlJT5b9Trv+CeRLYP2/dIaMIj+W//PJpKw3/1z9ODxaz
58rlv1eNnjuw7dc/zijjxeoG5r+KalEFZN7XPwieVEwNQ+a/BAYLsinR1z9t
KtK0Sn/mv5XOEUMCxtc/2ay4a5675r+UmlaR7rzXP2Irs9sD+Oa/cCxkTe+1
1z8T+BNudjTnvxfJUf8Esdc/4O8ti/Fw57/74LgGMK7XPwHNrZpwree/wcyt
mnCt1z9qcW7R
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMBcCjylb0j9QFwKPKVvSv6BzB1Gj
8NI/aAzNrNmT0r8YyA4c5IXTP+BI8R0fzdK/5kTrWusa1D9wBjGp+QbTv8ae
qXi4r9Q/qHi5FGlB07/Qo5DgSkTVP8AGIyZtfNO/GtAh/qHY1T/ohXGiBbjT
vxriGT29bNY/WHQUTjL007/abnEJnADXP9A05+zyMNS/+nVdzz2U1z+YSjFC
R27Uv0T1T/uhJ9g/WJamEC+s1L9QfPj5x7rYP1CTZxqq6tS/qL9EOK9N2T8Y
lQEhuCnVv8QrYSNX4Nk/IAZv5Vhp1b/Yd7kov3LaP8CmFyiMqdW/SDj5teYE
2z+gzNCoUerVvwBxDDnNlts/4KLdJqkr1r9QJyAgcijcP/Bq72CSbda/wPOi
2dS53D+ovSUVDbDWv5yTRdT0St0/WM0OARnz1r8Yevt+0dvdP9inp+G1Nte/
SGH7SGps3j/weVxz43rXv/Tav6G+/N4/iNIIcqG/17/k4Af5zYzfP/Dm95jv
BNi/lLJr30sO4D941+SizUrYv/zwu7ENVuA/yPT6STuR2L+odLwrrJ3gP6AF
1kc42Ni/MlrYBSfl4D8IjYJVxB/Zv0xZnvh9LOE/eBF+K99n2b8yDMG8sHPh
Pyhkt4GIsNm/7DYXC7+64T9A6Y4PwPnZv24OnJyoAeI/OODWi4VD2r+Of28q
bUjiPyCt06zYjdq/5HXWbQyP4j9QIjwoudjav3IiOyCG1eI/qMo5syYk2782
Qi372RvjPzg0aQIhcNu/lmRiuAdi4z/IO9rJp7zbv5AxthEPqOM/wFgQvboJ
3L/kryrB7+3jP2jpAo9ZV9y/CIvogKkz5D8YgB3yg6Xcv+xYPws8eeQ/oDBA
mDn03L85SWPR
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMpgZ5S3l3T8qmBnlLeXdvxcP7/Bo
Q94/7hyjPUiZ3b/oKCQd76LeP3QR2gYFT92/7b/SJ7kD3z9+nx3laQbdv7+U
eba/Zd8/ur2UXHy/3L8UVItW+8jfPwXmwtBBety/KLj/PrIW4D+PRh+Evzbc
v+Jh8sV5SeA/uHWul/r02786+Hpk0HzgP3+wngr4tNu/GrkXNLKw4D8Bq+a5
vHbbv9Crs0Mb5eA/mfrmX0062786S/OXBxrhP4UgDpSu/9q/yveBK3NP4T9a
PH/K5Mbav4crYO9ZheE/5Wy7U/SP2r8TajLLt7vhPwfmTVzhWtq/uOaQnYjy
4T8awnrsryfav3PaVzzIKeI/yJTw52P22b/eg/h0cmHiP47FfA0Bx9m/18rK
DIOZ4j93t8L2ipnZv6OBX8H10eI/qMP1FwVu2b9jPdNIxgrjPx8Mlr9yRNm/
er8hUvBD4z+lKzAW1xzZv57peYVvfeM/5ccfHjX32L8kNpKEP7fjP1oKVbOP
09i/Kq796lvx4z9wBB2L6bHYvyZXgU7AK+Q/IgPtM0WS2L9ZEWo/aGbkPxPW
MBWldNi/nuDiSE+h5D/qDRxvC1nYvxOZS/Fw3OQ/eDV+Wno/2L/46I+6yBfl
P/wImsjzJ9i/Mrl+IlJT5T+xrv+CeRLYv8fdIaMIj+U/X/NpKw3/17+oDxaz
58rlP7+Nnjuw7de/KynjxeoG5j/4alEFZN7Xv2eeVEwNQ+Y/eAYLsinR17/O
KtK0Sn/mPw/PEUMCxte/Pa24a5675j8Um1aR7rzXv8grs9sD+OY/9yxkTe+1
1797+BNudjTnP6PJUf8Esde/S/Ati/Fw5z+M4bgGMK7Xv27NrZpwrec/XM2t
mnCt179qGWv/
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtjnss1AEAx4/lMOe1aR6xDuURiTQj2ldiuFbRVo5qi2keeZ7LMOl6aDaK
KPOHNCru2m2uWnVEx9bWY93SPX+/u8PvHupQc7jqLq2lrT8++/zx+ecTXFR9
/JwjjUaL3OSf+3wdOyNPydD/3yKGVEj2yODCdc69b5GBmb0atF0qA++tR6Cp
VQ4RPU5gp8uRlbFcsBygANUw5lN2UI6we4IG8agCFnpoWGWzHDEPuihWuhJ+
12uHnMRycGaC/wwSSnRxfY7utcpRZfA/MFmhgm3fl69rsQrEVNe69tPUmGLF
pWVWKcCqP/PxwG01eL3DXnuECnR/P7YxGE6gtKck4NGSAgPNNvubcQKxdxyC
xZFKWCTpiaNHSCTSqxfYZUrQowtD8ygSxLBvRIdg86NhLELC0YD/YYafu6RE
R6L92ectWliGZsMEUSqk1DKSpL1a2MpXznZXqnAtnMnkROggmty51V2kgnV9
iFSM6cCWejj4r6sw05OhsLJmQY2M6J8lqJHetNHySTsLc+PpOmOTGtzCjazy
ijnwZC6cQYkagVrJ4KvfcyA+/+xb2UKAoXe2SzvmUao2DUlZBIafnJ8/7EFB
bP2VnXxrs6++fOx+kkKbkyozkSAwzp2IEt6lYO64cuL1dhKpBYRT+AKFHO+W
qPkSEuz8AdvFaD1oxS8ut4lIpDCmJ0R1evgt3vScspP4keDrJhnXw4tStbce
0oDr0d/PdzDAIpQLiRsa9F6q3lWZZQAzJCVijNDAfEFVyeg0oOZ90tOwHVrU
hyQzrysNsMWXOQbXaLE/bfcGuc2IrmTNu5EJLfqKi8TORUbw2F6T4646dMU9
9/bkG8FcdOzMz9PBNLpreuWbETOXgtauPtSB3m7mCeJNyIlN7Uuy6mBmwy2l
0YS/NB5NQA==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtxXss1AEAB3DPY16FYskjrQ0dzYS2om/tqikkFPPYJKdQQ5LGPBK21q2R
KZ2GIWurOY+TR7QrzXuaR/b73Yt7/e46o/N2I12P9cdnH9cbGRHJBnp6eh5/
/N3m5QHKixJj3/8Jx6bAILYYO1aa5RTGHOKsBTTjMDEm3I84aRrnkFzvRKXS
xPjGm3brNZxHw8eq+HyeCG+qcrt4yfNYpAYmz+aJ8DOSFbUzMo8HF1xKef4i
OPfoTnfYSVB/n1O9vS4EP3F1MPeiBMy2OjNtpxA+2jzmZL4E398qe/tzhLDt
tfftaJOgaFuZEHpSiNF3XMZBSoK0Q1ZVHJ0AvsFr1SYOUpwJKBpTDAkwuFVM
vxcmxfidvsj1cgFK6Nc1MWVSaKjQeGmsAHvTfMa7+6TQG8hbbHUToEtZUft4
VYrWqmVV0iYfdwXRASMeMuQM5lvqD/MxV6LNzkqUIaF7YPMJmw9ibMyihC1D
xZcNe+N0Pl4XJ3zemJLBxOIFL+scH8zAmaAhMzlYdG87wpGPAp5rxDJDjolh
F2e/LRKN6tyyjAI5GGbXuOUzJNz9K0vRLUeMkRNL3U7iGGd3IW5FDgvDpePn
K0l4Rhdf/kRXYHfWe39zNokE6zSk3FRg1tIxwzyGRLNEFhTWoECSX2FsHkg4
sINXMkUKqE1rRtbcSOiryz+M2FOo5ege5dqQCOgtPBwRSSFkLZVuqSMwJXZt
Mi2n0PK07lTbEgHuHjuuaoyCKi3cmDlH4ISHfHCBpsQtmnmHxxSB7LqrIZYM
JX59tWYYDBEQHZ3uvFSkhOGrqGc/+gmEtPTcrutTQu3JDNW8J0DQuUJDrRLP
R8N1Ru0EWFrb9BxfFYqkPTRvDoH4ZS/WSqYKVyZaajJbCDz8twq/ARfEWeA=

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtjWlIkwEAhnV44jXBMC1xS9PpCjVD5kVaWmpUGJWzA5YZonkfpGG6DkPK
1LJEwmRq6SYjV2FN094JQSaO1s7v26bu0kQLTRc5jcigHw/Pj+eFl55TcvIy
xc7OLmyLf+b6UlrCzsnB+e9Wd6mQbJNjssI5s3dFDpf0HwGBUjkSJjx3WhoU
aHWKEticFKCkLp1d8ldCUj3sk5+swEyXoFo8qITMKSikqFYBU2+rISNFhfWG
sh5HsQLBMvqfbkIFTqXP8X1WBWgmv8SxQjVk+79+W41UQltc5tppp0FHRtTB
I8VKrFZd+Jz4SAN2ex81QqhE3M8Tm92hBNLa8vwHFpVIql23fRwh4PLYni4O
U6EZKazBYyRcnErm2PkqPGNeDMoykOD3+TKaBCqIrg4zUK4Fd0rGz1xUgcay
Dc076CDpmQ4RMNWYKnWPlbbrMFGwzHlYpIZPKI1WztCDO7Z7m4dIjdtrPaRy
WA+a1NPeb02NU22pSmvGNHj9/cahGA2majbrvuimIao5X2G+psE6ZzOtoHAG
LLlLeTc04GnR/f73DHjzvzqWHQg0Gpxt0qZZ0DSWHmkGgdxXV2aPehpQbd1I
j39AYGLl3UuPMwYkOaqPsAgClZWjTOFTA3hNN09/CCSxkU04hs4ZQPWuY87m
kaBmd61f32OE5NLbG40iEla38VFRhRETC81eEhuJgRhfN4wYIZ5V32s4pEW4
Z2cn394EnlAhJO5rcbi+JLwozQQZPYExTGjxpEpd5N5iwvbJ2NchwToE74qn
3VFt7aPzKfRSHRaS926SO8yIjNd+6h/VISU3R+ycYwaDTR0bcdUjLuqNtxff
vPVPacnO0qN5MHx8+bsZpfUBq7ee6/Hi7gJXEG3BSkRSR6x1q7MPuCXUWPAX
/9p2pg==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtyX0s1AEAxnF5uQqXyXIj16XadC6jwh9esnYxL8m8jzQJDRkm2e7mZUJr
WbsyS6c5K6utmQtHXNgj5qVrLS/N7165199hyXm/sXap9cezz559Pe8UJ+Ra
W1lZMQ/21/CXbgYfgwq5/7Wnt4dG8lWIcloz5bEXwHOWU+ziVKAxz9HX3iyA
30Y35FNUcBuZ9RLbLOLHcFNGBZRYauJ8RO4iGOTo9FWuEsFJDSn7U4t4H8Go
Q+DBH7Bc6XFVY/aBsHlvS4GtrI1xTpQazV0Ce3OvAtFmbs50hRruHaR4qFwB
ppjm39OlRvcemRkbpMBCh4h90qBG6+ljTUKLHBExm82H3TUoDamW6CfkmN+t
Yd2P02C/cDBxiydHI+v2Wlq9BnQyNkOTLodHwaWv/YMa+I5yf37wkmOEfNb6
eEMDZZPJmL0jA1eeGjLF1KJ9vIJ6aFIGfa25rDRLi4b+0Z0nfBmUEoljLV+L
wbFtml2RDO9qMj9vz2hx0fEFSq/JkBs6Fzlhr0Mfy8+V8JChAp4JJrYOm5OM
UwG7UrQtc+qLK3XIt08W8eakOBvYWBfWr0OlLb1huVuK88LfKzfXdfC1Wb0c
3njQU2tujLD0YMz7nXhbJkWyc0FY3l09dqgexQ5pUvDV2si413rUBFSlc8Ok
oPJj1kuUetgebZna9JLCtMT7NEUzoF9oecg5LoW3uOpMQqIB2Zv5LKqFwLDK
s/0Iz4Cxp4LgrlUCrU6uIqPEgP2CeLucBQIMpm58hUKCQ3HoYc4QSBckXaey
STh9d2ZbTxAY8Z7tja4m4fIq5fmvIQK+nQP3BIMkti/kxK71ERCzRAobMwnB
l3iLbTeBQrNLUbm/EY80AxQ/IYEgk0/DeokRid86W0o6Cdz6pxF/AF/Lf+A=

        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAAAC0egp+nvXZPwBmhhoX
Z3C/mN7LFWaH2j8AiupI21SAvyz2ovxuGds/AOu8EudjiL+cZ5qguKvbPwBg
YW5TMJC/oiR8b0I+3D8A/6ZViSWUv6L80dYL0dw/gBCBSpERmL8WL+ZDFGTd
PwALbmFn9Ju/Gv7DI1v33T+ABx24B86fv3JBOOPfit4/wNG4OjfPob+G+dHu
oR7fP4Dsw+TLsqO/zOLisqCy3z8A6Nv2v5Glv7kEwM1tI+A/wNBMkhFsp7+J
LkEKqW3gP0CMBN2+Qam/daLDxAG44D9AsJQBxhKrvw+a+LJ3AuE/QFo0LyXf
rL8YH3SKCk3hP0D/wZnapq6/7FWtALqX4T8gm+I88jSwvwHI/sqF4uE/QEE4
hiAUsb+ArqaebS3iP0CJ0Un38LG/+TzHMHF44j/AQPWqdcuyvzfsZjaQw+I/
wEZCz5qjs789xXBkyg7jP+BmsN5lebS/Pqy0bx9a4z/AMJED1ky1v9Gr5wyP
peM/oM6Qauodtr8oQKTwGPHjP+DWtkKi7La/cqJqz7w85D8gHme9/Li3v04U
oV16iOQ/gIViDvmCuL9eK5RPUdTkP8DGx2uWSrm/6hx3WUEg5T/APRQO1A+6
v6gJZC9KbOU/ILAkMLHSur+TSVyFa7jlP2ASNg8tk7u/6rdID6UE5j+ASubq
RlG8vyv/+YD2UOY/IPA0Bf4Mvb9L5SiOX53mP0AKhKJRxr2/5pd26t/p5j+A
y5gJQX2+v5f4bEl3Nuc/IEqcg8sxv79q6X5eJYPnPyA4HFzw47+/V5kI3enP
5z8gy4Vw10nAv9zQT3jEHOg/gLNhMYOgwL+xPoTjtGnoP8CuARr79cC/kMS/
0bq26D8aHFtD
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAACAwbxsE09unSPlP0ALxTka
E36/udOqyxgq5T9cSt6KYguOv6nhDCydMeU/EPALNC6Clr+xBUH9KTrlPzR2
fb+r+Z2/+Mj7mL5D5T/oghZXzLWiv7YX50RaTuU/lPtfGbJrpr9aabAy/Fnl
PwYBjPs+Hqq/a20YgKNm5T8mQqUTK82tv+k7BDdPdOU/5ngjXxe8sL/2B5BN
/oLlP74NB1KBj7K/PlMjpq+S5T+8mILfr2C0v7Gghg9io+U/vLUEsH8vtr/R
pPpEFLXlPzrGFJrN+7e/4PFQ7sTH5T+y0/6kdsW5vwweBqBy2+U/hr17C1iM
u7+cYV3bG/DlP5h+VT5PUL2/+qp9Dr8F5j9uVwfnORG/v3QmkJRaHOY/z9Qs
9XpnwL9jN+C17DPmP/OofLWwRMG/NOD8p3NM5j81JwVmLSDCv+SW243tZeY/
mb/aWeD5wr82g/x3WIDmP5Kn2Aa50cO/9iOQZLKb5j8diuIGp6fEv05Ynj/5
t+Y/BHsjGZp7xb9ayi7jKtXmPxcVSiOCTca/0LdyF0Xz5j9Xq8EyTx3Hv5YV
8JJFEuc/MXXoffHqx78EC676KTLnP2GeQmVZtsi/YcFi4u9S5z/5Iqp0d3/J
v0KEosyUdOc/pWB7ZDxGyr8ILxArFpfnPzFGvhqZCsu/9uOOXnG65z/PCkys
fszLvwIJdbej3uc/01bxXd6LzL+QhsB1qgPoP7PHjKWpSM2/DERMyYIp6D/J
uSkr0gLOv2veBtIpUOg/G0IXykm6zr9UlCqgnHfoPxdD+5ECb8+/wmN2NNif
6D+qw/BjdxDQv7hUaIDZyOg/6majcwBo0L+y7HhmnfLoP6DZj9EVvtC/LsZX
uiAd6T/Rfljo
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAAwLw8egp+nvXZvwBkhhoX
Z3A/JN7LFWaH2r8AiepI21SAP7j1ovxuGdu/AOq8EudjiD8sZ5qguKvbv4Bf
YW5TMJA/NCR8b0I+3L+A/qZViSWUPzr80dYL0dy/gBCBSpERmD+qLuZDFGTd
vwALbmFn9Js/tv3DI1v33b8ABx24B86fPxBBOOPfit6/gNG4OjfPoT8m+dHu
oR7fv0Dsw+TLsqM/buLisqCy37/A59v2v5GlP4sEwM1tI+C/gNBMkhFspz9d
LkEKqW3gv0CMBN2+Qak/SqLDxAG44L9AsJQBxhKrP+SZ+LJ3AuG/QFo0LyXf
rD/vHnSKCk3hvwD/wZnapq4/xFWtALqX4b8gm+I88jSwP9vH/sqF4uG/QEE4
hiAUsT9brqaebS3iv2CJ0Un38LE/0zzHMHF44r/gQPWqdcuyPxTsZjaQw+K/
4EZCz5qjsz8cxXBkyg7jv8BmsN5lebQ/IKy0bx9a478AMZED1ky1P7Kr5wyP
peO/wM6Qauodtj8KQKTwGPHjvwDXtkKi7LY/VaJqz7w85L8gHme9/Li3PzQU
oV16iOS/oIViDvmCuD9EK5RPUdTkv8DGx2uWSrk/0Rx3WUEg5b/APRQO1A+6
P5AJZC9KbOW/QLAkMLHSuj9/SVyFa7jlv6ASNg8tk7s/1bdID6UE5r/ASubq
RlG8Pxj/+YD2UOa/YPA0Bf4MvT855SiOX53mv2AKhKJRxr0/1pd26t/p5r+A
y5gJQX2+P4j4bEl3Nue/YEqcg8sxvz9d6X5eJYPnv2A4HFzw478/SZkI3enP
579Ay4Vw10nAP8/QT3jEHOi/sLNhMYOgwD+mPoTjtGnov+CuARr79cA/h8S/
0bq26L8/0Vxy
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAABg0jx2E09unSPlvzgNxTka
E34/wtOqyxgq5b8oS96KYguOP7LhDCydMeW/WPALNC6Clj+6BUH9KTrlv2B2
fb+r+Z0/AMn7mL5D5b/yghZXzLWiP74X50RaTuW/kvtfGbJrpj9kabAy/Fnl
v/gAjPs+Hqo/dG0YgKNm5b8IQqUTK82tP/I7BDdPdOW/1HgjXxe8sD/+B5BN
/oLlv6INB1KBj7I/RlMjpq+S5b+bmILfr2C0P7ighg9io+W/krUEsH8vtj/Y
pPpEFLXlvwzGFJrN+7c/5vFQ7sTH5b+A0/6kdsW5PxQeBqBy2+W/TL17C1iM
uz+iYV3bG/Dlv1Z+VT5PUL0//6p9Dr8F5r8oVwfnORG/P3kmkJRaHOa/qtQs
9XpnwD9oN+C17DPmv8uofLWwRME/OOD8p3NM5r8KJwVmLSDCP+iW243tZea/
bL/aWeD5wj86g/x3WIDmv2Kn2Aa50cM/+SOQZLKb5r/pieIGp6fEP1BYnj/5
t+a/zXojGZp7xT9byi7jKtXmv+AUSiOCTcY/0rdyF0Xz5r8dq8EyTx3HP5gV
8JJFEue/9XToffHqxz8DC676KTLnvyCeQmVZtsg/YMFi4u9S57+3Iqp0d3/J
P0CEosyUdOe/YGB7ZDxGyj8GLxArFpfnv+tFvhqZCss/8+OOXnG657+JCkys
fszLP/4Idbej3ue/iVbxXd6LzD+MhsB1qgPov2nHjKWpSM0/BkRMyYIp6L97
uSkr0gLOP2XeBtIpUOi/zUEXykm6zj9OlCqgnHfov8VC+5ECb88/umN2NNif
6L+Cw/BjdxDQP7BUaIDZyOi/vmajcwBo0D+o7HhmnfLov3bZj9EVvtA/JMZX
uiAd6b+fJVpt
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtkWtIU2EAhufshmUut5OaXYisqalpICwyX5VMS7K7WTMzcV4q1C7E0sB5
ybxkaVSK2TIKWmmStSUWkZo5wZxkYhfcd75zzrbcirCkm2Rl0I+H5+/z8i5N
zdmuEotEIr8p/tm9zssaaDVD9t+HX2m1njEEOz1ld/VfzRhrEY6wOoKW408d
LjMJcu1JtzQuLDSSgK3BXgTpSt+yiUMsLBJjpU8AwWiTLDmun0VinzL2PQgi
CofaFR4UQ+uZQPVOAtve+RWGGIrFnQXm4SyCxPzX0d5qipTUip9iDcHcsDPS
LB2F+G3Zol+XCcrKRQu0byh6loXynS0Epx5UadpncZjY3zqyw0jgvPZj9iMF
hy+3y7WtlKBHu9W1MZOD2vWh4d0EAbP8YElWHYfS0oZmE8Ni4Eb6JNPLYXie
1KUqhMXCDd+u3/zOoaH/wDYmnsXgli0NMjmPIP9occbUrrMkxEOVwEPrP1ZX
WM4iQvdh3aXTPIINc8+l6Vio25RhN/U8esaNCW69LN76fAuvEXh8edaRVjjK
IthkPKp0F6DxdpOap1HoXfKmiyMFmCTdRSMMRW1SwvKSHAEXzIwhXE7RtWST
E3dVwN4VrNJ5DcXDUEevxwsB5u+Q+8dRHGs50SyfEOAadO35/X0U6dlkxM3X
AhvfJDTkUkS87Koc2GXBD0tywGgxRfPG/A+qYgtuhf6KvVhLMTjpuWrwngVz
zsu4xiaK+pSDFVJiwenPpfWuHRRXjL9D/GZbwSuKvN4NUTRO+indFVYsai8V
zXBM9b2cGWZKs0LPZ4xV/5n66UbB7KQaK05+2lyWx3CIGo1xevzEivHqNlXX
Sg539PZdDrsVckO+T2YUh3hFd5SdsYEN70s+tIfDwnUScVukDbuHVt/ty+Xw
F2PzTeY=
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAphNPbp0j5b8AAAAAAADevJI71qkT
TOW/AHygVJ7GbD9ORDuNxnTlvwBOFCeZm3w/qD2JYbWd5b+A6uQET1SFPyLC
vW7fxuW/wC45VA9FjD8gMsz7Q/Dlv6DPKyf3j5E/wvOgTuIZ5r8giTaRZvKU
P2S3JKy5Q+a/wIZGscZJmD+swD9YyW3mvwBJHYIIlps/FjTdlRCY5r8glHcw
HdeeP/Bo7qaOwua/QAqoDXsGoT+4P27MQu3mv5CREGrCm6I/3nxkRiwY579g
0pKPXSukP7In6VNKQ+e/MIPMeUW1pT+b7ScznG7nv4Aq+z1zOac/aIljISGa
579wNhsL4LeoP8Yu+VrYxee/oKEGKoUwqj+q+WMbwfHnv0Ajk/1bo6s/zGFA
ndod6L/Q6q8CXhCtP/axTxokSui/wOWC0IR3rj8yg3vLnHbovwCQhRjK2K8/
yjvZ6EOj6L8Ap1DTE5qwP/iRrakY0Oi/0KelsMtEsT9FEnBEGv3ov+j9z6SJ
7LE/gKnO7kcq6b9Q8r69SpGyP0Uysd2gV+m/cCHQFgwzsz/uBT1FJIXpv5B8
3NjK0bM/CZHYWNGy6b+IDkU6hG20Pw7rLkun4Om/yIP/fjUGtT91cTNOpQ7q
v3B1ovjbm7U/8GUlk8o86r/wdnEGdS62P+KPk0oWa+q/EOZoFf69tj/m4F+k
h5nqv6h9SaB0Src/YBzDzx3I6r9QqqMv1tO3PwaCUPvX9uq/uKDiWSBauD9V
e/lUtSXrvxA2V8NQ3bg/2EsRCrVU67+4eUIeZV25PzXEUEfWg+u/mBDgKlva
uT8A+Nk4GLPrvzhRcLcwVLo/GvY7Cnri678IIUKg48q6P7qDdub6Eey/kJK8
z3E+uz9bD1hg
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAMpgZ5S3l3T8qmBnlLeXdv24YFK20
9d0/g9OenhhH3r/IdL/qCgfePwev43HfqN6/lhAsUDAZ3j+G6VyngArfv/oQ
x4skLN4/fFsoiPpr379qy1tI5z/eP/yrFF5Lzd+/5kQVLXhU3j9KgdS5OBfg
vyzBf93Wad4/71oWirVH4L9sYor5AoDeP2F710UbeOC/DNmIHfyW3j8WPIcT
aajgv9AjNeLBrt4/kIkAGp7Y4L8CYLHcU8feP4SzjYC5COG/9KmJnrHg3j8K
O+xuujjhv3wNtrXa+t4/zp5QDaBo4b+GhpyszhXfPxwlaoRpmOG/0hETCo0x
3z/Wo2b9Fcjhv5bNYVEVTt8/Ikb2oaT34b8oKkUCZ2vfP9hPT5wUJ+K/lCrw
mIGJ3z+Q3jEXZVbivya1Do5kqN8/RqjrPZWF4r+488dWD8jfP3y3WzyktOK/
5MPAZIHo3z/dJPY+kePiv3gbDxPdBOA/NM7HclsS47/EEMSC3BXgP7gKegUC
QeO/iN0VtT4n4D+aXFYlhG/jv08m31sDOeA/xh9KAeGd47/R9z8nKkvgP7g1
6sgXzOO/AC6fxbJd4D92rnasJ/rjv9fiq+OccOA/aG7e3A8o5L/q5F4s6IPg
P0LRwovPVeS/mDX8SJSX4D+tSXvrZYPkv/uOFOGgq+A/0/0YL9Kw5L908Yaa
DcDgP5xgaooT3uS/zziCGdrU4D+cx/4xKQvlvwm5hgAG6uA/oP0pWxI45b+e
4mfwkP/gP8LRBzzOZOW/ZO5NiHoV4T8Co38LXJHlv92Qt2XCK+E/QehHAbu9
5b8PtXskaELhP6m06VXq6eW/xz7LXmtZ4T9MOMRC6RXmvz3UMq3LcOE/HD0Q
ArdB5r+xEWHT
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwligss1AEAh29WZlRI7KIziimaTpZHl37ynNO4cpvXFEmzQmeJQibOpCnO
pXnvvELyODqHsEPdPG6O2TjKuon/vTBp88gord/27du3/SzvPLwZo0Uikc4d
8M//J+qLMwpMqDyzDFIuj1kljkMobabJ6PpBM0/YlJanw9iL9kqctAzR6tKh
QGYOWG55UYLKZWQ6uDL1vfOxMtif8F28DPcpO5utAg40DpJdz/WD/0snzr2N
N8j/xQtYPEkg8oUPX+xXAqrQ6kOPJwERnZKl87YcqSKEjMYTkBenUCmzVVhy
XCg2KCFA1Ws8mqZdjYHYtXevhwhkFhncHyqvQS4SJB6rBNyniwoi7OrQmn7X
5zxZASpb8tRbUA+2jSqI7qlApt2u2yPXBsSt2jhWJBy0s5meXNgIWl60pWWZ
Au012rY51Pcosd8Jk31RINKKuxde24yMnWizwZ8KyDVtWrcMWlAd5V45T1FC
RGRNslNaIeEHmlrRlbDg5JDHZG3QyU4br0hWoqSBMW1U1g4ebU7pWatEZGN9
+7gXH1JOSxN5Uokn+9K6vBU+zI+zvEz3lFjfGOinczoQ1jSx5murgsHpSZMj
jp0wv8hf4AWr4PLsm2xsqhOjh928rXJUOKvvfZkd/xFLhbKQqQ4VWOw/GZe0
BVhR2/s3yFWwSK7Z/louQFCiY0D9MTUKUxK1H9t3YSLGmjt2RY12ItZ4v78L
gwVcuskDNUIy/HhJdCHE8tt1uaVqkJprL8xMC3Ht1LCUMqJGbPViqEVYN5TP
Gbuzm2qMOAUPMxa64Zy2wxRYa8BK9TCPiehBr7+hroCpQYih3DZ8vgfkzwzf
mWwNtm+whFRmL5a25lzInRqMWHrwfoz1grRJ001d1IDB7ZMmXv0EXnYy8dtw
BX8BOg1FKQ==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwtj3lI03EAxecyjZlpunlmUcw8UtNAWGSKkmlJaYdGzcTEqVNQOwhRwts8
0DSsRNYyExKv0lzLIp+KMcGjPOgQ9/t9f/vtZ1Mr7FBJ1FrQH48PjweP93Yn
ZJyW8Xk8nodR/xha58h5c1ok/adiUql0CKPQ5CBs717SwuUJe5luprB2DfMC
cwr1c7GP8wQ0Rqy9onwdKVRK3UtX02j4bNdUiL0obG0TxkWM0mgYloZ/DqIQ
lT/VI7En2BEq8s46S+HXBbtyVRhBYn+u9r2cgiznQ6hzFkFTQvlvfh4Fx4Cb
tvJmgiOfSl3W7lK4XcZzUn4kMBP76/o7KBQ/q8zr2cJAEt85c0ZDQXDoS/pL
CQOvljJlJ6EwooyybEhh0GX5XDW9auxzTS2S1zHoLVG0jYloTDxKWhcNMRDY
2Aoq/WjsPLr8sGmFwbvRS6dEJ2lMRkYqhG46xHuG8pONv8opP3tZjA4jnot1
+WU0ApsXDt8pNuaqbVWJzTSuqqUBTd06LP7UxFgN0ZgSLwfWsDo4DfYl5hto
eI5prkhtWNQ6W9lqTQnaBNmb+cEsiPVgwYyIoCo2xrUog0WjVqQKdCN4seu4
CXOfhXwvLd10kKDFf37IfoTF15UgN88IAlnH9Ta3VRbOPg/edF0kOJdOzVi5
6/FD18oqMgl8xwcq3kbrYcrFeRkKCeqP5SzICvXo9F8Lr71H0LvusH/iqR52
t4RMQytBSXxquS2lR9X3knrLPqPXbPh5WHAwSAocp6cIStc9pDYSDnt6Snhm
88Y94+YBY4kc1Lrkxeo/BIbGXIvYGg43vp0ozRYxcDeEmbx6zWGpWi0b2Meg
qnsuen6Og7sqR5wSwsBXMhgyJ5oFHTgcl3aewUaANV8dPIvoqQPtw5kM/gIk
s3Th
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAfBNPbp0j5T8AAAAAAADIPHA71qkT
TOU/AISgVJ7GbL8yRDuNxnTlP4BRFCeZm3y/lD2JYbWd5T8A7OQET1SFvxbC
vW7fxuU/QC85VA9FjL8bMsz7Q/DlP+DPKyf3j5G/w/OgTuIZ5j8giTaRZvKU
v2y3JKy5Q+Y/oIZGscZJmL+8wD9YyW3mP8BIHYIIlpu/LTTdlRCY5j+Ak3cw
Hdeevw5p7qaOwuY/8AmoDXsGob/cP27MQu3mPyCREGrCm6K/Cn1kRiwY5z+w
0ZKPXSukv+Un6VNKQ+c/gILMeUW1pb/U7ScznG7nP8Ap+z1zOae/qIljISGa
5z+ANRsL4Leovwwv+VrYxec/kKAGKoUwqr/4+WMbwfHnPyAik/1bo6u/IWJA
ndod6D+A6a8CXhCtv1GyTxokSug/UOSC0IR3rr+Tg3vLnHboP3COhRjK2K+/
MjzZ6EOj6D8wplDTE5qwv2aSrakY0Og/8KalsMtEsb+6EnBEGv3oP/D8z6SJ
7LG//anO7kcq6T9I8b69SpGyv8cysd2gV+k/YCDQFgwzs793Bj1FJIXpP2h7
3NjK0bO/mJHYWNGy6T9IDUU6hG20v6XrLkun4Ok/eIL/fjUGtb8ScjNOpQ7q
Pxh0ovjbm7W/k2Ylk8o86j+AdXEGdS62v4yQk0oWa+o/iORoFf69tr+W4V+k
h5nqPxh8SaB0Sre/Fh3Dzx3I6j+oqKMv1tO3v8KCUPvX9uo/AJ/iWSBauL8Y
fPlUtSXrPzg0V8NQ3bi/n0wRCrVU6z/Yd0IeZV25vwTFUEfWg+s/oA7gKlva
ub/W+Nk4GLPrPzBPcLcwVLq/9vY7Cnri6z/oHkKg48q6v5uEdub6Eew/WJC8
z3E+u78xpFY6
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAANpgZ5S3l3b8YmBnlLeXdP3IYFK20
9d2/cNOenhhH3j/MdL/qCgfev/Ou43HfqN4/mBAsUDAZ3r9y6VyngArfP/oQ
x4skLN6/ZlsoiPpr3z9qy1tI5z/ev+arFF5Lzd8/5kQVLXhU3r8+gdS5OBfg
PyzBf93Wad6/41oWirVH4D9qYor5AoDev1V710UbeOA/CtmIHfyW3r8KPIcT
aajgP8wjNeLBrt6/g4kAGp7Y4D/+X7HcU8fev3azjYC5COE/8KmJnrHg3r/8
OuxuujjhP3gNtrXa+t6/wJ5QDaBo4T+ChpyszhXfvw0laoRpmOE/zhETCo0x
37/Go2b9FcjhP5DNYVEVTt+/E0b2oaT34T8iKkUCZ2vfv8lPT5wUJ+I/jirw
mIGJ37+B3jEXZVbiPyC1Do5kqN+/NajrPZWF4j+u88dWD8jfv2u3WzyktOI/
2MPAZIHo37/MJPY+kePiP3MbDxPdBOC/I87HclsS4z+/EMSC3BXgv6cKegUC
QeM/gt0VtT4n4L+IXFYlhG/jP0gm31sDOeC/tB9KAeGd4z/K9z8nKkvgv6Y1
6sgXzOM/+S2fxbJd4L9irnasJ/rjP9Hiq+OccOC/Vm7e3A8o5D/i5F4s6IPg
vy7RwovPVeQ/kDX8SJSX4L+aSXvrZYPkP/KOFOGgq+C/v/0YL9Kw5D9r8Yaa
DcDgv4hgaooT3uQ/xjiCGdrU4L+Ix/4xKQvlP/+4hgAG6uC/jP0pWxI45T+V
4mfwkP/gv63RBzzOZOU/We5NiHoV4b/son8LXJHlP9KQt2XCK+G/LOhHAbu9
5T8FtXskaELhv5O06VXq6eU/uz7LXmtZ4b83OMRC6RXmPzHUMq3LcOG/BT0Q
ArdB5j/fm2Qa
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAAAAAAAA0jx1E09unSPlvwCCoFSe
xmy/ZDvWqRNM5b+AURQnmZt8vyJEO43GdOW/gOzkBE9Uhb9+PYlhtZ3lv4Aw
OVQPRYy/+8G9bt/G5b/A0Csn94+Rv/wxzPtD8OW/IIo2kWbylL+f86BO4hnm
v+CHRrHGSZi/RLckrLlD5r9ASh2CCJabv5DAP1jJbea/YJV3MB3Xnr/8M92V
EJjmv/AKqA17BqG/12jupo7C5r8wkhBqwpuiv6I/bsxC7ea/ENOSj10rpL/K
fGRGLBjnv/CDzHlFtaW/oCfpU0pD579QK/s9czmnv4vtJzOcbue/MDcbC+C3
qL9aiWMhIZrnv2CiBiqFMKq/ui75WtjF578AJJP9W6Orv6L5YxvB8ee/oOuv
Al4Qrb/HYUCd2h3ov4DmgtCEd66/8rFPGiRK6L/AkIUYytivvzCDe8ucdui/
aKdQ0xOasL/KO9noQ6PovziopbDLRLG/+pGtqRjQ6L9Q/s+kieyxv0sScEQa
/ei/uPK+vUqRsr+Jqc7uRyrpv+gh0BYMM7O/TzKx3aBX6b/4fNzYytGzv/oF
PUUkhem/8A5FOoRttL8YkdhY0bLpvzCE/341BrW/IOsuS6fg6b/gdaL425u1
v4pxM06lDuq/YHdxBnUutr8GZiWTyjzqv3jmaBX+vba/+o+TShZr6r8Yfkmg
dEq3vwHhX6SHmeq/uKqjL9bTt79+HMPPHcjqvyCh4lkgWri/JoJQ+9f26r94
NlfDUN24v3d7+VS1Jeu/KHpCHmVdub/8SxEKtVTrvwgR4Cpb2rm/XMRQR9aD
67+oUXC3MFS6vyn42TgYs+u/cCFCoOPKur9F9jsKeuLrv/iSvM9xPru/6IN2
5voR7L9Fk249
        "]]]}}, {
     {Hue[0.6, 0.7, 0.5], Opacity[0], Arrowheads[Medium], 
      ArrowBox[CompressedData["
1:eJyF1D8ohHEcx/GnUwYjCpNkciVSN5wePZOyKUYZKBLyZ2BANyoZpIQSizKZ
FLdcXVcG1iuDAdPtEkZR95tel56rp2/3ez+/3+fz/fN7emZXJ+aaoiga+3sy
4SlutRQuvp6TKPxOOzIHfVPV5CxE+U7b+Mp5by3Zu0wOJxfuY3nxY7i7lj2K
b8O6fOi0q9Zfe0my9ViWj4b1+RD1o36DX/TlrUG/PUT5UT2WT8J/+eZgvn10
sRpv1H2UB8L6eNhnPnLPk1sf+VXQnV77yV1vv5bk+rNevi+3/vJC2Dfzz371
7Yf1lzfMB9z+yN+/b59Gliql5eBLflyP5d235rtc9TFu8EP/5Ov7bTeVz4dS
HM6R619ufTxPfbn9k9s/eT6sd/6Tj/7Mx/fl6sudX7n98Tz7KTc/ufMhV995
c97l6svVl3u/5PpTz/mR679hP/WVO8/m4/dN7vzK9SdPmyf15fqXW2+5fuyX
+cm9P3LnUZ6mr1/vs/nJ7bc87Xz9pH1v5dYnbd7l+pPr7xdSTy9Y
       "]]}, 
     {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0]}], FaceForm[
      Opacity[0]], {DiskBox[{0.4056164008015161, 0.}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], 
        Offset[{2, 2}, {0.4056164008015161, 0.}], ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.2868141075672326, 0.28681410756723275`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "2"}], "}"}], 
        Offset[{2, 2}, {0.2868141075672326, 0.28681410756723275}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.28681410756722675`, -0.2868141075672285}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "3"}], "}"}], 
        Offset[{2, 2}, {0.28681410756722675, -0.2868141075672285}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.6605975298376587, 5.664226070673724*^-16}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], 
        Offset[{2, 2}, {0.6605975298376587, 5.664226070673724*^-16}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{6.99702747969524*^-17, 0.405616400801516}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "5"}], "}"}], 
        Offset[{2, 2}, {6.99702747969524*^-17, 0.405616400801516}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.4671129929832897, 0.4671129929832898}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "6"}], "}"}], 
        Offset[{2, 2}, {0.4671129929832897, 0.4671129929832898}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-6.92670381065753*^-16, -0.4056164008015093}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "7"}], "}"}], 
        Offset[{2, 2}, {-6.92670381065753*^-16, -0.4056164008015093}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.46711299298329145`, -0.467112992983291}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "8"}], "}"}], 
        Offset[{2, 2}, {0.46711299298329145, -0.467112992983291}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.4671129929832925, -0.46711299298329434`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "9"}], "}"}], 
        Offset[{2, 2}, {-0.4671129929832925, -0.46711299298329434}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.28681410756723236`, 0.2868141075672325}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "10"}], "}"}], 
        Offset[{2, 2}, {-0.28681410756723236, 0.2868141075672325}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.46711299298329184`, 0.46711299298329}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "11"}], "}"}], 
        Offset[{2, 2}, {-0.46711299298329184, 0.46711299298329}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-4.834719367710373*^-16, 0.660597529837657}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "12"}], "}"}], 
        Offset[{2, 2}, {-4.834719367710373*^-16, 0.660597529837657}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.6605975298376634, -1.6921517786986418`*^-15}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "13"}], "}"}], 
        Offset[{2, 2}, {-0.6605975298376634, -1.6921517786986418*^-15}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.28681410756723114`, -0.2868141075672295}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "14"}], "}"}], 
        Offset[{2, 2}, {-0.28681410756723114, -0.2868141075672295}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{1.0222443204062975`*^-15, -0.660597529837658}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "15"}], "}"}], 
        Offset[{2, 2}, {1.0222443204062975*^-15, -0.660597529837658}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.4056164008015143, 7.166803835241803*^-16}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "16"}], "}"}], 
        Offset[{2, 2}, {-0.4056164008015143, 7.166803835241803*^-16}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}}}, 
    {GrayLevel[0], AbsolutePointSize[5], PointBox[{0.4056164008015161, 0.}], 
     PointBox[{0.2868141075672326, 0.28681410756723275`}], 
     PointBox[{0.28681410756722675`, -0.2868141075672285}], 
     PointBox[{0.6605975298376587, 5.664226070673724*^-16}], 
     PointBox[{6.99702747969524*^-17, 0.405616400801516}], 
     PointBox[{0.4671129929832897, 0.4671129929832898}], 
     PointBox[{-6.92670381065753*^-16, -0.4056164008015093}], 
     PointBox[{0.46711299298329145`, -0.467112992983291}], 
     PointBox[{-0.4671129929832925, -0.46711299298329434`}], 
     PointBox[{-0.28681410756723236`, 0.2868141075672325}], 
     PointBox[{-0.46711299298329184`, 0.46711299298329}], 
     PointBox[{-4.834719367710373*^-16, 0.660597529837657}], 
     PointBox[{-0.6605975298376634, -1.6921517786986418`*^-15}], 
     PointBox[{-0.28681410756723114`, -0.2868141075672295}], 
     PointBox[{1.0222443204062975`*^-15, -0.660597529837658}], 
     PointBox[{-0.4056164008015143, 7.166803835241803*^-16}]}}},
  ImageSize->300,
  PlotRange->{{-1.1, 1.1}, {-1.1, 1.1}}]], "Output",
 CellChangeTimes->{
  3.9090560518364916`*^9, {3.9090561101798167`*^9, 3.9090561548715925`*^9}, 
   3.9091127161095977`*^9, 3.910153148939886*^9, {3.9101612802787886`*^9, 
   3.910161292364663*^9}, 3.9101655926503925`*^9, 3.9101720013638697`*^9},
 CellLabel->"Out[10]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
96.],ExpressionUUID->"8ac4efc5-3796-455d-97c8-7a4116f6c5dc"]
}, Open  ]],

Cell[TextData[{
 "The Haldane model consists of nearest-neighbor hoppings with amplitude ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "2d793d85-083b-40cb-96fb-e2dba38a3da0"],
 " and next-nearest-neighbor hoppings (positively oriented around each face) \
with amplitude ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["h", "2"], 
    SuperscriptBox[
     StyleBox["e",
      FontSlant->"Plain"], 
     RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]]}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "d7afd992-f2d3-4b5c-8329-a126826ba4d0"],
 ". Since the graph contains information about which edges correspond to \
nearest neighbors and which to next-nearest-neighbors and the latter are \
already correctly oriented, this can be simply implemented as follows"
}], "Text",
 CellChangeTimes->{{3.9091100794507523`*^9, 3.909110119897537*^9}, {
  3.910174905802904*^9, 3.910174906687784*^9}, {3.910174961935872*^9, 
  3.910175109290615*^9}},ExpressionUUID->"c2209bd6-4cc4-4819-aa86-\
47843f85de4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hopping", " ", "[", 
    RowBox[{"h1_", ",", "h2_", ",", "\[Phi]_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"Switch", "[", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", 
        RowBox[{"3", ",", "1"}], "]"}], "]"}], ",", " ", 
      RowBox[{"(*", " ", "NN", " ", "*)"}], "1", ",", " ", "h1", ",", " ", 
      RowBox[{"(*", " ", "NNN", " ", "*)"}], "2", ",", " ", 
      RowBox[{"h2", " ", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}], ")"}]}]}]}], "]"}],
     "&"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091102923304925`*^9, 3.909110298684972*^9}, {
  3.9091111264453907`*^9, 3.9091111317247286`*^9}, {3.910175416616406*^9, 
  3.9101754261471214`*^9}, {3.910176413071261*^9, 3.9101764171602554`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"692a663c-283b-40b3-9a89-d281f48d2470"],

Cell[TextData[{
 "Additionally, there is an alternating sublattice potential ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[PlusMinus]", "m"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "8da27dad-5b93-4eb8-b511-e17511098966"],
 ", which takes positive values on the sublattice:"
}], "Text",
 CellChangeTimes->{{3.9091111387642813`*^9, 3.909111147598441*^9}, {
  3.9091127289290066`*^9, 3.9091127383881497`*^9}, {3.9101754385299435`*^9, 
  3.9101754982753797`*^9}},ExpressionUUID->"762ab862-514c-4828-a6db-\
ce71becddb06"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sublat", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9101755012821813`*^9, 3.91017550445644*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"c63bb179-4023-481f-939d-a18618147d98"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"onsite", "[", "m_", "]"}], ":=", 
   RowBox[{
    RowBox[{"m", " ", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"MemberQ", "[", 
        RowBox[{"sublat", ",", " ", "#"}], "]"}], ",", "1", ",", 
       RowBox[{"-", "1"}]}], "]"}]}], "&"}]}], ";"}]], "Input",
 CellChangeTimes->{3.9091111503346624`*^9, 3.910175513224516*^9},
 CellLabel->"In[10]:=",ExpressionUUID->"3c4f3741-05e5-474c-94f2-5822eb2a0dee"],

Cell["\<\
With this information, we construct the Abelian Bloch Hamiltonian on the \
primitive cell:\
\>", "Text",
 CellChangeTimes->{{3.909112746681242*^9, 
  3.909112758737096*^9}},ExpressionUUID->"0d8b7607-39f6-4ace-8486-\
487582ad556d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Hpc", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{"pcmodel", ",", "1", ",", 
         RowBox[{"onsite", "[", "m", "]"}], ",", 
         RowBox[{"hopping", "[", 
          RowBox[{"h1", ",", "h2", ",", "\[Phi]"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"Assumptions", "->", 
       RowBox[{
        RowBox[{"h1", "\[Element]", "Reals"}], "&&", 
        RowBox[{"h2", "\[Element]", "Reals"}], "&&", 
        RowBox[{"\[Phi]", "\[Element]", "Reals"}]}]}]}], "]"}]}], ")"}], "//",
   "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.9091127598630133`*^9, 3.9091128051125402`*^9}, {
  3.909112887125308*^9, 3.909112890216216*^9}, {3.909114118715374*^9, 
  3.909114118938531*^9}, {3.910153339519004*^9, 3.9101533492091894`*^9}, {
  3.9101756316062946`*^9, 3.910175684683981*^9}, {3.9101764091227016`*^9, 
  3.910176424809532*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"d6c88616-b1d4-4505-9c64-c23556d70a65"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"m", "h1", "h1", "h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k4", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", "0", "0",
       "0", "0"},
     {"h1", 
      RowBox[{"-", "m"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "h1", "h1", 
      "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k2", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0"},
     {"h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{"-", "m"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "0", 
      "0", "h1", "h1", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k3", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "0"},
     {"h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{"-", "m"}], "0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k4", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "k2", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k3"}], "+", "k4", "+", "\[Phi]"}], ")"}]}]], " ", 
       "h2"}], "0"},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "h1", 
      "0", "0", "m", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k3", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k2", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "h1", 
      "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "h1", "0", 
      "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "m", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k2", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "k4", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k2", "-", "k3", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]], " ", "h1"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "0", "h1", 
      "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k2", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "m", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k3", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", "0", 
      "h1", "h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "0", 
      "h1", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k3", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "k4", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "m", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k2"}], "+", "k3", "+", "\[Phi]"}], ")"}]}]], " ", 
       "h2"}], "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]], " ", "h1"}], "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k2", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k2"}], "+", "k3", "+", "\[Phi]"}], ")"}]}]], " ", 
       "h2"}], "m", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]], " ", "h1"}], "0", "h1", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}]},
     {"0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k4", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "h1", "0", 
      "0", "0", "0", 
      RowBox[{"-", "m"}], "h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k3", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "h1"},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k4", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k2", "-", "k3", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k3", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      "h1", "m", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}]},
     {"0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k3", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "k2", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      "h1", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]], " ", "h1"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "0", 
      RowBox[{"-", "m"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k3", "-", "k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k2", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", "0"},
     {"0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]], " ", "h1"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]], " ", "h1"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k3", "-", "k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{"-", "m"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k1"}], "+", "k2", "+", "\[Phi]"}], ")"}]}]], " ", 
       "h2"}], "h1"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], "0", "0", 
      "h1", "0", "h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k2", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{"-", "m"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "h1"},
     {"0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k2", "-", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k3"}], "+", "k4", "+", "\[Phi]"}], ")"}]}]], " ", 
       "h2"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]], " ", "h1"}], "h1", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k3", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]], " ", "h1"}], "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "k1"}], "+", "k2", "+", "\[Phi]"}], ")"}]}]], " ", 
       "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{"-", "m"}], "0"},
     {"0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k4", "+", "\[Phi]"}], ")"}]}]], " ", "h2"}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Phi]"}]], " ", "h2"}], "h1", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "\[Phi]"}]], " ", "h2"}], "0", "h1", 
      "h1", "0", "m"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.909112806133675*^9, 3.9091128916577287`*^9, 
  3.909113216625798*^9, 3.9091141203995323`*^9, 3.91015335400698*^9, 
  3.910161299005518*^9, 3.9101656049358573`*^9, 3.9101756517631702`*^9, 
  3.9101756862929087`*^9, 3.9101764264952593`*^9},
 CellLabel->
  "Out[22]//MatrixForm=",ExpressionUUID->"b51a4812-87b3-45ea-8bec-\
957c1d8597c4"]
}, Open  ]],

Cell["We export the matrix", "Text",
 CellChangeTimes->{{3.90911280941973*^9, 
  3.9091128164730463`*^9}},ExpressionUUID->"1b435fa1-3899-41a3-947e-\
6b3d19a4c3dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
       "\"\<H_{8,3}-haldane_T2.1.dat\>\""}], "}"}], "]"}], ",", "Hpc", ",", 
    "\"\<Table\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.909112817642894*^9, 3.909112873040862*^9}, {
  3.9091135412614784`*^9, 3.9091135513819184`*^9}, {3.9091141224124656`*^9, 
  3.9091141227837057`*^9}, {3.9101533706269875`*^9, 3.910153387843902*^9}, {
  3.910161305435033*^9, 3.9101613071799307`*^9}, {3.9101656107114687`*^9, 
  3.9101656118116646`*^9}, {3.9101756995576763`*^9, 3.9101757042046995`*^9}, {
  3.9101758415137253`*^9, 3.910175841845538*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"3e18def3-d9d2-4075-bf24-8592f17e8f85"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909112902255294*^9, 
  3.909112904377528*^9}},ExpressionUUID->"beedb420-635d-44cb-a4f0-\
bd6bb91b2e32"],

Cell[TextData[{
 "We approximate the density of states by randomly sampling momenta, i.e., \
one-dimensional irreducible representations, and diagonalizing the Bloch \
Hamiltonian evaluated at those. For faster evaluation, we compile the \
expression for the Bloch Hamiltonian (for the parameter choices ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"m", "=", 
     RowBox[{"1", "/", "3"}]}], ",", " ", 
    RowBox[{
     SubscriptBox["h", "1"], "=", "1"}], ",", " ", 
    RowBox[{
     SubscriptBox["h", "2"], "=", 
     RowBox[{"1", "/", "6"}]}], ",", " ", 
    RowBox[{"\[Phi]", "=", 
     RowBox[{"\[Pi]", "/", "2"}]}]}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "dbd186d3-c66c-4b23-bd86-1ece57a52fc0"],
 "):"
}], "Text",
 CellChangeTimes->{{3.9091129164291873`*^9, 3.909112983734069*^9}, {
  3.9101534175388513`*^9, 3.910153418071595*^9}, {3.9101758519671125`*^9, 
  3.9101758573253603`*^9}, {3.910238162231159*^9, 
  3.910238189806696*^9}},ExpressionUUID->"c94d9ede-3a58-4aca-bdbe-\
e601d76a7f89"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hpccf", "=", 
  RowBox[{"AbelianBlochHamiltonian", "[", 
   RowBox[{"pcmodel", ",", "1", ",", 
    RowBox[{"onsite", "[", 
     RowBox[{"1", "/", "3"}], "]"}], ",", 
    RowBox[{"hopping", "[", 
     RowBox[{"1", ",", 
      RowBox[{"1", "/", "6"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
    RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9091129849959536`*^9, 3.9091129967523327`*^9}, {
   3.909114125339196*^9, 3.909114125798375*^9}, 3.910153426194847*^9, {
   3.910176046778378*^9, 3.9101760672534122`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"e3632868-71ce-4226-ac79-e353db21567b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["CompiledFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  StyleBox[
                   PaneBox[
                    RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ContentPadding -> False, FrameMargins -> 0, 
                    StripOnInput -> True, BaselinePosition -> Baseline, 
                    ImageSize -> {{1, 300}, Automatic}], LineBreakWithin -> 
                   False], "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{
              Thickness[0.038461538461538464`], {
               FaceForm[{
                 GrayLevel[0.93], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{1, 4, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}, {
                1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {0, 1, 0}}}, {{{
                25.499999999999996`, 2.5}, {25.499999999999996`, 
                1.3953100000000003`}, {24.604699999999998`, 
                0.49999999999999994`}, {23.5, 0.49999999999999994`}, {2.5, 
                0.49999999999999994`}, {1.3953100000000003`, 
                0.49999999999999994`}, {0.49999999999999994`, 
                1.3953100000000003`}, {0.49999999999999994`, 2.5}, {
                0.49999999999999994`, 23.5}, {0.49999999999999994`, 
                24.604699999999998`}, {1.3953100000000003`, 
                25.499999999999996`}, {2.5, 25.499999999999996`}, {23.5, 
                25.499999999999996`}, {24.604699999999998`, 
                25.499999999999996`}, {25.499999999999996`, 
                24.604699999999998`}, {25.499999999999996`, 23.5}, {
                25.499999999999996`, 2.5}}}]}, {
               FaceForm[{
                 RGBColor[0.5, 0.5, 0.5], 
                 Opacity[1.]}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{20.5426, 
                19.116799999999998`}, {16.3832, 21.876199999999997`}, {
                16.3832, 20.021499999999996`}, {6.930469999999999, 
                20.021499999999996`}, {6.930469999999999, 
                18.212100000000003`}, {16.3832, 18.212100000000003`}, {
                16.3832, 16.357399999999995`}, {20.5426, 
                19.116799999999998`}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{5.30508, 13.8391}, {
                9.46445, 11.079700000000003`}, {9.46445, 
                12.933999999999997`}, {18.917199999999998`, 
                12.933999999999997`}, {18.917199999999998`, 14.7438}, {
                9.46445, 14.7438}, {9.46445, 16.598}, {5.30508, 13.8391}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIRIGYC4r9qIkoPPog5zJd34+ifoeBwf6HGBfU8aYe0
2dKXhaMEHT77F2xc1CQH52elHtL/aqrg0KrArnpmjpRDvTCXYEG9gsOOYKuI
/6tlHZ5WFpRfO4qQn3ww8NOrXYpw/fNmfE3SCFCG8z8EiLwQ7lSF2w82/44y
nM937b/lmXNKDnK7FuxLZZFwMDfq/3NwgpKDccaL+Q9miDok9Mnt3x6k5FDt
mbylT0ECwk9QhOuXWfO/eIajPCq/WNYh5kh50jV+CYc1eV/nfGGShZsXte2a
OGevDNy8ZqG0W/9KpeD60cMLAIwUgfU=
                "]], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{12.82453, 
                5.289294374999999}, {11.960858124999998`, 8.29796625}, {
                11.080858124999999`, 8.29796625}, {12.417186249999999`, 
                4.337966249999999}, {13.193201874999998`, 
                4.337966249999999}, {14.540701874999998`, 8.29796625}, {
                13.688201874999999`, 8.29796625}, {12.82453, 
                5.289294374999999}}}], 
               
               FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                0}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0,
                 1, 0}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGIpIGYC4qwFP+fsFjB0WFcz7fnBvSIOLFaTza6GGTjM
l3fj6J+h4GC9PHLBXXc9DH7abOnLwlGCDtPNZKaxndfH4Is8/uOrISAD53uI
GTRGxyP4O4KtIv6fR/BbFdhVz8TIOqj9FNyfdEbfIejt5Y8zXiL4h7TunbCJ
koPzweYvkXP4mfT+6PSlBnD7n25Z/mROiSGcr7S/rqPX1AiuHsaHmQfjw+zz
lubzZjYxgrsHxoe5F8aH+QfGn/B91VROQQQfZr/Ei1viF75j8mHh6eiSdevo
cUM4Hz0+AG0eosQ=
                "]]}}, Background -> GrayLevel[0.93], Axes -> False, 
             AspectRatio -> 1, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}], Frame -> True, FrameTicks -> None, 
             FrameStyle -> Directive[
               Thickness[Tiny], 
               GrayLevel[0.7]]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Argument count: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["4", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Argument types: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"{", 
                    
                    RowBox[{
                    "_Real", ",", "_Real", ",", "_Real", ",", "_Real"}], 
                    "}"}], ImageSize -> {{1, 500}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Variables: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$213150", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213151", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213152", ",", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213153"}], 
                    "}"}], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                   RowBox[{"Block", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    
                    RowBox[{
                    "Compile`$2", ",", "Compile`$3", ",", "Compile`$6", ",", 
                    "Compile`$7", ",", "Compile`$8", ",", "Compile`$5", ",", 
                    "Compile`$10", ",", "Compile`$11", ",", "Compile`$12", 
                    ",", "Compile`$9", ",", "Compile`$13", ",", "Compile`$14",
                     ",", "Compile`$15", ",", "Compile`$31", ",", 
                    "Compile`$35", ",", "Compile`$36", ",", "Compile`$37", 
                    ",", "Compile`$38", ",", "Compile`$16", ",", 
                    "Compile`$48", ",", "Compile`$49", ",", "Compile`$40", 
                    ",", "Compile`$41", ",", "Compile`$44", ",", 
                    "Compile`$45", ",", "Compile`$27", ",", "Compile`$28", 
                    ",", "Compile`$56", ",", "Compile`$57", ",", 
                    "Compile`$58", ",", "Compile`$52", ",", "Compile`$53", 
                    ",", "Compile`$59", ",", "Compile`$32", ",", 
                    "Compile`$33", ",", "Compile`$29", ",", "Compile`$17", 
                    ",", "Compile`$18", ",", "Compile`$22", ",", 
                    "Compile`$23", ",", "Compile`$24", ",", "Compile`$25", 
                    ",", "Compile`$30", ",", "Compile`$62", ",", 
                    "Compile`$63", ",", "Compile`$50", ",", "Compile`$51", 
                    ",", "Compile`$42", ",", "Compile`$68", ",", 
                    "Compile`$69", ",", "Compile`$43", ",", "Compile`$19", 
                    ",", "Compile`$20", ",", "Compile`$66", ",", 
                    "Compile`$67"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"Compile`$2", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213150"}]}], 
                    ";", 
                    RowBox[{"Compile`$3", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$2"]}], ";", 
                    RowBox[{"Compile`$6", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213153"}]}], 
                    ";", 
                    RowBox[{"Compile`$7", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$6"]}], ";", 
                    RowBox[{"Compile`$8", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$7"}], "6"]}]}], 
                    ";", 
                    RowBox[{"Compile`$5", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$3"}], "6"]}], ";", 
                    RowBox[{"Compile`$10", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213151"}]}], 
                    ";", 
                    RowBox[{"Compile`$11", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$10"]}], ";", 
                    RowBox[{"Compile`$12", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$11"}], "6"]}], 
                    ";", 
                    RowBox[{"Compile`$9", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$3"}], "6"]}]}], 
                    ";", 
                    RowBox[{"Compile`$13", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213152"}]}], 
                    ";", 
                    RowBox[{"Compile`$14", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$13"]}], ";", 
                    RowBox[{"Compile`$15", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$14"}], "6"]}]}], 
                    ";", 
                    RowBox[{"Compile`$31", "=", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$213150", "+", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213153"}]}], 
                    ";", 
                    RowBox[{"Compile`$35", "=", 
                    
                    RowBox[{
                    "-", "PatrickMLenggenhager`HyperBloch`Private`k$213152"}]}\
], ";", 
                    RowBox[{"Compile`$36", "=", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$213151", "+", 
                    "Compile`$35"}]}], ";", 
                    RowBox[{"Compile`$37", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "Compile`$36"}]}], 
                    ";", 
                    RowBox[{"Compile`$38", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$37"]}], ";", 
                    RowBox[{"Compile`$16", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$7"}], "6"]}], ";", 
                    RowBox[{"Compile`$48", "=", 
                    RowBox[{"\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213150"}]}], 
                    ";", 
                    RowBox[{"Compile`$49", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$48"]}], ";", 
                    RowBox[{"Compile`$40", "=", 
                    
                    RowBox[{
                    "\[ImaginaryI]", " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213151"}]}], 
                    ";", 
                    RowBox[{"Compile`$41", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$40"]}], ";", 
                    RowBox[{"Compile`$44", "=", 
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$31"}]}], ";", 
                    RowBox[{"Compile`$45", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$44"]}], ";", 
                    RowBox[{"Compile`$27", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213152"}]}], 
                    ";", 
                    RowBox[{"Compile`$28", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$27"]}], ";", 
                    RowBox[{"Compile`$56", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", 
                    "PatrickMLenggenhager`HyperBloch`Private`k$213153"}]}], 
                    ";", 
                    RowBox[{"Compile`$57", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$56"]}], ";", 
                    RowBox[{"Compile`$58", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$57"}], "6"]}], 
                    ";", 
                    RowBox[{"Compile`$52", "=", 
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$36"}]}], ";", 
                    RowBox[{"Compile`$53", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$52"]}], ";", 
                    RowBox[{"Compile`$59", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$28"}], "6"]}]}], 
                    ";", 
                    RowBox[{"Compile`$32", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "Compile`$31"}]}], 
                    ";", 
                    RowBox[{"Compile`$33", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$32"]}], ";", 
                    RowBox[{"Compile`$29", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$28"}], "6"]}], 
                    ";", 
                    RowBox[{"Compile`$17", "=", 
                    
                    RowBox[{
                    "-", "PatrickMLenggenhager`HyperBloch`Private`k$213151"}]}\
], ";", 
                    RowBox[{"Compile`$18", "=", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$213150", "+", 
                    "Compile`$17"}]}], ";", 
                    RowBox[{"Compile`$22", "=", 
                    
                    RowBox[{
                    "-", "PatrickMLenggenhager`HyperBloch`Private`k$213153"}]}\
], ";", 
                    RowBox[{"Compile`$23", "=", 
                    
                    RowBox[{
                    "PatrickMLenggenhager`HyperBloch`Private`k$213152", "+", 
                    "Compile`$22"}]}], ";", 
                    RowBox[{"Compile`$24", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "Compile`$23"}]}], 
                    ";", 
                    RowBox[{"Compile`$25", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$24"]}], ";", 
                    RowBox[{"Compile`$30", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$11"}], "6"]}]}], 
                    ";", 
                    RowBox[{"Compile`$62", "=", 
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$18"}]}], ";", 
                    RowBox[{"Compile`$63", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$62"]}], ";", 
                    RowBox[{"Compile`$50", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$49"}], "6"]}]}], 
                    ";", 
                    RowBox[{"Compile`$51", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$41"}], "6"]}], 
                    ";", 
                    RowBox[{"Compile`$42", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$41"}], "6"]}]}], 
                    ";", 
                    RowBox[{"Compile`$68", "=", 
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$23"}]}], ";", 
                    RowBox[{"Compile`$69", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$68"]}], ";", 
                    RowBox[{"Compile`$43", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$14"}], "6"]}], 
                    ";", 
                    RowBox[{"Compile`$19", "=", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "Compile`$18"}]}], 
                    ";", 
                    RowBox[{"Compile`$20", "=", 
                    SuperscriptBox["\[ExponentialE]", "Compile`$19"]}], ";", 
                    RowBox[{"Compile`$66", "=", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$49"}], "6"]}], 
                    ";", 
                    RowBox[{"Compile`$67", "=", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$57"}], "6"]}]}], 
                    ";", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    FractionBox["1", "3"], ",", "1", ",", "1", ",", "1", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "Compile`$5", ",",
                     "0", ",", "Compile`$8", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "1", ",", "1", 
                    ",", "0", ",", "0", ",", "0", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "Compile`$9", 
                    ",", "0", ",", "Compile`$12", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "0", ",", "0", 
                    ",", "1", ",", "1", ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$15", ",", "Compile`$16", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", "Compile`$3", ",", "Compile`$8", ",", 
                    "Compile`$7", ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$20"}], "6"]}], 
                    ",", "0", ",", "Compile`$5", ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$25"}], "6"], ",", 
                    "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "1", ",", "0", 
                    ",", "0", ",", 
                    FractionBox["1", "3"], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "0", ",", 
                    "Compile`$29", ",", "Compile`$30", ",", "1", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "1", ",", "0", 
                    ",", "0", ",", "0", ",", 
                    FractionBox["\[ImaginaryI]", "6"]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    FractionBox["\[ImaginaryI]", "6"], ",", "1", ",", "0", 
                    ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    FractionBox["1", "3"], ",", "Compile`$12", ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$33"}], "6"], ",", 
                    "0", ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$38"}], "6"]}], 
                    ",", "0", ",", "Compile`$3", ",", "0", ",", "Compile`$11",
                     ",", "Compile`$9"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    FractionBox["\[ImaginaryI]", "6"], ",", "0", ",", "1", 
                    ",", "0", ",", "0", ",", "Compile`$42", ",", 
                    FractionBox["1", "3"], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "0", ",", 
                    "Compile`$43", ",", "0", ",", "0", ",", "1", ",", "1", 
                    ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "0", ",", "1", 
                    ",", "0", ",", "Compile`$15", ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$45"}], "6"]}], 
                    ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    FractionBox["1", "3"], ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$38"}], "6"], ",", 
                    "0", ",", "0", ",", "Compile`$14", ",", "Compile`$7", ",",
                     "0", ",", "0", ",", "Compile`$16"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"Compile`$50", ",", "0", ",", "0", ",", 
                    "Compile`$49", ",", "Compile`$51", ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$53"}], "6"]}], 
                    ",", 
                    FractionBox["1", "3"], ",", "0", ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$45"}], "6"], ",", 
                    "Compile`$41", ",", "0", ",", "1", ",", "0", ",", 
                    FractionBox["\[ImaginaryI]", "6"]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "0", ",", 
                    "Compile`$58", ",", "1", ",", "0", ",", "0", ",", "0", 
                    ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", "1", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "Compile`$59", 
                    ",", "1"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"Compile`$58", ",", "0", ",", "0", ",", 
                    "Compile`$57", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$53"}], "6"], ",", 
                    "Compile`$59", ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$33"}], "6"]}], 
                    ",", "1", ",", 
                    FractionBox["1", "3"], ",", "0", ",", "0", ",", "0", ",", 
                    "Compile`$28", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "Compile`$29", 
                    ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$63"}], "6"], ",", 
                    "1", ",", "0", ",", "0", ",", "Compile`$28", ",", 
                    "Compile`$11", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$25"}], "6"]}], 
                    ",", "Compile`$30", ",", "0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    
                    RowBox[{"0", ",", "Compile`$66", ",", "Compile`$67", ",", 
                    "0", ",", "0", ",", "Compile`$49", ",", "0", ",", 
                    "Compile`$57", ",", "0", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "0", ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$69"}], "6"], ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$63"}], "6"]}], 
                    ",", "1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "Compile`$50", 
                    ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "0", ",", 
                    "Compile`$51", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "1"}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Compile`$42", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", 
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$69"}], "6"]}], 
                    ",", "0", ",", "Compile`$41", ",", "1", ",", "0", ",", 
                    "0", ",", "Compile`$43", ",", "Compile`$14", ",", "0", 
                    ",", 
                    FractionBox[
                    RowBox[{"\[ImaginaryI]", " ", "Compile`$20"}], "6"], ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", 
                    RowBox[{"-", 
                    FractionBox["1", "3"]}], ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "Compile`$66", 
                    ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "Compile`$67", 
                    ",", 
                    RowBox[{"-", 
                    FractionBox["\[ImaginaryI]", "6"]}], ",", "1", ",", 
                    FractionBox["\[ImaginaryI]", "6"], ",", "0", ",", "1", 
                    ",", "1", ",", "0", ",", 
                    FractionBox["1", "3"]}], "}"}]}], "}"}]}]}], "]"}], 
                   ImageSize -> {{1, 500}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  CompiledFunction[{11, 13.3, 5468}, {
    Blank[Real], 
    Blank[Real], 
    Blank[Real], 
    Blank[Real]}, {{3, 0, 0}, {3, 0, 1}, {3, 0, 2}, {3, 0, 3}, {4, 2, 
   0}}, {{0, {2, 0, 1}}, {0.3333333333333333, {3, 0, 12}}, {
     Complex[0., -0.16666666666666666`], {4, 0, 6}}, {-0.3333333333333333, {3,
      0, 13}}, {0., {3, 0, 4}}, {
     Complex[0., -1.], {4, 0, 0}}, {
     Complex[0., 0.16666666666666666`], {4, 0, 8}}, {1, {2, 0, 0}}, {
     Complex[0., 1.], {4, 0, 3}}}, {0, 2, 142, 212, 
   1}, {{11, 0, 4, 1}, {17, 0, 1, 2}, {40, 32, 4, 0, 2, 4, 0, 1}, {11, 3, 4, 
    4}, {17, 3, 4, 5}, {40, 32, 4, 0, 5, 4, 0, 4}, {17, 6, 4, 7}, {17, 8, 1, 
    9}, {11, 1, 4, 10}, {17, 0, 10, 11}, {40, 32, 4, 0, 11, 4, 0, 10}, {17, 8,
     10, 12}, {17, 6, 1, 13}, {11, 2, 4, 14}, {17, 3, 14, 15}, {40, 32, 4, 0, 
    15, 4, 0, 14}, {17, 6, 14, 16}, {13, 0, 3, 5}, {19, 2, 6}, {13, 1, 6, 
    7}, {11, 7, 4, 17}, {17, 0, 17, 18}, {40, 32, 4, 0, 18, 4, 0, 17}, {17, 8,
     4, 19}, {11, 0, 4, 20}, {17, 3, 20, 21}, {40, 32, 4, 0, 21, 4, 0, 20}, {
    11, 1, 4, 22}, {17, 3, 22, 23}, {40, 32, 4, 0, 23, 4, 0, 22}, {11, 5, 4, 
    24}, {17, 3, 24, 25}, {40, 32, 4, 0, 25, 4, 0, 24}, {11, 2, 4, 26}, {17, 
    0, 26, 27}, {40, 32, 4, 0, 27, 4, 0, 26}, {11, 3, 4, 28}, {17, 0, 28, 
    29}, {40, 32, 4, 0, 29, 4, 0, 28}, {17, 8, 28, 30}, {11, 7, 4, 31}, {17, 
    3, 31, 32}, {40, 32, 4, 0, 32, 4, 0, 31}, {17, 6, 26, 33}, {11, 5, 4, 
    34}, {17, 0, 34, 35}, {40, 32, 4, 0, 35, 4, 0, 34}, {17, 8, 26, 36}, {19, 
    1, 8}, {13, 0, 8, 9}, {19, 3, 10}, {13, 2, 10, 11}, {11, 11, 4, 37}, {17, 
    0, 37, 38}, {40, 32, 4, 0, 38, 4, 0, 37}, {17, 6, 10, 39}, {11, 9, 4, 
    40}, {17, 3, 40, 41}, {40, 32, 4, 0, 41, 4, 0, 40}, {17, 6, 20, 42}, {17, 
    8, 22, 43}, {17, 6, 22, 44}, {11, 11, 4, 45}, {17, 3, 45, 46}, {40, 32, 4,
     0, 46, 4, 0, 45}, {17, 8, 14, 47}, {11, 9, 4, 48}, {17, 0, 48, 49}, {40, 
    32, 4, 0, 49, 4, 0, 48}, {17, 8, 20, 50}, {17, 6, 28, 51}, {17, 6, 48, 
    52}, {17, 8, 37, 53}, {17, 8, 34, 54}, {17, 6, 17, 55}, {17, 6, 24, 56}, {
    17, 8, 17, 57}, {17, 6, 31, 58}, {17, 8, 24, 59}, {17, 8, 31, 60}, {17, 6,
     34, 61}, {17, 8, 40, 62}, {17, 6, 37, 63}, {17, 8, 45, 64}, {17, 6, 40, 
    65}, {17, 6, 45, 66}, {17, 8, 48, 67}, {11, 12, 4, 68}, {10, 0, 14}, {11, 
    14, 4, 69}, {10, 0, 15}, {11, 15, 4, 70}, {10, 0, 16}, {11, 16, 4, 71}, {
    10, 1, 17}, {11, 17, 4, 72}, {10, 1, 18}, {11, 18, 4, 73}, {10, 1, 19}, {
    11, 19, 4, 74}, {10, 1, 20}, {11, 20, 4, 75}, {10, 1, 21}, {11, 21, 4, 
    76}, {10, 1, 22}, {11, 22, 4, 77}, {10, 0, 23}, {11, 23, 4, 78}, {11, 13, 
    4, 79}, {10, 0, 24}, {11, 24, 4, 80}, {10, 0, 25}, {11, 25, 4, 81}, {10, 
    1, 26}, {11, 26, 4, 82}, {10, 1, 27}, {11, 27, 4, 83}, {10, 1, 28}, {11, 
    28, 4, 84}, {10, 1, 29}, {11, 29, 4, 85}, {10, 1, 30}, {11, 30, 4, 86}, {
    10, 1, 31}, {11, 31, 4, 87}, {10, 0, 32}, {11, 32, 4, 88}, {11, 13, 4, 
    89}, {10, 1, 33}, {11, 33, 4, 90}, {10, 1, 34}, {11, 34, 4, 91}, {10, 0, 
    35}, {11, 35, 4, 92}, {10, 0, 36}, {11, 36, 4, 93}, {10, 1, 37}, {11, 37, 
    4, 94}, {10, 1, 38}, {11, 38, 4, 95}, {10, 1, 39}, {11, 39, 4, 96}, {10, 
    1, 40}, {11, 40, 4, 97}, {10, 0, 41}, {11, 41, 4, 98}, {11, 13, 4, 99}, {
    10, 1, 42}, {11, 42, 4, 100}, {10, 1, 43}, {11, 43, 4, 101}, {10, 1, 
    44}, {11, 44, 4, 102}, {10, 1, 45}, {11, 45, 4, 103}, {10, 1, 46}, {11, 
    46, 4, 104}, {10, 1, 47}, {11, 47, 4, 105}, {10, 0, 48}, {11, 48, 4, 
    106}, {10, 1, 49}, {11, 49, 4, 107}, {10, 1, 50}, {11, 50, 4, 108}, {11, 
    12, 4, 109}, {10, 1, 51}, {11, 51, 4, 110}, {10, 0, 52}, {11, 52, 4, 
    111}, {10, 0, 53}, {11, 53, 4, 112}, {10, 1, 54}, {11, 54, 4, 113}, {10, 
    1, 55}, {11, 55, 4, 114}, {10, 1, 56}, {11, 56, 4, 115}, {10, 0, 57}, {11,
     57, 4, 116}, {10, 1, 58}, {11, 58, 4, 117}, {10, 1, 59}, {11, 59, 4, 
    118}, {11, 12, 4, 119}, {10, 1, 60}, {11, 60, 4, 120}, {10, 1, 61}, {11, 
    61, 4, 121}, {10, 1, 62}, {11, 62, 4, 122}, {10, 1, 63}, {11, 63, 4, 
    123}, {10, 1, 64}, {11, 64, 4, 124}, {10, 0, 65}, {11, 65, 4, 125}, {10, 
    1, 66}, {11, 66, 4, 126}, {10, 1, 67}, {11, 67, 4, 127}, {11, 12, 4, 
    128}, {10, 1, 68}, {11, 68, 4, 129}, {10, 1, 69}, {11, 69, 4, 130}, {10, 
    1, 70}, {11, 70, 4, 131}, {10, 0, 71}, {11, 71, 4, 132}, {10, 0, 72}, {11,
     72, 4, 133}, {10, 1, 73}, {11, 73, 4, 134}, {10, 0, 74}, {11, 74, 4, 
    135}, {10, 1, 75}, {11, 75, 4, 136}, {11, 12, 4, 137}, {10, 1, 76}, {11, 
    76, 4, 138}, {10, 1, 77}, {11, 77, 4, 139}, {10, 1, 78}, {11, 78, 4, 
    140}, {10, 1, 79}, {11, 79, 4, 141}, {10, 1, 80}, {11, 80, 4, 142}, {10, 
    1, 81}, {11, 81, 4, 143}, {10, 1, 82}, {11, 82, 4, 144}, {11, 12, 4, 
    145}, {10, 1, 83}, {11, 83, 4, 146}, {10, 1, 84}, {11, 84, 4, 147}, {10, 
    0, 85}, {11, 85, 4, 148}, {10, 1, 86}, {11, 86, 4, 149}, {10, 1, 87}, {11,
     87, 4, 150}, {10, 1, 88}, {11, 88, 4, 151}, {10, 0, 89}, {11, 89, 4, 
    152}, {10, 1, 90}, {11, 90, 4, 153}, {10, 1, 91}, {11, 91, 4, 154}, {10, 
    1, 92}, {11, 92, 4, 155}, {10, 1, 93}, {11, 93, 4, 156}, {11, 13, 4, 
    157}, {10, 0, 94}, {11, 94, 4, 158}, {10, 0, 95}, {11, 95, 4, 159}, {10, 
    1, 96}, {11, 96, 4, 160}, {10, 1, 97}, {11, 97, 4, 161}, {10, 1, 98}, {11,
     98, 4, 162}, {10, 0, 99}, {11, 99, 4, 163}, {11, 12, 4, 164}, {10, 1, 
    100}, {11, 100, 4, 165}, {10, 1, 101}, {11, 101, 4, 166}, {10, 1, 102}, {
    11, 102, 4, 167}, {10, 1, 103}, {11, 103, 4, 168}, {10, 0, 104}, {11, 104,
     4, 169}, {10, 1, 105}, {11, 105, 4, 170}, {10, 1, 106}, {11, 106, 4, 
    171}, {10, 1, 107}, {11, 107, 4, 172}, {11, 13, 4, 173}, {10, 1, 108}, {
    11, 108, 4, 174}, {10, 1, 109}, {11, 109, 4, 175}, {10, 1, 110}, {11, 110,
     4, 176}, {10, 1, 111}, {11, 111, 4, 177}, {10, 1, 112}, {11, 112, 4, 
    178}, {10, 1, 113}, {11, 113, 4, 179}, {10, 1, 114}, {11, 114, 4, 180}, {
    10, 1, 115}, {11, 115, 4, 181}, {11, 13, 4, 182}, {10, 0, 116}, {11, 116, 
    4, 183}, {10, 1, 117}, {11, 117, 4, 184}, {10, 1, 118}, {11, 118, 4, 
    185}, {10, 1, 119}, {11, 119, 4, 186}, {10, 1, 120}, {11, 120, 4, 187}, {
    10, 0, 121}, {11, 121, 4, 188}, {10, 1, 122}, {11, 122, 4, 189}, {10, 0, 
    123}, {11, 123, 4, 190}, {10, 1, 124}, {11, 124, 4, 191}, {11, 13, 4, 
    192}, {10, 0, 125}, {11, 125, 4, 193}, {10, 1, 126}, {11, 126, 4, 194}, {
    10, 1, 127}, {11, 127, 4, 195}, {10, 0, 128}, {11, 128, 4, 196}, {10, 1, 
    129}, {11, 129, 4, 197}, {10, 1, 130}, {11, 130, 4, 198}, {10, 1, 131}, {
    11, 131, 4, 199}, {11, 13, 4, 200}, {10, 1, 132}, {11, 132, 4, 201}, {10, 
    1, 133}, {11, 133, 4, 202}, {10, 1, 134}, {11, 134, 4, 203}, {10, 1, 
    135}, {11, 135, 4, 204}, {10, 1, 136}, {11, 136, 4, 205}, {10, 0, 137}, {
    11, 137, 4, 206}, {10, 1, 138}, {11, 138, 4, 207}, {10, 0, 139}, {11, 139,
     4, 208}, {10, 0, 140}, {11, 140, 4, 209}, {10, 1, 141}, {11, 141, 4, 
    210}, {11, 12, 4, 211}, {34, 2, 16, 16, 68, 69, 70, 71, 8, 6, 6, 8, 9, 72,
     7, 73, 74, 75, 76, 77, 78, 79, 6, 8, 80, 81, 82, 83, 84, 8, 85, 6, 13, 
    86, 12, 87, 88, 8, 89, 6, 90, 91, 92, 93, 94, 95, 96, 16, 19, 6, 8, 97, 
    98, 6, 8, 99, 100, 101, 102, 103, 1, 7, 4, 52, 104, 9, 53, 105, 6, 106, 
    107, 108, 109, 8, 110, 36, 39, 111, 6, 112, 113, 114, 115, 8, 8, 116, 117,
     118, 6, 119, 12, 54, 120, 121, 55, 122, 1, 123, 10, 13, 8, 124, 125, 126,
     127, 44, 128, 6, 8, 129, 47, 130, 131, 132, 133, 6, 6, 134, 135, 136, 16,
     56, 8, 137, 57, 138, 139, 14, 4, 140, 141, 19, 42, 142, 143, 20, 43, 144,
     6, 58, 145, 146, 59, 22, 147, 148, 149, 8, 150, 6, 151, 30, 152, 153, 
    154, 155, 156, 157, 158, 8, 6, 8, 33, 159, 30, 160, 161, 28, 8, 60, 33, 
    162, 61, 163, 164, 165, 166, 167, 26, 6, 168, 8, 36, 62, 169, 170, 171, 
    26, 10, 6, 172, 173, 63, 39, 174, 175, 176, 50, 51, 177, 178, 20, 179, 28,
     180, 8, 181, 64, 182, 6, 65, 183, 184, 185, 8, 42, 186, 187, 188, 189, 
    190, 6, 191, 43, 8, 192, 6, 193, 194, 44, 6, 66, 195, 22, 196, 197, 198, 
    47, 14, 199, 67, 8, 200, 201, 202, 203, 204, 205, 6, 50, 8, 51, 6, 206, 8,
     207, 208, 209, 210, 211, 4, 0}, {1}}, 
   Function[{
    PatrickMLenggenhager`HyperBloch`Private`k$213150, 
     PatrickMLenggenhager`HyperBloch`Private`k$213151, 
     PatrickMLenggenhager`HyperBloch`Private`k$213152, 
     PatrickMLenggenhager`HyperBloch`Private`k$213153}, 
    Block[{
     Compile`$2, Compile`$3, Compile`$6, Compile`$7, Compile`$8, Compile`$5, 
      Compile`$10, Compile`$11, Compile`$12, Compile`$9, Compile`$13, 
      Compile`$14, Compile`$15, Compile`$31, Compile`$35, Compile`$36, 
      Compile`$37, Compile`$38, Compile`$16, Compile`$48, Compile`$49, 
      Compile`$40, Compile`$41, Compile`$44, Compile`$45, Compile`$27, 
      Compile`$28, Compile`$56, Compile`$57, Compile`$58, Compile`$52, 
      Compile`$53, Compile`$59, Compile`$32, Compile`$33, Compile`$29, 
      Compile`$17, Compile`$18, Compile`$22, Compile`$23, Compile`$24, 
      Compile`$25, Compile`$30, Compile`$62, Compile`$63, Compile`$50, 
      Compile`$51, Compile`$42, Compile`$68, Compile`$69, Compile`$43, 
      Compile`$19, Compile`$20, Compile`$66, Compile`$67}, 
     Compile`$2 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$213150; 
     Compile`$3 = E^Compile`$2; 
     Compile`$6 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$213153; 
     Compile`$7 = E^Compile`$6; Compile`$8 = Complex[0, 
         Rational[-1, 6]] Compile`$7; Compile`$5 = Complex[0, 
         Rational[1, 6]] Compile`$3; 
     Compile`$10 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$213151; 
     Compile`$11 = E^Compile`$10; Compile`$12 = Complex[0, 
         Rational[1, 6]] Compile`$11; Compile`$9 = Complex[0, 
         Rational[-1, 6]] Compile`$3; 
     Compile`$13 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$213152; 
     Compile`$14 = E^Compile`$13; Compile`$15 = Complex[0, 
         Rational[-1, 6]] Compile`$14; 
     Compile`$31 = 
      PatrickMLenggenhager`HyperBloch`Private`k$213150 + 
       PatrickMLenggenhager`HyperBloch`Private`k$213153; 
     Compile`$35 = -PatrickMLenggenhager`HyperBloch`Private`k$213152; 
     Compile`$36 = 
      PatrickMLenggenhager`HyperBloch`Private`k$213151 + Compile`$35; 
     Compile`$37 = Complex[0, -1] Compile`$36; Compile`$38 = E^Compile`$37; 
     Compile`$16 = Complex[0, 
         Rational[1, 6]] Compile`$7; 
     Compile`$48 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$213150; 
     Compile`$49 = E^Compile`$48; 
     Compile`$40 = 
      Complex[0, 1] PatrickMLenggenhager`HyperBloch`Private`k$213151; 
     Compile`$41 = E^Compile`$40; Compile`$44 = Complex[0, 1] Compile`$31; 
     Compile`$45 = E^Compile`$44; 
     Compile`$27 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$213152; 
     Compile`$28 = E^Compile`$27; 
     Compile`$56 = 
      Complex[0, -1] PatrickMLenggenhager`HyperBloch`Private`k$213153; 
     Compile`$57 = E^Compile`$56; Compile`$58 = Complex[0, 
         Rational[1, 6]] Compile`$57; Compile`$52 = Complex[0, 1] Compile`$36; 
     Compile`$53 = E^Compile`$52; Compile`$59 = Complex[0, 
         Rational[-1, 6]] Compile`$28; 
     Compile`$32 = Complex[0, -1] Compile`$31; Compile`$33 = E^Compile`$32; 
     Compile`$29 = Complex[0, 
         Rational[1, 6]] Compile`$28; 
     Compile`$17 = -PatrickMLenggenhager`HyperBloch`Private`k$213151; 
     Compile`$18 = 
      PatrickMLenggenhager`HyperBloch`Private`k$213150 + Compile`$17; 
     Compile`$22 = -PatrickMLenggenhager`HyperBloch`Private`k$213153; 
     Compile`$23 = 
      PatrickMLenggenhager`HyperBloch`Private`k$213152 + Compile`$22; 
     Compile`$24 = Complex[0, -1] Compile`$23; Compile`$25 = E^Compile`$24; 
     Compile`$30 = Complex[0, 
         Rational[-1, 6]] Compile`$11; 
     Compile`$62 = Complex[0, 1] Compile`$18; Compile`$63 = E^Compile`$62; 
     Compile`$50 = Complex[0, 
         Rational[-1, 6]] Compile`$49; Compile`$51 = Complex[0, 
         Rational[1, 6]] Compile`$41; Compile`$42 = Complex[0, 
         Rational[-1, 6]] Compile`$41; 
     Compile`$68 = Complex[0, 1] Compile`$23; Compile`$69 = E^Compile`$68; 
     Compile`$43 = Complex[0, 
         Rational[1, 6]] Compile`$14; 
     Compile`$19 = Complex[0, -1] Compile`$18; Compile`$20 = E^Compile`$19; 
     Compile`$66 = Complex[0, 
         Rational[1, 6]] Compile`$49; Compile`$67 = Complex[0, 
         Rational[-1, 6]] Compile`$57; {{
        Rational[1, 3], 1, 1, 1, 
        Complex[0, 
         Rational[1, 6]], 
        Complex[0, 
         Rational[-1, 6]], 
        Complex[0, 
         Rational[-1, 6]], 
        Complex[0, 
         Rational[1, 6]], Compile`$5, 0, Compile`$8, 0, 0, 0, 0, 0}, {1, 
        Rational[-1, 3], 
        Complex[0, 
         Rational[-1, 6]], 
        Complex[0, 
         Rational[1, 6]], 1, 1, 0, 0, 0, 
        Complex[0, 
         Rational[1, 6]], 0, 
        Complex[0, 
         Rational[-1, 6]], Compile`$9, 0, Compile`$12, 0}, {1, 
        Complex[0, 
         Rational[1, 6]], 
        Rational[-1, 3], 
        Complex[0, 
         Rational[-1, 6]], 0, 0, 1, 1, 0, 0, 0, Compile`$15, Compile`$16, 
        Complex[0, 
         Rational[-1, 6]], 
        Complex[0, 
         Rational[1, 6]], 0}, {1, 
        Complex[0, 
         Rational[-1, 6]], 
        Complex[0, 
         Rational[1, 6]], 
        Rational[-1, 3], 0, 0, 0, 0, Compile`$3, Compile`$8, Compile`$7, 
        Complex[0, 
          Rational[-1, 6]] Compile`$20, 0, Compile`$5, Complex[0, 
          Rational[1, 6]] Compile`$25, 0}, {
        Complex[0, 
         Rational[-1, 6]], 1, 0, 0, 
        Rational[1, 3], 
        Complex[0, 
         Rational[1, 6]], 0, Compile`$29, Compile`$30, 1, 
        Complex[0, 
         Rational[-1, 6]], 1, 0, 0, 0, 
        Complex[0, 
         Rational[1, 6]]}, {
        Complex[0, 
         Rational[1, 6]], 1, 0, 0, 
        Complex[0, 
         Rational[-1, 6]], 
        Rational[1, 3], Compile`$12, Complex[0, 
          Rational[1, 6]] Compile`$33, 0, 0, Complex[0, 
          Rational[-1, 6]] Compile`$38, 0, Compile`$3, 0, Compile`$11, 
        Compile`$9}, {
        Complex[0, 
         Rational[1, 6]], 0, 1, 0, 0, Compile`$42, 
        Rational[1, 3], 
        Complex[0, 
         Rational[-1, 6]], 
        Complex[0, 
         Rational[1, 6]], 0, Compile`$43, 0, 0, 1, 1, 
        Complex[0, 
         Rational[-1, 6]]}, {
        Complex[0, 
         Rational[-1, 6]], 0, 1, 0, Compile`$15, Complex[0, 
          Rational[-1, 6]] Compile`$45, 
        Complex[0, 
         Rational[1, 6]], 
        Rational[1, 3], Complex[0, 
          Rational[1, 6]] Compile`$38, 0, 0, Compile`$14, Compile`$7, 0, 0, 
        Compile`$16}, {Compile`$50, 0, 0, Compile`$49, Compile`$51, 0, 
        Complex[0, 
         Rational[-1, 6]], Complex[0, 
          Rational[-1, 6]] Compile`$53, 
        Rational[1, 3], 0, Complex[0, 
          Rational[1, 6]] Compile`$45, Compile`$41, 0, 1, 0, 
        Complex[0, 
         Rational[1, 6]]}, {0, 
        Complex[0, 
         Rational[-1, 6]], 0, Compile`$58, 1, 0, 0, 0, 0, 
        Rational[-1, 3], 1, 
        Complex[0, 
         Rational[1, 6]], 
        Complex[0, 
         Rational[-1, 6]], 
        Complex[0, 
         Rational[1, 6]], Compile`$59, 1}, {Compile`$58, 0, 0, Compile`$57, 
        Complex[0, 
         Rational[1, 6]], Complex[0, 
          Rational[1, 6]] Compile`$53, Compile`$59, 0, Complex[0, 
          Rational[-1, 6]] Compile`$33, 1, 
        Rational[1, 3], 0, 0, 0, Compile`$28, 
        Complex[0, 
         Rational[-1, 6]]}, {0, 
        Complex[0, 
         Rational[1, 6]], Compile`$29, Complex[0, 
          Rational[1, 6]] Compile`$63, 1, 0, 0, Compile`$28, Compile`$11, 
        Complex[0, 
         Rational[-1, 6]], 0, 
        Rational[-1, 3], Complex[0, 
          Rational[-1, 6]] Compile`$25, Compile`$30, 0, 0}, {
       0, Compile`$66, Compile`$67, 0, 0, Compile`$49, 0, Compile`$57, 0, 
        Complex[0, 
         Rational[1, 6]], 0, Complex[0, 
          Rational[1, 6]] Compile`$69, 
        Rational[-1, 3], 
        Complex[0, 
         Rational[-1, 6]], Complex[0, 
          Rational[-1, 6]] Compile`$63, 1}, {0, 0, 
        Complex[0, 
         Rational[1, 6]], Compile`$50, 0, 0, 1, 0, 1, 
        Complex[0, 
         Rational[-1, 6]], 0, Compile`$51, 
        Complex[0, 
         Rational[1, 6]], 
        Rational[-1, 3], 
        Complex[0, 
         Rational[-1, 6]], 1}, {0, Compile`$42, 
        Complex[0, 
         Rational[-1, 6]], Complex[0, 
          Rational[-1, 6]] Compile`$69, 0, Compile`$41, 1, 0, 0, Compile`$43, 
        Compile`$14, 0, Complex[0, 
          Rational[1, 6]] Compile`$20, 
        Complex[0, 
         Rational[1, 6]], 
        Rational[-1, 3], 0}, {0, 0, 0, 0, 
        Complex[0, 
         Rational[-1, 6]], Compile`$66, 
        Complex[0, 
         Rational[1, 6]], Compile`$67, 
        Complex[0, 
         Rational[-1, 6]], 1, 
        Complex[0, 
         Rational[1, 6]], 0, 1, 1, 0, 
        Rational[1, 3]}}]], Evaluate],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.9091129975570006`*^9, 3.909113219916849*^9, 
  3.909115025816557*^9, 3.9101534280800033`*^9, 3.910156813155707*^9, 
  3.9101614128065453`*^9, 3.9101652925382805`*^9, 3.910165619004306*^9, 
  3.910165724183712*^9, 3.9101665511186914`*^9, 3.910176124099779*^9, 
  3.910176257969966*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"9ae79b10-a8b8-4907-9e1e-707a16a2e10b"]
}, Open  ]],

Cell[TextData[{
 "As stated in the paper, we compute the DOS with an energy resolution of \
0.005 (but for demonstration purposes with a smaller sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "c9a14357-e476-466f-bbc7-1737b39471b8"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "8"], TraditionalForm]],ExpressionUUID->
  "a6f04569-c822-4069-b916-bd1e4ff8b573"],
 ")"
}], "Text",
 CellChangeTimes->{{3.909113068779531*^9, 3.9091131190954094`*^9}, {
  3.9101614549615393`*^9, 3.9101614564987535`*^9}, {3.910161500131562*^9, 
  3.910161500190627*^9}},ExpressionUUID->"357f7797-1983-43e7-adfa-\
48146443f21a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dospc", "=", 
   RowBox[{"ComputeDOS", "[", 
    RowBox[{"Hpccf", ",", 
     RowBox[{"10", "^", "5"}], ",", "32", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3.3"}], "-", "0.005"}], ",", "3.3"}], "}"}], ",", 
     "0.005"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091130888235645`*^9, 3.9091130961532984`*^9}, {
   3.90911413019394*^9, 3.9091141332449045`*^9}, {3.910161490577303*^9, 
   3.910161498644859*^9}, {3.9101656308871603`*^9, 3.9101656373735223`*^9}, {
   3.910176146109257*^9, 3.9101761506408443`*^9}, 3.910176221009781*^9, {
   3.910176351796934*^9, 3.9101763539143457`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"c2c0a132-c31b-453b-903c-b9573dd46dc5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"dospc", ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.1); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(5\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909113125377311*^9, 3.9091131344978976`*^9}, {
  3.90911413604417*^9, 3.9091141363413095`*^9}, {3.9091150932516265`*^9, 
  3.9091150966947627`*^9}, {3.909126411615711*^9, 3.909126429281196*^9}, {
  3.910161469973936*^9, 3.910161470044631*^9}, {3.910161502500625*^9, 
  3.9101615076578336`*^9}, {3.9101657725552626`*^9, 3.9101657844493575`*^9}, {
  3.9101762243133035`*^9, 3.910176224670022*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"618e713b-0c93-4697-add6-a19fd8f704fd"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.006944444444444445], AbsoluteThickness[2], LineBox[CompressedData["
1:eJxd3Ht8n1V9B/Df/VeYU6bToVOHyhjMW9XpqtN9z5zTqbih8FKmzFWEydAp
Q9wQHVZFAUUFREFlUECgVijphVJ6OyeXJuklye+atGnapG2aJmmTprnfszzn
8znPeb1O/5B91/S5nPc533PO93mevOHar33q+lQikbgsm0hE/z39yW2v/8GX
zzcJ/jl22x9v+MgXfNz+xE0fOP8zPj4Q/bncx3UTl17zsw/6ePlopz+5yscb
PrJ8xLf5ODpcx5t8/Kvoz6t9/LPogC/z8R3RBWZ9HF3esdnz4jg63BMjPv73
6E+fj6+JDtjl4+h2Txd9HF3ehiYfR4e7aZeP3/mu5T+bfXxpdMB1Po5ud9sj
Po4u77YHfBwd7gM/8vFS9Oc7Po6ar+4bPoaHj+HhY3j4GB4+hoeP4eFjePgY
Hj6Gh4/h4WN4+BgeK+IYHj6Gh4/h4WN4+BgePoaHj+HhY3j4GB4+hoeP4eFj
ePgYHj6Gh4/h4WN4+BgePoaHj+Hh42eth4/hscLM3n7jzlt+vkrg4eIbBB4r
zJvvfNWh1qmvCzxWmM7WqStPPPktgUfezP/uXOkT164ReOTNH0T3ff6dAo+8
uerEk79puOhegUfefAsNJfDImzcdnlk+4wMCj7xZqtw6cMk7HhJ4+BgeeXNJ
7ru/+PsfPyzwyJvznnntZ6/7m0cFHnnzyNmnGz/+148JTpM3k/YH1wo88qav
8MblMz4u8Mgbe7kdTwg88uY/7hv6trz7KYFH3qxbPtrdf7dO4JE3Sdt66wQe
eTN4yTtWPPPa9QKPvHnd8tV0//OzAo+8+foN0QGfFXjkzXei5r2wRuCRN3/6
9iMX5767UeCRN/907QVXv3dLDT3y5kV7Y5vokTe1+x77h61jG+mRN4u2fbbQ
I2c+vHVsoXLr8/TImS9Hp8tspUfOXL58N6tPbqFHju27jR458xfR7Xx2Gz1y
Zu1rogt8kR4584rvm+Ur2E6PnOmK+G7ZQY+ceb75v3c/+pod9MiZkYjj7l30
yLF9d9MjZ+ptw++iR858cyBqUEOPnJm+MupAhh45Y/PKhlp65My9tqHr6JFj
f6yjR8584WQEXkcPd38N9HDXt4ceOXo10SNneqPuW9NIj5z5c9v/mumRY/9t
pkfOXL+s/5MH99Eja9ZY7wP0yJoPro4uqIUeWfOfp+aWr7hNPmc9smZVxFMo
0iPL6y/Sw8UlemTNh378leUjlOVd1iNrzth/WKZH1hy3F1KmR9Y0Rd15dYUe
WfbvKj2yRj8agVfpkTXfWO49n35plR5Z9tcqPbLmnVFzXlehR9a80gJV6JE1
7/n89o++JFWmR9ZErfeVU0V6+PuFR9Z85qVv3fR/Z9vokTX9UfN8opUeWfMn
h6IEtJ8eWY7nffTImh/aC9tLjyzHUyM9MuwvDfTI0LOOHu7vDT0y5r/Q0PTI
8Hq20yPD8b+VHhnzL+/dsjwCNtMjw/atoUfG/FvUHG9+jh4Z87Lodp/eQI+M
+VHUHG/8PT0yzHfP0CNjno3SXfdz9MiYPRfV3HzDfRvpkTF/dHV0AZvokWG+
3UKPjLk/Gn6f30oPd38v0iNjNt4cDYAd9HDn30mPDPNrLT3cz9fSI8P2bqBH
hv19Dz0yRr076hDN9Egzn+6jR5r9yY2PtHnoqy9fzjgFeqSZz9z4SBvbfI0l
eqR5f2V6pM0/2oao0CNtPrbc+ne+qkqPtPnpg9EJqvRI8/ra6ZE21Sg9rmin
R5r368aHu54KPdLmX+2NV+iRZvuX6ZE2eTsAyvRIczyV6JE2X4tu9zE3Ptz1
u/GRZj4s0CPNfN9GD3c9rfRIm1/b/6OFHmnTYk+0jx5pU/lEBObyVYr5oYke
KbM5at6PN9EjZd4fpbevNtAjxXxTT4+U+cOoeQ/V0SNlfmsPVEePFK+vjh4p
jj9DjxTna0OPFPtzHT1S5pdR+pirp0eK91NHjxQ9G+jhrqeBHinznL2wPfRI
mbui5c2VTfRIMX800cPdbzM9UuaOaPrbupceKfMl2zD76OGu/wA9UpxPWujh
fr6VHu54bfID6+HO30aPJNcLBXokzd/aGy/QI8n1ixsfSfNn9kBufCTNF6Ph
2FygR9LsjabntxfpkTTvi9LVo0V6JOP+Bo+k2RVxfbpIjyTzX4keSa7vSnKe
9UjG+R0eSa4fSvRImp6oOV9eokeS+a5EjyT7U4keSVO2/dPNH0nzaTs/lOmR
NOuj6f6CsrxgPZLMP2V6JM3/RLd7pEyPJPtbmR7ufsr0SHL+qtIjyfFTpkfC
PBUtB26u0CMRz4/wSHD8VuiR4PVV6ZEwn7Idp0qPhNkRTQd3VumRYHu10yPB
9YfLVwmuF1y+SgT5yp2vnR6J+H7gkTAPR5d/g8tXCba/y1cJc/TiqIFcvkpw
PePyVYLtUaRHgvOXy1cJtn+BHgnmyyI9ElxfFOnh/n2BHgnmzyI9EmZ/tNxd
KNIjwf5TlHHbIEsa46MkPRZoSb8QpcMB5tMDSxr9p4Lr2baksR6pyuMWcEkj
/7bLT+0NLGkcvwPety1p5IcOud4CL2ms7w/KFdZxSSOfdcr77bhc0sg3nfC6
dEm/zc5PXfIK67CkMd6PyKIFWdRYPxyVQdtBFnm8o2jvjkUNvyNSa8EW9YJd
3x6RZ2wHWuTxuuQh24CLGvmwC/n9B4sa+7Uu+ZrtYIv6iag5K0fRP69Z1N+z
47VbPmzBF3Uh+vHfdGN9/65FPRp1p6s70d9ev6iRPzvQv853cYUeCxrreeex
oDF/s78cWNBt9vhFeizoN0TLl6ESPRa067/wWNDwdx4LGv3/MD0W2F499FjQ
Nl8PH6fHAq7vbQP0WNB2P7VqiB4LGnWKEXrMw//+UXrM6ydtPx2mx7y24/OH
ffSY18gfx+gxr39n13uH6TGvkf8P0mNeYz9doce8xnqlKJ+1HvN6OAq3t9Fj
Xq+Muucv9tJjXmM/0UyPeY31Uj095jX2V4Yec/TcSY85jfz0PD3mdNYm1Ofo
MaeR75+ix5z+S9tuD9NjTmN/9m16zGlXT4CHj+HhY3j4GB4+hoeP4TEbx/Dw
MTx8DA8fw8PH8PAxPHwMDx/Dw8fw8DE8fAwPH8PDx/CYiWN4+BgePoaHj+Hh
Y3j4GB4zgcdM4DETeMwEHjOBx0zgMR14TAce04HHdOAxHXhMBx7Tgcd04DEd
eEwHHtOBx3TgMR14TAUeU4HHVOAxFXhMBR5TgcdU4DEVeEwFHlOBx1TgMRV4
TAYek4HHZOAxGXhMBh6Tgcdk4DEZeEwGHpOBx2TgMRl4TAYeE4HHROAxEXhM
BB4TgcdE4DEReEwEHhOBx0TgMRF4TAQe44HHeOAxHniMBx7jgcd44DEeeIwH
HuOBx3jgMR54jAce44HHWOAxFniMBR5jgcdY4DEWeIwFHmOBx1jgMRZ4jAUe
Y4HHaOAxGniMBh6jgcdo4DEaeIwGHqOBx2jgMRp4+Ph11sPHK6zHaOBxLvA4
F3icCzzOBR7nAo9zgce5wONc4HEu8DgXeJwLPM4FHiOBx0jgMaJRL7mK66sR
ro9v4/pqhOu9H3J9NaJRD7mX66sRjf3HQ1xfueOv5fpqRBejcuGNv+X6aoTr
66e4vhrRqG9vEHiM6PFoO3HJRoHHCPcDm6XfXv9ZjfrGFjH2es/y+rfx+s5q
1Jt2yVft9Zzl+Yx8yJ7/LNdbdfJae76zGvXoJq7fhjXqoftln/Ud5v6mVdba
8w7rB6Lt51sLcqs977DG85si18PDGvv5klxifYa121/NW48htm9JKrb9hzTq
U0W295BGva8k37PtO8T9U0mutscZYnuVZKVtvyGN5wsltteQxn69JEdtBzuj
UY8oyxbbP89oW97ZXZJ7bH88o1GfL8p1tv+d0XY71VqU99n+dobr7aJcYNvx
DNbvG4r0OK1RPynS47RGfbNIj9P0KNLjtEZ9qUCP0xr1jAI9TvN+3X5zkO1R
oMcg+0MbPQY16u3OY1Dj+VSBHoMaz2sK9Bhke7fRY0Bjf91GjwFefxs9Brjf
aqPHgEb9u5UeAxr1r1Z6DGjsr1vp4Y8Pj379FrsfaaFHP/cjrfTo5/q/lR79
Gvv5Fnr0a9QHDtCjn+drpscp7kcb6XFKoz5eT49TGvX8enqc0qh31NHjlP4r
ex+19DjF/XctPfo06juGHn1sH02PPrbPbnr08fi76dHH/rubHn0a9bDd9Dip
Ua/bTY+TGs+7ND1Oxv8eHif1PdHjmHO76XFSo561ix4n2T81PU5iP7ptNz16
WT8w9OjVn4tu9ye19OhlPtD06GX7G3r0sp5RS49efUVUzvh+HT1OcH9eS48T
GvXKOnqc0Gk73pzHCY36UgM9TnD/XU+PE/RuoMdxjecTe+hxnPWHPfQ4rvG8
ookex5mPm+lxnNe3lx7H9e9tPWAfPY4xP+6nxzH+/QF6HNO3R9vnj7bS4xjH
axs9jjHfFelxTKNe6vLVMebvCj16OF7a6dHD/tpBjx6N+t0hevRwf9xJjx79
tK0XdtGjR19snxcekYK9/m70jy/3yBp7vd3IH1/o4fUxPtYtXfa/R1mfOip3
2fMf5X6/U1bZ8x1l/myn9xHtnv89YO/jCNu3KMp6HtGoZxZkxPp1aTy/d/ms
i+N1v1xufbri9p+2Hodjv3W2/Q9rPO9pYnsfZvs2ScYe9zD7Y6PU2PbsZH1k
j6y27dep8bylge3VGfe/nfa6DzEf1ssN9r+HON/XyYX2PIe0e97bbPvfQeb7
ernFuh6kT51cZPuX/3t4dLAeVUePDtZL6unRoV8dTbeb9tCjnfmoiR7tHA+N
9GjXqHc20qPK8bWXHlXOP/voUeX1tNGjwvxXpEeF479KjwrzSzs9yrE/PMqs
j7bTo8zx0E6PMut7VXqUmE8r9Cix/lSlR0mj3t1Oj6LG+whVehS53uigR5Hr
pw56FNg/qvQo8Pqq9Cho1McrshbzHNujJAn0S9a/luc7PEdh/2+WGns9Lfpx
W99slAvs+VvY3+vlJnu+A9o9r4T3fo53I5fadt6v223/2ylrrOc+er0gPbad
92q837CZXntRD8xtlIesTzPXJ+tlxHo0cT5eL1fY9m/ifPIU27uR+eUxWWHb
t5Eej8lq2557NJ73/FqMbb8G/vyv2F4NXH/8XG61/bVe432A+6Rg+2edxvO7
O2WlPU5dvH6+1x6mluP7O9KP526cP74hyjq4+HpR9vo158cbBS947dZ432Kl
1Njr2xmv51fb69kRxxfZ82/3+xd7vm1xDO8X/H7DttPWOE5Yz+fj2Fi/zXEM
r01xvNL6bPQ/bz2ei2Nl2/dZ//e2vdb767X3v84f3/ajJ/312P7yhP9767/W
H88W2B/2f283OA/62Pan+/zxrMfdPrYbkNt9bAfgdT6+0MYSxxfZn4/jNbaj
3O1jO7Du87EdTw/6mHXe+PpxP3G8Gvfrz2cXDk/6f4/28n9vB9b6OF6L9o7j
i+z/1vjjw8v/PDzjeATecazQH/z50V/89aM/xfEFl9n+5s+H/ujPh/4axz3o
z3G8Ev1d3PtyazAeBM+Hr5XVGC/i3pdLXIbn2O79uHUYb4LnUXfIFRiPgvXk
92UE41Uw/9wj92I8C96PuV9WYrwL9nv3y0HkA17PQ7IG+UKw/nlYLkI+Eew3
HxGDfCNY/zwuNyAfCfL5k3KBvctmce+z1SCfCfLFBrkC+U7c+2nTyIeC+X+L
wGufYD7bKgr5VNz7Iz3It4L14y65C/lYMH/Vykrka0G+Wp6Pkc8F+a9RbuJz
c+S7vXIh1ylorwNiuC/C/rjI9ioI5sOKrMF8I+55VQXzkWA90S6X8rk59qft
civ3jdifL89fXDdhfmmXCzEfCvJnu3wF86VY9kurbO+SYP+zPH9ivmX7LM+v
mI8F6/+qbMF8LdhPtMsK61Hh/S/P35wX4d8h67Ae4P1UZR7rBXHPW+FVFayH
WmUt1huC+apFRrAeEbce/xDPg/1qkzyE9Yy493f6sd4RzC97ZBXWQ4L5v17u
wXpJ8Hy9gd4d4t4HgcdBQX2gjh4Hxa234HFQ8Py5nh6HxO0P4XFI3PMueByK
jw+PTt5/PT06Bc8PG+jRyfM30OOwHLTXuYcehwXvZzXR47BgPdNEjy6Or330
6OL976VHl2C90kKPLsH6sI0eR8S93waPI+LqGfA4wvFRpsdRcesteBwVzP+d
9DjK8dlNj27Bfq6bHt307qFHt9j6w8YetlcP++cRUdivCNabXXIj9jOC97MO
ywPY7wiebx6SndgP0eOg9GK/xP5RlZdgPxWPv/dgvyVf4jhBex9jfizKXdiv
iatP1GA/J1h/t0gn9nuC9VGLZOx1HWe+OiBvwX5R3Pr6KuwnOT6a5HbsN9ne
zfQ6Tq8mKWC/ivZ5R6NMYz8b9483Yr/L/LRHLsd+mOOxQW7BflnwPLVeHsZ+
mvmqXhqx3xa8r1VP7xOC90dd/+0VvM9TS49enq+WHr3i3o+CR6/gfa1aevQK
np8bevSyvY28FPUGcfUL9JeT4uoP8Dgprj4Cj5O8H02Pk+Le14XHSbb/bnr0
Cd7P2kWPPkH9TNOjj+21W76NeoxgfbxbUEft4/jV9OgT7D80x1Mf85mRi1EP
4nxk6HEqbj94nBLUW2rpcSr2aUA9KvbDPHRKsF9upEe/4P2FvRyP/Rz/B5hf
+gX7u1Z69Av2xy306Gf/aaNHP/NFC8fHgLj3WzHuBpifWvF+9jUDHE9t9BiQ
K207tjI/DQj2I23ShXqhuHokPAYF6/c2egyKTe/dBXoMCvZnbfQYFPd+GjwG
BfvdNnoMMt8U6DEo2C8W6HGa65ECPU7Tv0CP04J6SZEepzlfFunhfr5Ij9Pi
6sHwOCOoX5focUawny/S44ygflGixxnOH0V6nGE+LtHjDPNXiR5DvN8SPYYE
7wOX6DHE85XoMSTu/TV4DDGflugxJK4+DY9hQb2jRI9hQf27SI9hcfVqeAzL
/9r+VqTHMNcHBXoMc/3ZSo9hcfVYeJzl/NpIj7OcD+rpcTbOD/A4y/Gxgx5n
6buNHmd5/K1srxFxz0OQH0fYH59jvh/h+Z+Rj+F5C/2els/jeYxg//9buRnP
a3h9j3HcjjB/P8h5wf39fcxHI4L9+x3MryP8uW8yP7m/v0qG8bwpXs+n7P+e
i+NX4XlVHKPu7WOsw3yMOoWPb8DzsjjGfOPj+/G8LY6fwvO4ON6O53Vx3Irn
eXGMvORjzAM+hsdoHMPDx/DwMTx8DA8fw8PH8PAx2tnH8PAxPHwMDx/DYzTw
GAs8xgKPscBjLPAYCzzGAo+xwGMs8BgLPMYCj7HAYyzwGAs8xgOP8cBjPPAY
DzzGA4/xwGM88BgPPMYDj/HAYzzwGA88JgKPicBjIvCYCDwmAo+JwGMi8JgI
PCYCj4nAYyLwmAg8JgKPycBjMvCYDDwmA4/JwGMy8JgMPCYDj8nAYzLwmAw8
JgOPqcBjKvCYCjymAo+pwGMq8JgKPKYCj6nAYyrwmAo8pgKPqcBjOvCYDjym
A4/pwGM68JgOPKYDj+nAYzrwmA48pgOP6cBjJvCYCTxmAo+ZwGMm8JgJPGYC
j5nAYybwmAk8ZgKPmcBjJvCYDTxmA4/ZwGM28JgNPGYDj9nAYzbwmA08ZgOP
2cBjNvCYCzzmAo+5wGMu8JgLPOYCj7nAY07c+7DwmBM8P3hY4DHHes9TAo85
cd9vwWNO3Pea8JiTS+16dyfXV/Os/xiur+bj/Qs85gXf7zRzfTUveN62l+ur
eXHfj8BjnuuhItdX87yfKtdN89x/dHB95Y53mOurea53j3F9NY/98y/7uL6a
x/784JDAYwE/f3xU4LGA++s8K/BYwPr8i0O8zwWs3380IPBYwPq897jAY4H1
uW7u5xe4Hz0s8Fjg/qqDHgusL1TpscB6UZkeC9wvl+ixwP8W6bHA/Z/bHywK
nl+W6bEY1wfhscj1aic9FmXO7oe66bHIdu+mxyL3Z938/y9y3e/qPIvcn3fR
Y5H1oS56LLJe1kWPRfodoYf/9/BY4v65ix5L3OccpccS9xNH6LHE+t9heiyx
/Q/SY0nwPPEgPZbYPw7SY4n7+3Z6LMX1TngscX9coceSuO/14LBEvzI9llgP
K6G9sgmF/XtJ7sP3Igr17qL8Bt+TKPe9Cd7jTyj3/g++C0govF9RxHWtSijs
9wroVx9MKLR3Afu6yxMK7VPEdX8mobBfK8kJfC+jsJ8qyxC+p1HYL5dlCt/b
KLRnGXW1NQmF77Gq7PcJ5erTr8T3PAr1lCrG4SMJ5eqBl+F7IIX9VDscNycU
xkNVBN8TKfd90EfxvZFy3x9cie+RFPb/VezLuhIK9aEq9oV9CYX8VMG+dCSh
sH+tIo/MJhTqLWV6JHk/FXoklfv+CR5JhfFSpkdSYf9dpkdS4XkC6+Krkjx/
mR5Jhfp+mR5J5b7vgkdSoX86j6RC/bBEj6RCPyrRI6lc/REeSeXed4NHUrn6
AjySCu8TleiRVBi3rPuvSypX34BHUrnvleCRVKivF+mRVO57GHgklfu+FR5J
hfpPgR5JZdPFL/jcYsRdT4EeSYXxV6BHSrnvQ+GRUu77EnikFL4naqVHiv25
hR4phfcZDtAjpVAf3EePlML7a3vpkWL7N9MjpZDfmuiRUu57UnikFL4/2kOP
lEKeaaBHSmG+aqBHSiFf1dMjpZAn6+mRYvvX0SPF/l1Lj5RCPjL0SHF81NEj
pfD+Wx09UvSqp0dKufdB4JFSl/G5HDxS9G6iR0qhftlEjzTzzX56pNne++mR
Vlg/HKBHWuF5gfNIK7yv10aPdNw/4JFWqAcX6ZFmPizRI61Qn3TjI01PNz7S
CusLl6/SCuuDCj3Syr2fAY80far0SLO/uHyVZv9w+SqtkNer9EgrPJ+p0CMd
j294pOPxDY+0wvOqEj3SCvWmIj3SCvU0Nz5ce7TQI63w/GAvPTK8n2Z6ZBTW
S430yCi8z9dAj4zC6z219Mgo1O8NPTIK31fuokeG/Wk7PTIK66kX6ZFhf3mB
HhmF97G20COjsF7ZRI+Mcu8jwyNDnxp6ZBTWP8/SI8P5cT09MpxfnqNHRqGe
t4EeGXrW0CPD/rCZHhmOr630yNBvGz0yHI+76JFReF5q6JFReF5QR48M80UD
PbKc35rokWV/aKZHlvlqHz2yyj3/hUdWob7bQg8Xu/GRVVi/ufGRZT5y4yOr
UM904yMbz3/wyCr3/Sw8srzfKj2yyr0/BQ/37934cPdToUdW4XlpBeuvde5+
yvJu65GN51N4uJ934yOr8P1niR5Z5kc3PrIc7258ZJWrx8Mjq7AfceMjq9zv
14BHjusll69y9HceOc6fzfTIcf5pokdOufd/4ZFT7n1QeOTifA+PHMdDPT1y
XL/V0SOn3PMyeOQ4n9XSI6ewvjT0yMX5Hh45jv9d9MhxPbebHrm4/8Ijp/A8
YQc9cgrr7R30yDF/bqdHTrl6OTzc/bnxkVOo52+jR06hnv08Pdz9PE+PHOfP
5+mRV3g/fQs98myfTfTIM/9uokee7VVDjzzz4UZ65Lk+q6FHnvPRs/TwMTzy
nC/X0yPP+elpeuSV+31J8Mgr9/uU4JHnevEJeuSV+31M8Mgr9/ua4JFX7vc5
wSOv3O97gkdeud8HBY+8cr8vCh4+hodrjwfokVfu91HBw7XvvfTIK/f7rOCR
V+59HnisUO73YcFjhXLv/8BjhXK/TwseLl5FjxXK1RPg4WN4+BgePoaHj+Hh
Y3j4GB4+hoeP4eFjePgYHj6Gh4/h4WN4+BgePoaHj+HhY3j4GB4+hoeP4XFe
HMPDx/DwMTx8DA8fw8PH8PAxPHwMDx/Dw8fw8DE8fAwPH8PDx/DwMTx8DA8f
w8PH8PAxPHwMDx/Dw8fw8DE8fAwPH8Pj/DiGh4/h4WN4+BgePoaHj+HhY3j4
GB4+xnv1Pv5/Fziryg==
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxd3Ht8n1V9B/Df/VeYU6bToVOHyhjMW9XpqtN9z5zTqbih8FKmzFWEydAp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             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-3.3024999999999998`, 3.2975000000000003`}, {
             0, 1.1803750000000002`}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-3.3024999999999998`, 3.2975000000000003`}, {
            0, 1.1803750000000002`}}, "Frame" -> {{True, True}, {True, True}},
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
          "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
          GoldenRatio^(-1), "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxd3Ht8n1V9B/Df/VeYU6bToVOHyhjMW9XpqtN9z5zTqbih8FKmzFWEydAp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          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-3.3024999999999998`, 3.2975000000000003`}, {
          0, 1.1803750000000002`}}, "Frame" -> {{True, True}, {True, True}}, 
        "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
        "Axes" -> {True, True}, "LabelStyle" -> {}, "AspectRatio" -> 
        GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.1); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(5\\)]\\)\"", TraditionalForm],
  PlotRange->{{-3.3024999999999998`, 3.2975000000000003`}, {
    0, 1.1803750000000002`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9091131356996164`*^9, {3.9091151092543554`*^9, 3.9091151641818786`*^9}, 
   3.9091264885492506`*^9, 3.9101535294359417`*^9, 3.910161470725986*^9, 
   3.9101615136304626`*^9, {3.910165766576762*^9, 3.910165784706767*^9}, 
   3.910176159577746*^9, 3.9101762725578403`*^9, 3.910176357253714*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"6be7175b-f567-4689-b6ee-6d0f073693f8"]
}, Open  ]],

Cell[TextData[{
 "The full data with larger sampling is stored  as ",
 StyleBox["data/DOS/dos_{8,3}-haldane_T2.1_{1,1_6,Pi_2,1_3}.dat", "Input"],
 " and we can import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091134847660837`*^9, 3.9091134940495186`*^9}, {
  3.909113659447389*^9, 3.909113670420266*^9}, {3.9091257465881844`*^9, 
  3.909125770268137*^9}, {3.9091262842252073`*^9, 3.909126291202912*^9}, {
  3.9101535429748435`*^9, 3.9101535465590334`*^9}, {3.910161515340441*^9, 
  3.9101615174640436`*^9}, {3.910165801435964*^9, 3.91016580427374*^9}, {
  3.9101762316624236`*^9, 3.9101762347384768`*^9}, {3.910176321141118*^9, 
  3.910176321522131*^9}},ExpressionUUID->"a0a0d16f-0b25-45b3-822e-\
c9b9a61c56f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<data\>\"", 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos\>\"", "Input"], 
       StyleBox[",", "Input"], 
       StyleBox["\"\<dos_{8,3}-haldane_T2.1_{1,1_6,Pi_2,1_3}.dat\>\"", 
        "Input"]}], "}"}], "]"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", "All"}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.1); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(8\)]\)\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909126193404081*^9, 3.909126208623426*^9}, 
   3.909126263048504*^9, {3.909126423755125*^9, 3.909126426329094*^9}, {
   3.910153550359743*^9, 3.9101535525745273`*^9}, {3.9101542103107257`*^9, 
   3.910154210498105*^9}, {3.910161464469494*^9, 3.9101614645404596`*^9}, {
   3.910161519021552*^9, 3.9101615205223827`*^9}, {3.9101658069587917`*^9, 
   3.9101658124585643`*^9}, {3.9101658669637184`*^9, 3.9101659131198244`*^9}, 
   3.910176239097285*^9, {3.9101763159669914`*^9, 3.910176348528557*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"134de706-f7cb-43df-8a0a-86307c5d7189"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
         0.006944444444444445], AbsoluteThickness[2], LineBox[CompressedData["
1:eJxd3XVcFfnXwHG4lN2xxqrYylqrrrG637Fb1lh77fy5oq6xdq3d3bp2BwYG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          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
       Slot["HighlightElements"], 
       Slot["LayoutOptions"], 
       Slot["Meta"], 
       Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
          Annotation[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            Line[CompressedData["
1:eJxd3XVcFfnXwHG4lN2xxqrYylqrrrG637Fb1lh77fy5oq6xdq3d3bp2BwYG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             "]]}, "Charting`Private`Tag#1"]}}, <|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PlotRange" -> {{-3.3, 3.3}, {0, 1.1589605}}, 
           "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
           "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
           "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
           "DefaultStyle" -> {
             Directive[
              PointSize[0.006944444444444445], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
               Identity[
                Part[#, 1]], 
               Identity[
                Part[#, 2]]}& ), 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-3.3, 3.3}, {0, 1.1589605}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[0.006944444444444445], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>],
      ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
       4.503599627370496*^15, -4.503599627370496*^15}}]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[0.006944444444444445], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxd3XVcFfnXwHG4lN2xxqrYylqrrrG637Fb1lh77fy5oq6xdq3d3bp2BwYG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          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PlotRange" -> {{-3.3, 3.3}, {0, 1.1589605}}, 
        "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
        "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
        "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[0.006944444444444445], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
            Identity[
             Part[#, 1]], 
            Identity[
             Part[#, 2]]}& ), 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"Energy \\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->GrayLevel[0],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Primitive cell (T2.1); k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(8\\)]\\)\"", TraditionalForm],
  PlotRange->{{-3.3, 3.3}, {0, 1.1589605}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9101665701922455`*^9, 3.9101762776444693`*^9, {3.9101763232367353`*^9, 
   3.9101763491709766`*^9}},
 CellLabel->"Out[17]=",ExpressionUUID->"8d81636d-163c-4b6a-9213-fac0c40f3a03"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the supercells", "Subsection",
 CellChangeTimes->{{3.909113688151761*^9, 
  3.909113691600689*^9}},ExpressionUUID->"33694482-f33f-43db-a135-\
63406bdd13e0"],

Cell["\<\
The model is extended to the supercells in the sequence by translation \
symmetry, which allows us to construct the Abelian Bloch Hamiltonians on the \
supercells\
\>", "Text",
 CellChangeTimes->{{3.909114061369022*^9, 
  3.9091140880436444`*^9}},ExpressionUUID->"640a672d-3d35-44c9-bc07-\
3616f2b69a3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{
        RowBox[{"AbelianBlochHamiltonian", "[", 
         RowBox[{
          RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
          RowBox[{"onsite", "[", "m", "]"}], ",", 
          RowBox[{"hopping", "[", 
           RowBox[{"h1", ",", "h2", ",", "\[Phi]"}], "]"}], ",", 
          RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "&"}], "/@", "supercells"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}, {
   3.910166185826136*^9, 3.910166187276629*^9}, {3.910176380553774*^9, 
   3.9101764043273516`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"2db2bdb7-2a79-4586-949a-d7a082372230"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{"\"\<H_{8,3}-haldane_T2.1_sc-``.dat\>\"", ",", "#"}], 
           "]"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@",
    "supercells"}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
  3.910154322749093*^9, 3.9101543310279417`*^9}, {3.91016160339386*^9, 
  3.910161605793605*^9}, {3.9101661483799353`*^9, 3.910166149293952*^9}, {
  3.9101763875940886`*^9, 3.910176390633175*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"37f1c067-b772-4acb-955e-b70f1381f563"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909114427990825*^9, 
  3.909114430083145*^9}},ExpressionUUID->"6af2d681-15f4-4011-bf54-\
29d9e6e6567f"],

Cell["\<\
Increasingly better approximations of the true density of states in the \
thermodynamic limit are obtained by considering one-dimensional irreducible \
representations on increasingly larger supercells. Again, we first compile \
the expressions for the Abelian Bloch Hamiltonians to speed up the evaluation:\
\>", "Text",
 CellChangeTimes->{{3.9091144367949524`*^9, 3.909114603985526*^9}, 
   3.91015441714965*^9},ExpressionUUID->"8f31c1df-82a7-4445-83e0-\
9c9c6511303e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hsccfs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{
         RowBox[{"scmodels", "[", "#", "]"}], ",", "1", ",", 
         RowBox[{"onsite", "[", 
          RowBox[{"1", "/", "3"}], "]"}], ",", 
         RowBox[{"hopping", "[", 
          RowBox[{"1", ",", 
           RowBox[{"1", "/", "6"}], ",", 
           RowBox[{"Pi", "/", "2"}]}], "]"}], ",", 
         RowBox[{"PCModel", "->", "pcmodel"}], ",", 
         RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091146138495903`*^9, 3.909114652753991*^9}, 
   3.909119478873217*^9, {3.910154420411165*^9, 3.910154425008809*^9}, {
   3.910163134806413*^9, 3.9101631355361147`*^9}, 3.9101764503148623`*^9},
 CellLabel->"In[26]:=",ExpressionUUID->"ac3c0ce7-7319-4e59-a74e-3c6158a20ee3"],

Cell[TextData[{
 "We compute the DOS with an energy resolution of 0.005  and a sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "3"], TraditionalForm]],ExpressionUUID->
  "8896285d-49f8-4724-a495-f598c814da10"],
 ":"
}], "Text",
 CellChangeTimes->{{3.9091148872154474`*^9, 3.909114904344953*^9}, {
  3.9101566973402805`*^9, 3.910156697549489*^9}, {3.910161660367123*^9, 
  3.9101616604374743`*^9}, {3.910176466542446*^9, 
  3.9101764692771397`*^9}},ExpressionUUID->"16a02a2c-fba0-403f-9a43-\
4e71e9e74023"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dosscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ComputeDOS", "[", 
        RowBox[{
         RowBox[{"Hsccfs", "[", "#", "]"}], ",", 
         RowBox[{"10", "^", "3"}], ",", "32", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3.3"}], "-", "0.005"}], ",", "3.3"}], "}"}], ",", 
         "0.005"}], "]"}]}], "&"}], "/@", "supercells"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9091148504724855`*^9, 3.909114863025732*^9}, {
   3.9101548693475285`*^9, 3.910154869724236*^9}, {3.9101549493832054`*^9, 
   3.9101549496375976`*^9}, {3.9101616621016417`*^9, 3.9101616850848536`*^9}, 
   3.9101674081448646`*^9, {3.9101687920816994`*^9, 3.9101687939546127`*^9}, {
   3.9101778768448086`*^9, 3.9101778868201704`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"fab797b8-4bd7-4c69-ba9c-1ae47023c1cb"],

Cell["\<\
We plot the successively better approximations of the (normalized) density of \
states as obtained from successively larger supercells:\
\>", "Text",
 CellChangeTimes->{{3.9091258353931103`*^9, 3.9091258729641294`*^9}, {
  3.909126315654191*^9, 
  3.9091263169689493`*^9}},ExpressionUUID->"a79ea780-d894-47c3-bc20-\
a292aed182e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Association", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<T2.1\>\"", "->", "dospc"}], "}"}], "]"}], ",", "dosscs"}],
     "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(3\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091194227381277`*^9, 3.9091194385257072`*^9}, {
   3.909125701919447*^9, 3.909125705158804*^9}, {3.9091264450645742`*^9, 
   3.9091264526411266`*^9}, {3.910154999941857*^9, 3.9101550239169064`*^9}, {
   3.9101562589192905`*^9, 3.910156259119133*^9}, {3.910157116954313*^9, 
   3.9101571172428455`*^9}, {3.910161666018202*^9, 3.910161678746447*^9}, 
   3.9101618458849573`*^9, 3.9101674115207944`*^9, {3.9101686910398192`*^9, 
   3.910168707914562*^9}, 3.910168774761067*^9, {3.9101782425609217`*^9, 
   3.910178242924181*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"cd658730-7590-4b15-a246-b1056fbb8768"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxd3Ht8n1V9B/Df/VeYU6bToVOHyhjMW9XpqtN9z5zTqbih8FKmzFWEydAp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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxd3HuMHld5x/H3vk6KiqVeFKSWJqWXhJY2NNAGaHpGCBWB+COkqI1CipyG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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxd3HuUXVV9B/D7nkCp4vIFy2qDVQQfXUG0VVr9nVorC7VLQFsRU1YoUh9U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          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxd3HmUHVWdB/C3d8i44HELLkxgGCW4gaCDuPxKRoeBwTGgjhgjJ6ggDqOA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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(3\\)]\\)\"", 
       TraditionalForm], 
     PlotRange -> {{-3.3024999999999998`, 3.2975000000000003`}, {
       0, 1.1803750000000002`}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T5.1\"", "\"T17.2\"", "\"T33.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091194429099684`*^9, {3.909125698510269*^9, 3.9091257066406164`*^9}, 
   3.909126457110761*^9, 3.9101549712826576`*^9, {3.910155008395378*^9, 
   3.910155025671894*^9}, 3.9101562605065956`*^9, 3.9101571574389143`*^9, 
   3.910160994196726*^9, 3.910162121594056*^9, 3.910168626815968*^9, {
   3.910168691810589*^9, 3.9101687086129065`*^9}, 3.910168775520574*^9, 
   3.9101695184383307`*^9, 3.910177831722453*^9, 3.91017793033576*^9, 
   3.9101782016654787`*^9, 3.910178243921321*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"dc34bae4-7e6e-48ed-80f7-7c121c54b721"]
}, Open  ]],

Cell[TextData[{
 "The full data is stored  as ",
 StyleBox["data/dos/dos_{8,3}-haldane_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient. We import and plot it due to the reduced \
noise:"
}], "Text",
 CellChangeTimes->{{3.9091257257973347`*^9, 3.9091257829464827`*^9}, {
   3.9091258161267524`*^9, 3.909125817972119*^9}, {3.9091263241669226`*^9, 
   3.9091263478044133`*^9}, {3.9101544811965094`*^9, 
   3.9101544880133915`*^9}, {3.9101556042258387`*^9, 3.910155604445711*^9}, 
   3.910161914298563*^9, {3.9101688116050744`*^9, 3.9101688125306997`*^9}, {
   3.910177576623019*^9, 
   3.9101775790298862`*^9}},ExpressionUUID->"4e5efa7c-23fa-4e52-baa1-\
c08216665c3b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{
              "\"\<dos_{8,3}-haldane_``_{1,1_6,Pi_2,1_3}.dat\>\"", ",", "#"}],
               "]"}]}], "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.1\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3.3"}], ",", "3.3"}], "}"}], ",", "All"}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<k sampling: \!\(\*SuperscriptBox[\(10\), \(8\)]\)\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "4"}], "]"}], "/", "4."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091263566114464`*^9, 3.909126393410284*^9}, {
  3.9091264603821816`*^9, 3.909126463017381*^9}, {3.9101544932422967`*^9, 
  3.910154495640236*^9}, {3.910155610950552*^9, 3.910155611196024*^9}, {
  3.9101562410776777`*^9, 3.910156285321762*^9}, {3.9101617452884254`*^9, 
  3.9101617608664107`*^9}, {3.910168721689234*^9, 3.910168728542076*^9}, {
  3.910168760533145*^9, 3.9101687649604893`*^9}, {3.9101775820379734`*^9, 
  3.910177584643213*^9}, {3.9101779037042403`*^9, 3.910177922324427*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"e21d9b01-c697-465a-a5c8-4dc22f03cc7a"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.782462, 0.3104325]], 
         LineBox[CompressedData["
1:eJxd3XVcFfnXwHG4lN2xxqrYylqrrrG637Fb1lh77fy5oq6xdq3d3bp2BwYG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          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.979377, 0.451467, 0.0511329]], 
         LineBox[CompressedData["
1:eJxd3XVYFOvbwHFYyk7s+IndB1tRecbu7u7uxu44NhbqsbvFQDGfQRoWWEpK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          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.5805400000000001, 0.197808, 0.3886405]], 
         LineBox[CompressedData["
1:eJxd3XVcVGkXwHGYIQxcc21dXbuxm+eu3YndYmB3F7rmirm65rqiaxcG5upz
kY4ZBgUJEREQQRBBWol3uOe593zeM/+8n9+7Ooz3e8/MXG41nL1szFydhYXF
zLIWFqX/61Au4uLyohqyhXg8rr8rdXQ+dqeO5kcW9u2BHzZWS8duMfXQy5xk
7H+X9y4XkYBd+nSPY7FPnzI/orCrlT5hGPbhlznNp4Zgl7683oHYu81PV98H
W3nI2BtLn/Apdm5z8wv0wC59eRfdsdPMT7frBva80sdl7PjSJ3TDLv3nNj+L
Xfryyp3AHlO6AI9gB5c+XLEHmRff7T3Ypf/cQzuwFY8txGM98VhFPJYSD2fi
4UQ8phOPScTDkXiMJB5DiEd/4iERjx7EozPxsCcerYhHU+LRkHjUJR41iEdl
4mFHPGyJh454FFXXGuYDG+YDG+YDG+YDG+YDG+YDG+YDG+YDG+YDG+YDG+YD
W3nI2DAf2DAf2DAf2DAf2DAf2DAf2DAf2DAf2DAf2DAf2DAf2DAf2DAfxGM9
8VhFPJYSD2fi4UQ8phOPScTDkXiMJB5DiEd/4iERjx7EozPxsCcerYhHU+LR
kHjUJR41iEdl4mFHPGyJh454FP2sNcwHNswHNswHNswHNswHNswHNswHNswH
NswHNswH9i5lPrCVh4wN84EN84EN84EN84EN84EN84EN84EN84EN84EN84EN
84EN84EN80E81hOPVcRjKfFwJh5OxGM68ZhEPByJx0jiMYR49CceEvHoQTw6
Ew974tGKeDQlHg2JR13iUYN4VCYedsTDlnjoiEdRNa1hPrBhPrBhPrBhPrBh
PrBhPrBhPrBhPrBhPrBhPrBhPrCVh4wN84EN84EN84EN84EN84EN84EN84EN
84EN84EN84EN84EN84EN80E81hOPVcRjKfFwJh5OxGM68ZhEPByJx0jiMYR4
9CceEvHoQTw6Ew974tGKeDQlHg2JR13iUYN4VCYedsTDlnjoiEdRVa1hPrA7
KvOBDfOBDfOBDfOBDfOBDfOBDfOBDfOBDfOBDfOBrTxk7E3KfGDDfGDDfGDD
fGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfBCP9cRjFfFYSjyciYcT8ZhO
PCYRD0fiMZJ4DCEe/YmHRDx6EI/OxMOeeLQiHk2JR0PiUZd41CAelYmHHfGw
JR464lFURWuYD2yYD2yYD2yYD2yYD2yYD2yYD2yYD2yYD2yYD2yYD2zlIWPD
fGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfBCP9cRjFfFY
SjyciYcT8ZhOPCYRD0fiMZJ4DCEe/YmHRDx6EI/OxMOeeLQiHk2JR0PiUZd4
1CAelYmHHfGwJR464lFUWWuYD2yYD2yYD2yYD2yYD2yYD2yYD2yYD2yYD2yY
D2yYD2zlIWPDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDD
fBCP9cRjFfFYSjyciYcT8ZhOPCYRD0fiMZJ4DCEe/YmHRDx6EI/OxMOeeLQi
Hk2JR0PiUZd41CAelYmHHfGwJR464lFUSWuYD2yYD2yYD2yYD2yYD2yYD2yY
D2yYD2yYD2yYD2yYD2zlIWPDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDDfGDD
fGDDfGDDfGDDfBCP9cRjFfFYSjyciYcT8ZhOPCYRD0fiMZJ4DCEe/YmHRDx6
EI/OxMOeeLQiHk2JR0PiUZd41CAelYmHHfGwJR468vq/V/z/15uBrby+JGzl
9cRgKz8/FFv5eX7YpU+3/Dm24nsfW/G8iv1L6QI/h614HcNWfP7AVh4u2Mry
X4OtLO9F2KUvb+AsbGV5TsA2lC6/YdjK8uqDrayv3bCV9bMttrI+NsJW1r9a
2KWLb2pFbGX9ssYGj5+0Bg9s8MAGD2zwwAYPbPDABg9s8MBW5ukcNnhggwe2
8nDBBg9s8MAGD2zwwAYPbPDABg9s8MAGD2zwwAYPbPDABo8KWoMHNnhggwc2
eGCDBzZ4YIMHNnhggwc2eGCDB7bycMEGD2zwwAYPbPDABg9s8MAGD2zwwAYP
bPDABg9s8MAGDzutwQMbPLDBAxs8sMEDGzywwQMbPLDBAxs8sMEDW3m4YIMH
Nnhggwc2eGCDBzZ4YIMHNnhggwc2eGCDBzZ4YINHea3BAxs8sMEDGzywwQMb
PLDBAxs8sMEDGzywwQNbebhggwc2eGCDBzZ4YIMHNnhggwc2eGCDBzZ4YIMH
Nnhgg0c5rcEDGzywwQMbPLDBAxs8sMEDGzywwQMbPLDBA1t5uGCDB3aq4oEN
HtjggQ0e2OCBDR7Y4IENHtjggQ0e2OCBDR5ltQYPbPDABg9s8MAGD2zwwAYP
bPDAhu9X2OCBDR7YysMFGzywwQMbPLDBAxs8sMEDGzywwQMbPLDBAxs8sMED
GzzKaA0e2OCBDR7Y4IENHtjggQ0e2OCBDR7Y4IENHtjKwwUbPLDBAxs8sMED
GzywwQMbPLDBAxs8sMEDGzywwQMbPGy1Bg9s8MAGD2zwwAYPbPCwlTOdE/Z6
5K92AA9buU3fuqnxXU47gIet3PvcX788DvRyAA9bOWF/7vqG9dIdwMNWPshG
R7lfrsLAw1Z+sfeh0+fbnZjyQ1xs5Q3T+Myui8cy8LCVRx3U9fN0XcbAw1be
41n4c4cauxl42Mr7F3/6ce3IaQYetvLJd3/u2dXyBgMPW7mnf6rnv86PGHjY
yu9H/PqSyzIDD1vZcOT4DJttXgw8bOUurPjVhaYvGXjYyp63nm24/voZO6V4
2MrZBc0btXV+yMDDVn7i1bTDqmvPGHjYynMPbNw7oKM3Aw8becW4qHX9k/0Y
eNjId0JXnt+j82HgYSNn7C0XbmjDGXjYyBPKp7U/MuQFAw8b+Z9ercNOX/dm
4GEjbx3X1rE4x5+Bh4282H350aTffRl42Mh5Nxc9qDvRk4GHjVwzbfeS/R08
GXjYyE16uUX8M8qXgYeN7K7b/GhDxwDhYSPP6rp4yrEcH+FhIz9r8dGjyjdP
4WEj7z2/MHvhYi/hYX7+Te1eOJf4CQ8b2WpN4MU6Hv7Cw0YurBV707OOj/Cw
kTvcGu60aZ+X8LCR6+nvRTxb5ys8bOSBRxtMtQz3Fx428tiyI5NzfvETHjZy
zI5LT13ueAsPG7ll4KXM8pt8hIeNfHTSc68vkX7Cw7y8iirVaZ3hJzys5XrH
7F/nvvURHtby3P3/vkuuoXpYy+1DG1iPDPUVHtZy9Us7Z47r7i88rOXoI597
8sZ+wsNajj1a1/3GLh/hYS0Hdrbu0LOn6mEt1+p2/lKrfv7Cw1rOqfhrrZWj
/IWHtXxjSu9mzzepHtZyVMjsFkf7+goPa/nmkWkLao32Fx7W8u5Pl2Y7VQkQ
Htayze6bS3O6+QkPa/n0zG4R9mN9hYe1nPn3yZzZo1QPa9m+VbWUracDhIe1
vG3hf6v/NPkJD2vZNqP6oFHOqoe1bFfm1p52A1UPa3l0/uJ6de0ChYe1PKX/
NuekSf7Cw1qe9X163+WbfYWHtbzg4M3CDpK/8LCW3W+XC5u9PFB4WMn7+rnN
fffaX3hYyUtrv1302wlf4WElT/SfWstxqL/wsJJf/OH60yBjoPCwkh8+s01+
0TxAeFjJa6/0HNlrv6/wsJKLt698+8L898HDSrYenWc5qHOQ8LCSLf840mTV
+gDhYSXXvuq67Z9pqoeVPMH0wDvQ7AceVvL8Z31+aX0/SHhYyVuvdpo9L0L1
sJIHfX/wR/EgX+FhJd+81rrcM/PyBw8r2arerYWDywcLDyv5dovDUZPsA4WH
ldxvVOeNnRN9hYf533/ox/jUagHCw0o+dOWj7e0ewcLDSq535OuYz1VUDys5
M6pHt8gzfsLDSi764Vretnqg8LCSC73+qj+8TbDwML9ez7H+xwMDhIde1v81
1Sd+leqhly/l/hp90DJIeOjl+KMJI1ISg4SHXl7UtmvNz8cChIdeflL3jpQ9
R/XQy2u7N2nQ9FaQ8NDLqy5M23VsT5Dw0Muzxj0vHHElQHjo5fe+8wZenx8o
PPTyjOkuW1bXDhYeejnsn6JBldsECQ+97OEd6JxYMVB46OXzncKaN54bxHIU
D73s/mnRX0Hm5QUeernEduKNtQWBwkMv3/o+dYmPb6Dw0Ms1T/78x+p2wcJD
Ly9YlrEroHEw81I89PKvJcENHKoFCQ+9PMIuIMD7WpDw0MvBaVk1P94KFh56
ue+f3kdXmr3BQy/vSOiwdKFrkPDQy712Zr5+vEf10MttPGKXPXgfLDx0ct2+
FsvTygazFYqHTh4Xe3D55H7BwkMnDzCdHBzWziA8dPL9EKdj818FCw+dfC5z
y4prI4LZQMVDJ1d0eXxjQkOD8NDJmU+3ei7daRAeOrl1pd4t/nwZLDx08sDk
+Z/X6A3CQyevc3syolGOQXjo5IufJ/T4ZatBeJj/fsVXYxMrGYSHTm675nDE
7y2MwkMnH+tYbd1/44zCQye/71jFrfJMg/DQybunOBw92sUoPHTylkZP509r
FyI8dHK/0g/8AoPw0MmOq554jmplFB462b7iqW8N00KEh06ePLjVC7cwo/DQ
yS6nJz9808goPHRytY1Fgzc7mISHTu42ZPrfTmEhwkMn20Td2zytrVF4WMqx
a80LYJlJeFjKSy/8lTR+qUl4WMppbltuxg01Cg9Lefyzpv92PmkSHpbynCZJ
kwZ/NAkPS7naiYSf9+4wCg9LeUbzmT1rcpPwsJQPTspt7D40VHhYyjWebRl/
ymAUHpZyF//GjebnmISHpTzt/Z7fd54OFR6W8tq4s5UvdQ8RHpZynXnOvSr3
CxUelnKTwNgxRkOo8LCUfYvvbfoWHCI8LOXrT2JmXr0fKjzMz+eb53MpKVR4
WMq/RbYYX2GQSXhYyiWhXRfU7vVKeFjKrnkJuUGfQoWHpZz5bfXt5qEm4WEp
71474r7k80p4WMruJT26LokOFR6W8vcKVSuMORoqPCzlrQcPVZ/f8rXwsJCj
LRZLO+NChYeFvLplLYvre18JDwt5XNycOo8HvxYeFnLLhPfzp3Z5JTws5Onz
+xafWvNaeFjIz+buyd/T/bXwsJDzbGacHKZ/LTws5ENLd/bvXyZMeFjIzcvP
mJE68bXwsJB3uLqUG1guTHhYyLzyu/u324UJDwuZdQk4lG8ZJjws5E5V7T7V
lsOEh4Us9x19fqRzmPCwkN8dn2b/ODdMeFjIXhmV2zcpFy48LOS0KyU3C5qE
Cw/z8kjYtXr9yXDhYSE3THnd8vumcOFhId/sunBXivUb4WEhX+16MelGdrjw
sJBL397cZ70RHhZyh/qXqpzb/EZ4mP/81e/Hjc/fCA8L+UGP7n1X6CPg8y+n
hIdVlg3xv0TA6/1Qwr3++WCovTuCKftTgkt4l55jtnzaFQGv53EJVz7fLSPh
518s4eeXlf/rc3oE/LxDJXzk5Mc3X26MZMrTbSzhsxK+r9syIhJ855Vwu0nv
Pnf/Ggmeo0v4x5bVeYurkeDXu4SHb+ShB2dFMeXlNS/hDR4HVi2TFQk+1Ur4
k8I92W8NUeBhUcJbxq8+ess+CpZ/ajFv9N0j53W7aPamdHlHFPPZ0V3zJjhF
wefzy2I+JS130tzN0bA8bxfze2d3vqpxLAqW36liXmvC1LrHL0azncoTFvMf
0yJP34qOgs/X5cV8/tOIwVtORMP6ObWYl9+2u+siKRo+PwcW89vtqkSvnBMN
61/HYl6lfZOjyc+jmbL46hdzU+j1v1Y3job1q1wxT5lbLajN8LfCo4gP++PQ
SP/vUcKjiH+fcbt/+aS3wqOIK/9/1WjhUcTzHUdsGrIzRngU8buLkw6HXY4W
HkV8gLSr0aDUGOFRxE9vWDl8e6UY4VHEQyJPLO5lihEeRbxHg7I/1k6OFR5F
fEzpwPjECA/zn6/W485dfZzwKOJpnXs3bx4VKzyK+Kq2PuPm3n0vPAr5m/ix
Fq65ccKjkP84/Ghq0aE44VHIXf+7uc+6KE54FPJp+6ScihEfhEchz6idfelR
9AfhUchnbOmV/e7LB+FRyNtVc6/nui5eeBTy+su+TVntHS88Cnlli7qbcpfF
C49CHmHfN2HfoQ/Co5CXTPune+qzWOFRyNccWnz7dHlZePzgj418Wm7qYuHx
g4+cNDyi6rQIB/D4wf/v9wWPscEDGzywwQMbPLDBAxs8sMEDGzyw4YENHt+1
Bg9s8MAGD2zwwAYPbPDABg9s8MAGD2zwwAYPbPAo0Bo8sMGjgHgUEI8C4lFA
PAqIRwHxKCAeBcSjgHgUEI8C4pFPPPKJRz7xyCce+cQjn3jkE4984pFPPPKJ
Rz7xyCceecQjj3jkEY884pFHPPKIRx7xyCMeecQjj3jkEY884pFHPHKJRy7x
yCUeucQjl3jkEo9c4pFLPHKJRy7xyCUeucQjh3jkEI8c4pFDPHKIRw7xyCEe
OcQjh3jkEI8c4pFDPHKIRzbxyCYe2cQjm3hkE49s4pFNPLCVpxuI3UHxyCYe
2cQjm3hkEY8s4pFFPLKIRxbxyCIeWcQji3hkEY8s4pFFPLKIRxbx+EY8vhGP
b8TjG/H4Rjy+EY9vxOMb8fhGPL4Rj2/E4xvxyCQemcQjk3hkEo9M4pFJPDKJ
RybxyCQemcQjk3hkEo9M4pFBPDKIRwbxyCAeGcQjg9tcaDZ3TN9NDuCRwa+1
G9qz84kgB/DI4Bn7h46Lji8H218DM7jVjc8f153uxcAjg+/LPD1hzXgn8f0q
gz+/lR29OG27+H6Vwa/2SJz3+LeTTNm/nPqVXx+06+4ul2vi++BX3vm3sC0W
8R7spPL6vvJfC/efb3+fi+97X/nZ5XeCp1iK368P/Mq7mTeHEkN8xc/7yp8f
7DZH/7c/y1YWaDpv0GxYTYNNoPj+nM6T3H8c/DA4SHxfTueWpRssA4LF9+N0
XnP64G9TqxrYKMUrnW9MrGhzLsIgvv+m85HT5+i2bjAyWGrp/MsOz87rMozi
++0Xvufl/NQ45xB2U1lAX3jByK6j4sJDxPfXLzwm+mXWmAom8X31C8/2KvMh
tLVJLL8v/IdN065/jDKxMsry+sLbpLMO9WabWJzyAtO4k6ms2+/LTeL7fxqP
npQ9wnq3iR1UFmAaP7brzp01+01sjrL+pfHtU9ZlOR4wsV4KQBo/u2TpsJF/
id8/VEvjuzYc6jj8mIl9VjxSefGAnkvz95iERypfcMt51Vnz84FHKv/t0YlO
A7abhEcqf3Br3t+Zi0xsgOKRyquMKD8929zgkcrX+BuW6yebhMdn7tB0zGlD
V5Pw+MxXbxrs9KCbiV1QnvAzf+GWEdWjgUl4fOZhWxc1GxIdIjw+85PvF3RI
yAkRHp95ZsScAxv/C2ElyiOFf998rHIN+xDhkcKV/QFrxO+XbqfwRblSK3tH
1SOFRyz+2KRknfj9z9QUfrR3H8PhYqPwSOF9TixPbuMQItbfFD6if0vXNvkG
4ZHMn72JvXJ9s/h91uNk3mHKvZYvt4QIj2Reff/7auPTDWJ7K5l/aVX6CzeD
8EjmLbs3yzU9DREeyXxHb/MC2m4UHp/49uN99y/eZBAen/id46ZpVfaECI9P
vFP7aXvDx4YIj0+8w+H5J5bdMgiPT/zC0yf5b+uHCI9P/PnqP2tavQgRHkn8
rm/UaqvWRuGRxPeMrtTrRbhReCTxw/Z2E1caQoRHEi+38+/Z4f8amfLyRifx
575tRz/3MAqPJL7f4sq6zOuqx0c+7cqRvwJT1fn4yPsGjry+5baR3VI8PvKf
i+2WvVmsenzkcU9nD1hfPkR4fOQ/Pi2QG7ipHh95S93ZWJ9WqsdH/nKxzi6o
xCg8Erlt/yyL6gdUj0Tesc6co0cSjMIjkee28Juz4q1ReCTy2xVTD0xeYhQe
ibzMxy11DaeMwiORHy3nVP6366pHAn870jffvq9ReCTw5r9fTAwfbBQeCdxu
XVvX7JVG4WH+8++j6j+vZxQeCXzMnFtuYcUG4WH+7/lVj1doZxQe8bx27E3P
H+b/Dh7xfGknl0fSSwNTFt/FeK4vHbgUg/CI52cvh/z0ON4gPOL5o1nVrA6d
Ud+v4vmi36uG3rlkEB4feKvvfTuOfGoQHh944+02Z3rsNwgPcw+udNtloUF4
fOBP281/2GqvgU1RPD7wK+Yfd3u1QXh84MO67vtt5m8GVlbx+MBb9iw637aP
Oh9x/Ov4v5JbDzQIjzj+esm+qcvrG4RHHK/Zt3vobZ06H3H8j0YV+1W3VOcj
jr98+3ulw1/F/oRqcfB+/jKYhSuv/z3/OHd464y7wex35fW+53GVroelXQtm
7ZXX957fbjVv56Pfg9l75fXE8kUROx/4zgxmB5SfH8vHtT++9eXoYNZT+Xmx
POTS4+tpPYNZirJA3/EvWTU/nqoYLHzfcSn2xvimGUHC8x3f19+up+u7IOEX
w5fPXHnR/0WQmJ8YXrAg5sz7w0Hi/SuGO5tMzHNJECtWPN7yp8OG7+g6MUh8
XrzlY9Md/Aa2CmKTleX9lgeds+ryKTtQfB685asit/hlhAWyh8ryjOYVK84q
7PQwULzfR3Mv88fPzE2BrIqyvKL5oZX2ZyxYIJOV9TWKXy25WZDZKJAtU9bP
KO51pvP6GUUBrJ6yPkbB73vuBLAgZf2L5AnX7339Y3UA26AARHJ9o3aLZi8I
YM2U9SuSb026ObK7Q4DwiOAl0pMl7yP8hUcE/7lkXb9dl/2FRwSv2n/QO+M9
f+Hxhmd4/dbn2DZ/4fGGe5/Y9+u/uX7C4w1fXaZu2U7+fsIjnDvce7LwnN6f
nVA8wnn3J+/dmsf4sf6KRzi/W+dhm8CafixL8QjjD+3Lfzkb6MvcFI8wPj2i
XWSFvn5spOIRxu+10RvHzPNjRYrHa55nKApP2OrLbiger3ncM0OdZk98hMdr
3nX87HPHO/mK9f01V37fn+PLHiker/j11uWeNZ/ty+YqHq/4jPIbl9mV9WFV
FY9XfFqdlr4F772Zp+IRyisUb20/5Sdf4RHKjX4ebrN3+gqPUP6fcXdhx74+
wsPEByWM4uVLvISHiS+eWnI75Ji38DDx/fsvrqxq7cuuK68/hFe4mZDvVuzD
bJTXG8KdTqdMb7bGm81WXp+Rh/20bfib817shfJ6DHxg95PDXa55s9rKzzfw
/Z0yf8rI8GFrlZ8XzIsHb063OuTDXineQfzbrNx7X2p6s7aKbxC//nr7zSu3
vdgfimcg3/rheOOQAG+WpPgF8JOjPD9Ye/iwPopXAK/x+54F7xv4sHOKjz8f
Nr7/44A0L/Zd8fDjz2t1ntGEe7HxyvL340m9nGbcO+XNHijL25cfHjGtoHUN
H7G++/LxLXq/Hrremy1VlqcPn9grZ9Dvv3uxQGX5efP61RcOzxrixZoqy8ub
/1uzQajVPS+2Q1lfvXj3is3s/37pxWKV9fMlbzdis8dFKy/WQ1kfX/I6OZUO
pBd6sr+U9c+TT9i4pMv4hZ7sm7K+ydzil//WLhjryUYo65fMH+7cbLqfIzNH
5fVz7lYlov3tmpzZKa/3BW9havat8YcnzFt5ff/xbvkv51wfdJ9tVl7PM27q
F5mRff0a66T8/KfcyaVf1eY7zrE05ec95g8SMx8USofZv4r3I543rXLhsibb
2FTF9yHfOWh33SkhC1k1xdODP/o6etvzl44sWPG7z69Yt/te7lUvtlPxuscf
tahfI/zXX1kvxecur9X7kel4GSuWrHjc4dbyepsKRQkOE5Xle4vbfao9z7mX
p4O/sryu85rlIn8akPang6T8+69yOP5ojsNjZf26xA988Tif5zvTobmyvlzU
tj9OKv7nta4EJ+RonaF8YJ3Q2qSsT0e0nql47NNaUtaPrVq7KAM4B/tnpZn2
55UdQlu1joPn07oSnACktT2cIKT1KHi9Wj+Gf4/Wg+Dfq3UkLA8Gy0NycIbl
xR7NcJjUfuoSh3xYngy2x8447IXlzUo27rLO079wsFOexZ359Gq1wKdrooMj
eDHl+JYAPTsLnqxWzw9NuuU0ZHHgzaoobxi9WGNYH9iE+8b8F48d2WJYX9jp
Rq24ne9C9gDWJ8Y+pL3pUGsbK4T1jSUsuRQxr+9h1g/WR/bq0O6xSbvPMVdY
X1nHeJ2p+a1rLAzWZ7bDyudQ+4H3WV1Y39neF8+ON4l/wpxhHljWqr5j19bm
bCLMCyv51Tm4ca4sfp7MrhW0LIgc7cnOw7yxf/6M7frCPG8SzCPLrrHRO7nI
kyXCvLLTv22e6af3Ynthntns1q/bVfbyYq1h3tnBiftHWrp7MRO8H7Dc6ZtD
6w/1Yqvh/YLdrxCzvYf579WE9xPGzyyNarjWm/0H7zesRquF9hXM7zcz4f2I
PXO6O7zlaW9mpXj4s40J/9p/fe7FrsL7GVtZOGqBt/n9bBi837GGEz5PqvSr
D8uA90NWpsfk8KMPfdgxeL9kvcv32fBLkDfrBu+nbHOb5Oftb3qxGHi/ZUXV
/LZPqOHNXOD9mE1ocmTL4QM+wtPA1nYducY/04f5w/s5u7kmfuV/172Fr5G9
+7JxwR/m9/tK8HnApIurU2aY/33gHcLYx5Ot00t8xPIyscMFLtJ8nS/bCp83
7PHRenW2mz9vYPmZmHvp562FN/sVPq9Y5raBjlf7+IjlGcoG1t/b+pX588wb
Pu/YisCYzY3Mn3fV4fOQXVrU9P1i8+ehM3xessQCu6tdbX3YU/g8ZVtr5yV1
nePL7ODzli2bu8/YIc+XTYfPY3YqO2/MevPnsTt8XrPSxTHX/HmtUzzCWI2d
3xwOmj/PHeHznvXpc6yd81w/dhm+D7DzXcyfWP38WD58X2D747a1igrwZUPg
+wS79u6ObnMdP3YWvm8w5XiRKD+WDt9HmLNVnQhu/j4C6+MbdjzLJ3a/nx87
Ct9n2IIuh7xmmr/PwPr5hqWnyt0bbfVnXeD7EOvWNuGyzUN/sb5GsILdL+en
/uvPouH7FFuf5bgnJtJfeEQy3/bmLdTeAcIjkvlc/+3kW/P3MfCIZDd9rljU
XBcgPKJY8baz9rPcA4RHFGvcImWWs/n7HnhEsSFNr6zd3TBQeESztcv6z97h
ECg8otntSuOdypq/T4JHNNvVv//ZEebvm+DxltlE1xtjZ/4+Ch5v2cWUtDnL
zd9XweMtq9WwV3S3lkHCI4ad7dD1/d7xQcIjhn3q8mH6qWVBwiOGFY0sTq93
JEh4xLC8oGatdvMg4fGOVQw/NqdebJDweMdmfv40vH96kPB4x/4Ldh/9pmqw
8IhlWb0e91xk/j4PHrGs/IlxkXajgoVHLEtd3SD12qxg4fGeJZrHd8XuYOHx
nu3yaL/25ZVg4fGeXXgyolEb8/YGLK841rOLLvOpeXsENkjj2JKSwCF/pgeL
5RfHLgb41JyoN7AjsL3Doh3fNTpTEiyWZxyza7C5eah5buNhe4nNKj3g1by9
VB62p9j8CrETPpq3pzrB9hbr8KnWj6Pm7a1psD3GLsxq/3nyKgPbDdtrbOH7
mBm9dxvYHdieYzd1HjV7LTawSNjeY+r2nKXiEc+qXG5+wpcbWEvYXmTlqg64
f8/NwMbC9iRLalLyJzdvT26G7U3WwqNG6NpEA7sE26PMM6lur6qfDcwI26vs
Z/PbU5CngeXB9iwz1v7vTmCRgTWA7V02d0XJkRR7IxsM28PMu2mHVdt/GNhK
2F5md4vmuFb8xcjOwPY0+ynvyJQ/zdvTsL4msH8M10PChxjZF9geZ/VdI5u5
9DEKj0SW3m/woH9vGYVHIisY0qDJWvP2PHgksiUHV51ZvsgoPBLZqV1rR9yP
MQqPRLZw3/FQ/wQjS4DfJ7A6L3atSThgFOv7R9Zjw5Gy+UVG4fGRLRq44mCP
liHC4yM77/hjda8LRuHxkSWVqeV/3zZEeHxkY7LGfbu7LER4fGR7edNFYTeM
wiOJtSnftLh5ulF4JLGp+ilNJt4MER5JbMIG3awrD4zCI4ktl4ZOcL9kFB5J
bP7cH4cfmUKERxK7lz981qVXRuGRxOrXlPJHtTUKj09MLrurTDc5RHh8Yl9X
Vn6/r16I8PjEEt8duRt90yA8PrFaJQ4JL0eHCI9PzOnL18WHdocIj0/s88ks
1y0bDMIjmZ0a8Of+9jtVj2TmWNd2eptnIcIjmXVYnXa+SoI6H8msb88rk85/
MQiPZDbm1OyfdmwNER7JbOfZvJIVW1WPFPbqWqt/Puao85HCXrY3bzE7qB4p
rPDgh7v/FKkeKezXsQ5W4zYZhUcKcxlyvPmmsapHCrN5st++/5oQ4fGZXR8y
ZWpCuxDh8ZnZNu36x83nqsdnNurQklrLv4UIj89s7aW5/8a+DREen1n/nyp3
vdLAJDw+s7CvL98s7m4SHp/Z8s1fTjXpahIeqczvWSMnj0km4ZHKhq5dbBW/
yCQ8Ulnp4aXe5gaPVFZ+i7trhe0m4ZHKUg/6dLnmahIeqWxS/vfJJ/aahEca
i4gJLVn5p0l4pLE6g2qcGf+XSXiksQF3Y14tNP998Ehjl1suWXFgv0l4pLHn
8dcG1t5tEh5pbPck50+dVpiExxdWs1GVXX/NMgmPL+xWxxft2o42CY8vbFRC
bOHuNibh8YV131a1XGU7k/D4wv5dtfWPhDDV4wsruNB7+qBFqkc6+zIo5+8Z
Gep8pLPbrUMnzdtgFB7pbMLpYzuWRqjvV+nsas+RveZXVd+v0llK6/tlfAYE
C490Fso8ff4YEiQ80pn1iIfbe5YJFB5fWdjc9ncLTvoLj69M/5uLXb0QX+Hx
lX396NC9nPn7D3h8ZZVSHt3RP+LC4yvzWFLT2jPBQ3h8Za4LLm/6e+c18f6e
wYqq/93aw+Gk+HkZrP/ObZU7JW0Xyy+DldxP8psx2Uns78hgQw31na139xLL
M4NNKFt9T0deTryeDLbj4HiPfy8GO8DyzWCw/bXT4TTs79G2P8T+IK29YH8R
bp/A/iStYX8NNjwytf4Z9ldpDT7YDrC/S2uxP0zr+bC/TGvwwz4M+9u0Fvvj
tH4C++u0Bl9s+HzFFvsDtQaPb1qDBzZ4YIMHNnhggwc2eGCDxzfi8Y14fCMe
34jHN+KRRTyyiEcW8cgiHlnEI4t4ZBGPLOKRRTyyiEcW8cgiHlnEI5t4ZBOP
bOKRTTyyiUc28cgmHtjwfoQN85xNPLKJRzbxyCEeOcQjh3jkEI8c4pFDPHKI
Rw7xyCEeOcQjh3jkEI8c4pFLPHKJRy7xyCUeucQjl3jkEo9c4pFLPHKJRy7x
yCUeecQjj3jkEY884pFHPPKIRx7xyCMeecQjj3jkEY884pFHPPKJRz7xyCce
+cQjn3jkE4984pFPPPKJRz7xyCce+cSjgHgUEI8C4lFAPAqIRwHxKCAeBcSj
gHgUEI8C4lFAPAqIx3fi8Z14fCce34nHd+LxnXh8Jx7ficd34oEdAcd7ag37
M7FhfxQ27K/4obU43lRr2D+HDfu3sGH/B7Y43lVr2P+HDfvLsGF/CrY43lZr
2L/4g82+ePP9sGERDrD/7Qf70nrjFV36YrF/ppC1KJe9r1cFWT3el22upPvW
5Gms2H9ZyPadTs4afeiD2J9XyH7bEe93cnm82N9ZyC4aY/q+9I5XjzdmW31q
t125Ll49HpkZS/cXfvkg9g8Wsn5FbRcboj+I/amF7HnPDuPPvPmgHu/M+rcx
3KpUpB0PzRYOrZeYcyhO7F8uZDd7bXcfmxsn9g8Wsp6OY4+uufdePd4atq+j
YtXjsVmfrwcaWljFif2lRax7y66jh/rEiP2NRWxX+tFurSbHiv1RRWzQgbLt
T5i048FZxx+9BmyoFCP2xxaxcgsO/Nbsc4zYf1nESpLPdKpwOVrs3ypiPuPm
vv95V4x6PDp7Ka/6+qFKtNjfW8QmVzl/+a+Pb8X+0CLmGLioyeofUcKjmP0z
JXmI1bC36vHwzL5K9Mq2TaKFRzGb945Vv/A8WngUs4dtAhcfdooWHsVsSXzi
1j1StHo8Pqu0ISj80AnteH2m3/jBuOttlPAoZl2mbAgouRAtPIpZWYuDvTcd
084HYA1m3oruvEU7X4CllG/4qWhWlPAoZuXapBbftY8WHsVM2d9lH6Wej8CG
3N9Q18agna/AlPNXsiKFRwnbv8/g52F+PvAoYTsrHW7ndlU7H4LVP9C3qG26
dr4E++Eee/XnUZHCo4T5net94tqGSOFRwsrP6vyXe3qE8ChhocfLOJZYRKrn
a7D6S+rerb4nQniUsOnVeme03x0hPErYph+rQg//EqGeDyIdNBa0OKiPUM8X
ke7+MG8wP9fOJ5HKn12sX7f5DRx/0MhC6jLpYv0Ls7TzUaSUmUX/eGVr56tI
r0pWtpls80acD2khHXZzsj2+MRxe3zAL6cXwbbmNToXD8p5gIXVI+Xopo3G4
er6M9Pzquzu6cuHq+TRS+BT9lCb52vk20oU5KxfOdw6D4xm2WUhWk5/uWCJr
5+tIbVc9bd1Up53PI4WXKRr2vG0YrG/nLKQF+xdtblo+DLyuWkjbOtuWSZqo
nS8kLTsv9yywCVPPJ5Ke7v3qfVOvnW8k1XatvK9P99dwvEWohWTe2KobvFY7
X0n6WHbn37M7a+czSd0H3Bt4dehrcX6mhfQkPv5qzO5X4P3dQmoxw9RHFxcK
66+1peRZ7+rY+q1eq+dTSc0HWl6YeTRUPd9KmvHw74cDokOFh6UUfajakVk+
r9TztaSVl85Zu5lM6vlc0t9vd26amxwqPCylSr/WWrm45yvhYSnZvrbf3G+A
SXhYSlNS9+98aP7z4nwyaUXd9R4x97XzzSTZOPzMisAQ9Xw0aWjSxNhxhlDh
YSlVfVRu9vn+2vls0tbxp1rc6hminu8mXfhy8mmrU6HCw1KasOX2w9k5JuFh
Kb147+xXIcSonk8n+dv2PjNuaKh6vp10Yk3JxL2ydj6eNKT5loaJLuJ4pFBL
6Xilm9dPfDSp5/NJQfl5tWqc1M73k8z/+t59h4njczIspc99bhaXWSKON/tu
/vO5DZc9WW5SzyeUVqSczHJtY1TPN5SuLdxx9UdYiHo+otSqfciQyb1NwkMn
DQ1YWWVII3F8U1uddD+0O/MJ1853lJTf730OER46Sfl9Wxtx/NUwnVTZ/PHk
mC+Oz5mgkwbWqzehUTv1/D6ddK7ZufvW3bTzMaX+bnPfsekG9XxNKWxIw8ND
JxqFh076U1d+ZmBzo3q+p/S5b42wR5W080GlA1sCfH/fIo5HOqeT/vm4Yfm6
XHH80FWd1KVBn6nd9dr5ptKbnjE/VfAKVs9HlbZb28+N22lQz1eVAtaMDVzU
UByPFGp+Pd/0EzaMCFbPd5XCrf8Ldg/VzoeV0vLbVbKyNwgPnWT+yrKnoI84
HvO7TrrnUjbmaXntfFtp76Dhz07GBqvn48L6s0c7X1eatKi5R40DQcJDL7ld
+Dyhh/nvg4deqvPTUD27HayeDyxNkNzOOVwPEh56STkfu2qQ8NBLyvEIjYOF
h15yejhn3M52wer5yFKLdf8kXPQJVM9Xlnbovia+zgtUz2eWnDLPvBzSO1h4
6KXI5z/vKztPOx9aurGx4O+mFQPV86WlveeODa7QJkh46KXeFWo23lI7WHjo
pe7hk0/umheono8t2bZYX+7J5QD1fG1JOf99b5Dw0Et2q7+UT74VJDz00txa
8RNrOAWo54NLrjsfnh16PEA9X1yqXGt85oCkIPV8csnTN+frd4sg4aGXynq5
NJmwRr0+gJWk/H49IEA9X136sGnb77ltVQ8rifnGeOysFig8rKS7S//r2eG0
n/Cwkua5/f26tfm/g4eVlHDZ5nRI92D1fHppSGZm2aifA4SHleQyiG+pl+gr
PKwk5foO9ur54VbSuurPx1qWV88fN//8FRZFL0b6Cw8rqavrjrjMwb7Cw0oa
XPoPfqNeT8NKanK8RVKDB0Hq9QSk3/67PcO9r7/wsJJuVdM98Z7mKzyspHFj
mp3ftz5AvV6BtPdpRWlhV/X8eStp/clcQ9Fgf+FhJSXdbpL4+x++wsNKenml
+4YjLVQPK0m/5deRR42B6vUUpHJtx4fNHKJdb0Hautxhzc2/fIWH+e//m5+/
M0y7XoPkXs81stly9foB1pJPUkL0qN+06z1IHS/lPLLa7Cs8rKVKycOiHSf5
Cw9raeWiV0v22ake1tLdq3tfDx7gr15vQio9Xbn5Il/hYS056g2fYgx+wsNa
mhx+9ODKswHq9SykbqUH0JiXP3hYS81qOM2sN9ZXeFhLLRqfCu/ZzU94WEvK
/okqqoe1tOixf+9po/3V621IX7a5eCzsK473PmctKfunNqke1pLnhNWpnUer
14+wltZF167s2le9/oq1NGylfLtpT1/hYS398WmxpdsuH+FhLXkNmMRPNfaD
75sx1lKsX2jdSd391euNSBbL06JWhfqq1yORNpb80mxYTR/hYS0Zr4eEj4/x
Ua9nIq24PWu371c/9Xon0tT6iwbYRKnXe7CRnDaffL54k4/wsJH2eeRXs7jj
LTxspIJF9wb0buCnXm9Fmnb9VfWIMNXDRhoc45TSd53qYSPFW11+/XSfl3o9
F+n+lwedf63ro17vRSrdXfDugephI7nFPPw6usRPeNhI3s3+HmS/xEt42Ejl
dvg9WpfpqV5vRpo0ok9K+Rwf9Xo0knJ9mk4BwsNG2tAkYNWWkb7q9Wyk1QOO
5dp09FSvdyPtfT5KXjvRU70ejrQpsrz14t9VDxvp6IbEija5/sLDRvLU68v8
ct1beNjA971hL9Tr8UhdHP4symrN1ev1SJvy/DaF61QPG2l+/7B+/3xSry9j
K8kNHa9FdfRWrwckDdrfcXf3a9r1gqTedrdGGJ0fCg9bqUKduUXzXj0THrbw
/aXZS/V6RNIoPyebltvU6+PYSpYxrae3lmXhYStd3zF68N/Oj9TrHUn5CblB
zVrdUK+HJC3bbuVz6Mhp9XpJErs+izervlt42EqjqyVX3XB0mfCwlRx9HL+X
nT9WvR6TFLMrqceBB52Eh630wObrjZVuVYSHraQcb90jXb3ek7R684NuTie9
1OtBSer1oMDDVlKvFwUetpK6vQ0e2OCBDR7Y4IENHtjgUUZr8MAGD2zwwAYP
bPDABg9s8MAGD2zwwAYPbPDABg9s8MAGD2zwwBbXQ9MaPLDBAxs8sMEDGzyw
wQMbPLDBAxs8ymoNHtjggQ0e2OCBDR7Y4IENHtjggQ0e2OCBDR7Y4IENHtjg
gQ0e2OJ6gVqDBzZ4YIMHNnhggwc2eGCDBzZ4YINHOa3BAxs8sMEDGzywwQMb
PLDBAxs8sMEDGzywwQMbPLDBAxs8sMEDW1xPU2vwwAYPbPDABg9s8MAGD2zw
wAYPbPAorzV4YIMHNnhggwc2eGCDBzZ4YIMHNnhggwc2eGCDBzZ4YIMHNnhg
i+vNag0e2OCBDR7Y4IENHtjggQ0e2OCBDR52WoMHNnhggwc2eGCDBzZ4YIMH
Nnhggwc2eGCDBzZ4YIMHNnhggwe2uB6z1uCBDR7Y4IENHtjggQ0e2OCBDR7Y
4FFBa/DABg9s8MAGD2zwwAYPbPDABg9s8MAGD2zwwFYeLtjggQ0e2OCBDdsf
2OCBDR7Y4IENHtiwPYgNHtjggQ0e2PD7xJ+0Bg9s8MAGD2z4fSI2eGCDBzZ4
YMP2IDZ4YIMHNnhgKw8XbPDABg9s8MAGD2zwwAYPbPDAFvcT0Bo8sMEDGzyw
wQMbPCpqDR7Y4IENHtjggQ0e2OCBDR7Y4IENHtjggQ0e2MrDBRs8sMEDGzyw
wQMbPLDBAxs8sMX9NrQGD2zwwAYPbPAgy0tXSWtxvxCtleVnhy3uN6K18n5T
A1t5PXWxleXbEFt5fU2xleXdClt5vfbY4n4q///6e2ArDwlbef/tj634DMFW
1reR2IqXI7a4X4zWit90bHG/Ga3F/Wi0VtbPpdiK7ypsZX1dj614b8FWPHYQ
jz3Ew5V4HCEeJ4jHWeLhRjwuE48bxMOdeHgQj6fEQyYePsQjkHiEEI8w4hFF
PGKJRwLxSCYe6cQji3jkY4v7RWkN81FZa3G/Ka2V69fZYYv7VWmtHP9RAxvm
A1vcD0trmA9scT8trWE+sMX9uLRWjvfoga08JGy4Hzc2zAe2uF+Y1jAf2OJ+
Y1orp4tNxxb3K9NaOX7FGRvmAxvuN4sN84Et7qemNcwH8dhDPFyJxxHicYJ4
nCUebsTjMvG4QTzciYcH8XhKPGTi4UM8AolHCPEIIx5RxCOWeCQQj2TikU48
sohHPvEoIh66KlqL+xVqDfOBLe53qDXMBzbMB7a4n6LWMB/Y4n6MWsN8YIv7
OWoN84GtPCRsmA9smA9scb9JrWE+sMX9KrWG+cAW97vUGuYDG+YDG+YDG+YD
W9yPU2uYD+Kxh3i4Eo8jxOME8ThLPNyIx2XicYN4uBMPD+LxlHjIxMOHeAQS
jxDiEUY8oohHLPFIIB7JxCOdeGQRj3ziUUQ8dFW1Fve71RrmA1vcL1drmA9s
mA9scT9erWE+sMX9fLVWrjdrjy3uB6w1zAe28pCwYT6wYT6wxf2KtYb5wBb3
O9Ya5gNb3C9Za5gPbJgPbJgPbJgPbHE/Z61hPojHHuLhSjyOEI8TxOMs8XAj
HpeJxw3i4U48PIjHU+IhEw8f4hFIPEKIRxjxiCIescQjgXgkE4904pFFPPKJ
RxHx0FXTWtwvXWuYD2xxv3WtYT6wYT6wxf3ctYb5wBb3g9ca5gNb3E9ea5gP
bOUhYcN8YMN8YIv73WsN84EN84EN84EN84EN84EN84EN84EN84EN84EN80E8
9hAPV+JxhHicIB5niYcb8bhMPG4QD3fi4UE8nhIPmXj4EI9A4hFCPMKIRxTx
iCUeCcQjmXikE48s4pFPPIqwlfNfdD9rDfOBDfOBDfOBDfOBDfOBDfOBDfOB
DfOBDfOBDfOBDfdDxVYeEjbMBzbMBzbMBzbMBzbMBzbMBzbMBzbMBzbMBzbM
BzbMBzbMB7bisYN47CEersTjCPE4QTzOEg834nGZeNwgHu7Ew4N4PCUeMvHw
IR6BxCOEeIQRjyjiEUs8EohHMvFIJx5ZxCOfeBQRD111rWE+sGE+sGE+sGE+
sGE+sGE+sGE+sGE+sGE+sGE+sGE+sJWHhA3zgQ3zgQ3zgQ3zgQ3zgQ3zgQ3z
gQ3zgQ3zgQ3zgQ3zgQ3zgQ3zQTz2EA9X4nGEeJwgHmeJhxvxuEw8bhAPd+Lh
QTyeEg+ZePgQj0DiEUI8wohHFPGIJR4JxCOZeKQTjyzikU88ioiHrobWMB/Y
MB/YMB/YMB/YMB/YMB/YMB/YMB/YMB/YMB/YMB/YykPChvnAhvnAhvnAhvnA
hvnAhvnAhvnAhvnAhvnAhvnAhvnAhvnAhvkgHnuIhyvxOEI8ThCPs8TDjXhc
Jh43iIc78fAgHk+Jh0w8fIhHIPEIIR5hxCOKeMQSjwTikUw80olHFvHIJx5F
2P8DG6ZJlQ==
          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxd3HVYFFsfB/AlFhTswsbuAPVaVznHwlevmNjd3YEt3ouKGHhVbFGwRVH0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          "]]}, 
        Annotation[#, "Charting`Private`Tag#4"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \\(8\\)]\\)\"", 
       TraditionalForm], PlotRange -> {{-3.3, 3.3}, {0, 1.1589605}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"T2.1\"", "\"T5.1\"", "\"T17.2\"", "\"T33.1\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.782462, 0.3104325]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.979377, 0.451467, 0.0511329]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.782462, 0.3104325]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.979377, 0.451467, 0.0511329]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[0.5805400000000001, 0.197808, 0.3886405]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091264714520893`*^9, 3.9101545008181863`*^9, 3.910155616253199*^9, {
   3.9101562517976747`*^9, 3.9101562871700735`*^9}, 3.910162253949086*^9, {
   3.910168716292123*^9, 3.9101687292935357`*^9}, {3.9101687617626452`*^9, 
   3.9101687658955555`*^9}, {3.9101778893722553`*^9, 3.9101779231383815`*^9}},
 CellLabel->"Out[12]=",ExpressionUUID->"339c522a-3a1c-4101-a06c-ea132fdea9bc"]
}, Open  ]],

Cell["\<\
We observe convergence of the density of states with increasing size of the \
supercell.\
\>", "Text",
 CellChangeTimes->{{3.909125877711278*^9, 3.909126045253215*^9}, {
  3.9101545181845226`*^9, 
  3.9101545262977867`*^9}},ExpressionUUID->"d82dee24-bf5f-46bd-afb5-\
18e0ac5fbc67"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BBH model on the {6,4} lattice", "Section",
 CellChangeTimes->{{3.9091097560137053`*^9, 3.9091097636740923`*^9}, {
  3.909109820746976*^9, 3.909109821007987*^9}, {3.9101530821292405`*^9, 
  3.9101530911518974`*^9}, {3.910161201243699*^9, 3.9101612014819603`*^9}, {
  3.910165347636364*^9, 3.9101653621092367`*^9}, {3.9101654348830037`*^9, 
  3.910165443877036*^9}, {3.910171891441964*^9, 3.9101718958277707`*^9}, {
  3.910178021562079*^9, 
  3.910178024740909*^9}},ExpressionUUID->"3829808c-565c-4820-89ff-\
bb32d0bf7205"],

Cell[CellGroupData[{

Cell["Import cells", "Subsection",
 CellChangeTimes->{{3.909109766864945*^9, 3.909109771535059*^9}, {
  3.909109823230064*^9, 
  3.9091098236720653`*^9}},ExpressionUUID->"13f2005b-aab7-4553-998f-\
e8b8a44b4635"],

Cell["\<\
We first import the cell, model, and supercell model graphs as produced by \
the HyperCells package (see \
https://github.com/patrick-lenggenhager/HyperCells for the package \
repository):\
\>", "Text",
 CellChangeTimes->{{3.90910977524686*^9, 3.9091097920317583`*^9}, {
  3.9091099483552275`*^9, 
  3.909109968542066*^9}},ExpressionUUID->"b4d23fbc-aaf5-4274-a1ee-\
624c8736b1c1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcell", "=", 
   RowBox[{"ImportCellGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<(2,4,6)_T2.2_3.hcc\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9090560618564167`*^9, 3.9090560733680687`*^9}, {
  3.9090561514000225`*^9, 3.9090561514836597`*^9}, {3.9091128212745233`*^9, 
  3.909112832496519*^9}, {3.910161215877681*^9, 3.910161217541376*^9}, {
  3.910178027636567*^9, 3.9101780380052023`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"db8621bf-7c8f-4a4d-a73a-75fab247f4ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pcmodel", "=", 
   RowBox[{"ImportModelGraphString", "[", 
    RowBox[{"Import", "[", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
        "\"\<{6,4}-tess_T2.2_3.hcm\>\""}], "}"}], "]"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.909055936914714*^9, 3.909055963188888*^9}, {
  3.9090560238348665`*^9, 3.909056040271286*^9}, {3.909112837065897*^9, 
  3.909112838796729*^9}, {3.9091137679617558`*^9, 3.909113768077687*^9}, {
  3.9101612202907867`*^9, 3.9101612228731327`*^9}, {3.910165372517359*^9, 
  3.9101653740399685`*^9}, {3.9101719178394775`*^9, 3.9101719362323914`*^9}, {
  3.910178040503416*^9, 3.910178066228732*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"b783d92e-135f-4090-8931-43390273972b"],

Cell["\<\
We consider the following sequence of supercells, defined in terms of \
quotients given in \
https://www.math.auckland.ac.nz/~conder/TriangleGroupQuotients101.txt by M. \
Conder:\
\>", "Text",
 CellChangeTimes->{{3.9091138575774813`*^9, 
  3.909113909312521*^9}},ExpressionUUID->"081ff5ec-023c-4811-bc55-\
9f4b556f709b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"supercells", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<T5.4\>\"", ",", "\"\<T9.3\>\"", ",", "\"\<T33.11\>\"", ",", 
     "\"\<T65.9\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091137371550074`*^9, 3.9091137399789495`*^9}, {
  3.9091138427067947`*^9, 3.9091138727916994`*^9}, {3.9091139154861975`*^9, 
  3.9091139250217147`*^9}, {3.910153107552163*^9, 3.9101531227109675`*^9}, {
  3.910161235495674*^9, 3.9101612492366943`*^9}, {3.910178074694395*^9, 
  3.910178087244066*^9}, {3.910178372771553*^9, 3.9101783737174253`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"01e64b66-5366-4b82-b858-eea5dcedab20"],

Cell[BoxData[
 RowBox[{
  RowBox[{"scmodels", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"ImportSupercellModelGraphString", "[", 
        RowBox[{"Import", "[", 
         RowBox[{"FileNameJoin", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<data\>\"", ",", "\"\<cells\>\"", ",", 
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<{6,4}-tess_T2.2_3_sc-``.hcs\>\"", ",", "#"}], 
              "]"}]}]}], "}"}], "]"}], "]"}], "]"}]}], "&"}], "/@", 
     "supercells"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.909113928164541*^9, 3.9091139908886857`*^9}, {
   3.9091142248348513`*^9, 3.909114238346472*^9}, {3.910161254190941*^9, 
   3.9101612556785207`*^9}, {3.9101654104848375`*^9, 3.910165411576088*^9}, 
   3.9101719465139456`*^9, {3.910178090171788*^9, 3.910178094709442*^9}, 
   3.9101785804782424`*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"5df09125-a132-4498-af16-7d3171ab8213"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the primitive cell T2.2", "Subsection",
 CellChangeTimes->{{3.9091098104889455`*^9, 3.90910982999617*^9}, 
   3.9101612604916887`*^9, 
   3.910178098238513*^9},ExpressionUUID->"afef30fb-f0db-4f46-9ae5-\
41da85564a36"],

Cell["\<\
We define the model on the primitive cell given by the quotient group T2.2. \
The primitive cell (Wigner-Seitz unit cell) forms an octagon with a single \
site at its center and nearest neighbors in adjacent copies of the cell:\
\>", "Text",
 CellChangeTimes->{{3.909109834065158*^9, 3.909109920885654*^9}, {
   3.909109996816284*^9, 3.9091100631664762`*^9}, {3.9091138866924057`*^9, 
   3.909113887462228*^9}, 3.910161267524358*^9, 
   3.910178099838792*^9},ExpressionUUID->"05c715df-5e3d-48b1-b786-\
592328cc5864"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VisualizeModelGraph", "[", 
  RowBox[{"pcmodel", ",", "\[IndentingNewLine]", 
   RowBox[{"Elements", "\[Rule]", 
    RowBox[{"<|", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ShowCellGraphFlattened", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"ShowCellBoundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ShowEdgeIdentification", "\[Rule]", "True"}], "}"}]}]}], 
     "\[IndentingNewLine]", "|>"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"CellGraph", "\[Rule]", "pcell"}], ",", "\[IndentingNewLine]", 
   RowBox[{"NumberOfGenerations", "\[Rule]", "3"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", "300"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9090560452383413`*^9, 3.9090560491912336`*^9}, {
   3.909056084328685*^9, 3.9090561117988863`*^9}, {3.9101612828124905`*^9, 
   3.9101612870015707`*^9}, 3.910178104061259*^9, {3.910178608612258*^9, 
   3.9101786091096015`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"2d209118-9a27-46a7-aeff-112480c3d7b1"],

Cell[BoxData[
 GraphicsBox[{{InsetBox[
     FormBox[
      GraphicsBox[
       TagBox[RasterBox[CompressedData["
1:eJzs3dtyMsu24PcO2xe+9Cv4LXzrS9+2ww/QHW53+KYd0e0Ih9/Kr6MPEIiP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         "], {{0, 300.}, {300., 0}}, {0, 255},
         ColorFunction->RGBColor,
         ImageResolution->288.],
        BoxForm`ImageTag[
        "Byte", ColorSpace -> "RGB", Interleaving -> True, Magnification -> 
         Automatic],
        Selectable->False],
       DefaultBaseStyle->"ImageGraphics",
       ImageSize->300,
       ImageSizeRaw->{300., 300.},
       PlotRange->{{0, 300.}, {0, 300.}}],
      TraditionalForm], Scaled[{0.5, 0.5}], Scaled[{0.5, 0.5}], Scaled[1]], 
    CircleBox[{0, 0}]}, {
    {RGBColor[
      NCache[
       Rational[2, 3], 0.6666666666666666], 0, 0], AbsoluteThickness[2], 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwVx30s1HEAx/GbiVSy8jCpq6Q/ouvBROWmT2uFLHGXk2WJ0AMrRppU6InT
5M56Yu7shOthrZErKhOny9M9uSfNMcv3+8sqPZh0tVD6473X3t5HM/ipdiwW
y3eu/9p7XuDwmhnMNvrkiJvb8WRrIIcrZeDKC/jLOdQBF+05TusVBndA/4TO
dkCcZykxpzE40WS6b65VQj+hqBDyGbxzaF2vj+jEZ93eekswg7jbRLJhshOO
1suT7T4MOmpkM1TyBtPPp9rCnRk8hS7kS5gKrgt1wRk2CuH2/dyQHyq0eCnL
A0cpgsbPK/tq3mKR4Rcj0VCkLFWUiaK74Bdmz5O/oGDnaiMKWN0Yb9AQvpwi
WFxdXt7YjQWmYnntTQotzf7amtyD2DFZReUligfxVcM2j16ovykaAjMpHMPf
q7f19SLiduFQ7hGKW7vcVpwt7EN+pomVEkVxt13IlgepMWgQ/raBoiBZ6vH6
ixp+TlmVgf4Ueb+xs7leg4RlgkdsH4ot67K7riZowZ0eGm9wpyh5adKwPXU4
dUDs+X0+xWjJ2rRcgw4ySZfVOk3Ank2NUYXqsXS01npmguC5Y0BofZ0eqz/O
U7z6QBA25eM4YNeP2JFrtoYhAmfbVZEgqR8JRembBEaCFqnQuLy9H5EjcuuD
XoJIS2nn2lUGyAQ9WY+VBLFeifvS8w2ISfublPiKoE1fdPDTsAGZIwucVQqC
JmthnyTEiB0pIdrBJwStUS6lF6VG3FFm/6x5SBAXnZdXPGPE6RtLNF71BFmL
B3KeHTaBRs+I9tQQDNLIeLs2E5x2S7PXVBO4ixIdTq404/oF073GKgLl2c08
mm/G8ToWJisJelxVbhkjZvT6/zoyVkEgjef72u+0YKO3k1vZ3HdwC45Vyyz4
B3PsWsc=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8748177652797064, 0.30304576336566275}], {}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA6B9QO2z0zD+EnmySdOXkvzN6Ytts
M8w/dukf0jDj5L/Nmp4kUXLLPywetIWf4eS/zSfxZiOxyj9oRJfCwODkv1s4
PfPt78k/h6yulJTg5L/qTc8auy7JP91MVv4a4eS/10fQLpVtyD92oWD4U+Lk
v+lYuH+GrMc/Ng4Xcj/k5L9CBsJcmevGP1XDOlHd5uS/RjddE9gqxj8qJAZy
LerkvwReou5MasU/LrAupy/u5L+Yv8U2AqrEPy5u57nj8uS/JeSKMALqwz9r
2eNpSfjkv8M1uBxXKsM/oFBbbWD+5L8B1oo3C2vCP7QGDXEoBeW/arEquCis
wT/SdEQYoQzlv4TYHtC57cA/yU3e/MkU5b+7JcKqyC/AP1LyTa+iHeW/dW9w
2b7kvj8IZqO2KiflvxmPxWYQa70/tsSRkGEx5b/qw64omvK7P503drFGPOW/
wharOXB7uj9oal+E2Uflv6SreqKmBbk/TH8VaxlU5b8Z4AxZUZG3PwCCIr4F
YeW/4mpvP4Qetj8IWdvMnW7lv1GLviJTrbQ/6DRp3eB85b8SVxa60T2zP6p8
0yzOi+W/oDSFpRPQsT9GNwrvZJvlv/iQ/2wsZLA/UvHwTqSr5b9cvan+XvSt
P1weam6LvOW/mNlLYmAkqz9m9WJmGc7lv3xHuXeDWKg/1MffRk3g5b/wa0p5
7pClPy3SCBcm8+W/JKbRZsfNoj/xhTfVogbmvzzVkwM0D6A/3ksEd8Ia5r8w
NIios6qaP969VOmDL+a/0OAFOrxAlT/mV2oQ5kTmv4Dpgn2XwY8/7J7xx+da
5r/Qao9hVxaFPza9EeOHcea/gLmT9JMAdT8mk3wsxYjmvwAAAAAAgNa8nzt/
Zp6g5r+2DF/h
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.17496355305594155, -0.9091372900969888}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwdyn0s1HEcB/CbuDVJGhHjilQyoYWrw97+sEt5GLFQ8pRueTwklq5snjLa
OA9ZLA8XEUcuJo+H81zS0TLSw9X9vmfkIQ/JH1JXn+299157f4xDuRevq9Bo
tBPK/GvGYU/7qI0x5JdF5ScQCuHJobNRp8eQPn9o0lpOQbW0zNQr/jVYjJaM
8q9Km61yjoheIdG5WNIro8A/47i+tDKKh8LGwkKljT3eGnRajmLR7dKOgfJf
00VqWRQ9gszK4C3vb8rdvy0lUzgMtqZePCgKyXRJwKPvQ+D0s7w+KSjcY17V
njYfAsuUHn9ygYJ9oGDZLWIQTk2WNVbLFCZ6Bu1U6gaAmLl2+RqFQCrbWmWh
H7wZefj5LQrbtm2Gvub9eOF5JTp4hwJrKpu5J1KCIfreODM1giqReZuZsA9U
gvPBSg0C8TRD2r7Ui4/un7dHdQg2j0rqRqx6Ebbm/lxgRLDEjZ0RU2IYcp60
mh8n4OcOcrQiuzE6wM8LOUVwbaDRrGStEyJmoojtQOCoV3829k4HeBFB6TPn
CIyEyYKnau0ISTkQqe9DUCzT8Pfiv4ROqolYLYQgKJKLdEYrGP6zY49jCKQ5
YhPvhhb8tgn/JOMR5Pvqdkw4NqOH985iPIfAxDajWlsqQgBTfSWslIDH/xNl
EdaE8NUfHlX1BGHiZzuBGw24yYiIyekiEH5wDQ02rQfvZyhHf5zggUt7Uppf
LRaHv7DdZQSq0RduL+dVgz25W+/YOoFDzQRn+I0A6pnM9wK6An5TBbts9lVg
01U1SWKgwA27rNrmuhL86vaZT7NSQEuuxupyKgLNL0JL4az0curd4r5c0MtX
h+cuK5DHzQ3x1c2AZ/d++f04BWj9BRsFtFtwKuBZDGYp/f+kDh32KZyyCgX+
Ap5nRck=
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.17496355305594155, 0.9091372900969888}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAAhh8LFG35T8UsiN1kLfAv6w3NSw7
neU/KVEz/yxawb8MznksvIPlP6w/5PtG/sG/jnrWidVq5T9+s9Sn1aPCv83x
tJiIUuU/7ga8K9BKw7/nz0ml1jrlP3GV45wt88O/A9uC88Aj5T/XoaD95JzE
v/i29b5IDeU/yj/PPe1Hxb8OC886b/fkP585Tjs99MW/sxrCkTXi5D9M7HvC
y6HGvwfS+OWczeQ/fRK0jo9Qx78lRwRRprnkPzV4zkp/AMi/5rDN41Km5D9T
kJ6RkbHIvwTUh6ajk+Q/6ORz7rxjyb9P56CYmYHkP8Fbm933Fsq/xu+0sDVw
5D8hSOHMOMvKv0SVgNx4X+Q/rUIUHHaAy792cNQAZE/kP7PAiB2mNsy/09KI
+fc/5D+aY50Wv+3MvyIJcpk1MeQ/lPk/QLelzb9WGVWqHSPkP1Aoc8eEXs6/
Mvzc7LAV5D+mutTNHRjPv2RTkBjwCOQ//okkanjSz7+YnMfb2/zjPyz+ZVTF
RtC/CeKj23Tx4z/FBzNGpaTQvxfpBbS75uM/VvUjB9cC0b9M34X3sNzjPxz3
hI9VYdG/VIZrL1XT4z/InYjTG8DRv0PfptuoyuM/XtaMwyQf0r+WVclyrMLj
P2YaYExrftK/Smr/YWC74z/O0IZX6t3Sv2XfCg3FtOM/xNuAy5w90780ZD3O
2q7jP85PD4x9ndO/jMJz9qGp4z9rUHp6h/3Tv2ONEc0apeM/hQ7XdbVd1L/Z
UP2PRaHjP+3kTVsCvtS//kOdcyKe4z8pj2AGaR7Vv3581KKxm+M/1nYwUeR+
1b9bpAA/85njP94TxRRv39W/vjH4X+eY4z+xW1IpBEDWvyIhCRSOmOM/1Tt/
Zp6g1r9hOXGF
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8748177652797064, -0.30304576336566275}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAiB9QO2z03L/6sSN1kLfgP70xueq/
IN2/KBVTkqWM4D84TqTGT07dvz4Ou8YNYuA/wmA0YBl93b+GF6JYyzfgPwFH
yzcard2/yqq/ieAN4D92+Cu9T97dvwLPOi6fyN8/v5GdT7cQ3r8C8vBxNXbf
PydBDz5ORN6/jHxGRYgk3z+vEj3HEXnev+JpzgSc094/fJnVGf+u3r82Us4C
dYPeP850oFQT5t6/LFcDhxc03j9HrqWGSx7fv1KgZ86H5d0/i+9Vr6RX37++
avgKypfdP/6Ms74bkt+/4658Y+JK3T99Y3yVrc3fv6BfTPPU/tw/XkOqgisF
4L+xRRjKpbPcPxrfeGgKJOC/XHqy61hp3D8C5yPWcUPgv2+E10/yH9w/4sRa
HmBj4L9sGvjhddfbP0FXmYzTg+C/z4wDgeeP2z/eQD9lyqTgv0PbMv9KSds/
Ypmn5ULG4L+yd9QhpAPbP/z9QEQ76OC/07kYofa+2j+kAKawsQrhvxMG3ydG
e9o/wPS1U6Qt4b+PqoNTljjaP8MXrk8RUeG/wHSus+r22T+EFEPA9nThv4QC
IspGttk/3t+6ulKZ4b8Y0YsKrnbZP0TtBk4jvuG/nwxV2iM42T/kud6CZuPh
v7AidJCr+tg/16zaWxoJ4r9hGj91SL7YPxhLj9U8L+K/TrQ+wv2C2D+hvajm
y1Xiv/1UAqLOSNg/WqgGgMV84r/uu/Qvvg/YP0RQ2IwnpOK/sokxeM/X1z9u
D7ny78viv1GXW3cFodc/MRXNkRz04r8sIXQaY2vXPxVx3kSrHOO/kceyPus2
1z/wZnrhmUXjvyVnXrGgA9c/jgoPOOZu4784y6YvhtHWP3IhCRSOmOO/DTx/
Zp6g1j9WhGKB
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.6998542122237658, 0.6060915267313275}], {}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAByBQO2z03D8NsiN1kLfgPzYyueq/
IN0/OhVTkqWM4D+pTqTGT07dP1AOu8YNYuA/LWE0YBl93T+YF6JYyzfgP2VH
yzcard0/26q/ieAN4D/S+Cu9T97dPyLPOi6fyN8/FJKdT7cQ3j8g8vBxNXbf
P3VBDz5ORN4/qXxGRYgk3z/2Ej3HEXneP/xpzgSc094/vJnVGf+u3j9PUs4C
dYPePwd1oFQT5t4/RFcDhxc03j95rqWGSx7fP2egZ86H5d0/te9Vr6RX3z/S
avgKypfdPyKNs74bkt8/9K58Y+JK3T+ZY3yVrc3fP65fTPPU/tw/aUOqgisF
4D+8RRjKpbPcPyDfeGgKJOA/ZXqy61hp3D8G5yPWcUPgP3aE10/yH9w/48Ra
HmBj4D9wGvjhddfbPz5XmYzTg+A/zowDgeeP2z/YQD9lyqTgP0DbMv9KSds/
WZmn5ULG4D+sd9QhpAPbP+79QEQ76OA/ybkYofa+2j+TAKawsQrhPwUG3ydG
e9o/rPS1U6Qt4T99qoNTljjaP6wXrk8RUeE/rHSus+r22T9pFEPA9nThP2sC
IspGttk/wN+6ulKZ4T/70IsKrnbZPyTtBk4jvuE/fwxV2iM42T/Aud6CZuPh
P4oidJCr+tg/sKzaWxoJ4j83Gj91SL7YP+1Kj9U8L+I/H7Q+wv2C2D90vajm
y1XiP8pUAqLOSNg/KagGgMV84j+2u/Qvvg/YPw5Q2IwnpOI/dYkxeM/X1z83
D7ny78viPw+XW3cFodc/9hTNkRz04j/mIHQaY2vXP9hw3kSrHOM/RMeyPus2
1z+uZnrhmUXjP9RmXrGgA9c/SgoPOOZu4z/iyqYvhtHWPywhCRSOmOM/sTt/
Zp6g1j/X8045
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.699854212223767, 0.6060915267313283}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwVjX0s1HEAxm/SC2VWk+lKefsj0lRGotu1VchUd1e0iZLUFjbmIikvIa4m
Lysbc4xwvaxw65qKebhzEe7cu9axW77fX6pFmnS9oeuPZ88+ez7b45mULrhg
x2KxfG3531vcrvvzuxgopN5ZVV19GNob5B/WwIDyApf94/rhp77q31PMQMil
f8KX+vE013TLmMJA8MzwwNgix+w3Wa1IwECzqmeHJkoBR82RNlMog4QaIt45
r8B2c9F8nzcDbXPTIhUPwKNroTfSiYGaO8aZiVAiZO1YaLqVQrrvWBjnuxIW
trw6aIoi7cs1+UjzawTrfjJiFcXDDbKKSt4gYiPs+ZKXtj1HHVXAGgJbqiIC
CcW9qsbqaukQwgxlkpa7FMGMcLbn/BuIpptq625QuMfXT1pdh7FiTtYZlEFR
Gvl+NGRkGCU1hRM5Zyk8DrpsyS4cwasMAyv5OEVAv8hdEjwKtl70y8ql8Epu
cMXMKNIcMuuCdlP4/eYe6GpToWVTzGN3b4q57cLBkjNqFP2d+NK5kYLXbVC5
u43hxYkqt7k1FLLbPik5ujF8FQ+azX8JypcunFSGa5A81WK+/I3Ab01geFur
BtmfVsq6PxDIF7xXj9tp0WG5ae2csPnWksqYc1r0lKYGxOgJOI0i/eY+Ldot
EvPDYYK3pnKFzzYd7GPfZD6RE1B2YnRqvg69KcvnErsJ+NrSU58ndZi0ODop
ZQTRE4UjYo4eHckc9bt2gjiec3legx7rFMIfzY8I/vByc8sW9fh4Z72K3UbA
dh7Pep5gQBJ/sfJwM0Epc/S0Xa8B5YcahF6NBMrKxFWXthqxIc9wX1pPkH1l
F5/mGzHfyuLO1xEUuyhd0i1GxO/5eXa61vYXL/C1P2DCgKeDS4WNC/cXXGxs
MuEfKsqFwA==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8748177652797089, -0.30304576336566386}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA7hlQO2z0zL8RnGySdOXkP0p0Ytts
M8y/EOcf0jDj5D/2lJ4kUXLLv9AbtIWf4eQ/CCLxZiOxyr8ZQpfCwODkP6ky
PfPt78m/Q6qulJTg5D9LSM8auy7Jv6RKVv4a4eQ/TULQLpVtyL9In2D4U+Lk
P3RTuH+GrMe/EgwXcj/k5D/iAMJcmevGvzzBOlHd5uQ//DFdE9gqxr8aIgZy
LerkP89You5MasW/KK4upy/u5D97usU2AqrEvzFs57nj8uQ/H9+KMALqw792
1+NpSfjkP9QwuBxXKsO/tE5bbWD+5D8q0Yo3C2vCv9AEDXEoBeU/rKwquCis
wb/2ckQYoQzlP97THtC57cC/80ve/MkU5T8uIcKqyC/Av4PwTa+iHeU/jGZw
2b7kvr9AZKO2KiflP2OGxWYQa72/9MKRkGEx5T9mu64omvK7v+I1drFGPOU/
cQ6rOXB7ur+zaF+E2UflP4WjeqKmBbm/nH0VaxlU5T8v2AxZUZG3v1WAIr4F
YeU/K2NvP4Qetr9jV9vMnW7lP82DviJTrbS/RjNp3eB85T++Txa60T2zvwx7
0yzOi+U/hC2FpRPQsb+tNQrvZJvlPw6K/2wsZLC/ve/wTqSr5T/kr6n+XvSt
v8ocam6LvOU/kMxLYmAkq7/W82JmGc7lP9A6uXeDWKi/R8bfRk3g5T+sX0p5
7pClv6LQCBcm8+U/PJrRZsfNor9phDfVogbmP7jJkwM0D6C/VkoEd8Ia5j/o
HYios6qav1i8VOmDL+Y/OMsFOrxAlb9hVmoQ5kTmP9C/gn2XwY+/aJ3xx+da
5j+gQo9hVxaFv7O7EeOHceY/AGyT9JMAdb+ikXwsxYjmPwAAAAAAKBQ9HDp/
Zp6g5j/vkltr
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.17496355305594194, 0.9091372900969922}], \
{}}}, 
     {RGBColor[0.528488, 0.470624, 0.701351], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAQSBQO2z0zL+DnmySdOXkv356Ytts
M8y/fukf0jDj5L8Mm54kUXLLvzwetIWf4eS/ACjxZiOxyr+BRJfCwODkv4E4
PfPt78m/qqyulJTg5L8FTs8auy7JvwhNVv4a4eS/50fQLpVtyL+qoWD4U+Lk
v+9YuH+GrMe/dA4Xcj/k5L8+BsJcmevGv5zDOlHd5uS/OTddE9gqxr96JAZy
Lerkv+5dou5MasW/irAupy/u5L96v8U2AqrEv5Nu57nj8uS/AOSKMALqw7/a
2eNpSfjkv5Y1uBxXKsO/GlFbbWD+5L/P1Yo3C2vCvzcHDXEoBeW/NLEquCis
wb9gdUQYoQzlv0jYHtC57cC/YU7e/MkU5b96JcKqyC/Av/TyTa+iHeW/7G5w
2b7kvr+1ZqO2Kiflv4yOxWYQa72/bsWRkGEx5b9Zw64omvK7v184drFGPOW/
MBarOXB7ur82a1+E2Uflvw+reqKmBbm/JYAVaxlU5b+H3wxZUZG3v+OCIr4F
YeW/TWpvP4Qetr/3WdvMnW7lv8KKviJTrbS/4jVp3eB85b+IVha60T2zv659
0yzOi+W/HDSFpRPQsb9YOArvZJvlv3yQ/2wsZLC/b/LwTqSr5b9wvKn+XvSt
v4Qfam6LvOW/0NhLYmAkq7+a9mJmGc7lv8RGuXeDWKi/FMnfRk3g5b9Ya0p5
7pClv3jTCBcm8+W/sKXRZsfNor9IhzfVogbmv+jUkwM0D6C/QU0Ed8Ia5r/Y
M4ios6qav02/VOmDL+a/wOAFOrxAlb9hWWoQ5kTmv0Dqgn2XwY+/c6Dxx+da
5r9AbI9hVxaFv8q+EeOHcea/IL6T9JMAdb/FlHwsxYjmvwAAAAAAAKy8Sj1/
Zp6g5r/XCnEO
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\
\\\\(\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \
\\\\\\\\(1\\\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\
\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \
\\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.17496355305594308, -0.9091372900969932}], \
{}}}, 
     {RGBColor[0.528488, 0.470624, 0.701351], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAthV8LFG35b+fsSN1kLfAP2c1NSw7
neW/t1Az/yxawT/Ny3ksvIPlvzs/5PtG/sE/VXjWidVq5b8Ns9Sn1aPCP5rv
tJiIUuW/fga8K9BKwz+7zUml1jrlv/2U45wt88M/3NiC88Aj5b9koaD95JzE
P9e09b5IDeW/Uj/PPe1HxT/yCM86b/fkvyU5Tjs99MU/nBjCkTXi5L/Q63vC
y6HGP/bP+OWczeS/+RG0jo9Qxz8YRQRRprnkv613zkp/AMg/3q7N41Km5L/F
j56RkbHIPwDSh6ajk+S/UuRz7rxjyT9Q5aCYmYHkvydbm933Fso/yu20sDVw
5L+AR+HMOMvKP0yTgNx4X+S/AkIUHHaAyz+CbtQAZE/kv/+/iB2mNsw/4tCI
+fc/5L/dYp0Wv+3MPzUHcpk1MeS/z/g/QLelzT9sF1WqHSPkv4Anc8eEXs4/
Svrc7LAV5L/MudTNHRjPP35RkBjwCOS/GIkkanjSzz+0msfb2/zjv7P9ZVTF
RtA/JuCj23Tx479HBzNGpaTQPzbnBbS75uO/1PQjB9cC0T9s3YX3sNzjv5L2
hI9VYdE/doRrL1XT4784nYjTG8DRP2bdptuoyuO/yNWMwyQf0j+4U8lyrMLj
v8oZYExrftI/bmj/YWC7478s0IZX6t3SP4ndCg3FtOO/G9uAy5w90z9WYj3O
2q7jvx5PD4x9ndM/rsBz9qGp47+0T3p6h/3TP4WLEc0apeO/yA3XdbVd1D/6
Tv2PRaHjvynkTVsCvtQ/HUKdcyKe479ejmAGaR7VP5161KKxm+O/BnYwUeR+
1T94ogA/85njvwcTxRRv39U/2S/4X+eY47/TWlIpBEDWPzofCRSOmOO/8Tp/
Zp6g1j/k13M0
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*\
SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\\\\\\)], \
\\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8748177652797087, 0.3030457633656644}], \
{}}}, 
     {RGBColor[0.772079, 0.431554, 0.102387], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAfiBQO2z03D+tsiN1kLfgv7Yyueq/
IN0/2BVTkqWM4L8zT6TGT07dP+oOu8YNYuC/wGE0YBl93T8wGKJYyzfgvwFI
yzcard0/cau/ieAN4L95+Su9T97dP0rQOi6fyN+/xZKdT7cQ3j9E8/BxNXbf
vzJCDz5ORN4/yH1GRYgk37+9Ez3HEXnePxprzgSc096/j5rVGf+u3j9oU84C
dYPev+V1oFQT5t4/WVgDhxc03r9jr6WGSx7fP3qhZ86H5d2/rPBVr6RX3z/j
a/gKypfdvyWOs74bkt8/A7B8Y+JK3b+pZHyVrc3fP71gTPPU/ty/+EOqgisF
4D/KRhjKpbPcv7bfeGgKJOA/cXuy61hp3L+i5yPWcUPgP4GF10/yH9y/hMVa
HmBj4D97G/jhddfbv+dXmYzTg+A/2o0DgeeP27+IQT9lyqTgP03cMv9KSdu/
EJqn5ULG4D+5eNQhpAPbv6z+QEQ76OA/2LoYofa+2r9YAaawsQrhPxYH3ydG
e9q/ePW1U6Qt4T+Rq4NTljjav38Yrk8RUeE/wXWus+r22b9EFUPA9nThP4MD
IspGttm/ouC6ulKZ4T8X0osKrnbZvw3uBk4jvuE/nw1V2iM42b+wut6CZuPh
P68jdJCr+ti/qK3aWxoJ4j9fGz91SL7Yv+5Lj9U8L+I/TbU+wv2C2L98vqjm
y1XiP/5VAqLOSNi/OakGgMV84j/wvPQvvg/YvydR2IwnpOI/tYoxeM/X179W
ELny78viP1aYW3cFode/HhbNkRz04j8zInQaY2vXvwdy3kSrHOM/m8iyPus2
17/mZ3rhmUXjPzJoXrGgA9e/iQsPOOZu4z9IzKYvhtHWv3IiCRSOmOM/IT1/
Zp6g1r/eXWL6
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\
\\\\(\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \
\\\\\\\\(2\\\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\
\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \
\\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.6998542122237672, -0.6060915267313289}], \
{}}}, 
     {RGBColor[0.772079, 0.431554, 0.102387], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAtR5QO2z03L88sSN1kLfgv+swueq/
IN2/bRRTkqWM4L9lTaTGT07dv4UNu8YNYuC/8F80YBl93b/QFqJYyzfgvy1G
yzcard2/F6q/ieAN4L+i9yu9T97dv6DNOi6fyN+/6ZCdT7cQ3r+k8PBxNXbf
v1FADz5ORN6/NHtGRYgk37/WET3HEXnev45ozgSc096/opjVGf+u3r/mUM4C
dYPev/FzoFQT5t6/4VUDhxc03r9praWGSx7fvwufZ86H5d2/qu5Vr6RX3798
afgKypfdvxyMs74bkt+/pK18Y+JK3b+XYnyVrc3fv2VeTPPU/ty/6kKqgisF
4L95RBjKpbPcv6TeeGgKJOC/KHmy61hp3L+K5iPWcUPgvz6D10/yH9y/aMRa
HmBj4L8/Gfjhddfbv8ZWmYzTg+C/o4sDgeeP279iQD9lyqTgvxvaMv9KSdu/
45in5ULG4L+NdtQhpAPbv3r9QEQ76OC/sLgYofa+2r8gAKawsQrhv/EE3ydG
e9q/OfS1U6Qt4b9vqYNTljjavzsXrk8RUeG/onOus+r22b/5E0PA9nThv2gB
IspGttm/UN+6ulKZ4b/8z4sKrnbZv7TsBk4jvuG/hQtV2iM42b9Qud6CZuPh
v5YhdJCr+ti/QqzaWxoJ4r9HGT91SL7Yv39Kj9U8L+K/NbM+wv2C2L8Gvajm
y1Xiv+VTAqLOSNi/vKcGgMV84r/VuvQvvg/Yv6FP2IwnpOK/mYgxeM/X17/K
Drny78vivzeWW3cFode/ihTNkRz04r8SIHQaY2vXv2tw3kSrHOO/dcayPus2
179BZnrhmUXjvwhmXrGgA9e/3QkPOOZu478YyqYvhtHWv74gCRSOmOO/7Dp/
Zp6g1r/Zw3hI
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*\
SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\\\\\\)], \
\\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.6998542122237666, -0.6060915267313277}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwVjX0s1HEAhy9ldiZS6DLJ1VXYJSGGuo+6ZGvkvTXROhSWvHTOwtBsSjUv
MS8tmZIxowu7ad4qouZGaF76/n6uu9/97qzXLSPymv549uz56+FHJ4dcNeBw
OA6b/DfXLsg7cZ7G9rYDspIONTT8aVHwGI28Ua/IZqKGdb6UcOU0ePEqyeqa
Gj+yq8SVhTQ8fMR+uXwNttmeaFxOpEFNjytdfTVIe/He6XgAjTev3Ft4CRro
A0z/+DnRkChjGoSFGjh+Om3ptoNG5Eh9WlKrBu3zPx8vz1EYH24apic08FGw
D6snKUjkRQnpyxpwrLBo3UXBX6lf89zHQG4a+C69lkJs2bDo0BkGr5WVX1/e
oRDm90vlmcDAynUgcOgGBVpRUiwtYlAsr5vqD6dQaVzPGW9nkC/mRdSIKKga
PqpDPzPoY3iNEfabPxPZzOI6A3OL+vt/d1LY6B941i3Qopn09mWtE9yLGaJq
z2kxOBvDZb4R6IuSXepStCiwuGt2ZJrgLLc0sK9CiyqBcU7UIIF6xJha7dYi
baxjQaogmPXoygrWaqGzFZml1hM4Cx5N9XJZVC/ZXwqvIBAc7SoTO7Pw3TMj
4RcQ1H6PDVNdYOHsXVY3kUngfnhXT2E2i5HS0KqbSQSZbgUpQc9ZcMp+y5ei
CWjv6R0HlSxqVoxC4i8StJXKYDzHwsZlYebteQLd7pNP1nk6VLBTTYZnCRbK
84Y4PjqcX3xg5CYiGHTYG2cWp0N/d4NXgAcB1SLd6VCkg/RWRl7wMYLbDveu
+yt0uCw0tDwlJMgRc81v0ZvdamBnY0/wpSPsadNWPWTW9AdGQBA5WtjJOOqx
JaZZWL6fYEX1fNk2RI+/caIrrnyC1M7YjagMPXyEJik9dgST3rnXamr1+AfD
R1F+
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.699854212223767, 0.6060915267313283}], \
{}}}, 
     {RGBColor[0.560181, 0.691569, 0.194885], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAArx1QO2z03L89sSN1kLfgP3Qf2D5R
0dy/kM86XKza4D+XgnPaCa/cvwJn3mH8/eA/VHuYQ5eN3L/+PkNHfyHhP1Ib
PKj6bNy/gNfSyzNF4T+pq8cuNU3cv0K3Nq0YaeE/AEsO9kcu3L/AyWOnLI3h
PyjQQhU0ENy/l8yldG6x4T+U8e2b+vLbv+rLqs3c1eE/AbLkkZzW279YrY5p
dvrhP6MSP/cau9u/IMnm/Tkf4j8xC0/EdqDbvxaRzT4mROI/HMiX6bCG27/j
RO7eOWniP1EvxU/Kbdu/SLOQj3OO4j+kq6PXw1Xbv+EHpQDSs+I/cj8YWp4+
278Hpc/gU9niP4feGKhaKNu/Zwl13ff+4j+uD6WK+RLbv+TAxaK8JOM/Hda+
wnv+2r9MYMrboErjPwzjYwni6tq/iItvMqNw4z+hD4cPLdjav8YFkk/CluM/
gR8Kfl3G2r9Aywrb/LzjPy3Mt/Vztdq/JzS7e1Hj4z9tGT4PcaXav04gmde+
CeQ/8vIoW1WW2r8jK7uTQzDkP2UT3WEhiNq/f+dkVN5W5D8dNZOj1Xrav/Ui
E72NfeQ/g4xTmHJu2r8ZMIhwUKTkP36M8a/4Ytq/XDfYECXL5D/j9AdSaFja
vxOOdT8K8uQ/Jyv13cFO2r8nEz2d/hjlP2Xd16oFRtq/GZGCygBA5T/f74sH
ND7av8wkHWcPZ+U/F7WnOk032r/EqHMSKY7lP4dweYJRMdq/TCSJa0y15T8x
JAUVQSzavyw+CRF43OU/8KgCIBwo2r9xslShqgPmP8MR3MjiJNq/0sqNuuIq
5j8KWqwslSLav1XZpPoeUuY/vl4+YDMh2r+wtGT/XXnmP74iDHC9INq/+jV/
Zp6g5j81Y160
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.6998542122237658, 0.6060915267313275}], {}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA6h9QO2z0zL+dnmySdOXkP6Kj5Dkm
kc2/3bVMC8/n5D8dllcswS3Ov+4H6jKf6uQ/GTPdjDfKzr8AMd/v5O3kP6bb
89aDZs+/UkmhJKDx5D/z8spDUAHQv+LvgK/Q9eQ/uq+1DkRP0L+Seqtqdvrk
P0/gfYwandC/kEssLJH/5D9Zx2/+0OrQvyRM7sUgBeU/1fX4pmQ40b+xjL0F
JQvlP7gIwcnShdG/6wlJtZ0R5T9+W8KrGNPRvziXJJqKGOU/wK5ikzMg0r8W
7sp16x/lPwrCi8ggbdK/kOKfBcAn5T/p38OU3bnSv4i88gIIMOU/iVtGQ2cG
07/0tQAjwzjlP9T+GyG7UtO/vJ33FvFB5T9SaDN91p7Tv1af+IuRS+U/71d5
qLbq07/mLhsrpFXlP7Lp8PVYNtS/2RlwmShg5T+wvcu6uoHUv8y7BHgea+U/
PAyCTtnM1L+8V+ZjhXblP5ml6gqyF9W/UJUl9lyC5T863FJMQmLVvxki2sOk
juU/1liWcYes1b+6diZeXJvlP1fXNtx+9tW/wr87UoOo5T/wy3PwJUDWvybq
XSkZtuU/aO9hFXqJ1r8m0+doHcTlP9qxArV40ta/gptPko/S5T8Kk1s8HxvX
v9wdKyNv4eU/dl+NG2tj178MiDSVu/DlP3dR68VZq9e/VBdPXnQA5j9iFRKy
6PLXvzT3i/CYEOY/GbD+WRU62L/GQi+6KCHmPxNHJTvdgNi/YCi1JSMy5j8d
yYfWPcfYv10v15mHQ+Y/CXfMsDQN2b/fn5F5VVXmP3hLVFK/Utm/RQwpJIxn
5j/+QFFH25fZvz78L/UqeuY/ynXcH4bc2b8yuYxEMY3mPyAsDHC9INq/zjt/
Zp6g5j/0T2VK
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.17496355305594194, 0.9091372900969922}], \
{}}}, 
     {RGBColor[0.922526, 0.385626, 0.209179], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAKBd8LFG35b+gsCN1kLfAv+445S3y
zOW/5pNHvIo0wL8Sp0849eLlv+L7XIgWZb+/pooDhVn55b+og99ELWO+v74E
20keEOa/OoFzxmJjvb9wT0m5Qifmv8K2URLAZby/dv1hAsY+5r9gdz0aTmq7
v0xY4FCnVua/pOczvBVxur9+3C7N5W7mv7zwG8Iferm/7NNunICH5r/E6Hbh
dIW4v6YNgOB2oOa/WPMRux2Tt79Iswi4x7nmvxQduNoio7a/Wzt9PnLT5r+o
NOW2jLW1v5R4KIx17ea/QGR5sGPKtL+oxTO20Afnv0CObRKw4bO/Wk2vzoIi
579ob4gRevuyv4VumuSKPee/mIkUzMkXsr/UO+wD6Fjnv3zZlkmnNrG/1hac
NZl057+4WYZ6Gliwvyxmqn+dkOe/wKwIcFb4rr90Zinl86znv/AlK4fCRa2/
qRVGZpvJ579Ii7iNiJirv6w4UQCT5ue/8NOlprfwqb+desit2QPov9jbD8Re
Tqi/rKVfZm4h6L94drSmjLGmvyj1CR9QP+i/ED9t3U8apb9QgAPKfV3ov8gr
rMS2iKO/wr3aVvZ76L9I5/mFz/yhv/seerK4mui/mPZ1F6h2oL/IwzHHw7no
vzBdsXac7J2/JEXBfBbZ6L8w/O3+nveav0eXYbiv+Oi/gCKQeXIOmL9+As9c
jhjpv8Cj2S0xMZW/ejJTSrE46b9wknL39F+Sv7Zbz14XWem/QKD/iq41j7+W
dsZ1v3npv2DeejPiw4m/8o9naKia6b+g5DkPtmqEv5wumA3Ru+m/wLmdzbRU
fr+Kzf45ON3pv4BijkX9BXS/U2oNwNz+6b8AOf4nRdNjv4cnDHC9IOq/AAAA
AAAQEz1IK3bw
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {-0.8748177652797089, -0.30304576336566386}], {}}}, 
     {RGBColor[0.528488, 0.470624, 0.701351], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAArhh8LFG35b8ZsiN1kLfAP4465S3y
zOW/OZVHvIo0wD/OqE849eLlvzz+XIgWZb8/fIwDhVn55b+4hd9ELWO+P7AG
20keEOa/CoNzxmJjvT9+UUm5Qifmv1i4URLAZbw/of9hAsY+5r+4eD0aTmq7
P5Na4FCnVua/xOgzvBVxuj/j3i7N5W7mv6zxG8Iferk/bNZunICH5r+A6Xbh
dIW4P0UQgOB2oOa/8PMRux2Ttz8Gtgi4x7nmv4QduNoio7Y/NT59PnLT5r/w
NOW2jLW1P4x7KIx17ea/bGR5sGPKtD+/yDO20Afnv1SObRKw4bM/kFCvzoIi
579ob4gRevuyP9pxmuSKPee/jIkUzMkXsj9IP+wD6Fjnv2DZlkmnNrE/ahqc
NZl057+UWYZ6GliwP+Bpqn+dkOe/eKwIcFb4rj9Iainl86znv6glK4fCRa0/
nBlGZpvJ578Ii7iNiJirP8A8UQCT5ue/wNOlprfwqT/Qfsit2QPov8jbD8Re
Tqg/AapfZm4h6L+QdrSmjLGmP5z5CR9QP+i/aD9t3U8apT/mhAPKfV3ov1As
rMS2iKM/ecLaVvZ76L8Y6PmFz/yhP9MjerK4mui/yPd1F6h2oD/ByDHHw7no
vzBgsXac7J0/PkrBfBbZ6L/w/+3+nveaP4KcYbiv+Oi/ICeQeXIOmD/cB89c
jhjpvzCp2S0xMZU/+jdTSrE46b8AmXL39F+SP1Zhz14XWem/YK//iq41jz9Y
fMZ1v3npvwDwejPiw4k/1ZVnaKia6b+A+DkPtmqEP6A0mA3Ru+m/AOedzbRU
fj+x0/45ON3pv4CVjkX9BXQ/nHANwNz+6b+Aqv4nRdNjP/ItDHC9IOq/AAAA
AACA6rzQ3GUa
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*\
SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\\\\\\)], \
\\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.8748177652797087, 0.3030457633656644}], \
{}}}, 
     {RGBColor[0.528488, 0.470624, 0.701351], LineBox[CompressedData["
1:eJwVjH0s1HEAh8+VUtSqRV6mY5yXXAiTl9qESVi4EealorBorsUNS4l0k1OR
d3O01GxaynYmsk+SEeLcuTvnZar9vj854aiTaVP649nzx7M9lokZ3KtMBoNh
v81/T7HCvNN/jSBQlF6eSSgUP6M8bco+o0gcoj82T2GzMorTe3wUFbvVLo1q
Cksus8KTQ6Nodp5boZYo8KZ/KgqTx7AW+NS6aZWCbG3IL0xHgvyV/DaJlkJV
m3i/f6gEnNzWa/xNCrZf8oSmDRLYB3M4ZX8pcAYytiRqCbqCl/stdAmatRsv
rniMw1/Yo8vWJyjU6/0kLRrHrT3nxA0HCfxjP7Qay8bRX2Vd98B4u79KfOJq
IUXT0lDWIotgsLdk0OK6FEbfGnXf227/5voqZt9KYfBujannTOATG+CXskuG
TDHDqs+DQLBlZtnNlcGj4bfR6hkCZqprnkIkw5hoo6QsmKA+KqelQy1DvKOZ
Q3MkQeyCRhvtPoEQE16t3SWCCz3DXV13J+DdvTP7aBrBnH7BedXIBOyi6KQi
PoHnc/Xe9iNydFaw1+MKCCanuSG+iXLkWU71NT8k4EVX3RC8lMOUb5MQV0+w
rHCfub0uBwve3MIWgnvDNzVsHwXyF+LtTToINpcvG+YWK5ArnU81/0iQ9oYp
zpYqIKsLLX8kJagpjz3FMlPCztzBKuMrwY6LpWZpSUpECNwquzUEOuGL/TGt
StQYhSZkMmioDx9q/76mRNZ6iabmAI2mtq0YQ69JMH2duuwsadQEsL1n8ydR
bStmW7ls90GB4vTAJB47KmsFfjRK+COv3fapsL+xLCcyksZGUAQXXBV4+vbW
whQaeT7hZ6erVUj+46Q9lksjKGuGdX9GhYhOof+JUhoiBwNej8UUfnjdSRY1
0fgHwD53QQ==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(3\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"3\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\
\\\\(\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \
\\\\\\\\(1\\\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\
\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \
\\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.17496355305594308, -0.9091372900969932}], \
{}}}, 
     {RGBColor[0.772079, 0.431554, 0.102387], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAFiJQO2z03L+DsyN1kLfgv+4j2D5R
0dy/DNI6XKza4L8ph3PaCa/cv7Rp3mH8/eC//n+YQ5eN3L/nQUNHfyHhvxcg
PKj6bNy/ntrSyzNF4b+MsMcuNU3cv5e6Nq0YaeG/AlAO9kcu3L9LzWOnLI3h
v0zVQhU0ENy/WdCldG6x4b/c9u2b+vLbv+PPqs3c1eG/b7fkkZzW27+GsY5p
dvrhvzoYP/cau9u/hs3m/Tkf4r/yEE/EdqDbv7GVzT4mROK/Dc6X6bCG27+1
Se7eOWniv3A1xU/Kbdu/ULiQj3OO4r/1saPXw1Xbvx8NpQDSs+K/90UYWp4+
2797qs/gU9niv0PlGKhaKNu/EQ913ff+4r+iFqWK+RLbv8PGxaK8JOO/TN2+
wnv+2r9hZsrboErjv3nqYwni6tq/0pFvMqNw479NF4cPLdjav0UMkk/CluO/
cCcKfl3G2r/z0Qrb/Lzjv2DUt/Vztdq/Dju7e1Hj47/nIT4PcaXav2onmde+
CeS/tPsoW1WW2r9yMruTQzDkv3Qc3WEhiNq/Au9kVN5W5L94PpOj1Xrav6sq
E72NfeS/LpZTmHJu2r8COIhwUKTkv3yW8a/4Ytq/eD/YECXL5L80/wdSaFja
v2CWdT8K8uS/zzX13cFO2r+mGz2d/hjlv2Xo16oFRtq/yZmCygBA5b86+4sH
ND7av60tHWcPZ+W/z8CnOk032r/VsXMSKY7lv598eYJRMdq/jC2Ja0y15b+q
MAUVQSzav5tHCRF43OW/zLUCIBwo2r8OvFShqgPmvwcf3MjiJNq/ndSNuuIq
5r+2Z6wslSLav07jpPoeUua/1Gw+YDMh2r/WvmT/XXnmvz8xDHC9INq/TEB/
Zp6g5r9w0XlF
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\\\\\\\\*\
SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\\\\\\)], \
\\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"\\\"], \
Rule[Editable, False]]\\)\"\>", {-0.6998542122237666, -0.6060915267313277}], \
{}}}, 
     {RGBColor[0.772079, 0.431554, 0.102387], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAA/B9QO2z03D8YsiN1kLfgv9Qh2D5R
0dw/jtA6XKza4L8LhXPaCa/cPyNo3mH8/eC/3n2YQ5eN3D9CQENHfyHhv/Qd
PKj6bNw/5tjSyzNF4b9krscuNU3cP8u4Nq0YaeG/1U0O9kcu3D9sy2OnLI3h
vxnTQhU0ENw/Zs6ldG6x4b+i9O2b+vLbP9zNqs3c1eG/LbXkkZzW2z9sr45p
dvrhv+0VP/cau9s/WMvm/Tkf4r+bDk/EdqDbP3CTzT4mROK/q8uX6bCG2z9f
R+7eOWnivwIzxU/Kbds/57WQj3OO4r96r6PXw1XbP6IKpQDSs+K/b0MYWp4+
2z/qp8/gU9niv6ziGKhaKNs/bAx13ff+4r/6E6WK+RLbPwrExaK8JOO/lNq+
wnv+2j+UY8rboErjv67nYwni6to/8o5vMqNw479wFIcPLdjaP1EJkk/CluO/
fiQKfl3G2j/szgrb/Lzjv1rRt/Vztdo/9De7e1Hj47/LHj4PcaXaPzwkmde+
CeS/gvgoW1WW2j8wL7uTQzDkvyoZ3WEhiNo/retkVN5W5L8WO5Oj1XraP0Mn
E72NfeS/spJTmHJu2j+GNIhwUKTkv+SS8a/4Yto/6TvYECXL5L+C+wdSaFja
P7+SdT8K8uS/ADL13cFO2j/yFz2d/hjlv3rk16oFRto/ApaCygBA5b8x94sH
ND7aP9MpHWcPZ+W/prynOk032j/orXMSKY7lv1V4eYJRMdo/jimJa0y15b8+
LAUVQSzaP4tDCRF43OW/QLECIBwo2j/st1ShqgPmv1Ya3MjiJNo/atCNuuIq
5r/hYqwslSLaPwnfpPoeUua/2mc+YDMh2j9/umT/XXnmvyEsDHC9INo/5Dt/
Zp6g5r+Z+2ci
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(4\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"4\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\
\\\\(\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \
\\\\\\\\(2\\\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\
\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \
\\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.6998542122237672, -0.6060915267313289}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAASNQO2z0zD8aoGySdOXkvwmn5Dkm
kc0/Z7dMC8/n5L/SmVcswS3OP4YJ6jKf6uS/GzfdjDfKzj+mMt/v5O3kv/Tf
89aDZs8/BkuhJKDx5L9A9cpDUAHQP6bxgK/Q9eS/LrK1DkRP0D9kfKtqdvrk
v+fifYwandA/dE0sLJH/5L8Wym/+0OrQPxlO7sUgBeW/tvj4pmQ40T+2jr0F
JQvlv70LwcnShdE/AgxJtZ0R5b+mXsKrGNPRP2KZJJqKGOW/DLJikzMg0j9T
8Mp16x/lv3bFi8ggbdI/3uSfBcAn5b9348OU3bnSP+u+8gIIMOW/OF9GQ2cG
0z9quAAjwzjlv6MCHCG7UtM/RqD3FvFB5b9CbDN91p7TP/Wh+IuRS+W//Vt5
qLbq0z+cMRsrpFXlv97t8PVYNtQ/pBxwmShg5b/6wcu6uoHUP66+BHgea+W/
pBCCTtnM1D+0WuZjhXblvx2q6gqyF9U/YJgl9lyC5b/b4FJMQmLVP0Al2sOk
juW/kF2WcYes1T/5eSZeXJvlvyvcNtx+9tU/GsM7UoOo5b/e0HPwJUDWP5jt
XSkZtuW/bvRhFXqJ1j+w1udoHcTlv/m2ArV40tY/Jp9Pko/S5b8+mFs8HxvX
P5ohKyNv4eW/wmSNG2tj1z/kizSVu/Dlv9hW68VZq9c/RxtPXnQA5r/YGhKy
6PLXP0L7i/CYEOa/orX+WRU62D/wRi+6KCHmv69MJTvdgNg/piy1JSMy5r/K
zofWPcfYP78z15mHQ+a/yHzMsDQN2T9epJF5VVXmv0ZRVFK/Utk/4RApJIxn
5r/aRlFH25fZP/gAMPUqeua/tXvcH4bc2T8JvoxEMY3mvxgyDHC9INo/xEB/
Zp6g5r8uX2YI
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.17496355305594155, -0.9091372900969888}], \
{}}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAACBh8LFG35T//sSN1kLfAP+I55S3y
zOU/KZVHvIo0wD8eqE849eLlPzb+XIgWZb8/xosDhVn55T/Ohd9ELWO+P/UF
20keEOY/OINzxmJjvT++UEm5QifmP5i4URLAZbw/2v5hAsY+5j8QeT0aTmq7
P8dZ4FCnVuY/MOkzvBVxuj8R3i7N5W7mPyTyG8Iferk/ldVunICH5j8Q6nbh
dIW4P2cPgOB2oOY/jPQRux2Ttz8itQi4x7nmPzgeuNoio7Y/Sz19PnLT5j+w
NeW2jLW1P5x6KIx17eY/OGV5sGPKtD/IxzO20AfnPyyPbRKw4bM/kk+vzoIi
5z9McIgRevuyP9ZwmuSKPec/fIoUzMkXsj89PuwD6FjnP1jalkmnNrE/WRmc
NZl05z+YWoZ6GliwP8hoqn+dkOc/kK4IcFb4rj8oaSnl86znP8AnK4fCRa0/
dhhGZpvJ5z8ojbiNiJirP5M7UQCT5uc/6NWlprfwqT+cfcit2QPoPwDeD8Re
Tqg/xqhfZm4h6D/QeLSmjLGmP1r4CR9QP+g/oEFt3U8apT+cgwPKfV3oP4Au
rMS2iKM/KMHaVvZ76D9I6vmFz/yhP3oierK4mug/6Pl1F6h2oD9gxzHHw7no
P2BksXac7J0/1kjBfBbZ6D8QBO7+nveaPxObYbiv+Og/ICuQeXIOmD9lBs9c
jhjpPxCt2S0xMZU/ezZTSrE46T+wnHL39F+SP9Bfz14XWek/gLb/iq41jz/K
esZ1v3npP6D2ejPiw4k/QZRnaKia6T/g/jkPtmqEPwQzmA3Ru+k/wPKdzbRU
fj8M0v45ON3pPwCgjkX9BXQ/724NwNz+6T8Avf4nRdNjPz0sDHC9IOo/AAAA
AAAA1rxXDEqQ
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(1\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"1\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.8748177652797064, 0.30304576336566275}], {}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAtRl8LFG35T9QsiN1kLfAv6Q75S3y
zOU/U5VHvIo0wL/2qU849eLlPzz+XIgWZb+/tI0DhVn55T+Khd9ELWO+v/gH
20keEOY/qoJzxmJjvb/WUkm5QifmP8i3URLAZby/CgFiAsY+5j/+dz0aTmq7
vw5c4FCnVuY/5OczvBVxur9u4C7N5W7mP6TwG8Iferm/CthunICH5j9U6Hbh
dIW4v/QRgOB2oOY/nPIRux2Tt7/Gtwi4x7nmPxgcuNoio7a/CEB9PnLT5j9o
M+W2jLW1v3J9KIx17eY/zGJ5sGPKtL+2yjO20AfnP5iMbRKw4bO/mlKvzoIi
5z+cbYgRevuyv/dzmuSKPec/rIcUzMkXsr94QewD6FjnP3DXlkmnNrG/rhyc
NZl05z+cV4Z6GliwvzZsqn+dkOc/eKgIcFb4rr+wbCnl86znP5ghK4fCRa2/
GRxGZpvJ5z/whriNiJirv1A/UQCT5uc/sM+lprfwqb91gcit2QPoP8jXD8Re
Tqi/uaxfZm4h6D+QcrSmjLGmv2j8CR9QP+g/eDtt3U8apb/GhwPKfV3oP3go
rMS2iKO/bcXaVvZ76D9o5PmFz/yhv9wmerK4mug/KPR1F6h2oL/dyzHHw7no
P1BZsXac7J2/b03BfBbZ6D+A+e3+nveav8ifYbiv+Og/ECGQeXIOmL81C89c
jhjpP7Cj2S0xMZW/aDtTSrE46T/wk3L39F+Sv9pkz14XWek/YKb/iq41j7/w
f8Z1v3npP0DoejPiw4m/gplnaKia6T9g8jkPtmqEv2I4mA3Ru+k/QN2dzbRU
fr+H1/45ON3pPwCPjkX9BXS/hnQNwNz+6T8ApP4nRdNjv/IxDHC9IOo/AAAA
AAAA6zwCrmQf
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(-1\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", \
StringForm[\\\"\\\\!\\\\(\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\\
), \\\\(`1`\\\\)], \\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"-1\\\"], \
Rule[Editable, False]]\\)\"\>", {0.8748177652797064, -0.30304576336566275}], \
{}}}, 
     {RGBColor[0.880722, 0.611041, 0.142051], LineBox[CompressedData["
1:eJwVjX0s1HEAhy9zWKrRRiI5cV6iCEnRPkWjG0UXy1smry0aSYYhL8nyuvOW
l3mprNlOMkPDTN5SiHOvTm5q+31/2plCTlhT+uPZ88fzx2MakcCNVmMwGNZ7
/LcVy881fmMKZxviy5MJhYxX1HkL3mcEd/lozyxRqKi6ZTt0ahpcDaVDk5LC
aQdF8bmJaXDsFn9SKxSC539J82JmkOX1wrx5jYLx+oSH3z4B1ley3wpUFHra
uw9d8RXgSSr/XsrOXl/MLDZsECCGY2vL+0theyxhV6AUQMH5McZiEnA2tl5H
uczCu3CAydYmYGgOfRLmzyJGk9PdoEtQHzTMNxDNorLSvK7QgKCrLaLCkSUE
d3ni0bIJgXiw6CPrvhD8xSbme0uCIsVIpaJXiNzedTUtewL1IE+PWA0RpjoZ
ZiMuBFZ/jEz7uSIk1f3WX7tMkBPtmCltFEFZv1XE8ybY9k9r7VGKEGhjZNMS
QFBDr6oCncWw1E+stQonSO6b7OvLEWPznXrq8TiCr1q51+VTYgzfpCPzUwiO
vVTu7zwigT2PvRmaS9A4x/Vxj5BAbDw/0lJKYBhQ/aCgTQK/JIuw0HqCLJHz
QtamBA79rty8VoKd8Yer7EtSJJDb1kd7CAKX7+ilP5Pi6vTSXeNRgo43at2p
Qikyqn3Ly4QEH0pD3EyMZGg3sDFL+Lb3DykxiouUoSfXqap/lYB5bXksiC+D
RNc3LJlBY17ncOf3dRlK1opWa3RoZPF3g/QuzEHlZtdnZUoj2p3tqsieQ9SJ
braZA42w0QLpxfE5uFjLags8aLgkTXU4HZSjrJaXFhBAo8bTnzvIlWOSaW1e
HEtDx+2G15fnctSq7FQn02kIEhdMni7IEd5ZfOVMCQ1DywOJA6x5CJ0exzQ2
0/gHTsVNjA==
       "]], {{}, 
       InsetBox["\<\"\\!\\(\\*InterpretationBox[\\\"\\\\\\\"\\\\\\\\!\\\\\\\\(\
\\\\\\\\*SuperscriptBox[SubscriptBox[\\\\\\\\(\[Gamma]\\\\\\\\), \\\\\\\\(2\\\
\\\\\\)], \\\\\\\\(\\\\\\\\)]\\\\\\\\)\\\\\\\"\\\", StringForm[\\\"\\\\!\\\\(\
\\\\*SuperscriptBox[SubscriptBox[\\\\(\\\\[Gamma]\\\\), \\\\(`1`\\\\)], \
\\\\(`2`\\\\)]\\\\)\\\", \\\"2\\\", \\\"\\\"], Rule[Editable, \
False]]\\)\"\>", {0.17496355305594155, 0.9091372900969888}], {}}}}, {}}, {
    {Arrowheads[{{Small, 0.5}}], 
     {RGBColor[0, 0, 1], ArrowBox[LineBox[CompressedData["
1:eJwtkosvFAAAhy81NKudPKZbk9dZnpm3efziJOQxFs2jElPbqZycCrOaxyjN
bnMMZ8rbFE6KcJ1nJHXu5d4eNZbHisxzRI/1bd++f+Azjk8OT1QjEAgWf/xb
hnrxQBZjFoT/yA7TSJbnZ/HIYzMzWTcHJtLvbW0bMzDSv+A06lCMt9v0dN2E
GRDy6+e99yrhrPHuoEA4DdqBcKcypRbU3G/lOr7TsPvUq29EbwKzoSm/p2sK
RN6cxt28FqxbH/qZYzMFf07r2svwdlC9dubT6lVgaHZqTyx2IDIi9mrpaRUW
Vh8HqhV0osz9ntsySwk7hLlY2HSDeVLgmUFSgn1gbGYu7wWVtW4QwFKgTCuU
qCzkQmVrfu2KoQIFD1RSZk0/JLGWhZxaOeh62p3paoOge2vsJ1nJYRZE6Xia
OAQ18od92hsZxCfcPbjjw+C5+vTwvWVYuNhdse84AtcMhQ+DL4XM8cymZ/Uo
RrhBjNfXpaBHBl+6RRzDjeXUhz4bEgSu7JWnZ39Ef5SO0KtQAvYErzBiaxzM
29W2raYSLD0T81bufAY7VseohDuJkIKwRZdFHuasmvW2YybRWN5dfdyBD8nX
/njlrhitRHXm6BofgTssL0qVGE61jfHcDgG4B27DDhQxaPSR0qU0IZh55DX2
kgjK2O0XFDcRKrz8m7lMEWqKnhMHfolgT+1rj/MWIYAXah49JIYkq51dsSpE
kDvZR/3JJDp1yfa0GiFS6862cMIkqDGX185FCtGQMFFHJ0mRnW8YuXtMiE2O
QQx5Tgpq+6vMrlEBbnKct963yjCoYFmcyhUgrohXEpwhByla/bI1RQCrkISA
Dj8FfKNMp5aOCBDs10P6oaPEukzzfvQYH+eqcHTjixKV//7jwyQlSauPrcJv
Ng9Jnw==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAHgiTwX2Q0D8zdGsLv7Dcv2DaCHda
ydA/P6E/CfXh27+eWiPd6gTRPzlJuhruE9u/ZFsGVyxD0T8DUWNJs0bav/jb
mykchNE/JZHOlU162b+OsrJ7t8fRPxm/NvfFrti/lIgeVvsN0j+SvxhbJeTX
v6In2aPkVtI/MGbPpHQa17+mFSUycKLSP+imL628Uda/sn6xsJrw0j+tPSVC
BorVvwJrv7FgQdM/l9BPJlrD1L9aP0iqvpTTP9yQoBDB/dO/RoYl8rDq0z//
XvirQznTv2QAOsQzQ9Q/gHbGlup10r/g+Zs+Q57UPzGlp2K+s9G/XuPAYtv7
1D+XEgaUx/LQv2IsqhX4W9U/fpu5oQ4z0L8iXRMglb7VP9KLUek36c6/+m2h
Lq4j1j9Go9TO727NvyBaE9I+i9Y/5NLOi1X3y7+863N/QvXWP1Ty/Jl5gsq/
Er9MkLRh1z9UWU1UbBDJv3562kKQ0Nc/jDco9j2hx78GOUK60EHYP3ROuZr+
NMa/NiXI/nC12D88FTs8vsvEv55BB/5rK9k/ZE5Ds4xlw7/8XCqLvKPZP4wX
EbZ5AsK/+i4mX10e2j94etzXlKLAv4Kb9BhJm9o/KA9PENuLvr+mGdE9ehrb
P/gCIiQm2bu/pjt2Oeub2z8oQlE3KS25v2JVXF6WH9w/mPOJSgKItr9wPvnl
daXcP+gKthHP6bO/9iwB8YMt3T9Qvq7yrFKxv5SmqIe6t90/kNHkB3KFrb9q
hOeZE0TePyDPuxYgdKi/Mge9/4jS3j/AAdP5nHGjv7L4dHkUY98/gIql5UH8
nL8c1+2vr/XfP6AYRzXHM5O/1QNwGipF4D9AP/Z7bxSDv44Gk8F9kOA/AAAA
AAAAuLyOPVoi
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQPYdt8sHaCRfs5QqzufdvuGO/OHZd9efG8/YKAfKt
M6ru2D/8PWVp58Oz9qu28/Vpud+xj7K963LB/oz9lGV708vF7tjzRDqtuTnn
lL3HOw7Txhe37RWXZdrs+HHC/pkp3y/PvbftXe1EkuuCj9tvCBOdc3nKbfvD
PAGz7NYetd8gVP1QPv+2fXfwinRutiP2E9TmFhr43LbXWh8a/T32kH3T9uNX
2HRu2z9flMsvuvWAPZ+cSskSPqD5Ocp+78T22XfxrZzJ9eWW/fRwm9kJh3bZ
75LnKbC6c8t+9Z4N2ctyttuv27CFyfT4LfvCPkujp6Jb7F/obrD9veWW/eYq
yVynfRvsd21b/rZ36S37xJPvPY6fXmXPpXx9/9sZt+wdH5ZdvCO5xF4ii9VJ
uv+WvebpCc6K52bZx2TVPRLruGV/cKHO8e3nuuz5hPk+PGi+Zc/HAAJHbNze
/5lZ2XTLfuF8sPx+mDznKbD+/TD9Ox+Azd8vBTX/6Amw/fth9mdC3Lcf5j5N
iPv3v4K6PxHiv/0boP7zhvh//x6o/69ng8NnPyx8DkLCb78QNPxYIOG7vwUa
vqmQ8N8/BRr+8yHxs38LNH4UIPG3fxM0/n4tBcfv/lfQ+H0eAY7//V7Q+DeF
pI/9M6DpYzck/exfB00/jZD0tV8Fmr46IelvvxI0/QEAX/dJ3Q==
        "]]], ArrowBox[LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQrcAx+WDthAv7+4qzufdvuLO/PWFd9efG8/tbguRb
Z1Td2T//35SlnQ/P7mfaxden5X5n/2f7uy4X7M/sf7Rib3q52J39tdFOa27O
ObW/4wOHaeOL2/uzVmTa7PhxYr+CBd8vz72396c4iCTXBR/f/yRCdM7lKbf3
7+YLmGW39uj+WyLVD+Xzb++PCl2Rzs12ZP8mjbmFBj6391/cEBr9PfbQ/jk7
j19h0wHqX5LLL7r1wH4NBZWSJXy395/IU/Z7J7Zv/xyBlTO5vtza/zLSZnbC
oV37TynyFFjdubV/1b4N2ctytu/fs2kLk+nxW/tlJlgaPRXdsv+L/gbb31tu
7Wevkcx12rdh/7Edy9/2Lr21P+L0e4/jp1ftl1C9vv/tjFv7Zz0qu3hHcsl+
lRxWJ+n+W/sbzkxwVjw3a39OTt0jsY5b+08s1Dm+/VzXfgVRvg8Pmm/tV9j2
HwiO28R8/DOzsunW/h1LwPL2GlD5H2fB+u1roPrDHoPNt7eDmi9wBmy/vRXU
/kSI++w/QN1XBHG/vZoBxP1/IP6z/wb1n2UU2P/2fEoQ/4vkg8PH/hk0fNoh
4WdfBQ2/T5Dwtf8FDd9KSPjbi2hCwv86JH7s3UQh8VMHiT/7sEhI/DVC4td+
DjR+J0Di357vIyT+WRzA6cO+YCUkfayGpB/7adD00wtJX/ZywZD0pQRJf/Ym
JZD0BwBJWGT5
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAjAaTwX2Q0L8kcWsLv7DcP+TYCHda
ydC/Qp4/CfXh2z84WSPd6gTRv09GuhruE9s/EloGVyxD0b8sTmNJs0baP7za
mykchNG/YI7OlU162T9msbJ7t8fRv2e8NvfFrtg/fIceVvsN0r/0vBhbJeTX
P6Am2aPkVtK/pWPPpHQa1z+2FCUycKLSv3GkL628UdY/0n2xsJrw0r9LOyVC
BorVPzRqv7FgQdO/SM5PJlrD1D+aPkiqvpTTv6COoBDB/dM/mIUl8rDq07/Y
XPirQznTP8b/OcQzQ9S/bXTGlup10j9Q+Zs+Q57UvzGjp2K+s9E/3uLAYtv7
1L+rEAaUx/LQP/IrqhX4W9W/ppm5oQ4z0D/AXBMglb7Vv0yIUek36c4/pm2h
Lq4j1r/on9TO727NP9RZE9I+i9a/rs/Oi1X3yz9+63N/QvXWv0zv/Jl5gso/
3r5MkLRh179wVk1UbBDJP1R62kKQ0Ne/1DQo9j2hxz/oOEK60EHYv+RLuZr+
NMY/IiXI/nC12L/UEjs8vsvEP5ZBB/5rK9m/IExDs4xlwz/4XCqLvKPZv3QV
EbZ5AsI/Ai8mX10e2r+IeNzXlKLAP5Kb9BhJm9q/mAtPENuLvj+6GdE9ehrb
v7D/ISQm2bs/wjt2Oeub2784P1E3KS25P4ZVXF6WH9y/+PCJSgKItj+aPvnl
daXcv6AIthHP6bM/JC0B8YMt3b9QvK7yrFKxP8imqIe6t92/MM7kB3KFrT+e
hOeZE0Tev1DMuxYgdKg/bge9/4jS3r+Q/9L5nHGjP/D4dHkUY9+/YIel5UH8
nD9e1+2vr/Xfv4AWRzXHM5M/+ANwGipF4L/APfZ7bxSDP7EGk8F9kOC/AAAA
AAAAyDwXxmH1
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAsgaTwX2Q4L8AAAAAAADIPPgDcBoq
ReC/gDz2e28Ug79g1+2vr/XfvwAXRzXHM5O/9vh0eRRj37+giKXlQfycv3gH
vf+I0t6/wADT+Zxxo7+qhOeZE0Tev+DNuxYgdKi/1qaoh7q33b9Q0OQHcoWt
vzgtAfGDLd2/qL2u8qxSsb+yPvnldaXcvygKthHP6bO/pFVcXpYf3L/A8olK
Aoi2v+Y7djnrm9u/SEFRNyktub/kGdE9ehrbvwgCIiQm2bu/wJv0GEmb2r8w
Dk8Q24u+vzgvJl9dHtq/8Hnc15SiwL82XSqLvKPZvwAXEbZ5AsK/1kEH/msr
2b/MTUOzjGXDv24lyP5wtdi/oBQ7PL7LxL9AOUK60EHYv9hNuZr+NMa/sHra
QpDQ17/gNij2PaHHv0S/TJC0Yde/pFhNVGwQyb/u63N/QvXWv5rx/Jl5gsq/
TloT0j6L1r8g0s6LVffLvypuoS6uI9a/fqLUzu9uzb9OXRMglb7VvwCLUek3
6c6/jCyqFfhb1b8Rm7mhDjPQv4bjwGLb+9S/KBIGlMfy0L8G+ps+Q57Uv72k
p2K+s9G/hgA6xDND1L8KdsaW6nXSv2iGJfKw6tO/hV74q0M50794P0iqvpTT
v1yQoBDB/dO/Imu/sWBB078X0E8mWsPUv8x+sbCa8NK/Jz0lQgaK1b+8FSUy
cKLSv16mL628Uda/tifZo+RW0r+iZc+kdBrXv6aIHlb7DdK/Ab8YWyXk17+c
srJ7t8fRv4W+NvfFrti/BNybKRyE0b+OkM6VTXrZv2xbBlcsQ9G/aFBjSbNG
2r+iWiPd6gTRv5pIuhruE9u/YtoId1rJ0L+doD8J9eHbvx4Ik8F9kNC/jXNr
C7+w3L/M1G2x
        "]]]}, 
     {RGBColor[1, 0, 0], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAkAaTwX2Q4D8AAAAAAAAAALn37EK7
wuA/gCgYjnTneD/fPfZmZvXgP4ADMKKRy4g/SpEINn4o4T+gLKDepIOSP86I
arYBXOE/oH3CZlOTmD9YXlTs74/hP2Czbsm2lJ4/j7302UfE4T9AkjjW2EOi
P1+cdX8I+eE/QBsBfhM2pT9vHQHbMC7iPxA+qvX8IKg/UnzG6L9j4j9gvJD6
hgSrP20D/6K0meI/gIMabqPgrT9qC/MBDtDiP4jX/SqiWrA/MAT/+8oG4z8g
bT3uLcGxPz6HmIXqPeM/aF9aKO4jsz9Ic1ORa3XjP9CPbxPcgrQ/GhHnD02t
4z/ofkX88N21P3lBM/CN5eM/2AtzQiY1tz8htEUfLR7kP8DXfVh1iLg/lidf
iClX5D+gTPrD19e5P8ix+BSCkOQ/SEerHUcjuz9uEcmsNcrkPwBjoRG9arw/
7QfKNUME5T+o51lfM669P9G7PZSpPuU/8Ffd2aPtvj+cI7SqZ3nlP4DQ7jOE
FMA/6HgQWny05T+U9OmBLbDAP6mzjoHm7+U/YP8O3spJwT+hDcn+pCvmP4Cy
jVlZ4cE/q429rbZn5j+w/6QP1nbCP/6a02gapOY/iC2xJT4Kwz8tmOEIz+Dm
P3DKOcuOm8M/xoUyZdMd5z8Ibv85xSrEP4ysi1MmW+c/pEgJtt63xD8TTzKo
xpjnP3iAso3YQsU/vWLxNbPW5z9YXLcZsMvFP+5PH87qFOg/yDtCvWJSxj9S
uaNAbFPoP9xb+OXt1sY/Mkr9WzaS6D8oaQYMT1nHP6WLR+1H0eg/DN4ssoPZ
xz+MwEDAnxDpP0wtzGWJV8g/OchPnzxQ6T/YuPC+XdPIP54HilMdkOk/UJRe
YP5MyT/4DkxX
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAjAaTwX2Q0L8kcWsLv7DcP3omhXwA
GdG/PPIk6vTV3D+8cUCmL6HRv0quejlY/Nw/10cmpQgp0r9ESMw96CPdP/4v
PeGIsNK/vqO7NaRM3T9Qhj3ErTfTv/6VMFqLdt0/0yCeuXS+078Ss1zenKHd
P/broC7bRNS/2ja/79fN3T82fl+S3srUv+IJKbY7+90/1qLXVXxQ1b8K4sBT
xyneP03b9+ux1dW/1H4H5XlZ3j9F16vJfFrWv0IB3IBSit4/zuLoZdre1r9i
X4A4ULzeP7BKujnIYte/IvOdF3Lv3j98tk3AQ+bXv44kSiS3I98/Nnj/dkpp
2L9QLwtfHlnfP1PRZt3Z69i/XgPdwqaP3z/NLGJ1723Zv8ZANkVPx98/Hk4j
w4jv2b8qpwZrCwDgP890O02jcNq/ncXuL/4c4D9/dKecPPHav8FN1mN/OuA/
AsHbPFJx27+R54d2jljgP4Vu0Lvh8Nu/z9EY1Sp34D9WJQ2q6G/cvx+w6+lT
luA/OQm1mmTu3L9EZrMcCbbgP++TkiNTbN2/jwB20knW4D/PYiPdsendv0ip
j20V9+A/J/ejYn5m3r88q7VNaxjhPzZpG1K24t6/HoH5z0o64T+ADWdMV17f
v/Dxy06zXOE/QgxG9V7Z378vOgAipH/hP2d1snnlKeC/yUHPnhyj4T9VgzR4
zGbgv9re2hccx+E/AgF+TGOj4L8EJTHdoevhP8uQa86o3+C/WMFPPK0Q4j+x
TWfXmxvhv+tiJ4A9NuI/OWtuQjtX4b+1Lx/xUVziP4nNFuyFkuG/9kUY1emC
4j+2mZSyes3hv+lJcW8EquI/PL6/dRgI4r+x/wkBodHiP1pzGRdeQuK/hfFG
yL754j8cI2cX
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAnAaTwX2Q0D8gcWsLv7DcP/7IVAl2
bNA/6FJdvJI53T8KCqwnnUnQP3oujMa0wt0/xNrqxvMn0D8uS7aLIkzeP6Th
l4t6B9A/xssnbNnV3j/YbNYoZNDPP26Bx8bWX98/rLSW9DWUzz+exSP5F+rf
P6iZlKBrWs8/SK2/L0064D9seUVHBiPPPwApb6qtf+A/wKtq9wbuzj8AfYkZ
LMXgP0RXDLRuu84/3GdlKccK4T9Mf3R0PovOP9K7zYV9UOE/WEsqJHddzj+a
3QfaTZbhP9CH7aIZMs4/ykXa0Dbc4T9sYLLEJgnOP5EEkxQ3IuI/PFSdUZ/i
zT/aRw5PTWjiP4Rj/wWEvs0/heO8KXiu4j84d1KS1ZzNP7vbqk229OI/dAI2
m5R9zT8i8YVjBjvjP+Dda7nBYM0/7y6kE2eB4z8cXdV5XUbNP5F6CgbXx+M/
HJ5wXWguzT/6JHPiVA7kP7ASVtniGM0/RX1UUN9U5D9IRLZWzQXNP7pk5/Z0
m+Q/tNHXMij1zD/r4y19FOLkP1ynFb/z5sw/7cD5ibwo5T+Acd1AMNvMP3IW
88Nrb+U/BEmu8d3RzD+2657RILblPzyaF//8ysw/E81lWdr85T9wRriKjcbM
PyRlmgGXQ+Y/XP89qo/EzD9LFoBwVYrmP2DdZGcDxcw/kZRRTBTR5j/UL/e/
6MfMP5x/RzvSF+c/2IfNpT/NzD/A/J7jjV7nP4j9zv4H1cw/9VCg60Wl5z+E
r/GkQd/MP5B6pfn46+c/7Hw7ZuzrzD+wyiC0pTLoP4z5wgQI+8w/Ln6jwUp5
6D+AnLA2lAzNP/NV5Mjmv+g/LClAppAgzT+hLsZweAbpP1hSwvH8Ns0/Vpde
YP5M6T/RAlom
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAHwiTwX2Q0D80dGsLv7Dcv/onhXwA
GdE/PPUk6vTV3L8oc0CmL6HRPzaxejlY/Ny/MEkmpQgp0j8gS8w96CPdv0Mx
PeGIsNI/iqa7NaRM3b+Bhz3ErTfTP7iYMFqLdt2/8SGeuXS+0z+8tVzenKHd
vwLtoC7bRNQ/cDm/79fN3b8vf1+S3srUP2oMKbY7+92/uqPXVXxQ1T+C5MBT
xynevx/c9+ux1dU/OIEH5XlZ3r8D2KvJfFrWP5QD3IBSit6/euPoZdre1j+k
YYA4ULzev0pLujnIYtc/VPWdF3Lv3r8Dt03AQ+bXP6wmSiS3I9+/q3j/dkpp
2D9cMQtfHlnfv7bRZt3Z69g/WgXdwqaP378eLWJ1723ZP7JCNkVPx9+/XE4j
w4jv2T8WqAZrCwDgv/t0O02jcNo/gMbuL/4c4L+adKecPPHaP5xO1mN/OuC/
C8HbPFJx2z9j6Id2jljgv3xu0Lvh8Ns/mNIY1Sp34L87JQ2q6G/cP9+w6+lT
luC/Dgm1mmTu3D/8ZrMcCbbgv7KTkiNTbN0/PQF20knW4L+BYiPdsendP+2p
j20V9+C/yPajYn5m3j/Xq7VNaxjhv8doG1K24t4/sIH5z0o64b8ADWdMV17f
P3nyy06zXOG/rwtG9V7Z3z+uOgAipH/hvxZ1snnlKeA/P0LPnhyj4b/7gjR4
zGbgP0nf2hccx+G/oAB+TGOj4D9nJTHdoevhv2GQa86o3+A/tMFPPK0Q4r8+
TWfXmxvhPz1jJ4A9NuK/v2puQjtX4T//Lx/xUVzivwfNFuyFkuE/NkYY1emC
4r8smZSyes3hPx9KcW8EquK/qb2/dRgI4j/e/wkBodHiv79yGRdeQuI/qfFG
yL754r/prWST
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwBoQJe/SFib1JlAgAAACkAAAACAAAAsQaTwX2Q4L8AAAAAAADEPNr37EK7
wuC/ACkYjnTneL/9PfZmZvXgv4AFMKKRy4i/aJEINn4o4b9gLqDepIOSv+uI
arYBXOG/IIDCZlOTmL91XlTs74/hv8C2bsm2lJ6/q7302UfE4b9QlDjW2EOi
v3ucdX8I+eG/wB0BfhM2pb+KHQHbMC7iv+BAqvX8IKi/bnzG6L9j4r+gv5D6
hgSrv4kD/6K0meK/EIcabqPgrb+GC/MBDtDiv4DZ/SqiWrC/TQT/+8oG479I
bz3uLcGxv1uHmIXqPeO/uGFaKO4js79mc1ORa3Xjv1iSbxPcgrS/NxHnD02t
47+YgUX88N21v5VBM/CN5eO/sA5zQiY1t78+tEUfLR7kv8DafVh1iLi/tSdf
iClX5L/YT/rD19e5v+mx+BSCkOS/qEqrHUcju7+PEcmsNcrkv4hmoRG9ary/
DwjKNUME5b9Q61lfM669v/S7PZSpPuW/yFvd2aPtvr/CI7SqZ3nlv3zS7jOE
FMC/DXkQWny05b+o9umBLbDAv9GzjoHm7+W/hAEP3spJwb/KDcn+pCvmv7C0
jVlZ4cG/1Y29rbZn5r/4AaUP1nbCvyqb02gapOa/6C+xJT4Kw79bmOEIz+Dm
v+DMOcuOm8O/94UyZdMd57+IcP85xSrEv72si1MmW+e/NEsJtt63xL9HTzKo
xpjnvxiDso3YQsW/9GLxNbPW578MX7cZsMvFvyhQH87qFOi/iD5CvWJSxr+M
uaNAbFPov7Be+OXt1sa/bkr9WzaS6L8IbAYMT1nHv+WLR+1H0ei/+OAssoPZ
x7/OwEDAnxDpv0gwzGWJV8i/fshPnzxQ6b/gu/C+XdPIv+YHilMdkOm/aJde
YP5Myb/aeXhw
        "]]], ArrowBox[LineBox[CompressedData["
1:eJwVi30s1HEAh69wXucfl5etNaHcmTCTVlZY87q7dXREi0znZVE0t0JuUqw4
Im5q3itqM2TNpLI+EXdmv+85NszLubufc4dTmyEskf549vzx7DmZnBWdcpTB
YHAO+e8TFjUD4iolnudkWKN7HqJRgeX9TCUCYxL6q8+rILLucG+MUOKLT7ms
Z1AFl/lV2Ya7Etd4vRIX7gJ26JeSfHMlpoh75szkApKypthC5RhSn8hlUzfV
cPxUu3lWOobHctddh1U1GA3SlozrY/DpgjfvggatD0PCmK5jmONktXcWaqDp
vL3N/KWAUlzq5DmsQXi8Tc/drwq8Tk/hyK208CsSiS5JFJD0kxIxXwtPnofb
gwQFIhfMZ3m1WpSX/nzj5KvAndBZpf+8FjbJH4dOWyrgYVbDOudC43tMY1Qz
TZAebnuFl05jU3hgVvyNwFLXz8ntovEsN7p6soHAb76d17tJo8PEv14qJnix
XnKLGbAIU3XG54EkgqverXZpRYtwS5zMSwglMOZbMaflh705OyHdiyDiVA4t
sNWh2C52hnYkkIgFfLVAB0ZIbywxI9gSGn6L6nWIm5j2ZW9ROK47I2bROmje
H8OGngJrYLe0n72EtXuqIJ85CpX2Gz8yspbAj+haV41TGDE2jTv3LkFU53Cw
N3r4k5T42b0llIf2lVXIKLik1B15eVkP4cHF9sohCsH2j7JjyvTgq4RpJsMU
CqRRXNa4Hq3e21iWUxAXhgVMOBhQ/pS0BRIKr/aaFisSDWD/VeybT1IY5LcY
Q9oMsPmw3hqspiDIb9vdMRoQVxCQumakkDnq3NPmuwzNzqCpxR8KGvHbgci8
ZfTVd/tLbQgaYnQjeiyDyw56V+VMEOQly85lruBG1OD6nj/BWm1i0j53Bf8A
7vd87g==
        "]]]}}, {
     {Hue[0.6, 0.7, 0.5], Opacity[0], Arrowheads[Medium], 
      ArrowBox[BezierCurveBox[{{0.5176380902050415, 0.}, {
        0.31451179737909657`, 0.18158347088013438`}, {0.25881904510252135`, 
        0.44828773608402805`}}]], 
      ArrowBox[BezierCurveBox[{{0.5176380902050415, 0.}, {
        0.46194533792848685`, -0.2667042652039087}, {
        0.2588190451025429, -0.44828773608407174`}}]], 
      ArrowBox[BezierCurveBox[{{0.25881904510252135`, 0.44828773608402805`}, {
        0.4619453379284657, 0.26670426520389334`}, {0.5176380902050415, 
        0.}}]], ArrowBox[
       BezierCurveBox[{{0.25881904510252135`, 0.44828773608402805`}, {
        6.474670228285811*^-16, 0.36316694176026937`}, {-0.2588190451025205, 
        0.4482877360840283}}]], 
      ArrowBox[BezierCurveBox[{{0.2588190451025429, -0.44828773608407174`}, {
        0.31451179737910034`, -0.18158347088015972`}, {0.5176380902050415, 
        0.}}]], ArrowBox[
       BezierCurveBox[{{0.2588190451025429, -0.44828773608407174`}, {
        1.0791117047141198`*^-15, -0.5334085304078332}, \
{-0.25881904510254294`, -0.4482877360840626}}]], 
      ArrowBox[BezierCurveBox[{{-0.2588190451025205, 0.4482877360840283}, {
        1.7265787275428726`*^-15, 0.533408530407787}, {0.25881904510252135`, 
        0.44828773608402805`}}]], 
      ArrowBox[BezierCurveBox[{{-0.2588190451025205, 
        0.4482877360840283}, {-0.3145117973790988, 
        0.1815834708801344}, {-0.5176380902050453, 6.71894144447725*^-16}}]], 
      ArrowBox[BezierCurveBox[{{-0.25881904510254294`, -0.4482877360840626}, \
{-5.395558523570593*^-16, -0.36316694176030123`}, {
        0.2588190451025429, -0.44828773608407174`}}]], 
      ArrowBox[BezierCurveBox[{{-0.25881904510254294`, -0.4482877360840626}, \
{-0.4619453379284862, -0.2667042652039057}, {-0.5176380902050453, 
        6.71894144447725*^-16}}]], 
      ArrowBox[BezierCurveBox[{{-0.5176380902050453, 
        6.71894144447725*^-16}, {-0.4619453379284672, 
        0.26670426520389534`}, {-0.2588190451025205, 0.4482877360840283}}]], 
      ArrowBox[BezierCurveBox[{{-0.5176380902050453, 
        6.71894144447725*^-16}, {-0.31451179737910284`, \
-0.18158347088015614`}, {-0.25881904510254294`, -0.4482877360840626}}]]}, 
     {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0]}], FaceForm[
      Opacity[0]], {DiskBox[{0.5176380902050415, 0.}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], 
        Offset[{2, 2}, {0.5176380902050415, 0.}], ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.25881904510252135`, 0.44828773608402805`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "2"}], "}"}], 
        Offset[{2, 2}, {0.25881904510252135, 0.44828773608402805}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{0.2588190451025429, -0.44828773608407174`}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "3"}], "}"}], 
        Offset[{2, 2}, {0.2588190451025429, -0.44828773608407174}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.2588190451025205, 0.4482877360840283}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "4"}], "}"}], 
        Offset[{2, 2}, {-0.2588190451025205, 0.4482877360840283}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.25881904510254294`, -0.4482877360840626}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "5"}], "}"}], 
        Offset[{2, 2}, {-0.25881904510254294, -0.4482877360840626}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}, {
       DiskBox[{-0.5176380902050453, 6.71894144447725*^-16}, 0.], InsetBox[
        RowBox[{"{", 
         RowBox[{"2", ",", "6"}], "}"}], 
        Offset[{2, 2}, {-0.5176380902050453, 6.71894144447725*^-16}], 
        ImageScaled[{0, 0}],
        BaseStyle->"Graphics"]}}}, 
    {GrayLevel[0], AbsolutePointSize[5], PointBox[{0.5176380902050415, 0.}], 
     PointBox[{0.25881904510252135`, 0.44828773608402805`}], 
     PointBox[{0.2588190451025429, -0.44828773608407174`}], 
     PointBox[{-0.2588190451025205, 0.4482877360840283}], 
     PointBox[{-0.25881904510254294`, -0.4482877360840626}], 
     PointBox[{-0.5176380902050453, 6.71894144447725*^-16}]}}},
  ImageSize->300,
  PlotRange->{{-1.1, 1.1}, {-1.1, 1.1}}]], "Output",
 CellChangeTimes->{
  3.9090560518364916`*^9, {3.9090561101798167`*^9, 3.9090561548715925`*^9}, 
   3.9091127161095977`*^9, 3.910153148939886*^9, {3.9101612802787886`*^9, 
   3.910161292364663*^9}, 3.9101655926503925`*^9, 3.9101720013638697`*^9, {
   3.9101785936371737`*^9, 3.9101786109268703`*^9}},
 CellLabel->"Out[18]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
288.],ExpressionUUID->"fb34719a-500c-4893-8516-fa5baaee05cb"]
}, Open  ]],

Cell[TextData[{
 "The BBH model consists of four orbitals on each site of the {6,4} lattice. \
The orbitals are coupled cyclically by an on-site term with amplitude ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[PlusMinus]", 
    SubscriptBox["h", "0"]}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "a04bac22-a6ef-4a0b-93b7-ad8d880939b8"],
 " with appropriate signs implementing the flux pattern:"
}], "Text",
 CellChangeTimes->{{3.9091100794507523`*^9, 3.909110119897537*^9}, {
  3.910174905802904*^9, 3.910174906687784*^9}, {3.910174961935872*^9, 
  3.910175109290615*^9}, {3.9101786255314093`*^9, 
  3.9101787046760106`*^9}},ExpressionUUID->"93cfb5a1-e458-4a50-870c-\
9e0596489475"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"onsite", "[", "h0_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"{", "\n", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "h0", ",", " ", "0", ",", " ", 
         RowBox[{"-", "h0"}]}], "}"}], ",", "\n", " ", 
       RowBox[{"{", 
        RowBox[{"h0", ",", " ", "0", ",", " ", "h0", ",", " ", "0"}], "}"}], 
       ",", "\n", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "h0", ",", " ", "0", ",", " ", "h0"}], "}"}], 
       ",", "\n", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "h0"}], ",", " ", "0", ",", " ", "h0", ",", " ", "0"}], 
        "}"}]}], "\n", "}"}], ")"}], "&"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.9091111503346624`*^9, 3.910175513224516*^9, {3.910178150491731*^9, 
   3.910178191291686*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"5f95843c-7071-4ea7-9f82-92e4c61b255b"],

Cell[TextData[{
 "Additionally, there are nearest-neighbor hoppings between the sites with \
amplitude ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "1"], TraditionalForm]],ExpressionUUID->
  "51448291-41dd-4b94-9864-44e8c29f1e86"],
 ":"
}], "Text",
 CellChangeTimes->{
  3.910178750519763*^9, 3.910179383332368*^9, {3.9101794357167273`*^9, 
   3.9101794623027472`*^9}},ExpressionUUID->"e4918313-8b53-44f7-8f64-\
2dc246dc120a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hopping", " ", "[", "h1_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"Normal", "@", 
     RowBox[{"SparseArray", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", "4"}], "}"}], "->", "h1"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"AssociationThread", "[", 
            RowBox[{
             RowBox[{"EdgeList", "[", 
              RowBox[{"pcmodel", "[", "\"\<Graph\>\"", "]"}], "]"}], "->", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"3", ",", "3"}], "}"}]}], "}"}]}], "]"}], "[", "#", 
           "]"}], "->", 
          RowBox[{"h1", " ", 
           RowBox[{
            RowBox[{"AssociationThread", "[", 
             RowBox[{
              RowBox[{"EdgeList", "[", 
               RowBox[{"pcmodel", "[", "\"\<Graph\>\"", "]"}], "]"}], "->", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1", ",", 
                RowBox[{"-", "1"}], ",", "1", ",", 
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}], ",", "1", ",", 
                RowBox[{"-", "1"}], ",", "1", ",", 
                RowBox[{"-", "1"}], ",", "1", ",", 
                RowBox[{"-", "1"}]}], "}"}]}], "]"}], "[", "#", "]"}]}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}], "&"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091102923304925`*^9, 3.909110298684972*^9}, {
  3.9091111264453907`*^9, 3.9091111317247286`*^9}, {3.910175416616406*^9, 
  3.9101754261471214`*^9}, {3.910176413071261*^9, 3.9101764171602554`*^9}, {
  3.9101782019197435`*^9, 3.9101782213948717`*^9}, {3.910237962537923*^9, 
  3.9102379963910737`*^9}, {3.910238116315558*^9, 3.9102381201866364`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"1a48e53a-3659-44e8-afb4-7bf6137b034f"],

Cell["\<\
With this information, we construct the Abelian Bloch Hamiltonian on the \
primitive cell:\
\>", "Text",
 CellChangeTimes->{{3.909112746681242*^9, 
  3.909112758737096*^9}},ExpressionUUID->"99c79b3d-cfd1-4053-9b15-\
6fb7de0f475b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Hpc", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"AbelianBlochHamiltonian", "[", 
        RowBox[{"pcmodel", ",", 
         RowBox[{"4", "&"}], ",", 
         RowBox[{"onsite", "[", "h0", "]"}], ",", 
         RowBox[{"hopping", "[", "h1", "]"}]}], "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"Assumptions", "->", 
       RowBox[{
        RowBox[{"h0", "\[Element]", "Reals"}], "&&", 
        RowBox[{"h1", "\[Element]", "Reals"}]}]}]}], "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.9091127598630133`*^9, 3.9091128051125402`*^9}, {
  3.909112887125308*^9, 3.909112890216216*^9}, {3.909114118715374*^9, 
  3.909114118938531*^9}, {3.910153339519004*^9, 3.9101533492091894`*^9}, {
  3.9101756316062946`*^9, 3.910175684683981*^9}, {3.9101764091227016`*^9, 
  3.910176424809532*^9}, {3.91017954390506*^9, 3.9101795784992914`*^9}, {
  3.910179609181083*^9, 3.910179612386073*^9}, {3.9102381322893887`*^9, 
  3.910238137492961*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"96c38553-a9ee-4ced-b4bd-52dad49f8ce7"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "h0", "0", 
      RowBox[{"-", "h0"}], "h1", "0", "0", "0", "h1", "0", "0", "0", "0", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"h0", "0", "h0", "0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k2"}]], " ", "h1"}], "0", "0", "0", 
      "h1", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"0", "h0", "0", "h0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "k2"}]]}], " ", "h1"}], "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]]}], " ", "h1"}], "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {
      RowBox[{"-", "h0"}], "0", "h0", "0", "0", "h1", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k1"}]], " ", "h1"}], "0", "0", 
      "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"h1", "0", "0", "0", "0", "h0", "0", 
      RowBox[{"-", "h0"}], "0", "0", "0", "0", "h1", "0", "0", "0", "0", "0", 
      "0", "0", "0", "0", "0", "0"},
     {"0", "0", "0", "h1", "h0", "0", "h0", "0", "0", "0", "0", "0", "0", "0",
       "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k3"}]], " ", "h1"}], "0", "0", "0", 
      "0", "0", "0", "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]]}], " ", "h1"}], "0", 
      "0", "h0", "0", "h0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "k3"}]]}], " ", "h1"}], "0", "0", "0", 
      "0", "0", "0", "0", "0", "0"},
     {"0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k2"}]], " ", "h1"}], "0", "0", 
      RowBox[{"-", "h0"}], "0", "h0", "0", "0", "0", "0", "0", "0", "h1", "0",
       "0", "0", "0", "0", "0", "0", "0", "0", "0"},
     {"h1", "0", "0", "0", "0", "0", "0", "0", "0", "h0", "0", 
      RowBox[{"-", "h0"}], "0", "0", "0", "0", "h1", "0", "0", "0", "0", "0", 
      "0", "0"},
     {"0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k1"}]], " ", "h1"}], "0", "0", "0", 
      "0", "h0", "0", "h0", "0", "0", "0", "0", "0", "0", "0", "0", "h1", "0",
       "0", "0", "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "k1"}]]}], " ", "h1"}], "0", "0", "0", 
      "0", "0", "0", "h0", "0", "h0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"k2", "+", "k4"}], ")"}]}]]}], " ", "h1"}], "0", "0", "0", 
      "0", "0"},
     {"0", "h1", "0", "0", "0", "0", "0", "0", 
      RowBox[{"-", "h0"}], "0", "h0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k2", "+", "k4"}], ")"}]}]], " ", "h1"}], "0", "0", "0", 
      "0", "0", "0"},
     {"0", "0", "0", "0", "h1", "0", "0", "0", "0", "0", "0", "0", "0", "h0", 
      "0", 
      RowBox[{"-", "h0"}], "0", "0", "0", "0", "h1", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "h1", "0", "0", "0", "0", "h0", "0", 
      "h0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", "k4"}]], " ", "h1"}]},
     {"0", "0", "0", "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]]}], " ", "h1"}], "0", 
      "0", "0", "0", "0", "0", "h0", "0", "h0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", "k4"}]]}], " ", "h1"}], "0"},
     {"0", "0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k3"}]], " ", "h1"}], "0", "0", 
      "0", "0", "0", "0", 
      RowBox[{"-", "h0"}], "0", "h0", "0", "0", "0", "0", "0", "0", "h1", "0",
       "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "h1", "0", "0", "0", "0", "0", 
      "0", "0", "0", "h0", "0", 
      RowBox[{"-", "h0"}], "h1", "0", "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k2", "+", "k4"}], ")"}]}]], " ", "h1"}], "0", "0", "0", 
      "0", "h0", "0", "h0", "0", "0", "0", "0", "h1"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"(", 
           RowBox[{"k2", "+", "k4"}], ")"}]}]]}], " ", "h1"}], "0", "0", "0", 
      "0", "0", "0", "h0", "0", "h0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"k1", "+", "k3"}], ")"}]}]]}], " ", "h1"}], "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "h1", "0", "0", "0", "0", 
      "0", "0", 
      RowBox[{"-", "h0"}], "0", "h0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "k3"}], ")"}]}]], " ", "h1"}], "0", "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "h1", "0", 
      "0", "0", "h1", "0", "0", "0", "0", "h0", "0", 
      RowBox[{"-", "h0"}]},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      "0", "h1", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         RowBox[{"(", 
          RowBox[{"k1", "+", "k3"}], ")"}]}]], " ", "h1"}], "h0", "0", "h0", 
      "0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]]}], " ", "h1"}], "0", 
      "0", "0", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          RowBox[{"(", 
           RowBox[{"k1", "+", "k3"}], ")"}]}]]}], " ", "h1"}], "0", "0", "h0",
       "0", "h0"},
     {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k4"}]], " ", "h1"}], "0", "0", 
      "0", "h1", "0", "0", 
      RowBox[{"-", "h0"}], "0", "h0", "0"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.910238137809517*^9},
 CellLabel->
  "Out[41]//MatrixForm=",ExpressionUUID->"b4cb2171-b0d5-4165-b130-\
b1ebfffc5b59"]
}, Open  ]],

Cell["We export the matrix", "Text",
 CellChangeTimes->{{3.90911280941973*^9, 
  3.9091128164730463`*^9}},ExpressionUUID->"70ad38f5-33b8-4487-bc6c-\
4d9bfb489d78"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"FileNameJoin", "[", 
     RowBox[{"{", 
      RowBox[{
      "\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
       "\"\<H_{6,4}-BBH_T2.1.dat\>\""}], "}"}], "]"}], ",", "Hpc", ",", 
    "\"\<Table\>\""}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.909112817642894*^9, 3.909112873040862*^9}, {
  3.9091135412614784`*^9, 3.9091135513819184`*^9}, {3.9091141224124656`*^9, 
  3.9091141227837057`*^9}, {3.9101533706269875`*^9, 3.910153387843902*^9}, {
  3.910161305435033*^9, 3.9101613071799307`*^9}, {3.9101656107114687`*^9, 
  3.9101656118116646`*^9}, {3.9101756995576763`*^9, 3.9101757042046995`*^9}, {
  3.9101758415137253`*^9, 3.910175841845538*^9}, {3.9101795918450627`*^9, 
  3.910179597389012*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"3fa2996c-845a-4dfd-8f60-ea7055301787"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909112902255294*^9, 
  3.909112904377528*^9}},ExpressionUUID->"a122a9fd-9794-41ae-ad2a-\
11a394b4d9a9"],

Cell[TextData[{
 "We approximate the density of states by randomly sampling momenta, i.e., \
one-dimensional irreducible representations, and diagonalizing the Bloch \
Hamiltonian evaluated at those. For faster evaluation, we compile the \
expression for the Bloch Hamiltonian (for the parameter choices ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["h", "0"], ",", 
       SubscriptBox["h", "1"]}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{"1.5", ",", "1"}], ")"}]}], ",", " ", 
    RowBox[{"(", 
     RowBox[{"0.77", ",", "1"}], ")"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{"0.38", ",", "1"}], ")"}]}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "97c3d659-ae8a-4134-9031-6c72bfebc8e3"],
 "):"
}], "Text",
 CellChangeTimes->{{3.9091129164291873`*^9, 3.909112983734069*^9}, {
  3.9101534175388513`*^9, 3.910153418071595*^9}, {3.9101758519671125`*^9, 
  3.9101758573253603`*^9}, {3.910238231911167*^9, 3.9102382473677783`*^9}, {
  3.9102382838787794`*^9, 
  3.910238294656232*^9}},ExpressionUUID->"b637fb6d-2cf6-4291-862d-\
03a82b007dc1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Hpctrivcf", "=", 
   RowBox[{"AbelianBlochHamiltonian", "[", 
    RowBox[{"pcmodel", ",", 
     RowBox[{"4", "&"}], ",", 
     RowBox[{"onsite", "[", "1.5", "]"}], ",", 
     RowBox[{"hopping", "[", "1", "]"}], ",", 
     RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hpccritcf", "=", 
   RowBox[{"AbelianBlochHamiltonian", "[", 
    RowBox[{"pcmodel", ",", 
     RowBox[{"4", "&"}], ",", 
     RowBox[{"onsite", "[", "0.77", "]"}], ",", 
     RowBox[{"hopping", "[", "1", "]"}], ",", 
     RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hpctopocf", "=", 
   RowBox[{"AbelianBlochHamiltonian", "[", 
    RowBox[{"pcmodel", ",", 
     RowBox[{"4", "&"}], ",", 
     RowBox[{"onsite", "[", "0.38", "]"}], ",", 
     RowBox[{"hopping", "[", "1", "]"}], ",", 
     RowBox[{"CompileFunction", "->", "True"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9091129849959536`*^9, 3.9091129967523327`*^9}, {
   3.909114125339196*^9, 3.909114125798375*^9}, 3.910153426194847*^9, {
   3.910176046778378*^9, 3.9101760672534122`*^9}, {3.9102383013192563`*^9, 
   3.9102383633313713`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"022461bc-8917-4328-963a-f8edca9748bb"],

Cell[TextData[{
 "As stated in the paper, we compute the DOS with an energy resolution of \
0.005 (but for demonstration purposes with a smaller sampling of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "5"], TraditionalForm]],ExpressionUUID->
  "5bf39014-77e6-453f-8fac-eee48536dfd5"],
 " instead of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "8"], TraditionalForm]],ExpressionUUID->
  "5f44efdd-9e8b-4024-af3b-c1f9835a60aa"],
 ")"
}], "Text",
 CellChangeTimes->{{3.909113068779531*^9, 3.9091131190954094`*^9}, {
  3.9101614549615393`*^9, 3.9101614564987535`*^9}, {3.910161500131562*^9, 
  3.910161500190627*^9}},ExpressionUUID->"2d4df2d9-e0bd-4a04-9b46-\
951d38255174"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dostrivpc", "=", 
   RowBox[{"ComputeDOS", "[", 
    RowBox[{"Hpctrivcf", ",", 
     RowBox[{"10", "^", "5"}], ",", "32", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], "-", "0.005"}], ",", "4"}], "}"}], ",", "0.005"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"doscritpc", "=", 
   RowBox[{"ComputeDOS", "[", 
    RowBox[{"Hpccritcf", ",", 
     RowBox[{"10", "^", "5"}], ",", "32", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], "-", "0.005"}], ",", "4"}], "}"}], ",", "0.005"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dostopopc", "=", 
   RowBox[{"ComputeDOS", "[", 
    RowBox[{"Hpctopocf", ",", 
     RowBox[{"10", "^", "5"}], ",", "32", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], "-", "0.005"}], ",", "4"}], "}"}], ",", "0.005"}],
     "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9091130888235645`*^9, 3.9091130961532984`*^9}, {
   3.90911413019394*^9, 3.9091141332449045`*^9}, {3.910161490577303*^9, 
   3.910161498644859*^9}, {3.9101656308871603`*^9, 3.9101656373735223`*^9}, {
   3.910176146109257*^9, 3.9101761506408443`*^9}, 3.910176221009781*^9, {
   3.910176351796934*^9, 3.9101763539143457`*^9}, {3.9102389527794423`*^9, 
   3.9102389759814253`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"284544f6-ff42-43ba-95d8-21e8fefa99c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"dostrivpc", ",", "doscritpc", ",", "dostopopc"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.6"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.1); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(5\)]\)\>\""}], ",", 
   RowBox[{"PlotLegends", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<trivial\>\"", ",", "\"\<critical\>\"", ",", "\"\<nontrivial\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909113125377311*^9, 3.9091131344978976`*^9}, {
  3.90911413604417*^9, 3.9091141363413095`*^9}, {3.9091150932516265`*^9, 
  3.9091150966947627`*^9}, {3.909126411615711*^9, 3.909126429281196*^9}, {
  3.910161469973936*^9, 3.910161470044631*^9}, {3.910161502500625*^9, 
  3.9101615076578336`*^9}, {3.9101657725552626`*^9, 3.9101657844493575`*^9}, {
  3.9101762243133035`*^9, 3.910176224670022*^9}, {3.9102390192852583`*^9, 
  3.9102390322037954`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"9d92cce4-aeaf-40eb-9213-0cb83f6bb94b"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, 
     InterpretationBox[{
       TagBox[{{{}, {}, 
          TagBox[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[
              NCache[
               Rational[1, 180], 0.005555555555555556]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            LineBox[CompressedData["
1:eJxF1VtIVFEUxvFpNKJ9NHuwq2iKBJVRD9IFQneENIVRKWQgZjdNqgelC5GG
TJF2gTDKHiIq6CoUohkhlbFQy4eyFJprSo6KBEkIZZBQNPt8x/kWDMN/4GzO
Xr+HyThQWVjudrlcN6If8905uaykwT1XXM7UJDd7IlNJsa7KUYH7E+xDZsbY
JQ3REwbYhe1pdd/72Vsi1cnNPWxzXFUHO9tMG3u5ObCJHT2toP0O27xedSPb
HJdzmW2Pl/07er3Ok+zoaWl1R9nm9Tz72eY4tZv9wcw2tr2vTWxz3YL1bPN6
yavYD8wCM9k3zSxim/WVJLHNddNmsuExJ9bwYMODDQ82PNjwYMODDQ82PNjw
YMODDQ+2PV42PNjwYMODDQ82PNjwYMODDQ82PNjwYMODDQ82PBJjDQ82PNjw
YMOD7bE92PBgw4MNDzY82PBgw4Ntj5cNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNj4RYw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PZ42fBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PCwYg0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY
8LDk4fB4V0VwqbZ/9FoyVXvk9YnrTXrS9rBk38o/b6/t7dbwsOTRre70lmN9
Gh6WjKurNb11nzU8LCk7N+tn3t+A7rU9LDGnLYwPa3hYkuDOujA/FNbwsORj
7pn6PTPCGh6WpBaXbfi6I6ThYcns8l8vnvpCGh6W2HvICWt4WBJ3e23f4biQ
hgefh4eSxFfu0dLjIQ0PJa2jC/JrW4MaHkpOvbm7ePVgUMNDSZ49QQ0PJZmN
/V+eFQU0PJQUbK58X5wa0PBQsmJexZLcLr+Gh5Lzp+/9u7LTr+Gh5MlBsxCf
hocSex1Ffg0PJfb/ksen4aHk4qeWrI0/fI6HEr2m9OXWBL/jocS+TkbI8VCS
8u352e0pA46HkrainviksUHHQzn7H3I8lEQvH93AkOMx/X4Rx0PJxON3+esu
RRyP6eeHHQ/l7HtEd+yqr+1NV2LfO3tE/we7DLKx
             "]], 
            LineBox[CompressedData["
1:eJxd3HmcnEWZB/C+uwdx0QUExEVARFRUFBUWgapFRAVEAx6IiIggIAsCoovI
YkABoyKHiIjcMRyiIQcJyRypIoHchJlkZhJyHzOTmckx99Fzbr/1+z1Va/Uf
4fPQPd1v17feqvftep465oofX3hVJpVKDedSqeS/N11w4Q3la6vsye6xS+24
7ZCZX/x+lb17z5QFR929Q62ffuMZB3yryrr/v2O7enN15XF+lf3iCdNfveqf
29XigRMuvf+sKnuse2xXlT/aM+XUKvsfB5/+6Ic6t6nKH912yMer7Il6/2cO
e2ir+lvl7dZ/oMp+9N73vL1maJP6S/I4osrO+PChV7//zPXq/uQND6qyD/zi
zbv/9uEm5Y4jX2W/MH7kM7/fulb9IjmMkZK94Ip3Xfyfr9Sr5O2md5dscjR/
qFqjfpg82kpWfeay6i8fuFJdmrzhZnn9cnVhcoANJdt3dvKGS1VyeDOXlaw7
7gVLVfJ2N9aV7DUbDj166LElyjXL3JJ1//+MxerDyRu+ULLbHpl32vG3WuX+
7MmS/eP3Tiy/8ZBRyeHd9nDJuo/P1Cj3Z78t2fprs098tn6hSiWPqSWbPPvR
e+erpPkW/7Rkf3LMtee+8faryjX7dSX76b0HVJpgHj1K9huP/+/wgTVz6FGy
v/vv3aMv9syhR8nueXT7a6dPeZkeJfv815M/eIkeJTu44+TKO75Ej8rxzdi5
d8nVL9CjZP/9V3blM194jh4lu2vGX18/etaz9CjZSuMetfrgGfQo2Xe7xzP0
KNpXDnrq+9+a+jg9ivagtmkjp5z1F3oU7Y9XXZJ0CXoU7SVXfm7bV+/7Mz2K
duDHv/7Ubd95hB5F+/0nX/jlBx5+kB4hhkfRvn51AvRbehTZP+5R73ceReve
/Ya76FFkf7qbHkV7/K0nfbXR3EmPonXf47Zb6CF/fzM9iuxfl9EjxPAoWtec
Gz5Dj6JN8QGPEMMjxPAI8XTnEWJ4hBgeIYZHiOFR8DE8QgyPEMMjxFOcR4jh
EWJ4FOyUcxLRi+hR4Pe/ih4Fe8GR7a/cecEv6FFge91BD3m9eBRscnL+bNH9
9CjY137182cn7nuAHgWeL4/Qo2A7jv9k6R/ve4weBbt1S/J4gh5yfNPpUbA3
fPulH9xVnM7zo2BPemTsihWfeI7nR4H99UWeHwV7ijthZyl4FOxdxWTEmM3z
o2AXPfXeT2w5bj7Pj4I/3+FR4PmzmOdH3mL4WcrzI28/kgx3S2S8ytv6WR+t
jJDreH7krXvf+5sVPPL2g4U7//T5323g+ZG3P6q95Y+H5zby/Mhb9/Y/20iP
vP1Oc2dlRNhMj7z9Z9MnK026lR55jlfb6JG3yej83Ne30yPP82krPfJ26gce
btg0Zys98vav7/jyRR9Zs5UeeVuTabnsJ8dsoUfenjO/b7zx1i30yNt/u2Wj
fv6dm+mRt2dMmTznhOmb6JFnf9lEj7x108NFm+iRt9nk7a/dSI/K+31szhNd
z2+kR57j4UZ65O1gcpwDG+iRtz89v/vyJ19YT4+cvTz5+t/bQI+crQyulW+w
nh45e0LnttJV/c30yNFTPHI2+fZn3t5Mj5xd2X59pYc10yPH8a6RHjnrhvd7
19Ejx/l1HT1yNuMmxHX0yLF/raVHjv19LT0qx3tRckT19MjZ/PK6trPW1tMj
ZyuTTaUDr6FHzr41lPzBanrkrOs+31xKj5yt4FcmjFp65GwFvzLDzadHjvPj
THrk6Pc8PXL2yMrRFu6cQY+cPf+Uaf91eevT9MjxfJf5I8f5fzo9svasy1vr
j930Ij2yNvnr+mNfokfWfvy6RHAmPSrxcV958dTRWfTI2uoHPl35iLn0yNrk
4qN01Sv0yNrbk+H/0FfpkbWbr0veYQE9sjZp3UuurKFH1jqHQxbRI0tPS4+s
ffUfyQn1Gj2y1nWvXy6hR9a+K5kONy+hR9buW5JMWMvokfXXI/DIWtdc9Svp
kbUvL0y+0Gp6ZO1zSfe7uZ4eWY6na+mR5fleT48s57cGemRto3l3pYs20CNr
7/lbcsG1lh5Zu/ShZECQ66uM7dqfPNbSI2PPdo9GemRscnbumiHjVcYmo/dT
711HjwyvP9bRI2OT3vGnz6+jR8Ze//S6wmnXy/mRsW64PriRHhn210Z6ZOz/
uBOikR4ZjleN9MhYd7l0dyM9MvYb7tFEj4x1p+s9TfTIcLxvokfGzrszGYGa
6JGxs5Ph+LBmemRsZfCtjDBN9MhwvmmiR8bO/eay3EFtTfTI8PxrpkfGDj2W
DJjN9MjYrzqQJnpkeH0o17sZ67rj52S8StsD3QDRTI+0fz080ja5epvf10SP
NOevRnqkrbt8ahCPtP2Q6/CN9EjbHyVvd+06esj7NdAjbb/kGqqBHmnrhusj
6+mR5ni5hh5p69px/Sp6pDlfLKVH2r7n6KRF5PxI83qumh5p69px5qv0SFv3
PX84nx5pu+4r7gSiR9oms9M3l71Cj7Sdf1pyBrxCj7RNRrvKnEGPNMfzOfRI
W3f5O38uPdJ2r2u42fRI27zrMHPokbKP3pBcMc+mR8p2P7/0vFOmzaZHyqYX
rr/0S4/NoUfK/swN0HPoEZ6HR8r2z08GlLn0SHE8mUuPlHXD65/m0iNlZ7cc
dt4ds1+hR4rXt/PokbKb5yQdcj49UvbUs46o+9h18+iRshdiQKdHiuPLAnqk
7P7bkzuohfRI2Tcqz17zYB09Uvb5dyYTeh09UvZzGHDokWL/sPRI8frgNXqk
7OGVo285bAk9Ujxf36BHitdDy+iRsq67XLSSHileX6zA8Q9MGow3q9R2d586
aXA9sFKtdo9JA99VOJ4Fkwbj5Wp8/vRJg+udNeoP7gtMmuRqse/sN5V7u9sm
zc6T3QgD3x9Ommse3FdpoTW4f5kyaWS+xX1i5fPnJjdE9cod3gmTxp3O296C
zyGT5jA34dbDIzVpMN5x/t4zYZ5Opv9Cg2p2Bzhh3OXizHq07+IJ44avIxrQ
njMnjLucOZHj/V8mjHt5qkH92r3hhMF8zvH8xglzmhuAG9A/L50w1yfNtbYB
/fGLEwbjU4P6lOuAE0bmC9d8R00YzH8N6F8HTLB9Gugx7o8PHuNm2XnJDNdA
j3Hjuv+FDfQYN5hfOH9NHzfuvnR6PT3GjYw38Bg3mC/q6TFuDnQXZPU4v6aM
G9zPrlGnuwMcN3e4C7w19Bg37nLy3DfpMW7Q396ix7jvH/AYMxhfVtNjzGxI
Dv+mNfQYMwuucnfI9BgzuN9eRY8xg+vLVfQYM6OnJCfkKnqMmcn7vlb5Svy9
4tIxM165O3lkbCU9xgzmo5X0GDPfTT5+cAU9xgyun1bQY8zg/n45PUYNzr8V
9Bg1P0je/ooV9Bg17vL0reX0GGV/XUaPUYP7jaX0GDVu3DnqDXqMmtqa5LGE
HuF5eIyaRZWr04d/u4Qeo8bd7j21mB6jBtdfS+gxanA9spgeo8aNLu9eTI8R
85hr19foMWL6K6NBx/Gv0WPEOL7TOd7MHDHfcT9ILabHCM9PS48R9vc6eoyY
k29LeoClx4jB71mGHiMG10eL6DFi3HB23iJ6VF7vfuCoo8cIz7c6epTNZ90A
UEePspHrTXiUef7U0aNs3Lh/Qi09yiY5uxeur6VH2RyTDM/7aulRZv+roUfZ
yHgNj7Kp3FxXOlwNPcqm6dbkDqOWHmWD67saepTNne4CqIYeZeMuv7sX0mPY
3Jj8fNNcTY9hjsc19Bhm/66mx7DB9dJCegz744HHML2r6TFspv0meSygx7BZ
fXDyi1E1PYbNk13JBLyQHsPmXHfBtJAewxwvaulRid38sZAeQ+wf1fQYMrje
W0iPIYP7r2p6DPnvB48h863k60yrpseQeenvyaOaHkMG80I1PYYMrv8X0GPI
tx88hjh+L6RH5fVuABSPId8+8BgyuJ+socegue/PyQWKeAwam1z+f1s8Bg1+
zxWPQdP7uw+ai3tr6DFo3O3kw9X0GDTJaLPj5Fp6DJr3uQmlmh6DHM9q6DHI
8biWHoPm5VQy4lfTY9D8y++jBwwad/mZlfNjwMfwGDC4f6ihx4DB/XstPQaM
+3nmGTk/BjhfLaLHgMH1fx09Bvz5CI8Bg99jFtFjwODnyUX0GDB3OYBF9Bgw
DcduKt/xo1p6DJjjK61XaUJ6DJg/JN39kjp69PvxAh79ZrT7iOSSkB4hhke/
/37w6DfudvK6RfToN7gfXkSPfvNz10Fr6dHP+auWHv3G/dz1iHj0G9yvGXr0
+/EGHv2+PeHRx/G9hh59xk03ZRmv+gzuRxfRo898yv2AV0ePPt9+8OgzR7jL
cfHoM5+vzA5zDzL06DP4vcTQI7weHuHz4dFn3NNP8Pf3Q/q8LzzC38Oj1493
8Oj14y88eo1cz8Kj1+B+r44evf77waM3mj96fX+DR6+5CRf29Og1iebHj6uj
R6/ZeO9blSsQmT/C6+HR68d/ePT4+QUePQa/v9fSo8d/Pjx6ovOjxx8vPHp8
e8OjJ5o/ekxz8vPhs3J+9Bjcf9fSo8fg90mZP3p8e6Nde/z3hUc4Hnh08/pJ
PLr98cGj248/8Og27nZzvpwf3f7z4NHtzx94dBvcz4pHtx9f4NFt8HuLnB/d
fjyDR7cf3+HR7c+3Tnf8Xf556463i9cnC9Wj7r9dxq2GlebxeLoMfo+do85x
n99l8HvILPU+93ld5ifuBmOG6ncNup/3Mw/Rd78Zq1ytf+WKqepZ94b7jfw+
f6tr8BB/zXmFGD4hnphMHvt83OjaP8T/cA0UYrRviNGeIUb7hbjk2ivE6K97
fYz+GWL0xxBf6fpfiNHfQoz+FWJ47PExPEIMjxDDI8TwCDE8QgyPTh/DI8Tw
6Iw8OiOPzsijM/LoiDw6Io+OyKMj8uiIPDoij47Ioz3yaI882iOP9sijPfJo
jzx2Rx67I4/dkcfuyGN35LE78miLPNoij7bIoy3yaIs82iKP1sijNfJojTxa
I4/WyKM18miNPFoij5bIoyXyaIk8WiKPlshjV+SxK/LYFXnsijx2RR67Io+d
kcfOyGNn5LEz8tgZeeyMPHZEHjsijx2Rx47IY0fksSPy2BF5bI88tkce2yOP
7ZHH9shje3T823w81R1viE9yx7ctOp6tPv69+/wQn+o+L8TtzntL5Bvis51n
iLtdg2/28dPOa3PkE+Ix57HJxy+49g/xxa69N0Xtuylqz41R+4X4Xa69Qoz+
+nbUP0OM/hji5a7/bYj6W4jRvzZEHusjj/WRx/rIoznyaI48miOPpsijKfJo
ijwaI4/GyKMx8lgXeayLPNZFHusij7WRx9rIY23k0RB5NEQeDZFHfeRRH3nU
R8f/lo9T7nhDfLk7vjXR8bzp48Pd54f4Rvd5q31cj3WKyDfEv3GeK4O381vh
Y+28VkQ+y3087DyWBS/X/iGehbyjqH2XRu35RtR+r/v4aNdeIUZ/XRL1z8VR
fwzxA/gdLepvNupfNjp+Ezxw3xTa3x1fbXQ8NaF98TtIOD73eQtC+2HdJ/Kd
H9rHec4Ln+f85obPc15zIp/Z4fOcx8vhede+/wzv59rr7+F59/1fCMfn+teM
8P1df5kePt+BPR2edz6PR/33z+HzXH96MDzvPKaF2PWPO0Ls+u+Vcayi14fY
3YhM8/FUt2DxYIhxPCHG8frY4vv4WOP7hufRHuF5tFf4fLdg9vfwerS3j492
/87y8eXw8vHT8PTxdniHv0d/CH/PdUL/91xH9MfjbqQXhNfzdzn/ev6O5j8P
/Tl8Hn8n8H+P88HHPF98zPMpvD9/t/avZ16hfz3OVx8/gPPZxyfhfPdxPcYD
H3O88DHHk9D+zHP0r8d4FF7v/l3u41kYz8LxYrwLx4vxMBwvxstwvBhPw/H+
/3XhymMqxuPweozX4fUYz8PxYrwPx4v5IBwv5gsfcz7xMeebqP1CfALmq/B6
zGc+Xo75zseHYz708TWYL33M+dTHnG+j/hPiBZivw+vdv40+vhjzvY9fwPWA
j4dxveBjrNs3+ZjXG5FfiL+E65XweuahSdyO6x0fn4rrIR//BtdLPt6A66nI
Y0PksSHy2BB5vB15vB15vB15bIw8NkYeGyOPTZHHpshjU+SxOfLYHHlsjjw2
Rx5bIo8tkceWyGNr5LE18tgaeWyLPLZFHiHm/YiPeb8StV+IH8b9jo9rcT/k
4xbmiUt8IO6nfPxp3G/5mPdjPub9WnQ+h3gz7vd8nHP/7vTxibhf9PHXcT/p
49txv+ljrDOHmPerkV+Ij8P9ro/Px/2wj2/B/bKPH8f9tI9fx/22j5Fnsivy
aIk8WiKPlsijJfJoiTxaIo/WyKM18miNPFojj9bIozXyaIs82iKPtsijLfJo
izzaIo+2yGN35LE78tgdeeyOPHZHHrsjj/bIoz3yaI882iOP9sijPfLoiDw6
Io+OyKMj8uiIPDoij87IozPy6Iw8OiOPzsijM/LojDz2RB57Io89kceeyGNP
5LEn8tgbeeyNPPZGHnsjj72Rx97IY1/ksS/y2Bd57Is89kUe+yKP/ZHH/shj
f+SxP/LYH3nsV7IeAI/9StYL4NGlZD0BHl1K1hvg0aVkPQIeXUrWK+DRpWQ9
Ax5dKloPUbIewvUS/zzar1vJesq5WG9Rst5yGdZjlKzH3Iz1GiXrNfdgPUfJ
eg6Oo1vJeg/Xg5SsB3G9SMl6Eea7biXrSfux3qRkvSnjWrFHyXrUe7BepWS9
6iNYz/KfdybWu5SsdyH/q0fJehjXy5Ssl8GvR8l62kNYb1Oy3vYc1uP88VVj
vc4fzxqs5ylZz9uJ9T4l633Ic+9R/5pv0qtkvZDriUrWE+HRq2S9ER69/vvC
I7weHr3+8+HR648XHr1K1kO5XqpkvZTrqUrWU+HRq2S9FR69StZj4dHn2xse
fUrWc+HRp2S9Fx59StaD4RH+nuvJvr3h0adkvRke4fXw6FOyXg2PPv/94NGn
ZL0bHuHz4dGnZL2c6+nek+vtStbb4dGvZD0eHv1K1uvh0a9kPR8e/f58g0e/
knwAePQryRdgPoE/f5hvoCTfAB4hhke/knwFeAwoyWeAx4CSfAd4DCjJh4DH
gG8/eAwoyadgvoWSfAt4DHhfeAz4/gaPASX5HPAYiM6PAf/94DGgJF8EHgN+
fGG+iY+Zj6IkHwUeg0ryVeAxqCSfBR6DfjyDx6CSfBh4DPrxBx6DSvJpmG+j
JN+G+ThK8nHgMagkXwceg0ryeeAxpCTfBx5DSvKB4DGkJF8IHkNK8ongMaQk
34j5SErykeAxpCRfCR5DSvKZ4DHkx3d4DCnJh4LHkJJ8KXgMKcmngseQknwr
5mMpycdivpaSfC14DCvJ54LHsJJ8L3gMK8kHg8ewknwxeAz79oHHsJJ8M+aj
KclHY76aknw1eAz77wePYd9+8CgryYeDR1lJvhw8ykry6eBR9uMdPMr+eJiv
pyRfDx7laP4oK8n3g0dZST4gPMp+/IdH2Y838Cj78RceZSX5iMxX9Ocj8xn9
/AKPESX5jvAY8eMFPCqvZ74kPEaU5FPCYySaP0aU5GMyX1NJvibzOZXkc8Jj
REm+JzxGlOSDwmNUSb4oPEaV5JPCY1RJvik8RpXko8JjVEm+KvNZleSzwmNU
Sb4rPMLz8BhVki8Lj1El+bTwGFWSbwuPUSX5uPAYVZKvy3xeJfm8zPdVku8L
jzEl+cDwGFOSLwyPMSX5xPAYU5JvDI8xJfnIaMcxJfnKzGdWks/MfGcl+c7w
GFOSDw2PMSX50vAYV5JPDY9xJfnW8BhXko8Nj3El+drwGFeSz818byX53vAY
V5IPDo9xJfni8BhXkk8Oj3El+ebwGFeSjw6PcSX56vAYV5LPznx3JfnuzIdX
kg8Pjwkl+fLwmFCSTw+PCSX59vCYUJKPD48JJfn68JhQks/PfH8l+f6sB/DH
B48JJfUC8JhQUk8Aj0kl9QbwmFRSjwCPSSX1CvCYVFLPwHoHJfUOrIdQUg8B
j0kl9RLwmFRSTwGPSSX1FvCY9P0DHpNK6jXgMamkngMek0rqPVgPoqUe5AHU
i2ipF/kr6km01JPMQL2JlnqTl1GPoqUeZSHqVbTUqyxBPYuWehbWu2i5nmU9
jJbxmvUyWupl9qKeRks9zRDqbbTU26QTjqkpLfU470C9jpZ6nUNRz6Olnof1
PlrqfVgPpKUeiPVCWuqFzkQ9kZZ6oi+j3khLvdFFqEfSUo/0XdQraalXuhr1
TP75m1DvpKXeifVQWuqhWC+lpV4KHmkt9VTwSGupt4JHWks9FjzSWuq14JHW
Us8Fj7SWei/Wg2mpB2O9mJZ6MdaTaakng0daS70ZPNJa6tHgkdZSrwaPtJZ6
NniktdS7sR5Oy3jDejkt9XKsp9NSTwePtJZ6O3iktdTjwSOtpV4PHmkt9Xzw
kPdrokdaSz0g6wW11AuynlBLPSE8Mv718MhoqUeER0ZLvSI8MlrqGeGR0VLv
CI+MlnpI1ktqqZdkPaWWekrWW2qpt4RHRks9JjwyWuo14ZHRUs8Jj4yWek94
ZLTUg7JeVEu9KOtJtdSTst5US70pPDJa6lHhkdFSrwqPjJZ6VnhktNS7wiOj
pR4WHhkt9bKsp9VST8t6Wy31tvDIapkv4JHVUq8Lj6yWel54ZLXU+8Ijq6Ue
GB5ZLfXCrCfWUk/MemMt9casR9ZSjwyPrJZ6ZXhktdQzwyOrpd4ZHlkt9dDw
yGqpl2Y9tZbrTdZba6m3Zj22lnpseGS11GvDI6ulnhseWS313vDIaqkHh0cl
Zr04PLJa6slZb66l3hweOS316PDIaalXh0dOSz07PHJa6t3hkdNSDw+PHJbB
F8ykR05LPT3r7bXU28Mjp6UeHx45LfX68MhpmW/hkdNS7w+PnJb9AOCR07Jf
ADxyWvYT4H4DWvYb4H4EGveTUv+b07JfATxyWvYzgEdOy34H8Mhp2Q8BHjkt
+yXAI6dlPwV4VI6X+y1wPwYt+zHAI69lvwZ45LXs5wCPvJb9HuCR17IfBDzy
WvaLgEdey34S8Mhr2W+C+1Fo2Y8CHpX3434V8Mhr2c8CHnkt+13AI69lPwx4
5LXslwGPvJb9NOCR17LfBvfj0LIfB/fr0LJfBzzyWvbzgEdey34f8Mhr2Q8E
Hnkt+4XAI6/v5zouPPJa9huBR17LfiTcr0TLfiXwKGjZzwQeBS2/l8CjoGU/
FHgUtOyXAo+Clv1U4FHQst8KPApa9mPhfi1a9muBR0HLfi7wKGjZ7wUeBS37
wcCjoGW/GHgUtOwnA4+Clv1m4FHQsh8N96vRsl8N97PRsp8NPOT1V9FDju8i
ehS0/D4PjxDDI8TwCDE8Qsz9fHwMj6KP4RFieIQYHiGGR4jhEWJ4hJj7GfkY
HkUt+x3Bo6hlPyR4hBgeRS37KcGjqGW/JXgUtezHBI+ilv2auJ+Tlv2cuN+T
lv2e4FHUsh8UPIpa9ouCR4jhUdSy3xQ8ilr2o4JHUct+VfAoatnPivtdadnv
Ch4lLfthwaOkZb8seJS07KcFj5KW/bbgUdKyHxc8Slr264JHSct+XtzvS8t+
X/AoadkPDB4lLfuFwaOkZT8xeJS07DcGj5KW/cjgUdKyXxk8Sv58h0dJy35n
3A9Ny35o8Cghre6MxfQoadlPDR4lzo9L6VHSsh8bPEr+egQeJS37ucGjpGW/
N+4Hp2U/OHhUadkvDh5VWvaTg0eVlv3m4FGlZT86eFRp2a8OHlVa9rODR5WW
/e64H56W/fDgUYW0wx3bZT89zq871M3Ybw9pdCfvUv8HkPsVYw==
             "]], 
            LineBox[CompressedData["
1:eJxF0VlIVFEcx/FxiehczZdsEzcksIx6iBYIPX9CMjEqiwxEbdOketA2ooWh
Im2BSMqXkAoSSyhMM8I2H9LyoSyFZk3JUZFAC6EkEorO3N91fgcuw/fh/ud/
zyd9X9X2imiXy1VvnvBv585ad2+aklX2GdFN1dnKl6Ek5vaavoMxI/pxXuj0
vBVKDr06fnNh7LB+nlIzXrhOyeSDdwVrr4R011RmyfUNSh7uvzD7Z25I934w
Z7OSAnfb6IKCIe1rNAN3zbw/pM20lry9StqLemITxgb1RGFHSs1hJUnfnp7f
kjSgf5txb04oeRk9WnYsPaCjzI6uc0r06rIX+XFebYUHXlVy+VNrlvzw6MQW
s2C9kk32YI9ONet13FFi/12RVy8146aaZ/bzaPsz25VcPHXv37VtXp2jzMDX
SpYlVqbmdHl1fnhOj5LCjVXvi5N9eodZb7xfSUZ9/5cnRT5dasZlDijJtY9f
Vx4wZ0zJyc67i1cO+vURc32Nk0rCX+9u8+szZqvQtJJ4+4MCOrxeyixLkovL
13/dGtB1ZlxJguXcd0A33DJnkSXhMdXZQcfDkjkVv5498gQcD74PD0s+5pyt
LY0KOh6WxEVnXZofCDoelnP/QcfDkvLwdfz1OR6WTKi6M701nx0PS+43dKe1
Hu1zPCzZs/zP2xu7ux0PS6bd4YnNjoclTcMTXZX+JY6HJS7nwIMNDzY82PBg
w4MNDzY82PBgw4MNDzY84iINDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNj/hIw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw2NupOHB
hgcbHmx4sOHBhgcbHmx4sIdtD/Z324MNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBIiDQ82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBg
w4MNDzY82PBgw4MNDzY82PBgw4MND/Z/G6Rlkg==
             "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
          TagBox[{
            Hue[0.9060679774997897, 0.6, 0.6], 
            Directive[
             PointSize[
              NCache[
               Rational[1, 180], 0.005555555555555556]], 
             RGBColor[0.880722, 0.611041, 0.142051], 
             AbsoluteThickness[2]], 
            LineBox[CompressedData["
1:eJxF0TGIl2UAx/G/cqd1WtdwEC0n4VJDLS4tctBygRGcS8stCbY46CKBQryL
i4uLi0uLDU5COChEcEjQUkNTS4NH4eLSYoOT9z5feT+/5eWzPDzv8/3w0tWL
l4+vVqtPjq1W8/fpy4/27xx/72D1Zje3Hu4evtpcfO38xl/3/+Nv5z3n/TtH
J/zNF59s33rxJ39xeGPr4W88H3ftFz437xF/PB/4gI9O23vyA8/Xu3GX5+PO
3+axif8/+r2n1/notO1bV3i+3u43PB+38TX/Pu9LHu/1Oc+/u/cZz9fb+pR/
nB/wLN+b9wHPz7e/yfPvbq9zPd5dXA+uB9eD68H14HpwPbgeXA+uB9eDxyau
B9eD68H14HpwPbgeXA+uB9eD68H14Hq8s7geXA+uB9eDd0cPrgfXg+vB9eB6
cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfpxfXgenA9uB5cD64H14Pr
wfXgenA9eGzienA9uB5cD64H14PrwfXgenA9uB5cD67HqcX14HpwPbgeXA+u
B9eD68H14HpwPXhs4pejB9eD68H14D9GD64H14PrwfXgenA9uB5cj43F9eB6
cD24HlwPrgfXg+vB9eB6cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfb
i+vB9eB6cD24HlwPrgfXg+vB9eB68NjE9eB6cD24HlwPrgfXg+vB9eB6cD24
HlyPtxbXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6cD24HlwPrgfXg+vB
9eB6cD24HicX14PrwfXgenA9uB5cD64Hnxk9uB5cDx6buB5cD64H14PrwfXg
enA9+P7owfXgenA9uB4nFteD68H14L3Rg+vB9eB6cD24HlwPrgePTVwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9VhfXA+uB9eD68H14HpwPbgeXA+uB9eDxyau
B9eD68H14HpwPbgeXA+uB9eD68H14HqsLa4H14PrwfXgenA9uB5cD64H14Pr
wWMT14PrwfXgenA9uB5cD64H14PrsXbw3djjnXqsHVz4/qd/37/wbOfXsz9v
frWxdjDe5dw/O68By85eEQ==
             "]], 
            LineBox[CompressedData["
1:eJxd1UFIVFEUxvHxQhBuyhyIKI0wwgiCDMkIORWkQUnqprIpSEyIqFGhEGsh
pUKhlSCELoo0TCksK2hc2LsomJmBSqhhWBJEMVQGzaZ6U3PPl37QBZEfyPHc
9x/erCsNF58wgUDgZOLH/a4enJ6t+mbsVj0fpNydj8aWLj+0/cnwrISuDcQy
3xq7vqA759f8GymKpNdHx41t/nJBso9NSv5cTbDn+cLfT0hu8lRHRb+xeeGX
JWmpY6JjHxvbdOPMikt2RDa6gV3Gdg3t23Z517CsrY8WRW4aa1NGPp0+PCjB
nsTEFmPvVLhJVty43CvGVmKwBNypNXbs4aadX7OfSiwzMfCssfN33cBeiboF
Txm7Zen9NSVl98Stl3/c2Fi4LqvmSKe4cckHjU3qmwrtbWuXV6OJs9/YxPLn
nt1qkwE3cLexvW78yovirluUY+zv7u8TBaWF4tYLbjY28O+4cVMZdKs7q2j3
+ELLaHfd9CX0eXfhn0mL1mvP0+hBoweNHjR60HhsNHrQ6EGjB40eNHrQ6EGj
B40eNHrQ6EGjB40eNHrQ6EGjB40eNHrQ6EGjR2DR6EGjB40eNHrQ6EGjB40e
NHrQ6EGjB40etJ5aGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRg0aP//aP/fEW
/N7tO0eP6qF1nwit/7+DvqoXoHVcDa19y+liHUhrv1xa18ukdVyQxqH1+Ufj
i57UBWldb4DWcT20Pr9Wuk4H0nrdClrXC9E6Lp/O0g9g3Nvjr77dONsg+vjS
49504u1YXNmJ929y3Pvhv67+vKEX79uY76WVlO14d6Bf0MP3ajNaxmceDQl6
+F7D0aSqB31jeH9GfK893lSYF54R9PC9FD1zcr0x9UVOs+8tfP/8BelcCqk=

             "]], 
            
            LineBox[{{-1.8097222222222222`, 0.6}, {-1.8074999999999999`, 
             0.5953333333333334}, {-1.8039999999999998`, 0.6}}], 
            LineBox[CompressedData["
1:eJxdmnmUVdWVxivGTowhSlrjEIfg2A6J4tQxtvrRJnGImuCwDNGohJaWtBqN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             "]], 
            
            LineBox[{{1.8040000000000003`, 0.6}, {1.8075000000000006`, 
             0.5953333333333334}, {1.8097222222222227`, 0.6}}], 
            LineBox[CompressedData["
1:eJxF1X1ozVEcx/F7TynxBzMPiU2aNJTysEzieyjzuGzzB2ZbWUMSd1sRsz8W
tqKtmVYyRYbZIjNbMTWtrWbmoW3JpmkaJRozZRR+l9/3fGyfU7u3V63v75zz
vt07NzOUstcEAoED/p++lxdHPokv82SZW++lKnv1hJ5rnkS4NSAPowsHkx94
UhkuSUoI9cmLZ7o8KUoP5tY2dsq7vKl3Ngx4UhBT3tV3r01+xKaVtox4EpWa
terttibxh/kTw/Lde3ns0/w6ceOiw9KbtrEiJadKlrvnhmW9N+tqcX+RbB7Q
gWEJ/F8Z/rTYNDpXt5dNF+m4Qrrioi7a35w/kNZppS10r26vhx7ScYO0ca9/
xzzdDaQX6nFj6TXuwHSKjkum97lF5+v15dHn3QZp9KDRg0YPGj1o9KDd9Y8L
2FGf0+dNoi/p9c2kb+jzY+haPf5iulH3E0+36vbX0c91e1tp93HYQbvce+jP
ev8H6Z+6/yN0UF8K6Ik68Cw9Ta+znJ6jB75ML9DrqKbdx6+edv2a6E26wcf0
du3ZRadr/jf0fs37gc7RfMP0Cc3zi0aP4JjRg0YPGj1o9KDRg0YPGj1o9KDR
g0YPGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRw4wZPWj0oNGD
Rg8aPYz9U/OtOzEzSdDD2LpFdihuxklBD2NXNrQffXSlQtDD2GBjj/8NWSno
YexI6PTSvN1Vgh7GLhl/e3Zq1i1BD2OHb7ZtWXGmTtDD2M67+oD7gh7GunNn
Nwl6GHvdfa80C3oY2xzR8fHQrlZBD2Orddzadvwu1BtbcuHwlFPNHYIexiaE
nqZGRXYKehibOXmnf4RuQQ9jy77kS1zGK0EPY+cl1sT/Hn4t6DH6//1yvLW3
P/ersaO/P/8AvRPWkg==
             "]], 
            LineBox[CompressedData["
1:eJxF0SGIlgcYwPHPcTo9p1c2ZOVELA6GxWJxd1gOuTE4DRYXFNzCglsQwcGw
WCwzWERYOYSlEzHsxrCcgsWFJYth6ljRwYoIJt/v+8v7e8L78isPz/v+D5y7
cPL8B5PJ5PNtk8n0/fDgHwtfzc8tH5nNi6XrW68PnVmYW1796e4/+1b/Xrp1
c5hP55Yvzea3pdvfH5t/cnBuefJ+7qw8u/zxYf598erLtaP8YFj383H+8/Ew
X/KT9WHhaR62bayc5Vdrm4tXv+M3w7qti7xt+rjCu6cLr/EnG8OBN3j/cN7m
L/zZsO71rzz7Dff4i/lh4X0+MT3wEZ8aznv5F389rDv0lL/9Zph/+Yfh963/
zz8On/vsLU/PW9y+fXQ9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9doyuB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+ux4ej68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD67FzdD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD12ja4H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H/Oh6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB67B5dD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cj49G14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H12PP6Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hrs
HV0PrgfXg+vB9eB6cD24Hvx81oP/m/XgenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrsTC6HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD34Hb8+xWY=
             "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
          TagBox[{
            Hue[0.1421359549995791, 0.6, 0.6], 
            Directive[
             PointSize[
              NCache[
               Rational[1, 180], 0.005555555555555556]], 
             RGBColor[0.560181, 0.691569, 0.194885], 
             AbsoluteThickness[2]], 
            LineBox[CompressedData["
1:eJxF0S1sV1cAh+F/y9fo+BI1M4UFsxkSgpkhJDOdmGkNpmYkYBCrAQHJcg0G
g8FgMExMYTA1SwhmBgRqZoaQYJYlGCZQ6z3vcp+fuXnMyTn3/frGz7s311er
1d211Wr+vvr0zd6j9XMvV//v/ubz7Xefzy7ev7rx57OPfGveB957dHjCX7x7
sPXg77f8w7t7m8//4Pm4/d/5yrwX/O184G98eNrOwVOer3fvMc/HXX3IYxP/
e/i8V3f48LStB7d5vt72Tzwft3GdX8/7kcf/+p7n5+58x/P1Ni/xr/MPvMhP
5n3F8+/bO8vzc7eOcT3OLK4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXg
enA9uB5cD64H14PrwfXgenA9Ti+uB9eD68H14O3Rg+vB9eB6cD24HlwPHpu4
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+txanE9uB5cD64H14PrwfXgenA9uB5c
Dx6buB5cD64H14PrwfXgenA9uB5cD64H14Pr8eXienA9uB5cD64H14PrwfXg
enA9uB48NvGn0YPrwfXgevCb0YPrwfXgenA9uB5cD64H12NjcT24HlwPrgfX
g+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwPrgfXg+txcnE9uB5c
D64H14PrwfXgenA9uB5cDx6buB5cD64H14PrwfXgenA9uB5cD64H14Pr8cXi
enA9uB5cD64H14PrwfXgenA9uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H
1+PE4npwPbgeXA+uB9eD68H14POjB9eD68FjE9eD68H14HpwPbgeXA+uBz8b
PbgeXA+uB9fj+OJ6cD24HrwzenA9uB5cD64H14PrwfXgsYnrwfXgenA9uB5c
D64H14PrwfXgenA9uB7HFteD68H14HpwPbgeXA+uB9eD68H14LGJ68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeRxfXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB
9eB6cD24HlwPrgfXg+vB9eB6cD24HkcW14PrwfXgenA9uB5cD64H14PrwfXg
sYnrwfXgenA9uB5cD64H14PrwfXgenA9uB7ri+vB9eB6cD24HlwPrgfXg+vB
9eB68NjE9eB6cD24HlwPrgfXg+vB9eB6cD24HlyPtcX14HpwPbgeXA+uB9eD
68H14HpwPXhs4npwPbgeXA+uB9eD68H14Hrw5a1fjv5zYe3lePeV99f+A71B
YLg=
             "]], 
            LineBox[CompressedData["
1:eJxd1jFoE1EYwPGzUIQiOJilChERJCo46NLBeuBSCjqkDi51UNBFwSLoEDM4
2BZUmkWEIgjSQetQ0KkU5EIWHWLHFh2kQdAhiw7Ju/fePfXuO+on/wch/CF8
/e79AumRa7dnro9EUbSYv4r3A29qz/e+jdpn5HyLj8+2OoPXUTscevnk67PP
8eH5fn39RdSOmwtX9tz5EFfWpnqNp1F7bHtlbnLsVSzvj6J29P95oD2o5QPv
aufTqvM3tXuNfOJVbRl7WftTNz8XtDvFwPPa+bR+fUK7WK9ySrsYt31Ue7k4
49qtYuB+7eJxq6PYf/An2e2dYt+edleOtuyzri1/f0V7SR5AW8Y1tG/I0Z6R
gdqTcuHasl5NW8ZVtMujLfff//2vt2RBbVmvoy3j1rTl/pa1H8pAbXncOW1Z
b1Zbxk1pn5bvnbZcX1W7/J5plx4BHgEeAR4BHgEeAR4BHtpyfXXts7JggEeA
R4BHgEcGjwweGTwyeGTwyOCRwSODRwaPDB4ZPDJ4eHh4eHh4eHh4eHh4eHh4
eHh4eHh4eHh4eHg4eDh4OHg4eDh4OHg4eDh4OHg4eDh4OHhYeFh4WHhYeFh4
WHhYeFh4WHhYeFh4WHhYeKTwSOGRwiOFRwqPFB4pPFJ4pPBI4ZHCI4WHgYeB
h4GHgYeBh4GHgYeBh4GHgYdJNqb3jZxcXCh/3ysmeXzrh1/99S4uP2WSg/dG
P77/3olLj2FycXXC/xzfjEuPYTJ96cTmueZWXHoMk/syaCfufmk1j20Mk93/
L/4CPUWE7Q==
             "]], 
            LineBox[CompressedData["
1:eJw9kU8og3EYx19E/i0HoxQzOZCiTJEyDzkMueCgNNIKramthgMKGRfFhQPF
ZS0O2q6vpKf2WhrLaLWhFTYlIav392sHB949xrd+PT2/er59nu9TZbIOjGcK
glChvFR9ee39LBQ5NpHi4LTp8yPOv/4JNry81rjJMWd5u2t96gHm1G7D0xzH
lmtz1l5zFCZIHOfp/xb6Rc3qWz9Hj3AcMXaHoU1xs+k5buZpAsU8BIqZ4sjR
ejlcUdx2DTSm5vghTd6WaIMgkDjuHy5Wb91cwhsZMqy7al9YG/FDmAAZdh6o
pu87zoHwvAwTY6mJMyA7N8NSbXK3oEeCHRJD09BS1NJwBg4yZHh3lRyMuySg
dW0MXbF3hcAHhGdkqDrJfB61+4HsDAwVeKtDdwE6yoVhTWPuUflwAFLbihqG
v3NBoHXzGUrEdQNUuJzmDcEjBShjZbvkViKCAElGe5W513cXAYpPlLHstN4y
0xdN30PG1q9E2Wz2Y/oeMlIcGTHY+i6696zI//f7AfR/80Q=
             "]], 
            LineBox[CompressedData["
1:eJw9kUsohFEYhscslKFm4RaLMRLJpSliIXxl45LNDGExciksJEOhLLBwqylT
smFDKWUzykyaUXyuoTTlOu7NjIWFS+ecmoQF//n8vPV3Vv9znve8qa3dljat
RqMxKp88C8ND+tdJgfmURxh9NnsMYwKrYrTZEwmPYCvR+RdtAt8KEqeXakNg
deyEM60CNZQQlAcH45zlAsuSNnI7+wKQRxyBEV6/tWLuAQxjEijwODbcPZp3
A5JWohP4uttxFW/0gwJTiBztLv18S/05BCQuyPE8sqhr4ewUjikcrxSapccH
HgJybM752J9u2oNFEuQ4sDmfbLp3w5TUc3AkTccqEG6Qq/1c0E7hOJI2c3K7
ugZmAnLckzrv61BMghypTvUWkF4mR/dhv3LDARAujuP7XHRlTZYPft+B4wuB
ToCe75lh19PXMj+9gEsSZHgkfzddA2ntMJwNbBebv2+AcE6m9r+DWQrD354P
6h4Mxxsjele8AXUPhhnYIOzpQXUPhrJN3cHfHgyz4jtSSndD6h4Ml4dl4RD0
Ge4/o0zsf+8fnV8LiA==
             "]], 
            LineBox[CompressedData["
1:eJxdmX+QVmUVx1eGKUJLLBthNAatlBodN9Oksg6aIRVhEBkRykqQleNIozQM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             "]], 
            LineBox[CompressedData["
1:eJw9kUsohFEYhn8WyqUs3GIxSKRByqUkvGXjko0hLMa1sNDkUigJC7eymJps
zIaaUjbUkFDuhNKUWzOuzfwWFi6dc2oIC/7v9PPV6dQ59fS835vY0mlqDVQU
JUE7dPcZ7r+CMxmy5TwiR94MC8NJ02e3Ksp9A5GLJQzGqPb4on0VDdY9f6qZ
Qft01hyp6CkMcTu6GFK268RUsg/jz5VrhjGG8fqAnqV1L+wzNAzao/bzgMUS
AjJMLYfPNtfegWjWPYYZ725B5c8NPI4ujchw0rc1G5d5jTfCPTNYnr4X+PkV
yFlROF7k+xmiJZDjwx5aVmV0wWgmQY6VYwIcoYj0CjliNzM6eit2YJIiHAft
nqiEjw20yeEYobjOVQxGEpDr+1iGTQpyyNhWJ+ZJz8HRT3r3K9iQuTia0j8P
bY0HcJ3ScHjMpXZTtwsqrc/HcRmUb5m7OMc7xfVzPf8lpF6IwOs+CbkhcQaB
0wh/52jWjd6HQMC6WyM+6H0IFMtAXr0PAbkW5a8PgbfcGNt8tar3IVAeFpg2
Ef2IPP9Q+Ouk+O/7F6BG+7E=
             "]], 
            LineBox[CompressedData["
1:eJw9kUsoRFEcxi8izywwpcwgC1KUR6SYjyww2WChNCSFRI28FijEzMZiSiRT
bDRYyGw9splLwjRIuUNTzIzN5DV1zzELC8453Xx1Opt/v//3/778Pkt7f6wk
SXr2+L/+m/7kWlRRIRTCipsWme0qvMZZW3dMEDujdcnKtoqan0j2VPwLjg3W
t7ZDFdmnJcOTrX54PVwqxvOHTOePCoLTmQdNARW5RvlAOlLwzWhuqqJhN23i
qf4eDMaIBDJf476DwBkI+FSR+QaVwgdBYVnifk6XB6YABxJ4MqhlqfwKPWKO
IO0k9rVn/BJj3N4ogTP4Lg/6zmHjOCvBozfaEXLKcGxwEfR1zvuHS8/AzDEg
gS4v6khpkSHOdRNEerf25grO4OP2FKL5vcAnx70RFItALsEzkyQKPr16dw2d
AFJ8sO1ZeTcoFodQWK679Bm1tzCKgynsSQZ2wj3aOa6NwsXCMTc/YECIYobH
Nu3DrPgpqm+H4jar/FofFAkLa43LI89aH1TrK4Bw2PSVekj/+/sD2NTk+g==

             "]], 
            LineBox[CompressedData["
1:eJxd1j9oU1EUx/HbQhGi4GAVqlARQWIFFx262PNwkYoOrYNLFRR0UbAUdKgZ
XJqCChURQQuCFP/UoaJTDbjEQYea0aqDWAUdFNEh73n/m3Of7YHfhTR8h5yc
dz8ZuuP0hdEz3Uqp6c6L35c+ztR2NXLal85XararYzPNnC73LhxamfxM7+fG
D1SWcxo+NtAaqr2jXyOL/VM/cjo6P2h/97WIZyhV0NZLPW9efmvSFv5Yb0HX
zn+383+e00BnWrtaUGN4Q/ee6ToNVZY7EwtS/88ojxuRPpuOdC3tIX0zLSj9
kNebk27wuEXp1hIf6S+TPFA658dtS6f1Kn/XOo3rl96f7kn68AoPlD7Jjzsm
PcHrjUvXedyU9N07fKTT9S1Ilx7SpYd06SFdeui1Lj2kSw/p0kODhwYPDR4a
PDR4aPDQ4KHBQ4OHBg8DHgY8DHgY8DDgYcDDgIcBDwMeBjwMeBjwsOBhwcOC
hwUPCx4WPCx4WPCw4GHBw4KHBQ8LHg48HHg48HDg4cDDgYcDDwceDjwceDjw
cODhwcODhwcPDx4ePDx4ePDw4OHBw4OHBw8PHh48AngE8AjgEcAjgEcAjwAe
ATwCeATwCOARwCOCRwSPCB4RPCJ4RPCI4BHBI4JHBI8IHhE8pNP196hstW/w
922UnuXr65N+wN+/U/opP/5e6Re8z6D0K17/oPRbXu+IdPo5HJdO3Kekf/L9
n5MueP+L0l3854r0eh54VXozX+ctlZW/u0e0nR/4nsqoVj/RNfGadvN1PFaZ
33b/+qfbH2jTk+rsumcqW/3/4h875kI/
             "]], 
            LineBox[CompressedData["
1:eJxF0S+sTgEYwOHv+u9e3EJQLqZQFEXBnWI2BUEhsCEICAqbKYpCUMymmE26
gkJQCApBUhRsCjblziY53/3Zed5wzp7y7j3nt+v8lZMXVk0mk+szk8n0vX/h
1ppfO2cW96/Mt8NPrx6c/bR7ZnHyf54f/XJj6z5+tXDnx4kD/HZ5z5l7R/jD
+2GO86cnw8LTPGxbOnqOf554uXDnMv8Z1r25zjPTx22emy68y9uWhgMf8I7h
vJePee+wbvkZr3zmCz40Oyx8zcemB77jU8N5Pz7y2WHdns986eIw3/na8Pue
/Oabw+d++cvT8xbWrhp9f1h3Zp4fPRxmO9eD68H14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXI/Vo+vB9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxZnQ9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA91o6uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+ux7rR9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9Vg/uh5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB4bRteD
68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9dj
4+h6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6zI6uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+ux9zoenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrwfXgemwaXQ+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXI/No+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+uxZXQ9uB5cD64H14PrwfXgevDXlR78a6UH14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cj/nR9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB/wAY+aPO
             "]]}, Annotation[#, "Charting`Private`Tag#3"]& ]}}, {
        "WolframDynamicHighlight", <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
       DynamicBox[
        (Charting`HighlightActionBox["DynamicHighlight", {}, 
         Slot["HighlightElements"], 
         Slot["LayoutOptions"], 
         Slot["Meta"], 
         Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
            Annotation[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJxF1VtIVFEUxvFpNKJ9NHuwq2iKBJVRD9IFQneENIVRKWQgZjdNqgelC5GG
TJF2gTDKHiIq6CoUohkhlbFQy4eyFJprSo6KBEkIZZBQNPt8x/kWDMN/4GzO
Xr+HyThQWVjudrlcN6If8905uaykwT1XXM7UJDd7IlNJsa7KUYH7E+xDZsbY
JQ3REwbYhe1pdd/72Vsi1cnNPWxzXFUHO9tMG3u5ObCJHT2toP0O27xedSPb
HJdzmW2Pl/07er3Ok+zoaWl1R9nm9Tz72eY4tZv9wcw2tr2vTWxz3YL1bPN6
yavYD8wCM9k3zSxim/WVJLHNddNmsuExJ9bwYMODDQ82PNjwYMODDQ82PNjw
YMODDQ+2PV42PNjwYMODDQ82PNjwYMODDQ82PNjwYMODDQ82PBJjDQ82PNjw
YMOD7bE92PBgw4MNDzY82PBgw4Ntj5cNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNj4RYw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PZ42fBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PCwYg0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY
8LDk4fB4V0VwqbZ/9FoyVXvk9YnrTXrS9rBk38o/b6/t7dbwsOTRre70lmN9
Gh6WjKurNb11nzU8LCk7N+tn3t+A7rU9LDGnLYwPa3hYkuDOujA/FNbwsORj
7pn6PTPCGh6WpBaXbfi6I6ThYcns8l8vnvpCGh6W2HvICWt4WBJ3e23f4biQ
hgefh4eSxFfu0dLjIQ0PJa2jC/JrW4MaHkpOvbm7ePVgUMNDSZ49QQ0PJZmN
/V+eFQU0PJQUbK58X5wa0PBQsmJexZLcLr+Gh5Lzp+/9u7LTr+Gh5MlBsxCf
hocSex1Ffg0PJfb/ksen4aHk4qeWrI0/fI6HEr2m9OXWBL/jocS+TkbI8VCS
8u352e0pA46HkrainviksUHHQzn7H3I8lEQvH93AkOMx/X4Rx0PJxON3+esu
RRyP6eeHHQ/l7HtEd+yqr+1NV2LfO3tE/we7DLKx
               "]], 
              Line[CompressedData["
1:eJxd3HmcnEWZB/C+uwdx0QUExEVARFRUFBUWgapFRAVEAx6IiIggIAsCoovI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               "]], 
              Line[CompressedData["
1:eJxF0VlIVFEcx/FxiehczZdsEzcksIx6iBYIPX9CMjEqiwxEbdOketA2ooWh
Im2BSMqXkAoSSyhMM8I2H9LyoSyFZk3JUZFAC6EkEorO3N91fgcuw/fh/ud/
zyd9X9X2imiXy1VvnvBv585ad2+aklX2GdFN1dnKl6Ek5vaavoMxI/pxXuj0
vBVKDr06fnNh7LB+nlIzXrhOyeSDdwVrr4R011RmyfUNSh7uvzD7Z25I934w
Z7OSAnfb6IKCIe1rNAN3zbw/pM20lry9StqLemITxgb1RGFHSs1hJUnfnp7f
kjSgf5txb04oeRk9WnYsPaCjzI6uc0r06rIX+XFebYUHXlVy+VNrlvzw6MQW
s2C9kk32YI9ONet13FFi/12RVy8146aaZ/bzaPsz25VcPHXv37VtXp2jzMDX
SpYlVqbmdHl1fnhOj5LCjVXvi5N9eodZb7xfSUZ9/5cnRT5dasZlDijJtY9f
Vx4wZ0zJyc67i1cO+vURc32Nk0rCX+9u8+szZqvQtJJ4+4MCOrxeyixLkovL
13/dGtB1ZlxJguXcd0A33DJnkSXhMdXZQcfDkjkVv5498gQcD74PD0s+5pyt
LY0KOh6WxEVnXZofCDoelnP/QcfDkvLwdfz1OR6WTKi6M701nx0PS+43dKe1
Hu1zPCzZs/zP2xu7ux0PS6bd4YnNjoclTcMTXZX+JY6HJS7nwIMNDzY82PBg
w4MNDzY82PBgw4MNDzY84iINDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNj/hIw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw2NupOHB
hgcbHmx4sOHBhgcbHmx4sIdtD/Z324MNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBIiDQ82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBg
w4MNDzY82PBgw4MNDzY82PBgw4MND/Z/G6Rlkg==
               "]]}, "Charting`Private`Tag#1"], 
            Annotation[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.880722, 0.611041, 0.142051], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJxF0TGIl2UAx/G/cqd1WtdwEC0n4VJDLS4tctBygRGcS8stCbY46CKBQryL
i4uLi0uLDU5COChEcEjQUkNTS4NH4eLSYoOT9z5feT+/5eWzPDzv8/3w0tWL
l4+vVqtPjq1W8/fpy4/27xx/72D1Zje3Hu4evtpcfO38xl/3/+Nv5z3n/TtH
J/zNF59s33rxJ39xeGPr4W88H3ftFz437xF/PB/4gI9O23vyA8/Xu3GX5+PO
3+axif8/+r2n1/notO1bV3i+3u43PB+38TX/Pu9LHu/1Oc+/u/cZz9fb+pR/
nB/wLN+b9wHPz7e/yfPvbq9zPd5dXA+uB9eD68H14HpwPbgeXA+uB9eDxyau
B9eD68H14HpwPbgeXA+uB9eD68H14Hq8s7geXA+uB9eDd0cPrgfXg+vB9eB6
cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfpxfXgenA9uB5cD64H14Pr
wfXgenA9eGzienA9uB5cD64H14PrwfXgenA9uB5cD67HqcX14HpwPbgeXA+u
B9eD68H14HpwPXhs4pejB9eD68H14D9GD64H14PrwfXgenA9uB5cj43F9eB6
cD24HlwPrgfXg+vB9eB6cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfb
i+vB9eB6cD24HlwPrgfXg+vB9eB68NjE9eB6cD24HlwPrgfXg+vB9eB6cD24
HlyPtxbXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6cD24HlwPrgfXg+vB
9eB6cD24HicX14PrwfXgenA9uB5cD64Hnxk9uB5cDx6buB5cD64H14PrwfXg
enA9+P7owfXgenA9uB4nFteD68H14L3Rg+vB9eB6cD24HlwPrgePTVwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9VhfXA+uB9eD68H14HpwPbgeXA+uB9eDxyau
B9eD68H14HpwPbgeXA+uB9eD68H14HqsLa4H14PrwfXgenA9uB5cD64H14Pr
wWMT14PrwfXgenA9uB5cD64H14PrsXbw3djjnXqsHVz4/qd/37/wbOfXsz9v
frWxdjDe5dw/O68By85eEQ==
               "]], 
              Line[CompressedData["
1:eJxd1UFIVFEUxvHxQhBuyhyIKI0wwgiCDMkIORWkQUnqprIpSEyIqFGhEGsh
pUKhlSCELoo0TCksK2hc2LsomJmBSqhhWBJEMVQGzaZ6U3PPl37QBZEfyPHc
9x/erCsNF58wgUDgZOLH/a4enJ6t+mbsVj0fpNydj8aWLj+0/cnwrISuDcQy
3xq7vqA759f8GymKpNdHx41t/nJBso9NSv5cTbDn+cLfT0hu8lRHRb+xeeGX
JWmpY6JjHxvbdOPMikt2RDa6gV3Gdg3t23Z517CsrY8WRW4aa1NGPp0+PCjB
nsTEFmPvVLhJVty43CvGVmKwBNypNXbs4aadX7OfSiwzMfCssfN33cBeiboF
Txm7Zen9NSVl98Stl3/c2Fi4LqvmSKe4cckHjU3qmwrtbWuXV6OJs9/YxPLn
nt1qkwE3cLexvW78yovirluUY+zv7u8TBaWF4tYLbjY28O+4cVMZdKs7q2j3
+ELLaHfd9CX0eXfhn0mL1mvP0+hBoweNHjR60HhsNHrQ6EGjB40eNHrQ6EGj
B40eNHrQ6EGjB40eNHrQ6EGjB40eNHrQ6EGjR2DR6EGjB40eNHrQ6EGjB40e
NHrQ6EGjB40etJ5aGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRg0aP//aP/fEW
/N7tO0eP6qF1nwit/7+DvqoXoHVcDa19y+liHUhrv1xa18ukdVyQxqH1+Ufj
i57UBWldb4DWcT20Pr9Wuk4H0nrdClrXC9E6Lp/O0g9g3Nvjr77dONsg+vjS
49504u1YXNmJ929y3Pvhv67+vKEX79uY76WVlO14d6Bf0MP3ajNaxmceDQl6
+F7D0aSqB31jeH9GfK893lSYF54R9PC9FD1zcr0x9UVOs+8tfP/8BelcCqk=

               "]], 
              
              Line[{{-1.8097222222222222`, 0.6}, {-1.8074999999999999`, 
               0.5953333333333334}, {-1.8039999999999998`, 0.6}}], 
              Line[CompressedData["
1:eJxdmnmUVdWVxivGTowhSlrjEIfg2A6J4tQxtvrRJnGImuCwDNGohJaWtBqN
rTYxNkHjhIoNSBQRtRBRAYECi6KoaReIUjLWPAI1UPNc9eb3Ktr3nv3tU2vl
/aGreO/ee+7+7Xnv02Y8fOvMw7KysiqD/4T/f/edutz86jG5xH0OYVvsnN/+
37YxmXvG4oqmjW1Yd13rk8euG5PbD618a/ukNrzpPmNy/dJb/xhvbcWzfbfk
n/rcmPScfdERH5/chkeuOrJuxSNjcmzs4WcvfrIVwc2CO45J8OWd9/1bK9zt
rhuTHzwXXtiKi91zx2T1SOXNMya24FT372Nyx1E/2vj2UDPCu111pN3/INzx
Yhm54IHHbxqe3oiW8HatGbk1P7yyHrvdJyPn7b36qefvroH75/yMPHjBmTev
urwKK9wBM1It393Z/VAFXnUvnJEbbguv2At3uyczkvnxNScW/2gX/tN9MvJm
y9Yrb/nqc9zibpiRCe6C7bjSHTAjdzuBbIU73jkZaXxhX875U0rgbndsRr55
xUPZVd8oQJb7ZOQnmeETn/infDjx9aXlyFN3HxN7OBe17oBpab/nv0/7/S82
kUdaFvx5z3Pvn7uJPNLyl/8qeuy1E3LJIy2X9h8Z/GQTeaRlx40/nvfv0zeR
R1p+cPWn67K2bCaPtHw1f+q1D+8qII+01MwOJVxEHmk573v3B5eUkEdaAtiX
9B9ZSh5pOXn5Kwdf37SNPFLi1CNnG3mkeP7PyCMlI8HblhV/Th4pCb5reGFf
GXmkxL3+szvJIyXfjPzs7yct300eKZkxcdpPcsv2kkdKZNroy2dJOXmkJPjy
iZJ3K8kjJRPf/d2v5+6vIo+UnO4+teSRkkAZm381v4487Dz15JEUlVMTeSTl
NPeDJvJIymv3/jD12aIm8kjKZfcU3DDhsCbySMr5LxzXsDfRRB5J2RZoz7Xn
NJFHUnbdecoxVy5pIo+kNKXmBESbyCMpPQ/9Zs1/PNNEHkkJtf2dj5rIY/w8
yiMpk18fm/HFhY3kkZBHAuu7q9bsIyFdmVWBhTWSR0Kc+hzeSB4J+ee/lu5c
/vNG8kjIiYeHFthAHgmZGc37uOaiBvJICNwLN5JHQk668MCZ33i6gTwSct8z
IcE68kjwfevIIyF5V5w9e/Kv6skjIc/+6b0v50+tJY+EZH8/vGENecTltJxH
Zy0cqCaPuHQcf+OcDe1V5BEXlUMVecSpj5XkEZc/OrlXkEec+riXPOK0593k
EZd5L4afMvKIk7eQR5z+MY884hLS+csZueQRl7WvfitQ6U3kEZPwaZ3XbCSP
GP3TBvKISSiNatlAHjH5lhP4BvKIkd9G8hi/n/KISXfu0788qTuXPGL0Z3nk
EZOrQvVbsZk8YrJmdfgpII+YTEos/fYNtxWQR0ycetxRQh4x+tdS8ohK6F06
yreRR1T2uPfYTh5R8thBHlHa507yiMpFLiDsIo+olAfecvCyfeQRpf/fRx5R
+sdy8rDnlZNHVBYOPBWoZCV5RGXJH0KNriCPqKzP2lL32+srySNCfaskjwjt
tYo8IhJq899+WkUeEfkgVKdHq8kjQr415BGRIJgEBltLHhFxx2ytJY+IOHW5
o448IvJSOgwwNeQRkQmHhSeoJY+IOHdyfh15RCgf81cRxkvzV6P017XkMSqh
dlQuriWPUbnXueMa8hiV/Rvv2HH40bXkMf638hj/vfIYlS+rwwBRTR6j8vzd
X3t0/ZZq8hiVox5rnPLhd6rJY1QqTg89WjV5jEog3NsOrawij1GZ5YAZjxFx
7vgN4zHieSmPEcqrgjxGxIX/d8rJY0Re/uTowOOXk8eIOHfx1D7yGJEgGDxw
wZl7yGNEzgrxvrybPEa8PiqPEXnv53mRv1eXkceIhNH7iofKyMPO+zl5jIgL
r3XbyWNYznAOfTt5DIsLz8+ZfQzLLUH0vfOUT8ljWFz4u3gbeQzL70J3sngr
eQzLslD9Zm0lj2H5rvtsJY9hibuDlpLHsLzvflhKHsNyXWD8M9daPB8Wl441
C3kMyykuIBaj151/iPIsRak775B8EVjv9y8sxhJ3vvG/9TxD4tKbK4pxrXv+
EOVdjJPd84akNEy3flOIqDvnoHwWvs7CYvIdpDxL8J674aB8+J1QoYox2wl8
0N9vquM16PMV5TNI/SjGl1+FnwEJs7cHHi9CtZP/gFy89a+BxRfjYyegAcan
Qsp3QPJnhhZdRHkOyDOhN326hPIbYDwsxhFOXgMSRp/jbyyhvvaLS0+eKKF+
9svjofs8qpj62C/rtyy4dGVbEe5z+tcvYfYybbSQ+tbvn6/61S+hdj7YVUge
fZ6f8uiTV8P07U7j0SfTw/B0bxF59Mn2++u/NylRQB59ovctIY8+z1t59Mqi
D25f9r/JIvLo9edTHr1yvyaQ5NHrz6c8emVW+LilheTRK648uKSIPHpkTnJC
4WHtJeTRIy7dyikkjx7ma8ajh/63kDx6xLmXxwrIo0dc+lxmPHq8vJVHtzz/
/rmBRzQe3XJXmH78SwF5dPv4pzy6vTyUR7c/j8qtm/loEXl0ydff/tfy33+9
mDy6WF8UkkcX45Px6PLyUh5d/8CjS4JkL3iE8ej08lQenVJU6D7k0Skums80
++j0+q48Or08lEenOHdzjPHokMHLjg+Qm310eP7Ko4P1m/Ho8PqrPDq8fSqP
Dm9fyqPDy0d5tIt7zecKyaPdv6/yaJfOec6AyaOd8cLsY/x7lVu73FXbu6Rl
q/E4JK48WVBIHocYT0vI45CXl/I4xPrOeBySn1YufumTo4U8Dnl7Uh5tXn+U
Rxv9dQF5tMnR7oBmH22sjwrIo83bo/JoE+feKwrJo9Xbi/JoZf5QQB6t3h6V
R6vXN+XRKmE2c+3DheTRKtcE2dnpTVvII7g+TBembSGPFl+PKo8WGQzTp4It
5NEiTl0zW8ijRX4dZAed8wrIo4X1Vz55tHj71PM3Mz/Jx1x33mYJDhuYbB4m
u/M1y/xAOlecnc/zHJR0WP68lo9X3PMP+udd7p53kPEtH92O9wHWR5vJ94CE
0eHmVfn4mRPcAXlKExQMu+v2y/+E4epALrIdr/0SRvfZPXnks19cOvDgZow5
Hk2ya3mYAOTiIyf/Jv+8aVoXijOPu/Io3ybROL6Z8mwUl+7tyKX8Gv37TnQ/
bGQ/IY/62sB8IZf62cB8cTP1sUEC4wwcaC7KnP7Vy8q2/k/vr99Efav3+b/q
V72/n/Kok3tCaSzIJY86CemuGtlIHnXi0t/bPiGPWuYnn5BHrcxwATiXPGqZ
724kjxr2PzaQR41sCNPV4zeSR4248P6HjeRRLc58r9xAHtUSDXGcvYE8qlmP
55BHlf9eeVSJU/9MDnlUyU2uIMkhjyp/f+VRyXxwPXlUylvfDiukdeRRyXix
jjwqWE+sJo8K+rO15FFB+1tDHuXMZ9eRRznzo7XkUU77WM3z72P8Xossd959
9HdrMN2dby/9/RqeZw/tdxVOcM/fQ/sIzueet5v6/xHKHe9dtP9V5LtLnDvc
+yFedDx30n+tRovj94V86p6zElMcry/kchdQVpJPGevp95B0PHYw338fU538
d/jrc5y8P6f+rKB8PxeXLs1ZTnl+Rv17j/LbLse5AnQFJjl5bfe/V339VJpD
85mdTf3cxnx4OfVxG/uB72CB07+t4sL1K+9Q30qZ771F/SqVP7mG4jKeX9if
fBdZGpfFpX+/fAulGsfJ/22ep5D+/k1Mds8vkL+9FCbMb6BF/ZS48u2F15Gt
foH9xjfJN4/1+yJMdDw3ydfCcmfpIpQ6fp+IC6fzF2Cu47WR8nyNfDbwfV5G
i+Ox3l8/xcl3Levtl1Dq5LWa8f4VTHHv/xHPPw/Zyo3yfBpZTl9W8PzPY64D
ls16I/je8VnGfuTj1N83KM8HUer0aSHPexuyHI95Mha2L2ZMRZbTjzn0X2ch
y+nvfZJlH/0b/m/9Pfzvl7r7we431zUmFsKeN1fPAzvPXD0v7Lyl+j6w95mi
7wt731LqscmD8oLJK+vPTp4weZaqvGHynuQOnQPjMV15wXhlK08YzxblDeM9
SfVh/HrVF5i+UJ9g+pR1rsZF07fpqo8wfcxm3mX62sK81PR5EvNQ0/fpag8w
e6C9wOyF9gSzp2y1N5i9TVV7hNnjsNorzF4XqD3D7Hmy2jvM3svZRzJ/QH8B
8xf0J/73pepvYP7mEfVHMH800fEog/mrHPVnMH82Vf0dzN8Nqz/01y9Qfwnz
l/SnMH9Kfwvzt3PVH8P88WT11zB/Xa7+HObPH1F/D/P3EzUewOJBjsYLWLxg
PIHFE8YbWLwpZ1/M4tE5Gq9g8Wo2+6AWz8o03sHi3QkaD2HxcJbGS1i8ZDyF
xVPGW1i8Vf2pgsXjfI3XsHh9hONRDYvn0zTew+L9R5oP+O+Tmi/4+1+v+QQs
n2C+Acs3lF8NLB+5XvMVWL6yRPMZWD7TzT6d5TuXaz4Ey4de1HwJli/Vaz4F
y6eYb8HyLeZjsHxMedTD8jXl0QDL55RHAyzfUx4N/n7KoxGWLyqPRlg+yXwT
lm8yH4Xlo9M5x7B8VXk0wfJZ5bEflu8qj/2wfFh57Ifly8pjPyyfVh4HYPk2
83FYPq48DvjnKY+DsHxeeRyE5fvK4yCsHlAezf59lUczrJ5QHs2weoP1CKwe
Yb0Cq1dUfi3+eYu13oHVO0VaD8HqoXatl2D10gStp2D11KVab8HqLdZjsHqM
9RqsXlN7Dq5nPbdf6z1YvXe449EGqwd/qPUirF68XetJWD35lNabsHpT+35t
sHqU9SqsXlV+bbB69kytd2H17k1aD8Pq4ce0XobVy8u0nobV09u13obV2/1a
j8PqcdbrsHqd9Tysnlce7bB6X3mMf6882mH9AuXRDusnKI8OWL9BeXTA+hHs
V8D6FexnwPoZyqMD1u9QHh2wfojy6IT1S5RHJ6yfojw6Yf0W5dEJ68coj04v
L/ZzYP0c5dEJ6/cojy7/vsqjC9YvUh5dsH6S8uiC9ZuUR5fXN+XR5eXDfhas
n8V+F6zfpTy6Yf0w5dEN65cpj26vP8qjG9ZvUx49Xh7KowfWr2M/z9sn+32w
fp/y6PHnUR49sH6h8uiF9ROVR6+3F+XR6+WpPHq9vJRHL6yfyX6nt0fl0ev5
K48+Lw/l0fcPPPq8PSqPPm9PyqMP1q9VHn2wfi77vf587AfD+sHKo9+fT3n0
e/1VHv1e3sqjH9aPVh4DsH618hiA9bPZ74b1u9kP989XHgOwfrnyGPD2pTwG
vb4rj0FYP155DML69cpjENbPVx6D3j45D4DNA5THIGxeoDyGYPME5THk76c8
hmDzCOUxBJtXKI/xv5XHEGzewXmI5815CWxeovIb9vx+ofMW2LzlHp3HwOYx
j+q8BjaveV7nObB5zlKd98DmPZwHweZBnBfB5kUa74Zh86RBnTfB5k2H6TwK
No86TudVsHnVeTrPgs2zrtZ5F2zepXPeEdg8jPMy2LxM+Y3A5mmLdN4Gm7d9
oPM42DyuQOd1sHndXp3nweZ5bTrvg837VG523kqbF8LmhZwnwuaJymMUNm9U
HqOweaTyGIXNK5XHKGyeqTxGYfNO5TEKm4dyXur/5jzV/155jMLmrcpjFDaP
VR4R2LxWeURg81zlEYHNe5VHBDYPVh4R2LyY82TYPFl5RGDzZuURgc2jlUcE
Nq9WHhHYPFt5RGDzbuURgc3DlUcENi/nPN3z4rwdNm9XHlHYPF55RGHzeuUR
hc3zlUcUNu9XHlHYPoDyiHp95D4BbJ+A+wawfQPlYc8z+4jC9hWURwy2z6A8
YrB9B+URg+1DKI+Yj396XQy2T8F9C9i+hfKI+fxfecRg+xrKIwbb51AeMdi+
h/KIwfZBlEcMti+iPMbvx30T2L4J91Fg+yjKIw7bV1Eecdg+i/KIw/ZdlEcc
tg+jPOKwfRnlEYft03DfBrZvw30c2D6O8ojD9nWURxy2z6M8ErB9H+WRgO0D
KY8EbF9IeSRg+0TKIwHbN+I+EmwfSXkkYPtKyiMB22dSHgnYvpPySMD2oZRH
ArYvpTwSsH0q5ZGA7VtxHwu2j8V9Ldi+lvJIwva5lEcStu+lPJKwfTDlkYTt
iymPJGyfTHkkYftm3EeD7aNxXw22r6Y8xs+jPJKwfTflkYLtwymPFGxfTnmk
YPt0yiMF27dTHinYPh739WD7esojBdvnUx4p2L6f8kjB9gGVh52njDxSsH1C
5ZGC7RsqjxRsH5H7irB9Re4zwvYZlUcatu+oPNI+X1Eeadi+pPJIw/YplUca
tm+pPNKwfUzua8L2NbnPCdvnVB5p2L6n8kjD9kGVRwa2L6o8Mr4eVR4Z2L6p
8sjA9lGVRwa2r8p9Vtg+q/LIwPZdlUcGtg+rPDKwfVnlkYHt0yqPDGzfVnlk
YPu4yiMD29flPi9sn5f7vrB9X+UxBtsHVh5jsH1h5TEG2ydWHmOwfWPlYfdv
I48x2L4y95lh+8zcd4btO2frPjRsH/r/AQw/NGA=
               "]], 
              
              Line[{{1.8040000000000003`, 0.6}, {1.8075000000000006`, 
               0.5953333333333334}, {1.8097222222222227`, 0.6}}], 
              Line[CompressedData["
1:eJxF1X1ozVEcx/F7TynxBzMPiU2aNJTysEzieyjzuGzzB2ZbWUMSd1sRsz8W
tqKtmVYyRYbZIjNbMTWtrWbmoW3JpmkaJRozZRR+l9/3fGyfU7u3V63v75zz
vt07NzOUstcEAoED/p++lxdHPokv82SZW++lKnv1hJ5rnkS4NSAPowsHkx94
UhkuSUoI9cmLZ7o8KUoP5tY2dsq7vKl3Ngx4UhBT3tV3r01+xKaVtox4EpWa
terttibxh/kTw/Lde3ns0/w6ceOiw9KbtrEiJadKlrvnhmW9N+tqcX+RbB7Q
gWEJ/F8Z/rTYNDpXt5dNF+m4Qrrioi7a35w/kNZppS10r26vhx7ScYO0ca9/
xzzdDaQX6nFj6TXuwHSKjkum97lF5+v15dHn3QZp9KDRg0YPGj1o9KDd9Y8L
2FGf0+dNoi/p9c2kb+jzY+haPf5iulH3E0+36vbX0c91e1tp93HYQbvce+jP
ev8H6Z+6/yN0UF8K6Ik68Cw9Ta+znJ6jB75ML9DrqKbdx6+edv2a6E26wcf0
du3ZRadr/jf0fs37gc7RfMP0Cc3zi0aP4JjRg0YPGj1o9KDRg0YPGj1o9KDR
g0YPGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRw4wZPWj0oNGD
Rg8aPYz9U/OtOzEzSdDD2LpFdihuxklBD2NXNrQffXSlQtDD2GBjj/8NWSno
YexI6PTSvN1Vgh7GLhl/e3Zq1i1BD2OHb7ZtWXGmTtDD2M67+oD7gh7GunNn
Nwl6GHvdfa80C3oY2xzR8fHQrlZBD2Orddzadvwu1BtbcuHwlFPNHYIexiaE
nqZGRXYKehibOXmnf4RuQQ9jy77kS1zGK0EPY+cl1sT/Hn4t6DH6//1yvLW3
P/ersaO/P/8AvRPWkg==
               "]], 
              Line[CompressedData["
1:eJxF0SGIlgcYwPHPcTo9p1c2ZOVELA6GxWJxd1gOuTE4DRYXFNzCglsQwcGw
WCwzWERYOYSlEzHsxrCcgsWFJYth6ljRwYoIJt/v+8v7e8L78isPz/v+D5y7
cPL8B5PJ5PNtk8n0/fDgHwtfzc8tH5nNi6XrW68PnVmYW1796e4/+1b/Xrp1
c5hP55Yvzea3pdvfH5t/cnBuefJ+7qw8u/zxYf598erLtaP8YFj383H+8/Ew
X/KT9WHhaR62bayc5Vdrm4tXv+M3w7qti7xt+rjCu6cLr/EnG8OBN3j/cN7m
L/zZsO71rzz7Dff4i/lh4X0+MT3wEZ8aznv5F389rDv0lL/9Zph/+Yfh963/
zz8On/vsLU/PW9y+fXQ9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9doyuB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+ux4ej68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD67FzdD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD12ja4H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H/Oh6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB67B5dD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cj49G14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H12PP6Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hrs
HV0PrgfXg+vB9eB6cD24Hvx81oP/m/XgenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrsTC6HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD34Hb8+xWY=
               "]]}, "Charting`Private`Tag#2"], 
            Annotation[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.560181, 0.691569, 0.194885], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJxF0S1sV1cAh+F/y9fo+BI1M4UFsxkSgpkhJDOdmGkNpmYkYBCrAQHJcg0G
g8FgMExMYTA1SwhmBgRqZoaQYJYlGCZQ6z3vcp+fuXnMyTn3/frGz7s311er
1d211Wr+vvr0zd6j9XMvV//v/ubz7Xefzy7ev7rx57OPfGveB957dHjCX7x7
sPXg77f8w7t7m8//4Pm4/d/5yrwX/O184G98eNrOwVOer3fvMc/HXX3IYxP/
e/i8V3f48LStB7d5vt72Tzwft3GdX8/7kcf/+p7n5+58x/P1Ni/xr/MPvMhP
5n3F8+/bO8vzc7eOcT3OLK4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXg
enA9uB5cD64H14PrwfXgenA9Ti+uB9eD68H14O3Rg+vB9eB6cD24HlwPHpu4
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+txanE9uB5cD64H14PrwfXgenA9uB5c
Dx6buB5cD64H14PrwfXgenA9uB5cD64H14Pr8eXienA9uB5cD64H14PrwfXg
enA9uB48NvGn0YPrwfXgevCb0YPrwfXgenA9uB5cD64H12NjcT24HlwPrgfX
g+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwPrgfXg+txcnE9uB5c
D64H14PrwfXgenA9uB5cDx6buB5cD64H14PrwfXgenA9uB5cD64H14Pr8cXi
enA9uB5cD64H14PrwfXgenA9uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H
1+PE4npwPbgeXA+uB9eD68H14POjB9eD68FjE9eD68H14HpwPbgeXA+uBz8b
PbgeXA+uB9fj+OJ6cD24HrwzenA9uB5cD64H14PrwfXgsYnrwfXgenA9uB5c
D64H14PrwfXgenA9uB7HFteD68H14HpwPbgeXA+uB9eD68H14LGJ68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeRxfXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB
9eB6cD24HlwPrgfXg+vB9eB6cD24HkcW14PrwfXgenA9uB5cD64H14PrwfXg
sYnrwfXgenA9uB5cD64H14PrwfXgenA9uB7ri+vB9eB6cD24HlwPrgfXg+vB
9eB68NjE9eB6cD24HlwPrgfXg+vB9eB6cD24HlyPtcX14HpwPbgeXA+uB9eD
68H14HpwPXhs4npwPbgeXA+uB9eD68H14Hrw5a1fjv5zYe3lePeV99f+A71B
YLg=
               "]], 
              Line[CompressedData["
1:eJxd1jFoE1EYwPGzUIQiOJilChERJCo46NLBeuBSCjqkDi51UNBFwSLoEDM4
2BZUmkWEIgjSQetQ0KkU5EIWHWLHFh2kQdAhiw7Ju/fePfXuO+on/wch/CF8
/e79AumRa7dnro9EUbSYv4r3A29qz/e+jdpn5HyLj8+2OoPXUTscevnk67PP
8eH5fn39RdSOmwtX9tz5EFfWpnqNp1F7bHtlbnLsVSzvj6J29P95oD2o5QPv
aufTqvM3tXuNfOJVbRl7WftTNz8XtDvFwPPa+bR+fUK7WK9ySrsYt31Ue7k4
49qtYuB+7eJxq6PYf/An2e2dYt+edleOtuyzri1/f0V7SR5AW8Y1tG/I0Z6R
gdqTcuHasl5NW8ZVtMujLfff//2vt2RBbVmvoy3j1rTl/pa1H8pAbXncOW1Z
b1Zbxk1pn5bvnbZcX1W7/J5plx4BHgEeAR4BHgEeAR4BHtpyfXXts7JggEeA
R4BHgEcGjwweGTwyeGTwyOCRwSODRwaPDB4ZPDJ4eHh4eHh4eHh4eHh4eHh4
eHh4eHh4eHh4eHg4eDh4OHg4eDh4OHg4eDh4OHg4eDh4OHhYeFh4WHhYeFh4
WHhYeFh4WHhYeFh4WHhYeKTwSOGRwiOFRwqPFB4pPFJ4pPBI4ZHCI4WHgYeB
h4GHgYeBh4GHgYeBh4GHgYdJNqb3jZxcXCh/3ysmeXzrh1/99S4uP2WSg/dG
P77/3olLj2FycXXC/xzfjEuPYTJ96cTmueZWXHoMk/syaCfufmk1j20Mk93/
L/4CPUWE7Q==
               "]], 
              Line[CompressedData["
1:eJw9kU8og3EYx19E/i0HoxQzOZCiTJEyDzkMueCgNNIKramthgMKGRfFhQPF
ZS0O2q6vpKf2WhrLaLWhFTYlIav392sHB949xrd+PT2/er59nu9TZbIOjGcK
glChvFR9ee39LBQ5NpHi4LTp8yPOv/4JNry81rjJMWd5u2t96gHm1G7D0xzH
lmtz1l5zFCZIHOfp/xb6Rc3qWz9Hj3AcMXaHoU1xs+k5buZpAsU8BIqZ4sjR
ejlcUdx2DTSm5vghTd6WaIMgkDjuHy5Wb91cwhsZMqy7al9YG/FDmAAZdh6o
pu87zoHwvAwTY6mJMyA7N8NSbXK3oEeCHRJD09BS1NJwBg4yZHh3lRyMuySg
dW0MXbF3hcAHhGdkqDrJfB61+4HsDAwVeKtDdwE6yoVhTWPuUflwAFLbihqG
v3NBoHXzGUrEdQNUuJzmDcEjBShjZbvkViKCAElGe5W513cXAYpPlLHstN4y
0xdN30PG1q9E2Wz2Y/oeMlIcGTHY+i6696zI//f7AfR/80Q=
               "]], 
              Line[CompressedData["
1:eJw9kUsohFEYhscslKFm4RaLMRLJpSliIXxl45LNDGExciksJEOhLLBwqylT
smFDKWUzykyaUXyuoTTlOu7NjIWFS+ecmoQF//n8vPV3Vv9znve8qa3dljat
RqMxKp88C8ND+tdJgfmURxh9NnsMYwKrYrTZEwmPYCvR+RdtAt8KEqeXakNg
deyEM60CNZQQlAcH45zlAsuSNnI7+wKQRxyBEV6/tWLuAQxjEijwODbcPZp3
A5JWohP4uttxFW/0gwJTiBztLv18S/05BCQuyPE8sqhr4ewUjikcrxSapccH
HgJybM752J9u2oNFEuQ4sDmfbLp3w5TUc3AkTccqEG6Qq/1c0E7hOJI2c3K7
ugZmAnLckzrv61BMghypTvUWkF4mR/dhv3LDARAujuP7XHRlTZYPft+B4wuB
ToCe75lh19PXMj+9gEsSZHgkfzddA2ntMJwNbBebv2+AcE6m9r+DWQrD354P
6h4Mxxsjele8AXUPhhnYIOzpQXUPhrJN3cHfHgyz4jtSSndD6h4Ml4dl4RD0
Ge4/o0zsf+8fnV8LiA==
               "]], 
              Line[CompressedData["
1:eJxdmX+QVmUVx1eGKUJLLBthNAatlBodN9Oksg6aIRVhEBkRykqQleNIozQM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               "]], 
              Line[CompressedData["
1:eJw9kUsohFEYhn8WyqUs3GIxSKRByqUkvGXjko0hLMa1sNDkUigJC7eymJps
zIaaUjbUkFDuhNKUWzOuzfwWFi6dc2oIC/7v9PPV6dQ59fS835vY0mlqDVQU
JUE7dPcZ7r+CMxmy5TwiR94MC8NJ02e3Ksp9A5GLJQzGqPb4on0VDdY9f6qZ
Qft01hyp6CkMcTu6GFK268RUsg/jz5VrhjGG8fqAnqV1L+wzNAzao/bzgMUS
AjJMLYfPNtfegWjWPYYZ725B5c8NPI4ujchw0rc1G5d5jTfCPTNYnr4X+PkV
yFlROF7k+xmiJZDjwx5aVmV0wWgmQY6VYwIcoYj0CjliNzM6eit2YJIiHAft
nqiEjw20yeEYobjOVQxGEpDr+1iGTQpyyNhWJ+ZJz8HRT3r3K9iQuTia0j8P
bY0HcJ3ScHjMpXZTtwsqrc/HcRmUb5m7OMc7xfVzPf8lpF6IwOs+CbkhcQaB
0wh/52jWjd6HQMC6WyM+6H0IFMtAXr0PAbkW5a8PgbfcGNt8tar3IVAeFpg2
Ef2IPP9Q+Ouk+O/7F6BG+7E=
               "]], 
              Line[CompressedData["
1:eJw9kUsoRFEcxi8izywwpcwgC1KUR6SYjyww2WChNCSFRI28FijEzMZiSiRT
bDRYyGw9splLwjRIuUNTzIzN5DV1zzELC8453Xx1Opt/v//3/778Pkt7f6wk
SXr2+L/+m/7kWlRRIRTCipsWme0qvMZZW3dMEDujdcnKtoqan0j2VPwLjg3W
t7ZDFdmnJcOTrX54PVwqxvOHTOePCoLTmQdNARW5RvlAOlLwzWhuqqJhN23i
qf4eDMaIBDJf476DwBkI+FSR+QaVwgdBYVnifk6XB6YABxJ4MqhlqfwKPWKO
IO0k9rVn/BJj3N4ogTP4Lg/6zmHjOCvBozfaEXLKcGxwEfR1zvuHS8/AzDEg
gS4v6khpkSHOdRNEerf25grO4OP2FKL5vcAnx70RFItALsEzkyQKPr16dw2d
AFJ8sO1ZeTcoFodQWK679Bm1tzCKgynsSQZ2wj3aOa6NwsXCMTc/YECIYobH
Nu3DrPgpqm+H4jar/FofFAkLa43LI89aH1TrK4Bw2PSVekj/+/sD2NTk+g==

               "]], 
              Line[CompressedData["
1:eJxd1j9oU1EUx/HbQhGi4GAVqlARQWIFFx262PNwkYoOrYNLFRR0UbAUdKgZ
XJqCChURQQuCFP/UoaJTDbjEQYea0aqDWAUdFNEh73n/m3Of7YHfhTR8h5yc
dz8ZuuP0hdEz3Uqp6c6L35c+ztR2NXLal85XararYzPNnC73LhxamfxM7+fG
D1SWcxo+NtAaqr2jXyOL/VM/cjo6P2h/97WIZyhV0NZLPW9efmvSFv5Yb0HX
zn+383+e00BnWrtaUGN4Q/ee6ToNVZY7EwtS/88ojxuRPpuOdC3tIX0zLSj9
kNebk27wuEXp1hIf6S+TPFA658dtS6f1Kn/XOo3rl96f7kn68AoPlD7Jjzsm
PcHrjUvXedyU9N07fKTT9S1Ilx7SpYd06SFdeui1Lj2kSw/p0kODhwYPDR4a
PDR4aPDQ4KHBQ4OHBg8DHgY8DHgY8DDgYcDDgIcBDwMeBjwMeBjwsOBhwcOC
hwUPCx4WPCx4WPCw4GHBw4KHBQ8LHg48HHg48HDg4cDDgYcDDwceDjwceDjw
cODhwcODhwcPDx4ePDx4ePDw4OHBw4OHBw8PHh48AngE8AjgEcAjgEcAjwAe
ATwCeATwCOARwCOCRwSPCB4RPCJ4RPCI4BHBI4JHBI8IHhE8pNP196hstW/w
922UnuXr65N+wN+/U/opP/5e6Re8z6D0K17/oPRbXu+IdPo5HJdO3Kekf/L9
n5MueP+L0l3854r0eh54VXozX+ctlZW/u0e0nR/4nsqoVj/RNfGadvN1PFaZ
33b/+qfbH2jTk+rsumcqW/3/4h875kI/
               "]], 
              Line[CompressedData["
1:eJxF0S+sTgEYwOHv+u9e3EJQLqZQFEXBnWI2BUEhsCEICAqbKYpCUMymmE26
gkJQCApBUhRsCjblziY53/3Zed5wzp7y7j3nt+v8lZMXVk0mk+szk8n0vX/h
1ppfO2cW96/Mt8NPrx6c/bR7ZnHyf54f/XJj6z5+tXDnx4kD/HZ5z5l7R/jD
+2GO86cnw8LTPGxbOnqOf554uXDnMv8Z1r25zjPTx22emy68y9uWhgMf8I7h
vJePee+wbvkZr3zmCz40Oyx8zcemB77jU8N5Pz7y2WHdns986eIw3/na8Pue
/Oabw+d++cvT8xbWrhp9f1h3Zp4fPRxmO9eD68H14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXI/Vo+vB9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxZnQ9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA91o6uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+ux7rR9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9Vg/uh5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB4bRteD
68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9dj
4+h6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6zI6uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+ux9zoenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrwfXgemwaXQ+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXI/No+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+uxZXQ9uB5cD64H14PrwfXgevDXlR78a6UH14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cj/nR9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB/wAY+aPO
               "]]}, "Charting`Private`Tag#3"]}}, <|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-2., 2.}, {0., 0.6}}, 
             "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
             "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
             "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                PointSize[
                 Rational[1, 180]], 
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[2]], 
               Directive[
                PointSize[
                 Rational[1, 180]], 
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[2]], 
               Directive[
                PointSize[
                 Rational[1, 180]], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PlotRange" -> {{-2., 2.}, {0., 0.6}}, 
            "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.560181, 0.691569, 0.194885], 
               AbsoluteThickness[2]], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.880722, 0.611041, 0.142051], 
               AbsoluteThickness[2]], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLinePlot, "GroupHighlight" -> False|>|>]]}, 
      Annotation[{{{}, {}, 
         Annotation[{
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[
             Rational[1, 180]], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJxF1VtIVFEUxvFpNKJ9NHuwq2iKBJVRD9IFQneENIVRKWQgZjdNqgelC5GG
TJF2gTDKHiIq6CoUohkhlbFQy4eyFJprSo6KBEkIZZBQNPt8x/kWDMN/4GzO
Xr+HyThQWVjudrlcN6If8905uaykwT1XXM7UJDd7IlNJsa7KUYH7E+xDZsbY
JQ3REwbYhe1pdd/72Vsi1cnNPWxzXFUHO9tMG3u5ObCJHT2toP0O27xedSPb
HJdzmW2Pl/07er3Ok+zoaWl1R9nm9Tz72eY4tZv9wcw2tr2vTWxz3YL1bPN6
yavYD8wCM9k3zSxim/WVJLHNddNmsuExJ9bwYMODDQ82PNjwYMODDQ82PNjw
YMODDQ+2PV42PNjwYMODDQ82PNjwYMODDQ82PNjwYMODDQ82PBJjDQ82PNjw
YMOD7bE92PBgw4MNDzY82PBgw4Ntj5cNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNj4RYw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PZ42fBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PCwYg0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY
8LDk4fB4V0VwqbZ/9FoyVXvk9YnrTXrS9rBk38o/b6/t7dbwsOTRre70lmN9
Gh6WjKurNb11nzU8LCk7N+tn3t+A7rU9LDGnLYwPa3hYkuDOujA/FNbwsORj
7pn6PTPCGh6WpBaXbfi6I6ThYcns8l8vnvpCGh6W2HvICWt4WBJ3e23f4biQ
hgefh4eSxFfu0dLjIQ0PJa2jC/JrW4MaHkpOvbm7ePVgUMNDSZ49QQ0PJZmN
/V+eFQU0PJQUbK58X5wa0PBQsmJexZLcLr+Gh5Lzp+/9u7LTr+Gh5MlBsxCf
hocSex1Ffg0PJfb/ksen4aHk4qeWrI0/fI6HEr2m9OXWBL/jocS+TkbI8VCS
8u352e0pA46HkrainviksUHHQzn7H3I8lEQvH93AkOMx/X4Rx0PJxON3+esu
RRyP6eeHHQ/l7HtEd+yqr+1NV2LfO3tE/we7DLKx
            "]], 
           Line[CompressedData["
1:eJxd3HmcnEWZB/C+uwdx0QUExEVARFRUFBUWgapFRAVEAx6IiIggIAsCoovI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            "]], 
           Line[CompressedData["
1:eJxF0VlIVFEcx/FxiehczZdsEzcksIx6iBYIPX9CMjEqiwxEbdOketA2ooWh
Im2BSMqXkAoSSyhMM8I2H9LyoSyFZk3JUZFAC6EkEorO3N91fgcuw/fh/ud/
zyd9X9X2imiXy1VvnvBv585ad2+aklX2GdFN1dnKl6Ek5vaavoMxI/pxXuj0
vBVKDr06fnNh7LB+nlIzXrhOyeSDdwVrr4R011RmyfUNSh7uvzD7Z25I934w
Z7OSAnfb6IKCIe1rNAN3zbw/pM20lry9StqLemITxgb1RGFHSs1hJUnfnp7f
kjSgf5txb04oeRk9WnYsPaCjzI6uc0r06rIX+XFebYUHXlVy+VNrlvzw6MQW
s2C9kk32YI9ONet13FFi/12RVy8146aaZ/bzaPsz25VcPHXv37VtXp2jzMDX
SpYlVqbmdHl1fnhOj5LCjVXvi5N9eodZb7xfSUZ9/5cnRT5dasZlDijJtY9f
Vx4wZ0zJyc67i1cO+vURc32Nk0rCX+9u8+szZqvQtJJ4+4MCOrxeyixLkovL
13/dGtB1ZlxJguXcd0A33DJnkSXhMdXZQcfDkjkVv5498gQcD74PD0s+5pyt
LY0KOh6WxEVnXZofCDoelnP/QcfDkvLwdfz1OR6WTKi6M701nx0PS+43dKe1
Hu1zPCzZs/zP2xu7ux0PS6bd4YnNjoclTcMTXZX+JY6HJS7nwIMNDzY82PBg
w4MNDzY82PBgw4MNDzY84iINDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNj/hIw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw2NupOHB
hgcbHmx4sOHBhgcbHmx4sIdtD/Z324MNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBIiDQ82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBg
w4MNDzY82PBgw4MNDzY82PBgw4MND/Z/G6Rlkg==
            "]]}, "Charting`Private`Tag#1"], 
         Annotation[{
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            PointSize[
             Rational[1, 180]], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJxF0TGIl2UAx/G/cqd1WtdwEC0n4VJDLS4tctBygRGcS8stCbY46CKBQryL
i4uLi0uLDU5COChEcEjQUkNTS4NH4eLSYoOT9z5feT+/5eWzPDzv8/3w0tWL
l4+vVqtPjq1W8/fpy4/27xx/72D1Zje3Hu4evtpcfO38xl/3/+Nv5z3n/TtH
J/zNF59s33rxJ39xeGPr4W88H3ftFz437xF/PB/4gI9O23vyA8/Xu3GX5+PO
3+axif8/+r2n1/notO1bV3i+3u43PB+38TX/Pu9LHu/1Oc+/u/cZz9fb+pR/
nB/wLN+b9wHPz7e/yfPvbq9zPd5dXA+uB9eD68H14HpwPbgeXA+uB9eDxyau
B9eD68H14HpwPbgeXA+uB9eD68H14Hq8s7geXA+uB9eDd0cPrgfXg+vB9eB6
cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfpxfXgenA9uB5cD64H14Pr
wfXgenA9eGzienA9uB5cD64H14PrwfXgenA9uB5cD67HqcX14HpwPbgeXA+u
B9eD68H14HpwPXhs4pejB9eD68H14D9GD64H14PrwfXgenA9uB5cj43F9eB6
cD24HlwPrgfXg+vB9eB6cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfb
i+vB9eB6cD24HlwPrgfXg+vB9eB68NjE9eB6cD24HlwPrgfXg+vB9eB6cD24
HlyPtxbXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6cD24HlwPrgfXg+vB
9eB6cD24HicX14PrwfXgenA9uB5cD64Hnxk9uB5cDx6buB5cD64H14PrwfXg
enA9+P7owfXgenA9uB4nFteD68H14L3Rg+vB9eB6cD24HlwPrgePTVwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9VhfXA+uB9eD68H14HpwPbgeXA+uB9eDxyau
B9eD68H14HpwPbgeXA+uB9eD68H14HqsLa4H14PrwfXgenA9uB5cD64H14Pr
wWMT14PrwfXgenA9uB5cD64H14PrsXbw3djjnXqsHVz4/qd/37/wbOfXsz9v
frWxdjDe5dw/O68By85eEQ==
            "]], 
           Line[CompressedData["
1:eJxd1UFIVFEUxvHxQhBuyhyIKI0wwgiCDMkIORWkQUnqprIpSEyIqFGhEGsh
pUKhlSCELoo0TCksK2hc2LsomJmBSqhhWBJEMVQGzaZ6U3PPl37QBZEfyPHc
9x/erCsNF58wgUDgZOLH/a4enJ6t+mbsVj0fpNydj8aWLj+0/cnwrISuDcQy
3xq7vqA759f8GymKpNdHx41t/nJBso9NSv5cTbDn+cLfT0hu8lRHRb+xeeGX
JWmpY6JjHxvbdOPMikt2RDa6gV3Gdg3t23Z517CsrY8WRW4aa1NGPp0+PCjB
nsTEFmPvVLhJVty43CvGVmKwBNypNXbs4aadX7OfSiwzMfCssfN33cBeiboF
Txm7Zen9NSVl98Stl3/c2Fi4LqvmSKe4cckHjU3qmwrtbWuXV6OJs9/YxPLn
nt1qkwE3cLexvW78yovirluUY+zv7u8TBaWF4tYLbjY28O+4cVMZdKs7q2j3
+ELLaHfd9CX0eXfhn0mL1mvP0+hBoweNHjR60HhsNHrQ6EGjB40eNHrQ6EGj
B40eNHrQ6EGjB40eNHrQ6EGjB40eNHrQ6EGjR2DR6EGjB40eNHrQ6EGjB40e
NHrQ6EGjB40etJ5aGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRg0aP//aP/fEW
/N7tO0eP6qF1nwit/7+DvqoXoHVcDa19y+liHUhrv1xa18ukdVyQxqH1+Ufj
i57UBWldb4DWcT20Pr9Wuk4H0nrdClrXC9E6Lp/O0g9g3Nvjr77dONsg+vjS
49504u1YXNmJ929y3Pvhv67+vKEX79uY76WVlO14d6Bf0MP3ajNaxmceDQl6
+F7D0aSqB31jeH9GfK893lSYF54R9PC9FD1zcr0x9UVOs+8tfP/8BelcCqk=

            "]], 
           
           Line[{{-1.8097222222222222`, 0.6}, {-1.8074999999999999`, 
            0.5953333333333334}, {-1.8039999999999998`, 0.6}}], 
           Line[CompressedData["
1:eJxdmnmUVdWVxivGTowhSlrjEIfg2A6J4tQxtvrRJnGImuCwDNGohJaWtBqN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            "]], 
           
           Line[{{1.8040000000000003`, 0.6}, {1.8075000000000006`, 
            0.5953333333333334}, {1.8097222222222227`, 0.6}}], 
           Line[CompressedData["
1:eJxF1X1ozVEcx/F7TynxBzMPiU2aNJTysEzieyjzuGzzB2ZbWUMSd1sRsz8W
tqKtmVYyRYbZIjNbMTWtrWbmoW3JpmkaJRozZRR+l9/3fGyfU7u3V63v75zz
vt07NzOUstcEAoED/p++lxdHPokv82SZW++lKnv1hJ5rnkS4NSAPowsHkx94
UhkuSUoI9cmLZ7o8KUoP5tY2dsq7vKl3Ngx4UhBT3tV3r01+xKaVtox4EpWa
terttibxh/kTw/Lde3ns0/w6ceOiw9KbtrEiJadKlrvnhmW9N+tqcX+RbB7Q
gWEJ/F8Z/rTYNDpXt5dNF+m4Qrrioi7a35w/kNZppS10r26vhx7ScYO0ca9/
xzzdDaQX6nFj6TXuwHSKjkum97lF5+v15dHn3QZp9KDRg0YPGj1o9KDd9Y8L
2FGf0+dNoi/p9c2kb+jzY+haPf5iulH3E0+36vbX0c91e1tp93HYQbvce+jP
ev8H6Z+6/yN0UF8K6Ik68Cw9Ta+znJ6jB75ML9DrqKbdx6+edv2a6E26wcf0
du3ZRadr/jf0fs37gc7RfMP0Cc3zi0aP4JjRg0YPGj1o9KDRg0YPGj1o9KDR
g0YPGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDRw4wZPWj0oNGD
Rg8aPYz9U/OtOzEzSdDD2LpFdihuxklBD2NXNrQffXSlQtDD2GBjj/8NWSno
YexI6PTSvN1Vgh7GLhl/e3Zq1i1BD2OHb7ZtWXGmTtDD2M67+oD7gh7GunNn
Nwl6GHvdfa80C3oY2xzR8fHQrlZBD2Orddzadvwu1BtbcuHwlFPNHYIexiaE
nqZGRXYKehibOXmnf4RuQQ9jy77kS1zGK0EPY+cl1sT/Hn4t6DH6//1yvLW3
P/ersaO/P/8AvRPWkg==
            "]], 
           Line[CompressedData["
1:eJxF0SGIlgcYwPHPcTo9p1c2ZOVELA6GxWJxd1gOuTE4DRYXFNzCglsQwcGw
WCwzWERYOYSlEzHsxrCcgsWFJYth6ljRwYoIJt/v+8v7e8L78isPz/v+D5y7
cPL8B5PJ5PNtk8n0/fDgHwtfzc8tH5nNi6XrW68PnVmYW1796e4/+1b/Xrp1
c5hP55Yvzea3pdvfH5t/cnBuefJ+7qw8u/zxYf598erLtaP8YFj383H+8/Ew
X/KT9WHhaR62bayc5Vdrm4tXv+M3w7qti7xt+rjCu6cLr/EnG8OBN3j/cN7m
L/zZsO71rzz7Dff4i/lh4X0+MT3wEZ8aznv5F389rDv0lL/9Zph/+Yfh963/
zz8On/vsLU/PW9y+fXQ9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9doyuB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+ux4ej68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD67FzdD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD12ja4H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H/Oh6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB67B5dD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cj49G14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H12PP6Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hrs
HV0PrgfXg+vB9eB6cD24Hvx81oP/m/XgenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrsTC6HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD34Hb8+xWY=
            "]]}, "Charting`Private`Tag#2"], 
         Annotation[{
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            PointSize[
             Rational[1, 180]], 
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJxF0S1sV1cAh+F/y9fo+BI1M4UFsxkSgpkhJDOdmGkNpmYkYBCrAQHJcg0G
g8FgMExMYTA1SwhmBgRqZoaQYJYlGCZQ6z3vcp+fuXnMyTn3/frGz7s311er
1d211Wr+vvr0zd6j9XMvV//v/ubz7Xefzy7ev7rx57OPfGveB957dHjCX7x7
sPXg77f8w7t7m8//4Pm4/d/5yrwX/O184G98eNrOwVOer3fvMc/HXX3IYxP/
e/i8V3f48LStB7d5vt72Tzwft3GdX8/7kcf/+p7n5+58x/P1Ni/xr/MPvMhP
5n3F8+/bO8vzc7eOcT3OLK4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXg
enA9uB5cD64H14PrwfXgenA9Ti+uB9eD68H14O3Rg+vB9eB6cD24HlwPHpu4
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+txanE9uB5cD64H14PrwfXgenA9uB5c
Dx6buB5cD64H14PrwfXgenA9uB5cD64H14Pr8eXienA9uB5cD64H14PrwfXg
enA9uB48NvGn0YPrwfXgevCb0YPrwfXgenA9uB5cD64H12NjcT24HlwPrgfX
g+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwPrgfXg+txcnE9uB5c
D64H14PrwfXgenA9uB5cDx6buB5cD64H14PrwfXgenA9uB5cD64H14Pr8cXi
enA9uB5cD64H14PrwfXgenA9uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H
1+PE4npwPbgeXA+uB9eD68H14POjB9eD68FjE9eD68H14HpwPbgeXA+uBz8b
PbgeXA+uB9fj+OJ6cD24HrwzenA9uB5cD64H14PrwfXgsYnrwfXgenA9uB5c
D64H14PrwfXgenA9uB7HFteD68H14HpwPbgeXA+uB9eD68H14LGJ68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeRxfXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB
9eB6cD24HlwPrgfXg+vB9eB6cD24HkcW14PrwfXgenA9uB5cD64H14PrwfXg
sYnrwfXgenA9uB5cD64H14PrwfXgenA9uB7ri+vB9eB6cD24HlwPrgfXg+vB
9eB68NjE9eB6cD24HlwPrgfXg+vB9eB6cD24HlyPtcX14HpwPbgeXA+uB9eD
68H14HpwPXhs4npwPbgeXA+uB9eD68H14Hrw5a1fjv5zYe3lePeV99f+A71B
YLg=
            "]], 
           Line[CompressedData["
1:eJxd1jFoE1EYwPGzUIQiOJilChERJCo46NLBeuBSCjqkDi51UNBFwSLoEDM4
2BZUmkWEIgjSQetQ0KkU5EIWHWLHFh2kQdAhiw7Ju/fePfXuO+on/wch/CF8
/e79AumRa7dnro9EUbSYv4r3A29qz/e+jdpn5HyLj8+2OoPXUTscevnk67PP
8eH5fn39RdSOmwtX9tz5EFfWpnqNp1F7bHtlbnLsVSzvj6J29P95oD2o5QPv
aufTqvM3tXuNfOJVbRl7WftTNz8XtDvFwPPa+bR+fUK7WK9ySrsYt31Ue7k4
49qtYuB+7eJxq6PYf/An2e2dYt+edleOtuyzri1/f0V7SR5AW8Y1tG/I0Z6R
gdqTcuHasl5NW8ZVtMujLfff//2vt2RBbVmvoy3j1rTl/pa1H8pAbXncOW1Z
b1Zbxk1pn5bvnbZcX1W7/J5plx4BHgEeAR4BHgEeAR4BHtpyfXXts7JggEeA
R4BHgEcGjwweGTwyeGTwyOCRwSODRwaPDB4ZPDJ4eHh4eHh4eHh4eHh4eHh4
eHh4eHh4eHh4eHg4eDh4OHg4eDh4OHg4eDh4OHg4eDh4OHhYeFh4WHhYeFh4
WHhYeFh4WHhYeFh4WHhYeKTwSOGRwiOFRwqPFB4pPFJ4pPBI4ZHCI4WHgYeB
h4GHgYeBh4GHgYeBh4GHgYdJNqb3jZxcXCh/3ysmeXzrh1/99S4uP2WSg/dG
P77/3olLj2FycXXC/xzfjEuPYTJ96cTmueZWXHoMk/syaCfufmk1j20Mk93/
L/4CPUWE7Q==
            "]], 
           Line[CompressedData["
1:eJw9kU8og3EYx19E/i0HoxQzOZCiTJEyDzkMueCgNNIKramthgMKGRfFhQPF
ZS0O2q6vpKf2WhrLaLWhFTYlIav392sHB949xrd+PT2/er59nu9TZbIOjGcK
glChvFR9ee39LBQ5NpHi4LTp8yPOv/4JNry81rjJMWd5u2t96gHm1G7D0xzH
lmtz1l5zFCZIHOfp/xb6Rc3qWz9Hj3AcMXaHoU1xs+k5buZpAsU8BIqZ4sjR
ejlcUdx2DTSm5vghTd6WaIMgkDjuHy5Wb91cwhsZMqy7al9YG/FDmAAZdh6o
pu87zoHwvAwTY6mJMyA7N8NSbXK3oEeCHRJD09BS1NJwBg4yZHh3lRyMuySg
dW0MXbF3hcAHhGdkqDrJfB61+4HsDAwVeKtDdwE6yoVhTWPuUflwAFLbihqG
v3NBoHXzGUrEdQNUuJzmDcEjBShjZbvkViKCAElGe5W513cXAYpPlLHstN4y
0xdN30PG1q9E2Wz2Y/oeMlIcGTHY+i6696zI//f7AfR/80Q=
            "]], 
           Line[CompressedData["
1:eJw9kUsohFEYhscslKFm4RaLMRLJpSliIXxl45LNDGExciksJEOhLLBwqylT
smFDKWUzykyaUXyuoTTlOu7NjIWFS+ecmoQF//n8vPV3Vv9znve8qa3dljat
RqMxKp88C8ND+tdJgfmURxh9NnsMYwKrYrTZEwmPYCvR+RdtAt8KEqeXakNg
deyEM60CNZQQlAcH45zlAsuSNnI7+wKQRxyBEV6/tWLuAQxjEijwODbcPZp3
A5JWohP4uttxFW/0gwJTiBztLv18S/05BCQuyPE8sqhr4ewUjikcrxSapccH
HgJybM752J9u2oNFEuQ4sDmfbLp3w5TUc3AkTccqEG6Qq/1c0E7hOJI2c3K7
ugZmAnLckzrv61BMghypTvUWkF4mR/dhv3LDARAujuP7XHRlTZYPft+B4wuB
ToCe75lh19PXMj+9gEsSZHgkfzddA2ntMJwNbBebv2+AcE6m9r+DWQrD354P
6h4Mxxsjele8AXUPhhnYIOzpQXUPhrJN3cHfHgyz4jtSSndD6h4Ml4dl4RD0
Ge4/o0zsf+8fnV8LiA==
            "]], 
           Line[CompressedData["
1:eJxdmX+QVmUVx1eGKUJLLBthNAatlBodN9Oksg6aIRVhEBkRykqQleNIozQM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            "]], 
           Line[CompressedData["
1:eJw9kUsohFEYhn8WyqUs3GIxSKRByqUkvGXjko0hLMa1sNDkUigJC7eymJps
zIaaUjbUkFDuhNKUWzOuzfwWFi6dc2oIC/7v9PPV6dQ59fS835vY0mlqDVQU
JUE7dPcZ7r+CMxmy5TwiR94MC8NJ02e3Ksp9A5GLJQzGqPb4on0VDdY9f6qZ
Qft01hyp6CkMcTu6GFK268RUsg/jz5VrhjGG8fqAnqV1L+wzNAzao/bzgMUS
AjJMLYfPNtfegWjWPYYZ725B5c8NPI4ujchw0rc1G5d5jTfCPTNYnr4X+PkV
yFlROF7k+xmiJZDjwx5aVmV0wWgmQY6VYwIcoYj0CjliNzM6eit2YJIiHAft
nqiEjw20yeEYobjOVQxGEpDr+1iGTQpyyNhWJ+ZJz8HRT3r3K9iQuTia0j8P
bY0HcJ3ScHjMpXZTtwsqrc/HcRmUb5m7OMc7xfVzPf8lpF6IwOs+CbkhcQaB
0wh/52jWjd6HQMC6WyM+6H0IFMtAXr0PAbkW5a8PgbfcGNt8tar3IVAeFpg2
Ef2IPP9Q+Ouk+O/7F6BG+7E=
            "]], 
           Line[CompressedData["
1:eJw9kUsoRFEcxi8izywwpcwgC1KUR6SYjyww2WChNCSFRI28FijEzMZiSiRT
bDRYyGw9splLwjRIuUNTzIzN5DV1zzELC8453Xx1Opt/v//3/778Pkt7f6wk
SXr2+L/+m/7kWlRRIRTCipsWme0qvMZZW3dMEDujdcnKtoqan0j2VPwLjg3W
t7ZDFdmnJcOTrX54PVwqxvOHTOePCoLTmQdNARW5RvlAOlLwzWhuqqJhN23i
qf4eDMaIBDJf476DwBkI+FSR+QaVwgdBYVnifk6XB6YABxJ4MqhlqfwKPWKO
IO0k9rVn/BJj3N4ogTP4Lg/6zmHjOCvBozfaEXLKcGxwEfR1zvuHS8/AzDEg
gS4v6khpkSHOdRNEerf25grO4OP2FKL5vcAnx70RFItALsEzkyQKPr16dw2d
AFJ8sO1ZeTcoFodQWK679Bm1tzCKgynsSQZ2wj3aOa6NwsXCMTc/YECIYobH
Nu3DrPgpqm+H4jar/FofFAkLa43LI89aH1TrK4Bw2PSVekj/+/sD2NTk+g==

            "]], 
           Line[CompressedData["
1:eJxd1j9oU1EUx/HbQhGi4GAVqlARQWIFFx262PNwkYoOrYNLFRR0UbAUdKgZ
XJqCChURQQuCFP/UoaJTDbjEQYea0aqDWAUdFNEh73n/m3Of7YHfhTR8h5yc
dz8ZuuP0hdEz3Uqp6c6L35c+ztR2NXLal85XararYzPNnC73LhxamfxM7+fG
D1SWcxo+NtAaqr2jXyOL/VM/cjo6P2h/97WIZyhV0NZLPW9efmvSFv5Yb0HX
zn+383+e00BnWrtaUGN4Q/ee6ToNVZY7EwtS/88ojxuRPpuOdC3tIX0zLSj9
kNebk27wuEXp1hIf6S+TPFA658dtS6f1Kn/XOo3rl96f7kn68AoPlD7Jjzsm
PcHrjUvXedyU9N07fKTT9S1Ilx7SpYd06SFdeui1Lj2kSw/p0kODhwYPDR4a
PDR4aPDQ4KHBQ4OHBg8DHgY8DHgY8DDgYcDDgIcBDwMeBjwMeBjwsOBhwcOC
hwUPCx4WPCx4WPCw4GHBw4KHBQ8LHg48HHg48HDg4cDDgYcDDwceDjwceDjw
cODhwcODhwcPDx4ePDx4ePDw4OHBw4OHBw8PHh48AngE8AjgEcAjgEcAjwAe
ATwCeATwCOARwCOCRwSPCB4RPCJ4RPCI4BHBI4JHBI8IHhE8pNP196hstW/w
922UnuXr65N+wN+/U/opP/5e6Re8z6D0K17/oPRbXu+IdPo5HJdO3Kekf/L9
n5MueP+L0l3854r0eh54VXozX+ctlZW/u0e0nR/4nsqoVj/RNfGadvN1PFaZ
33b/+qfbH2jTk+rsumcqW/3/4h875kI/
            "]], 
           Line[CompressedData["
1:eJxF0S+sTgEYwOHv+u9e3EJQLqZQFEXBnWI2BUEhsCEICAqbKYpCUMymmE26
gkJQCApBUhRsCjblziY53/3Zed5wzp7y7j3nt+v8lZMXVk0mk+szk8n0vX/h
1ppfO2cW96/Mt8NPrx6c/bR7ZnHyf54f/XJj6z5+tXDnx4kD/HZ5z5l7R/jD
+2GO86cnw8LTPGxbOnqOf554uXDnMv8Z1r25zjPTx22emy68y9uWhgMf8I7h
vJePee+wbvkZr3zmCz40Oyx8zcemB77jU8N5Pz7y2WHdns986eIw3/na8Pue
/Oabw+d++cvT8xbWrhp9f1h3Zp4fPRxmO9eD68H14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXI/Vo+vB9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxZnQ9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA91o6uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+ux7rR9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9Vg/uh5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB4bRteD
68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9dj
4+h6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6zI6uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+ux9zoenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrwfXgemwaXQ+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXI/No+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+uxZXQ9uB5cD64H14PrwfXgevDXlR78a6UH14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cj/nR9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB/wAY+aPO
            "]]}, "Charting`Private`Tag#3"]}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-2., 2.}, {0., 0.6}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.560181, 0.691569, 0.194885], 
             AbsoluteThickness[2]], 
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.880722, 0.611041, 0.142051], 
             AbsoluteThickness[2]], 
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>, 
       "DynamicHighlight"]], {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"Primitive cell (T2.1); k sampling: \
\\!\\(\\*SuperscriptBox[\\(10\\), \\(5\\)]\\)\"", TraditionalForm], 
     PlotRange -> {{-2., 2.}, {0., 0.6}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"trivial\"", "\"critical\"", "\"nontrivial\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091131356996164`*^9, {3.9091151092543554`*^9, 3.9091151641818786`*^9}, 
   3.9091264885492506`*^9, 3.9101535294359417`*^9, 3.910161470725986*^9, 
   3.9101615136304626`*^9, {3.910165766576762*^9, 3.910165784706767*^9}, 
   3.910176159577746*^9, 3.9101762725578403`*^9, 3.910176357253714*^9, 
   3.9102390330161934`*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"de4ae2ee-8733-4927-b30b-0b3fdc2d60b3"]
}, Open  ]],

Cell[TextData[{
 "The full data with larger sampling is stored  as ",
 StyleBox["data/DOS/dos_{6,4}-BBH_T2.2_{1.5,1}.dat", "Input"],
 " and we can import and plot it:"
}], "Text",
 CellChangeTimes->{{3.9091134847660837`*^9, 3.9091134940495186`*^9}, {
  3.909113659447389*^9, 3.909113670420266*^9}, {3.9091257465881844`*^9, 
  3.909125770268137*^9}, {3.9091262842252073`*^9, 3.909126291202912*^9}, {
  3.9101535429748435`*^9, 3.9101535465590334`*^9}, {3.910161515340441*^9, 
  3.9101615174640436`*^9}, {3.910165801435964*^9, 3.91016580427374*^9}, {
  3.9101762316624236`*^9, 3.9101762347384768`*^9}, {3.910176321141118*^9, 
  3.910176321522131*^9}, {3.9102387503587284`*^9, 
  3.9102387646278863`*^9}},ExpressionUUID->"bef2632d-cf0f-4f4e-a654-\
c81eb26e08b4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Import", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos\>\"", "Input"], 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos_{6,4}-BBH_T2.2_{1.5,1}.dat\>\"", "Input"]}], "}"}],
        "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Import", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos\>\"", "Input"], 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos_{6,4}-BBH_T2.2_{0.77,1}.dat\>\"", "Input"]}], 
        "}"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Import", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos\>\"", "Input"], 
         StyleBox[",", "Input"], 
         StyleBox["\"\<dos_{6,4}-BBH_T2.2_{0.38,1}.dat\>\"", "Input"]}], 
        "}"}], "]"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.6"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Primitive cell (T2.2); k sampling: \!\(\*SuperscriptBox[\(10\), \
\(8\)]\)\>\""}], ",", 
   RowBox[{"PlotLegends", "->", 
    RowBox[{"{", 
     RowBox[{
     "\"\<trivial\>\"", ",", "\"\<critical\>\"", ",", "\"\<nontrivial\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.909126193404081*^9, 3.909126208623426*^9}, 
   3.909126263048504*^9, {3.909126423755125*^9, 3.909126426329094*^9}, {
   3.910153550359743*^9, 3.9101535525745273`*^9}, {3.9101542103107257`*^9, 
   3.910154210498105*^9}, {3.910161464469494*^9, 3.9101614645404596`*^9}, {
   3.910161519021552*^9, 3.9101615205223827`*^9}, {3.9101658069587917`*^9, 
   3.9101658124585643`*^9}, {3.9101658669637184`*^9, 3.9101659131198244`*^9}, 
   3.910176239097285*^9, {3.9101763159669914`*^9, 3.910176348528557*^9}, {
   3.9102387686860237`*^9, 3.910238809021721*^9}, {3.9102388408905435`*^9, 
   3.910238874655692*^9}, {3.9102389922281284`*^9, 3.910239008683799*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"a75a888b-5dd3-427a-bd30-ed9f8cfdb2a4"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, 
     InterpretationBox[{
       TagBox[{{{}, {}, 
          TagBox[{
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[
              NCache[
               Rational[1, 180], 0.005555555555555556]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]], 
            LineBox[CompressedData["
1:eJxF0VtIVFEUxvHB8qF9NKEGu2CGSGFQviiUt3aIYJAVGmoXS5M0yAcr8YK9
TKAEZQhhlCEaGKVUFmgRRbEqI1BLrXScwbLJCtIgExXRHjrnfAe/BcPwn4fF
2vOLKizNKgpyuVwN5sf6PufuSA8shInLmTMpyts6xS625ic7r/7VbMwoO+tJ
ZO3kIHt3oNrd8Za901x3+jk7zppO9hZrYRt7Y+1k5pNmtnVedQPbWpdykW2P
hz0XYy4sZ//ONA8sYVvnpR9nW+tULvtdnzkZbPO1efWpbOu5mTvY1nnuWPYt
c503mn2j0Zx1bOvvywtjW8+NDGbDY+VSw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PZ42PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PAIXWp4sOHBhgcb
Hmx4sFNsDzY82PBgw4MNDzY82PZ42PBgw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PAIWWp4sOHBhgcbHmx4sOHBhgcbHmx4sOHBhgfbHg8bHmx4sOHBhgcb
Hmx4sOHBhgcbHmx4sOHBhgcbHsZSw4MNDzY82PBgw4MNDzY82PBgw4MNDzY8
DJnIv9LjLtul7R89hsx3J2a/ONmm4WFISXt71s3kbj1pexgye3V916mJAQ0P
Q/72b7yf1vlJw8OQptzCSz1lXg0PQ6Zr9nQN3vbp17aHIQ3nwzctVvs1PAxZ
lvaybstBv4aHIcaasZRtW/0aHoakPyo/+mPOp+FhSKCgtHD3e5+GhyH7qiLW
vbju0/AwZLAi4/PVoz4NDyX+Y/MdsW6fhoeSexGHTySNjWh4KPmesfpxS92I
hoeShNH41pDUEQ0PJU2PD/VH+7waHkqm9revKir1aniYvdB3qGV6WMNDSVnl
w5GEgmENDyV3rq3tnekd0vBQ0hmUEzV/dkjDQ8mzyPzsgfQhDQ8lT1cMxicV
DTkeShYflH0sjhh2PMz7uouCSlJ9joeShX8bKrcnjzoeSq4fCCpcFfvF8VDy
5W7O5n8fxhwPJWeC3RO/Wr86HkreXD7S17834HgomQkP+5MwFXA8lDQmV7ma
L3xzPJRUhIY2R6wd1zX1ictno5TY744b1/8Bjq+3rQ==
             "]], 
            LineBox[CompressedData["
1:eJxd3HdUFNcXB/Dtu1h+lliTWNHYEjVRE1t8zx57izEx1thjjUYTNUaNPcYW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             "]], 
            LineBox[CompressedData["
1:eJxF0UtIVVEUxvGb5aC9NaHMNMyQKBTKSUKZxl6IYJAVGtlL0yQVcqAmPqhJ
gRGUEYSShWgglVJpYEkPEiojUEut9HrFtNsL0iATLbEG7et38FtwOPwni7X5
ReYUpuX6uVyuavv5/pWXti2ZiVSyeX4+mxtF25V7nZKywMD68NDPpjXZezI4
RsnVhApX/blP5lHE2YnUrUqmQ4J+xk16zYuZqIxLiUpeXjzc07vLa1732ElR
UuwfPP698aNxN9qF+5WM3k7f8O/tmLHbWpKPKqnd65ezPGbUTKQ+jDhboGTu
35ryLQkj5rdd97xUSVxnrl9Boscssje6Tiv521ryLi980GjfwvNKHi/tj43P
HTArW+yB1UqeRGTt60seMGvteQ/rlbT5pUfOnhgw0XbdTJOSW1dCu6e7B8z8
M9uUlJTfG4rLHjT2tY1FT5VMzvUcbJgaNDt8B76yvad5eW6h2+y15030K6lr
P9i7zuM2mXZd1Ii9byS2MSBxyOTn2fmm5EvKivaGqiFT7Fs4qeRO+KFj8WND
5pR9rndOyfCR2ZaYYI/xnRfhr6W/LOVDTabH+NZlBGnZXREe1lHrMdeu2gnT
4s0uzNnxxuN4aEl+UJr59bfH8dCiV41t37Rx2PHQsjjpWVX0gWHHQ0v1mZD1
f08OOx5apip33u+/6XE8tNTtz7nQVeJ2PLT86l17N6ntveOhZaZm9f3j432O
h5aC5ua06wmdjoeW2c5t+zrymxwPLeNZl7uCS8Tx0OJyBh5seLDhwYYHGx5s
eLDhwYYHGx5seLDhEbDQ8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8GDD
gw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8AhcaHiw4cGGBxsebHiw4cGGBxse
bHiw4cGGBxsebHiw4cGGBxsebHiw4cGGBxsebHiw4cGGBxsebHgsW2h4sOHB
hgcbHmx4sOHBhgcbHmx4sH/Me7D/zHuw4cGGBxsebHiw4cGGBxsebHiw4cGG
BxsebHiw4cGGR9BCw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PBg/wejhm3l
             "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
          TagBox[{
            Hue[0.9060679774997897, 0.6, 0.6], 
            Directive[
             PointSize[
              NCache[
               Rational[1, 180], 0.005555555555555556]], 
             RGBColor[0.880722, 0.611041, 0.142051], 
             AbsoluteThickness[2]], 
            LineBox[CompressedData["
1:eJxF0S1sXlUAx+F3pOWjfEysE5gRghkJwcxguiZDFIGgNYSlBhJmEIDADHPN
DGZmZluyCRBTMwgWEpJmiBkQUwsJgmUJpggMCBTvPb/lPn9z85iTc+7v9U8+
P/j0mdVq9daJ1Wr+fr19d+/xfyePVk/35c7Wo2//5kvz/uTDq/f/Ofs7H9w7
c+X4Ib/3+PL23Qd8fn3cFz/xuXnf85vzgXf4tSvH+/du8Xy9y9d4Pm7nGx6b
+N+z6wO/4r/21xf8jOfr7X3M83FbH/Kvv6z3Pq9fe3j1As/P3X+H5+ttv83f
rY979AbfuL7eqzz/vsOTPD/3zCbX45XF9eB6cD24HlwPrgfXg+vB9eB6cD14
bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfLi+vB9eB6cD24HrwzenA9uB5c
D64H14PHJq4H14PrwfXgenA9uB5cD64H14PrwfXgery0uB5cD64H14PrwfXg
enA9uB5cD64Hj01cD64H14PrwfXgenA9uB5cD64H14PrwfV4cXE9uB5cD64H
14PrwfXgenA9uB5cDx6buB58PHpwPbgeXA/+efTgenA9uB5cD64H14PrsbW4
HlwPrgfXg+vB9eB6cD24HlwPrgePTVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9XhhcT24HlwPrgfXg+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vx/OJ6cD24HlwPrgfXg+vB9eB6cD24Hjw2cT24HlwPrgfXg+vB9eB6
cD24HlwPrgfX47nF9eB6cD24HlwPrgfXg+vB9eDTowfXg8cmrgfXg+vB9eB6
cD24HlwPrgdfHz24HlwPrsezi+vB9eB6cD14b/TgenA9uB5cD64H14PHJq4H
14PrwfXgenA9uB5cD64H14PrwfXgemwurgfXg+vB9eB6cD24HlwPrgfXg+vB
YxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD02FteD68H14HpwPbgeXA+uB9eD
68H14LGJ68H14HpwPbgeXA+uB9eD68H12Di69dvNzQcHP+zWY+Po9sN3L36w
+cfuRxfO/3hqa+No/JdzT3b/B2diWms=
             "]], 
            LineBox[CompressedData["
1:eJxd1W9IU1EcxvHtSFESVKCmEAsRdBGUYImQ80RFRn8IJQ1iURb5Ql+4Fb5o
IUk1kwINNEKhpJYhyMQMZEVyTxb6QiUlcyWBLUkCJQqbgbXZvecpH+qAjA+y
3z33fOEs/XRV8Vlhs9kqzT/rc2rY9urtN6Fy9JqWXldiOPBVqOal3qSazo+y
3FozQk1VZ6SdTJ+S7sb+qPO9UCXz29zZBydlccjhnx0Tanyi/tRG94QsjPiS
ugaFKvN97riZ+lpa4zx9QuV5vjuOHhmV+jGPhXK12aPl40NyszWwQ6gufFFu
8s8Whe4KVT9WN3HH/lImW/9oFupS1q6s2++UtMa5rguVci3HaE14Jm3WqhWq
6sCF4NUvvXLBaQ6sFspRuW/lkxs90pzm8FcKtcPe0r0uOyitpxSWCeXudM35
xUNpjUs8Zs7bUvPz8M42OTJsrkNC3UtO7Xn6pkm+iJoDdwvlnU6ZP7/nirRe
tyhPqNL67RvavSVS73urULY/64E5LpxBt1grjbaOz72Wtl7XsYK+aG4vsmhf
NnrQ6EGjB40eNI6VRg8aPWj0oNGDRg8aPWj0oNGDRg8aPWj0oNGDRg8aPWj0
oNGDRg8aPWj0oNHDtmz0oNGDRg8aPWj0oNGDRg8aPWj0oNGDRg9ar1oaPWj0
oNGDRg8aPWj0oNGDRg8aPWj0oNGDRo//9h9dMv7Zb4Qe1ovW+wnR+vkBWj+v
kdbjfLTuW07rnkV0gT5wWvdy0npcEo1Fz1nnPxtftj7vMK2310/jnqRb9QHS
+rz8tH5dD62356b36wOk8TsQN0ZH1q9Z/FQn9fE54kZ17o+K4/kB3L+JcaMp
cyj3RP4j3LfRmFESPNeQVdWH+zUSM+I1A/6E9EGJHjHDWVEa2Js3hvszFDMa
Vg08bz8zKdEjZszPeIIL3R8kesSM1b5b9y9nT8tw7a/MAtN/f59+Ax4YGaI=

             "]], 
            LineBox[CompressedData["
1:eJw9mndcleUbxjEpVyn+REszR2pq5sy9LpyYmjMNrQQ0M83UzJUjcePIRa5y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             "]], 
            LineBox[CompressedData["
1:eJxF1W9Ik1EUx/HtStE/qEBNIRYiqBWUZImQei4VFf0htDSIWVlkoC+cxl60
kKSaSYEKGqFQUqIIYpmCpCSVhXuhlpJNk8BUkkCJwjSwNnvOPenvghufN8d7
7/fhWdSF/PRLymaz5Vl//D1S/DcmtTxACWZNUkX3XJzT8mrPvcc34iepwZWy
ZrguQLNTrub5li/U6fBOpz0PUNmqntf1F0fpXR+vAMXlZtYdSBqkCU/ok0Pj
AQoW9XhDonw0b03rngtQRnNhWWx+F1nDrIlBqozpTcxKfkZmnCNI7sTfuWeS
62iX2UeQBvo3rlv4WkKHx3lgkGz/19ly3iBcyNtzwSU8zgvXVPOCrc1ZA2Fz
3G7Yz9sbhmd43DSszOfissPNQHgbHzcOTjUHhtN5XBqcYxZsrs8DSw9YesDS
A5YesPSApQdsrn+FTS/ZXO962NxfJFzP/z8afsrH3wF38H6S4De8/X1wP2/v
GGweh9OwyZ0Nm5x5sNm/G7bzRzG8lgfegcP4OqvgLXzgh/BWvo5G2Dx+bbB5
vLpg8zz64JPccxDO4gv8DF/mvFNwAQ/8AV/jPAuw9LAvW3rA0gOWHrD0gKUH
LD1g6QFLD1h6wNIDlh6w9IClByw9YOkBSw9YesDSA5YesPSApQcsPWDpAUsP
WHqoZUsPWHrA0gOWHrD0UDqzdPem+oIMkh5KF0yGz17Zf5Okh9KPwiJaOz9W
kvRQOnx70Z/je2tJeijtbEqZ8aoGkh5K77FXt2yIb5b3rVtpR97BlR13W0l6
KJ1/5Grzre/tJD2sebcTXtaEvCDpofT1WB17/9Mrkh5Klw6W+B/Y35L0UFre
mz75nWhTOqXWPpcz1EvSQ+kk1y/HqRMD8r72KZ3t+dZYEfGBpIfSQ/7S85ud
fpIeSmfM7nTGHx0l6aH0mDs68lzUGEkPpasW20OLmiZorM/2fuSn0ku/T/8A
8FjkSg==
             "]], 
            LineBox[CompressedData["
1:eJxF0S1sVgcUgOGvpAVWfirGxEwJmRkJwcxgoA0TTCBGJ5aRTbAEEAhAYIbB
1GBqZgYJE2QJCsTEypKZTtSAQBGSCQgJphMYIEFxv77kPkfcm8ecnHvfQz9f
Xjm/YzKZHJmZTKbvH06e+PvT+dnlr7bn5dLaxpsvf1yYXf79yddnv517vnTr
t2E+n12+8+z23ObKX0t/XDk+//SL2eXJx3lw6sUvB47yw8XVrTPH+N9h3dpJ
fvxomNP89O6w8Hsett0/dY63zqwvrl7it8O6jWs8M33c4D3ThTf5s/vDgb/y
weG89Tt8eFj35h5v/4Y/efjau1f+4W+mB27yd8N5W0/4p+kP/I8vXhjmFV+d
LnzN14fPffGep+ctzs2NrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrsfO0fXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXYNboeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpwPbgeu0fXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX45PR9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9ZgfXQ+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXI89o+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxd3Q9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA99o2u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
x/7R9eB6cD24HlwPrgfXg+vB9eD/t3vwu+0eXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HosjK4H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD/4AHbLEzQ==
             "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
          TagBox[{
            Hue[0.1421359549995791, 0.6, 0.6], 
            Directive[
             PointSize[
              NCache[
               Rational[1, 180], 0.005555555555555556]], 
             RGBColor[0.560181, 0.691569, 0.194885], 
             AbsoluteThickness[2]], 
            LineBox[CompressedData["
1:eJxF0S+sV2UAx+Hf5Y/AFWVzl2ABnQULhUK5uFmugXIplFtkw0JQAwXKKRQL
hQLBjWkgUSgUN6aBosEEgcJklEuwSDDxO++Hnedbzp7y7n3P5/Mr31+6emC1
Wl3fWK3m782thzsv/z/xZPV+P25vPvvlX/5u3mveu/37f2de8KXHp27t/83f
vLyx9fApX1gf98NvfG7eI/5yPvABn761v/v4Z56vd+MOz8dt/8RjE789sz7w
Or/ZXV/wGs/X2/mW5+M2L/Nff653kdev3bv9Nc/P3T3P8/W2zvKv6+OefcH3
7q73Kc+/b+8Ez889dZjr8fHienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+OjxfXgenA9uB5cD94ePbgeXA+uB9eD68Fj
E9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4vrgfXg+vB9eB6cD24HlwPrgfX
g+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD0+XFwPrgfXg+vB9eB6cD24
HlwPrgfXg8cmrgfvjx5cD64H14P/GD24HlwPrgfXg+vB9eB6bC6uB9eD68H1
4HpwPbgeXA+uB9eD68FjE9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4trgfX
g+vB9eB6cD24HlwPrgfXg+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD2O
Lq4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXgenA9uB5cD64H14PrwfXg
enA9jiyuB9eD68H14HpwPbgeXA+uB58cPbgePDZxPbgeXA+uB9eD68H14Hpw
Pfju6MH14HpwPT5YXA+uB9eD68E7owfXg+vB9eB6cD24Hjw2cT24HlwPrgfX
g+vB9eB6cD24HlwPrgfX4/DienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+PQ4npwPbgeXA+uB9eD68H14HpwPbgePDZx
PbgeXA+uB9eD68H14HpwPbgeXA+uB9fj4OJ6cD24HlwPrgfXg+vB9eB6cD24
Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwPrgfX48DienA9uB5cD64H14PrwfXg
enA9uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H12NjcT24HlwPrgfXg+vB
9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24Hvx84/4nrz7beDLefe6fr94B
T9leJw==
             "]], 
            LineBox[CompressedData["
1:eJxd1j9oE2EYx/EX0cEsOsTBJaIu0cFFhILEV0WohVJoQV3ioGIXh3ZxCQ5d
olDEYhEhHSqlWqxDqCJaRbkjDiK0OGlEKJq6CAluufe/evcc+ujvhRC+cDz3
vu8nQ/ZenBi7vEUIcSP9ZN/D8bMzP1ZEfJjWN3mgOtPqPxTxwFH5ZOneJ7mn
3h1dnRfxxsLI+PLmW7mrOdip3RHxixOfe0cOPpCF9uJkZVrE4t81xZ2U04FX
udNppfoV7k6t2By8wJ2NK5zjXl9L1zD3m3468CR3Oq07OsCdba94iPt+Oq69
n7uRrd3c6WnL1R3c2XFL22D//V/Rf/vtcK/R4qb9rHLT+xe56X0z3DSuxj1O
i3uMBnIfowvnJq8yN40rcueLu5fdf/fn36b7bnPT9lrcNK7JPUcXyE33Veem
405y0/aq3KfpArnz3x03XV+Jm45b4M49AngE8AjgEcAjgEcAjwAeATy46bgV
btpeOYBHAI8AHh48PHh48PDg4cHDg4cHDw8eHjw8eHjw8ODhwMOBhwMPBx4O
PBx4OPBw4OHAw4GHAw8HHg48LHhY8LDgYcHDgocFDwseFjwseFjwsOBhwcOA
hwEPAx4GPAx4GPAw4GHAw4CHAQ8DHgY8DHho8NDgocFDg4cGDw0eGjw0eGjw
0OChwUODhwIPBR4KPBR4KPBQ4KHAQ4GHAg8FHiq6NnTp6a1H12XuoaLGxtSr
U5uPZf6Uirbf3dn4crYlc48kGtn3YXpodl3mHkn0/f3tiXdbP8rcI4kWesdX
Xi9/leeXnlduvkyiP/8vfgM9KYmy
             "]], 
            LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbX65g69l19f9xmDw2H6HXOvrwB1f98/aKjLh2/9H
9ksKbLmuL/66f96s07xtVg/t+w991Yjp/7pfdseHlZ3a9+2rRNa5P6z6ut/N
MM2im+WOfRoYfN0/OWtTJAfrTfsgsIFf98doxdR8N7lmDzKtwPbrfv7fWs94
5162BxoGNPHrfmGlz7df+Vy0Bxsn8nW/pq5nt8Luc/YMYPB1/27XhDX5Caft
3wSCDPyy/4Ls9Zmhm07Yg0zjuv5l/7bLL4MXTjlmD3beoS/7K6uW6jjLHLUH
G7fuy/7+hicb+KKO2M+aCQJf9nPVRDTN9z5iD/KtXOuX/Umhqwz5pI/ag71b
8GX/s9x6x6dFx+zBzov5sr84K33GraAT9h4g49y/7J/lHMStOvmUPSTcvuzP
dp39+I7aWXtw8Ml92d/IziZgJ3LBHuxdLqD+jIlva/ZftP8G9vDn/UeUP34q
WXfZHmzcw8/751Vavtn3+Kr9GTD4vP/Xpdvzu9tuQOPj836RYmX7r0p3oPHx
ef9ZzXepJ+QeQOPj8/6jVqH70p88tPedL+24qf4zPD4B/UD+Iw==
             "]], 
            LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQzdV/3ymn8dN+YzB4bF9gy3V9ccGn/duz9fuVZjyy
j+k/9FUj5tP+sqrTh46ceWjv8bBKZJ37p/0h7GlF4XMe2EP0fdp/K/KLH+ud
u/Zyra8Dd8h92i+2c1dZTd8te5Bptlyf9v/LTpOySr5u/00DZOLH/ZFfEi/I
5FyxBxv38OP+0AYmpg1TLtqfAYOP+9umzA/5XXLWfgfYwI/7t35aeoor4oj9
ErADP+63/ThHV2HLFnuw8/o/7t+yYbnsv1mb7MHGVX3cLxNj9cwmebN9Ghh8
3D/j767Lc9W32QeBDfy4/4jc20ne33bZg71r+3H/9sJ5R35JHrQHO0/j4/6m
ObLTPm86Zg82TuTjfmfZsB1Plc/aM4DBx/3CEjcCwp9ctH8TCDLww37Nm9eX
c3pctQd79/qH/cU671exn7lhD3beoQ/75++63xfbf9sebNy6D/unrGvbWBR6
137WTBD4sL+wa+F6Y4n79uDga/2w/xC3qaxI+gNofHzYn5Z09vZr84fQ+Piw
PyQtdtsGxkfQ+Piw38/SMszmxCP7pftKvmvafIDHJwDo5gA/
             "]], 
            LineBox[CompressedData["
1:eJxdmX9wVNUVxwOl/qSOgECACYVWJaWtOqUIUuiJMAUclEr4WQuYIli0A1gK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             "]], 
            LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQvWRfyXdNmw/2xmDw2N7jYZXIOvcP9n6WlmE2Jx7Z
x/Uf+qoR88E+JC122wbGR/ZFtlzXFxd8sE9LOnv7tflD+7bXgTvkWj/YH+I2
lRVJf2A/ayYIfLAv7Fq43ljivv06d5CBH+ynrGvbWBR61x5kWv+hD/bzd93v
i+2/bX9tcQHQxA/2xTrvV7GfuWH/BmTc6w/2mjevL+f0uGoPciMDw0d7YYkb
AeFPLtqLgQ38aO8sG7bjqfJZe60YkAM/2jfNkZ32edMxezuQ82w/2m8vnHfk
l+RB+yCQcYEf7Y/IvZ3k/W2XfRoYfLSf8XfX5bnq2+xBvn1Y9dFeJsbqmU3y
ZvsJYAd+tN+yYbnsv1mb7JeBnLf4o73txzm6Clu22O8CGbfjo/3WT0tPcUUc
sT93BgQ+2rdNmR/yu+Ss/SOwgR/tQxuYmDZMuWj/DeTdrx/tI78kXpDJuWIP
dh7XJ/t/2WlSVsnX7cHGyX2yF9u5q6ym75a9ETgePtnfivzix3rnLjQ+PtmH
sKcVhc95AI2PT/ZlVacPHTnzEBofn+y3Z+v3K814ZM/df98pp/ETPD4BLQTx
Rg==
             "]], 
            LineBox[CompressedData["
1:eJw9kV8o63EYxn+dOERGWW7YOoeIcS78uUDxJPkXLkwrtCQ1TpMIN9ZqnI5F
u5iTc8HEkiiStCJR1Nq0/Avr2Dm2YoZy/Am/75fiwvl9f63z1Nt79X56nvf5
3Nyh1HzgOE4uDNvV1vgim4FHtqgAhu00VW3m4cxXbbRe+DHbWRDhmeaxl3av
ccnPsCYfuKlZ5SHtTgJN9GF/l4nH65HXajL+xrlOuljm5zHZm3e7EfiFZ4Fm
pzwcSY9PPYtuCDCBSND99cedfvMQIk5O0B/2MaZQeoAs0QdBW8l4wJeyh3I/
AxJYipWRySPbaDQzg8K9tnX0ROlCF7PXSXDVbii67NqCkeEGCJpV85mSeCcs
Y0wEEfq6b9ZKBwRzApDA3HexJGlwQIxrJ+jVzWQUJzhxzOx5CFbc17VTP7dw
y3A3BAcyz5jK5gL7GcdRrJc0LXQ07SBOBFKkfakwfVrfh4LFTaWITeS9f6sO
USgGpoh+U1xFTbihZLgaCrVCrX/JOUaLKIoRra0+PPQPxPfpKEozW3JNIb5g
HxSy1Ye5ofTTYB8Uk5adKGO+P9gHhWVZOvz8fo4896Dk+xr93+c/VEbvPA==

             "]], 
            LineBox[CompressedData["
1:eJxd1j9I1HEYx/FvUUPXUIMFLUa1mENDEQhhz68IShBBoVosqMilQQlapMFF
BYn+EcE1FCIe2WAWUSoFcQ0RZE1pBFJeS9DR5l3f/93z/aUPfL5wd7yX557f
93XD7bnY33N5o1JqtPHiz3OlV+035mt0KJ2fVF5t6b1VrtF4NZt5M/WDFicG
2gtLNfr1+U7/h02LVO2ebR7+XaOuvV/GOu4uEM9Qqk5b7m8vfj9Tpp3TJ1cG
m+pUXB56faLyjFob01Zb6nS949KLm09G6GhhqTGxTur/6eFx3dJ96UgPNvFA
6dtpQekSrzchPc/jZqU/feQjXUkDpWv8uKvSab3C3/VO45qlD6Z7kj61wgOl
z/Pj9kpf5fUGpEd43LD0gyIf6XR909K5h3TuIZ17SOceer1zD+ncQzr30OCh
wUODhwYPDR4aPDR4aPDQ4KHBw4CHAQ8DHgY8DHgY8DDgYcDDgIcBDwMeBjws
eFjwsOBhwcOChwUPCx4WPCx4WPCw4GHBw4KHAw8HHg48HHg48HDg4cDDgYcD
DwceDjwceHjw8ODhwcODhwcPDx4ePDx4ePDw4OHBw4OHB48AHgE8AngE8Ajg
EcAjgEcAjwAeATwCeATwiOARwSOCRwSPCB4RPCJ4RPCI4BHBI4JHBA/pdP2b
VbbW6Xq3Saf72yU9yd+/T/opP/4B6Tnep036Ha9/XHqB1+uUTj+Hs9KJ+4J0
4rwinfa/Jr2B34akt/LAMekdfJ33VDZ37Fv1cOsk7eYHfqiy5fGuvqnKe9rP
1/FYZW1H6Hnp0VfqfPvy9J8Zla39v/gHXLhGjA==
             "]], 
            LineBox[CompressedData["
1:eJxF0S2sjnEYwOH39f1tM4JyMIWiKIoxhaAcgkJgQxAQFIqiKIpCsJnZpCMo
BIWgEKQzm2JMOYKCTfK852fPdYfn2VXu3f/99ly4euriislkcmM6mcz+n6aP
t33bPT16cHm+Hnl67fCGxb3To5P/8/z4l5vbD/CruTtL84f47a99Z+8d4w/v
hznJi0+GhWd42LZw/Dwvzb+cu3OFfw/r3tzg6exzmzfOFt7lHQvDgfd513De
y0e8f1j36xkvP/MFD699cu01n5gd+I5PD+ctfeRzw7p9n/nypWG+8/XZwp98
a3jul788O29u9YrRs3Vnt/LDB8Ps5HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD67FydD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD1Wja4H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H6tH14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1WDO6HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HmtH14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H12Pd6HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HqsH10P
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlyP
DaPrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrsXF0PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPTaNrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrsfm0fXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXYMroeXA+uB9eD68H14HpwPbge/GO5B/9Z7sH14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+ux9bR9eB6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB/wA6bqQn
             "]]}, Annotation[#, "Charting`Private`Tag#3"]& ]}}, {
        "WolframDynamicHighlight", <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
       DynamicBox[
        (Charting`HighlightActionBox["DynamicHighlight", {}, 
         Slot["HighlightElements"], 
         Slot["LayoutOptions"], 
         Slot["Meta"], 
         Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
            Annotation[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJxF0VtIVFEUxvHB8qF9NKEGu2CGSGFQviiUt3aIYJAVGmoXS5M0yAcr8YK9
TKAEZQhhlCEaGKVUFmgRRbEqI1BLrXScwbLJCtIgExXRHjrnfAe/BcPwn4fF
2vOLKizNKgpyuVwN5sf6PufuSA8shInLmTMpyts6xS625ic7r/7VbMwoO+tJ
ZO3kIHt3oNrd8Za901x3+jk7zppO9hZrYRt7Y+1k5pNmtnVedQPbWpdykW2P
hz0XYy4sZ//ONA8sYVvnpR9nW+tULvtdnzkZbPO1efWpbOu5mTvY1nnuWPYt
c503mn2j0Zx1bOvvywtjW8+NDGbDY+VSw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PZ42PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PAIXWp4sOHBhgcb
Hmx4sFNsDzY82PBgw4MNDzY82PZ42PBgw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PAIWWp4sOHBhgcbHmx4sOHBhgcbHmx4sOHBhgfbHg8bHmx4sOHBhgcb
Hmx4sOHBhgcbHmx4sOHBhgcbHsZSw4MNDzY82PBgw4MNDzY82PBgw4MNDzY8
DJnIv9LjLtul7R89hsx3J2a/ONmm4WFISXt71s3kbj1pexgye3V916mJAQ0P
Q/72b7yf1vlJw8OQptzCSz1lXg0PQ6Zr9nQN3vbp17aHIQ3nwzctVvs1PAxZ
lvaybstBv4aHIcaasZRtW/0aHoakPyo/+mPOp+FhSKCgtHD3e5+GhyH7qiLW
vbju0/AwZLAi4/PVoz4NDyX+Y/MdsW6fhoeSexGHTySNjWh4KPmesfpxS92I
hoeShNH41pDUEQ0PJU2PD/VH+7waHkqm9revKir1aniYvdB3qGV6WMNDSVnl
w5GEgmENDyV3rq3tnekd0vBQ0hmUEzV/dkjDQ8mzyPzsgfQhDQ8lT1cMxicV
DTkeShYflH0sjhh2PMz7uouCSlJ9joeShX8bKrcnjzoeSq4fCCpcFfvF8VDy
5W7O5n8fxhwPJWeC3RO/Wr86HkreXD7S17834HgomQkP+5MwFXA8lDQmV7ma
L3xzPJRUhIY2R6wd1zX1ictno5TY744b1/8Bjq+3rQ==
               "]], 
              Line[CompressedData["
1:eJxd3HdUFNcXB/Dtu1h+lliTWNHYEjVRE1t8zx57izEx1thjjUYTNUaNPcYW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               "]], 
              Line[CompressedData["
1:eJxF0UtIVVEUxvGb5aC9NaHMNMyQKBTKSUKZxl6IYJAVGtlL0yQVcqAmPqhJ
gRGUEYSShWgglVJpYEkPEiojUEut9HrFtNsL0iATLbEG7et38FtwOPwni7X5
ReYUpuX6uVyuavv5/pWXti2ZiVSyeX4+mxtF25V7nZKywMD68NDPpjXZezI4
RsnVhApX/blP5lHE2YnUrUqmQ4J+xk16zYuZqIxLiUpeXjzc07vLa1732ElR
UuwfPP698aNxN9qF+5WM3k7f8O/tmLHbWpKPKqnd65ezPGbUTKQ+jDhboGTu
35ryLQkj5rdd97xUSVxnrl9Boscssje6Tiv521ryLi980GjfwvNKHi/tj43P
HTArW+yB1UqeRGTt60seMGvteQ/rlbT5pUfOnhgw0XbdTJOSW1dCu6e7B8z8
M9uUlJTfG4rLHjT2tY1FT5VMzvUcbJgaNDt8B76yvad5eW6h2+y15030K6lr
P9i7zuM2mXZd1Ii9byS2MSBxyOTn2fmm5EvKivaGqiFT7Fs4qeRO+KFj8WND
5pR9rndOyfCR2ZaYYI/xnRfhr6W/LOVDTabH+NZlBGnZXREe1lHrMdeu2gnT
4s0uzNnxxuN4aEl+UJr59bfH8dCiV41t37Rx2PHQsjjpWVX0gWHHQ0v1mZD1
f08OOx5apip33u+/6XE8tNTtz7nQVeJ2PLT86l17N6ntveOhZaZm9f3j432O
h5aC5ua06wmdjoeW2c5t+zrymxwPLeNZl7uCS8Tx0OJyBh5seLDhwYYHGx5s
eLDhwYYHGx5seLDhEbDQ8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8GDD
gw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8AhcaHiw4cGGBxsebHiw4cGGBxse
bHiw4cGGBxsebHiw4cGGBxsebHiw4cGGBxsebHiw4cGGBxsebHgsW2h4sOHB
hgcbHmx4sOHBhgcbHmx4sH/Me7D/zHuw4cGGBxsebHiw4cGGBxsebHiw4cGG
BxsebHiw4cGGR9BCw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PBg/wejhm3l
               "]]}, "Charting`Private`Tag#1"], 
            Annotation[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.880722, 0.611041, 0.142051], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJxF0S1sXlUAx+F3pOWjfEysE5gRghkJwcxguiZDFIGgNYSlBhJmEIDADHPN
DGZmZluyCRBTMwgWEpJmiBkQUwsJgmUJpggMCBTvPb/lPn9z85iTc+7v9U8+
P/j0mdVq9daJ1Wr+fr19d+/xfyePVk/35c7Wo2//5kvz/uTDq/f/Ofs7H9w7
c+X4Ib/3+PL23Qd8fn3cFz/xuXnf85vzgXf4tSvH+/du8Xy9y9d4Pm7nGx6b
+N+z6wO/4r/21xf8jOfr7X3M83FbH/Kvv6z3Pq9fe3j1As/P3X+H5+ttv83f
rY979AbfuL7eqzz/vsOTPD/3zCbX45XF9eB6cD24HlwPrgfXg+vB9eB6cD14
bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfLi+vB9eB6cD24HrwzenA9uB5c
D64H14PHJq4H14PrwfXgenA9uB5cD64H14PrwfXgery0uB5cD64H14PrwfXg
enA9uB5cD64Hj01cD64H14PrwfXgenA9uB5cD64H14PrwfV4cXE9uB5cD64H
14PrwfXgenA9uB5cDx6buB58PHpwPbgeXA/+efTgenA9uB5cD64H14PrsbW4
HlwPrgfXg+vB9eB6cD24HlwPrgePTVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9XhhcT24HlwPrgfXg+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vx/OJ6cD24HlwPrgfXg+vB9eB6cD24Hjw2cT24HlwPrgfXg+vB9eB6
cD24HlwPrgfX47nF9eB6cD24HlwPrgfXg+vB9eDTowfXg8cmrgfXg+vB9eB6
cD24HlwPrgdfHz24HlwPrsezi+vB9eB6cD14b/TgenA9uB5cD64H14PHJq4H
14PrwfXgenA9uB5cD64H14PrwfXgemwurgfXg+vB9eB6cD24HlwPrgfXg+vB
YxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD02FteD68H14HpwPbgeXA+uB9eD
68H14LGJ68H14HpwPbgeXA+uB9eD68H12Di69dvNzQcHP+zWY+Po9sN3L36w
+cfuRxfO/3hqa+No/JdzT3b/B2diWms=
               "]], 
              Line[CompressedData["
1:eJxd1W9IU1EcxvHtSFESVKCmEAsRdBGUYImQ80RFRn8IJQ1iURb5Ql+4Fb5o
IUk1kwINNEKhpJYhyMQMZEVyTxb6QiUlcyWBLUkCJQqbgbXZvecpH+qAjA+y
3z33fOEs/XRV8Vlhs9kqzT/rc2rY9urtN6Fy9JqWXldiOPBVqOal3qSazo+y
3FozQk1VZ6SdTJ+S7sb+qPO9UCXz29zZBydlccjhnx0Tanyi/tRG94QsjPiS
ugaFKvN97riZ+lpa4zx9QuV5vjuOHhmV+jGPhXK12aPl40NyszWwQ6gufFFu
8s8Whe4KVT9WN3HH/lImW/9oFupS1q6s2++UtMa5rguVci3HaE14Jm3WqhWq
6sCF4NUvvXLBaQ6sFspRuW/lkxs90pzm8FcKtcPe0r0uOyitpxSWCeXudM35
xUNpjUs8Zs7bUvPz8M42OTJsrkNC3UtO7Xn6pkm+iJoDdwvlnU6ZP7/nirRe
tyhPqNL67RvavSVS73urULY/64E5LpxBt1grjbaOz72Wtl7XsYK+aG4vsmhf
NnrQ6EGjB40eNI6VRg8aPWj0oNGDRg8aPWj0oNGDRg8aPWj0oNGDRg8aPWj0
oNGDRg8aPWj0oNHDtmz0oNGDRg8aPWj0oNGDRg8aPWj0oNGDRg9ar1oaPWj0
oNGDRg8aPWj0oNGDRg8aPWj0oNGDRo//9h9dMv7Zb4Qe1ovW+wnR+vkBWj+v
kdbjfLTuW07rnkV0gT5wWvdy0npcEo1Fz1nnPxtftj7vMK2310/jnqRb9QHS
+rz8tH5dD62356b36wOk8TsQN0ZH1q9Z/FQn9fE54kZ17o+K4/kB3L+JcaMp
cyj3RP4j3LfRmFESPNeQVdWH+zUSM+I1A/6E9EGJHjHDWVEa2Js3hvszFDMa
Vg08bz8zKdEjZszPeIIL3R8kesSM1b5b9y9nT8tw7a/MAtN/f59+Ax4YGaI=

               "]], 
              Line[CompressedData["
1:eJw9mndcleUbxjEpVyn+REszR2pq5sy9LpyYmjMNrQQ0M83UzJUjcePIRa5y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               "]], 
              Line[CompressedData["
1:eJxF1W9Ik1EUx/HtStE/qEBNIRYiqBWUZImQei4VFf0htDSIWVlkoC+cxl60
kKSaSYEKGqFQUqIIYpmCpCSVhXuhlpJNk8BUkkCJwjSwNnvOPenvghufN8d7
7/fhWdSF/PRLymaz5Vl//D1S/DcmtTxACWZNUkX3XJzT8mrPvcc34iepwZWy
ZrguQLNTrub5li/U6fBOpz0PUNmqntf1F0fpXR+vAMXlZtYdSBqkCU/ok0Pj
AQoW9XhDonw0b03rngtQRnNhWWx+F1nDrIlBqozpTcxKfkZmnCNI7sTfuWeS
62iX2UeQBvo3rlv4WkKHx3lgkGz/19ly3iBcyNtzwSU8zgvXVPOCrc1ZA2Fz
3G7Yz9sbhmd43DSszOfissPNQHgbHzcOTjUHhtN5XBqcYxZsrs8DSw9YesDS
A5YesPSApQdsrn+FTS/ZXO962NxfJFzP/z8afsrH3wF38H6S4De8/X1wP2/v
GGweh9OwyZ0Nm5x5sNm/G7bzRzG8lgfegcP4OqvgLXzgh/BWvo5G2Dx+bbB5
vLpg8zz64JPccxDO4gv8DF/mvFNwAQ/8AV/jPAuw9LAvW3rA0gOWHrD0gKUH
LD1g6QFLD1h6wNIDlh6w9IClByw9YOkBSw9YesDSA5YesPSApQcsPWDpAUsP
WHqoZUsPWHrA0gOWHrD0UDqzdPem+oIMkh5KF0yGz17Zf5Okh9KPwiJaOz9W
kvRQOnx70Z/je2tJeijtbEqZ8aoGkh5K77FXt2yIb5b3rVtpR97BlR13W0l6
KJ1/5Grzre/tJD2sebcTXtaEvCDpofT1WB17/9Mrkh5Klw6W+B/Y35L0UFre
mz75nWhTOqXWPpcz1EvSQ+kk1y/HqRMD8r72KZ3t+dZYEfGBpIfSQ/7S85ud
fpIeSmfM7nTGHx0l6aH0mDs68lzUGEkPpasW20OLmiZorM/2fuSn0ku/T/8A
8FjkSg==
               "]], 
              Line[CompressedData["
1:eJxF0S1sVgcUgOGvpAVWfirGxEwJmRkJwcxgoA0TTCBGJ5aRTbAEEAhAYIbB
1GBqZgYJE2QJCsTEypKZTtSAQBGSCQgJphMYIEFxv77kPkfcm8ecnHvfQz9f
Xjm/YzKZHJmZTKbvH06e+PvT+dnlr7bn5dLaxpsvf1yYXf79yddnv517vnTr
t2E+n12+8+z23ObKX0t/XDk+//SL2eXJx3lw6sUvB47yw8XVrTPH+N9h3dpJ
fvxomNP89O6w8Hsett0/dY63zqwvrl7it8O6jWs8M33c4D3ThTf5s/vDgb/y
weG89Tt8eFj35h5v/4Y/efjau1f+4W+mB27yd8N5W0/4p+kP/I8vXhjmFV+d
LnzN14fPffGep+ctzs2NrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrsfO0fXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXYNboeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpwPbgeu0fXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX45PR9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9ZgfXQ+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXI89o+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxd3Q9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA99o2u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
x/7R9eB6cD24HlwPrgfXg+vB9eD/t3vwu+0eXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HosjK4H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD/4AHbLEzQ==
               "]]}, "Charting`Private`Tag#2"], 
            Annotation[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.560181, 0.691569, 0.194885], 
               AbsoluteThickness[2]], 
              Line[CompressedData["
1:eJxF0S+sV2UAx+Hf5Y/AFWVzl2ABnQULhUK5uFmugXIplFtkw0JQAwXKKRQL
hQLBjWkgUSgUN6aBosEEgcJklEuwSDDxO++Hnedbzp7y7n3P5/Mr31+6emC1
Wl3fWK3m782thzsv/z/xZPV+P25vPvvlX/5u3mveu/37f2de8KXHp27t/83f
vLyx9fApX1gf98NvfG7eI/5yPvABn761v/v4Z56vd+MOz8dt/8RjE789sz7w
Or/ZXV/wGs/X2/mW5+M2L/Nff653kdev3bv9Nc/P3T3P8/W2zvKv6+OefcH3
7q73Kc+/b+8Ez889dZjr8fHienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+OjxfXgenA9uB5cD94ePbgeXA+uB9eD68Fj
E9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4vrgfXg+vB9eB6cD24HlwPrgfX
g+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD0+XFwPrgfXg+vB9eB6cD24
HlwPrgfXg8cmrgfvjx5cD64H14P/GD24HlwPrgfXg+vB9eB6bC6uB9eD68H1
4HpwPbgeXA+uB9eD68FjE9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4trgfX
g+vB9eB6cD24HlwPrgfXg+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD2O
Lq4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXgenA9uB5cD64H14PrwfXg
enA9jiyuB9eD68H14HpwPbgeXA+uB58cPbgePDZxPbgeXA+uB9eD68H14Hpw
Pfju6MH14HpwPT5YXA+uB9eD68E7owfXg+vB9eB6cD24Hjw2cT24HlwPrgfX
g+vB9eB6cD24HlwPrgfX4/DienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+PQ4npwPbgeXA+uB9eD68H14HpwPbgePDZx
PbgeXA+uB9eD68H14HpwPbgeXA+uB9fj4OJ6cD24HlwPrgfXg+vB9eB6cD24
Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwPrgfX48DienA9uB5cD64H14PrwfXg
enA9uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H12NjcT24HlwPrgfXg+vB
9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24Hvx84/4nrz7beDLefe6fr94B
T9leJw==
               "]], 
              Line[CompressedData["
1:eJxd1j9oE2EYx/EX0cEsOsTBJaIu0cFFhILEV0WohVJoQV3ioGIXh3ZxCQ5d
olDEYhEhHSqlWqxDqCJaRbkjDiK0OGlEKJq6CAluufe/evcc+ujvhRC+cDz3
vu8nQ/ZenBi7vEUIcSP9ZN/D8bMzP1ZEfJjWN3mgOtPqPxTxwFH5ZOneJ7mn
3h1dnRfxxsLI+PLmW7mrOdip3RHxixOfe0cOPpCF9uJkZVrE4t81xZ2U04FX
udNppfoV7k6t2By8wJ2NK5zjXl9L1zD3m3468CR3Oq07OsCdba94iPt+Oq69
n7uRrd3c6WnL1R3c2XFL22D//V/Rf/vtcK/R4qb9rHLT+xe56X0z3DSuxj1O
i3uMBnIfowvnJq8yN40rcueLu5fdf/fn36b7bnPT9lrcNK7JPUcXyE33Veem
405y0/aq3KfpArnz3x03XV+Jm45b4M49AngE8AjgEcAjgEcAjwAeATy46bgV
btpeOYBHAI8AHh48PHh48PDg4cHDg4cHDw8eHjw8eHjw8ODhwMOBhwMPBx4O
PBx4OPBw4OHAw4GHAw8HHg48LHhY8LDgYcHDgocFDwseFjwseFjwsOBhwcOA
hwEPAx4GPAx4GPAw4GHAw4CHAQ8DHgY8DHho8NDgocFDg4cGDw0eGjw0eGjw
0OChwUODhwIPBR4KPBR4KPBQ4KHAQ4GHAg8FHiq6NnTp6a1H12XuoaLGxtSr
U5uPZf6Uirbf3dn4crYlc48kGtn3YXpodl3mHkn0/f3tiXdbP8rcI4kWesdX
Xi9/leeXnlduvkyiP/8vfgM9KYmy
               "]], 
              Line[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbX65g69l19f9xmDw2H6HXOvrwB1f98/aKjLh2/9H
9ksKbLmuL/66f96s07xtVg/t+w991Yjp/7pfdseHlZ3a9+2rRNa5P6z6ut/N
MM2im+WOfRoYfN0/OWtTJAfrTfsgsIFf98doxdR8N7lmDzKtwPbrfv7fWs94
5162BxoGNPHrfmGlz7df+Vy0Bxsn8nW/pq5nt8Luc/YMYPB1/27XhDX5Caft
3wSCDPyy/4Ls9Zmhm07Yg0zjuv5l/7bLL4MXTjlmD3beoS/7K6uW6jjLHLUH
G7fuy/7+hicb+KKO2M+aCQJf9nPVRDTN9z5iD/KtXOuX/Umhqwz5pI/ag71b
8GX/s9x6x6dFx+zBzov5sr84K33GraAT9h4g49y/7J/lHMStOvmUPSTcvuzP
dp39+I7aWXtw8Ml92d/IziZgJ3LBHuxdLqD+jIlva/ZftP8G9vDn/UeUP34q
WXfZHmzcw8/751Vavtn3+Kr9GTD4vP/Xpdvzu9tuQOPj836RYmX7r0p3oPHx
ef9ZzXepJ+QeQOPj8/6jVqH70p88tPedL+24qf4zPD4B/UD+Iw==
               "]], 
              Line[CompressedData["
1:eJxTTMoPSmViYGCQA2IQzdV/3ymn8dN+YzB4bF9gy3V9ccGn/duz9fuVZjyy
j+k/9FUj5tP+sqrTh46ceWjv8bBKZJ37p/0h7GlF4XMe2EP0fdp/K/KLH+ud
u/Zyra8Dd8h92i+2c1dZTd8te5Bptlyf9v/LTpOySr5u/00DZOLH/ZFfEi/I
5FyxBxv38OP+0AYmpg1TLtqfAYOP+9umzA/5XXLWfgfYwI/7t35aeoor4oj9
ErADP+63/ThHV2HLFnuw8/o/7t+yYbnsv1mb7MHGVX3cLxNj9cwmebN9Ghh8
3D/j767Lc9W32QeBDfy4/4jc20ne33bZg71r+3H/9sJ5R35JHrQHO0/j4/6m
ObLTPm86Zg82TuTjfmfZsB1Plc/aM4DBx/3CEjcCwp9ctH8TCDLww37Nm9eX
c3pctQd79/qH/cU671exn7lhD3beoQ/75++63xfbf9sebNy6D/unrGvbWBR6
137WTBD4sL+wa+F6Y4n79uDga/2w/xC3qaxI+gNofHzYn5Z09vZr84fQ+Piw
PyQtdtsGxkfQ+Piw38/SMszmxCP7pftKvmvafIDHJwDo5gA/
               "]], 
              Line[CompressedData["
1:eJxdmX9wVNUVxwOl/qSOgECACYVWJaWtOqUIUuiJMAUclEr4WQuYIli0A1gK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               "]], 
              Line[CompressedData["
1:eJxTTMoPSmViYGCQA2IQvWRfyXdNmw/2xmDw2N7jYZXIOvcP9n6WlmE2Jx7Z
x/Uf+qoR88E+JC122wbGR/ZFtlzXFxd8sE9LOnv7tflD+7bXgTvkWj/YH+I2
lRVJf2A/ayYIfLAv7Fq43ljivv06d5CBH+ynrGvbWBR61x5kWv+hD/bzd93v
i+2/bX9tcQHQxA/2xTrvV7GfuWH/BmTc6w/2mjevL+f0uGoPciMDw0d7YYkb
AeFPLtqLgQ38aO8sG7bjqfJZe60YkAM/2jfNkZ32edMxezuQ82w/2m8vnHfk
l+RB+yCQcYEf7Y/IvZ3k/W2XfRoYfLSf8XfX5bnq2+xBvn1Y9dFeJsbqmU3y
ZvsJYAd+tN+yYbnsv1mb7JeBnLf4o73txzm6Clu22O8CGbfjo/3WT0tPcUUc
sT93BgQ+2rdNmR/yu+Ss/SOwgR/tQxuYmDZMuWj/DeTdrx/tI78kXpDJuWIP
dh7XJ/t/2WlSVsnX7cHGyX2yF9u5q6ym75a9ETgePtnfivzix3rnLjQ+PtmH
sKcVhc95AI2PT/ZlVacPHTnzEBofn+y3Z+v3K814ZM/df98pp/ETPD4BLQTx
Rg==
               "]], 
              Line[CompressedData["
1:eJw9kV8o63EYxn+dOERGWW7YOoeIcS78uUDxJPkXLkwrtCQ1TpMIN9ZqnI5F
u5iTc8HEkiiStCJR1Nq0/Avr2Dm2YoZy/Am/75fiwvl9f63z1Nt79X56nvf5
3Nyh1HzgOE4uDNvV1vgim4FHtqgAhu00VW3m4cxXbbRe+DHbWRDhmeaxl3av
ccnPsCYfuKlZ5SHtTgJN9GF/l4nH65HXajL+xrlOuljm5zHZm3e7EfiFZ4Fm
pzwcSY9PPYtuCDCBSND99cedfvMQIk5O0B/2MaZQeoAs0QdBW8l4wJeyh3I/
AxJYipWRySPbaDQzg8K9tnX0ROlCF7PXSXDVbii67NqCkeEGCJpV85mSeCcs
Y0wEEfq6b9ZKBwRzApDA3HexJGlwQIxrJ+jVzWQUJzhxzOx5CFbc17VTP7dw
y3A3BAcyz5jK5gL7GcdRrJc0LXQ07SBOBFKkfakwfVrfh4LFTaWITeS9f6sO
USgGpoh+U1xFTbihZLgaCrVCrX/JOUaLKIoRra0+PPQPxPfpKEozW3JNIb5g
HxSy1Ye5ofTTYB8Uk5adKGO+P9gHhWVZOvz8fo4896Dk+xr93+c/VEbvPA==

               "]], 
              Line[CompressedData["
1:eJxd1j9I1HEYx/FvUUPXUIMFLUa1mENDEQhhz68IShBBoVosqMilQQlapMFF
BYn+EcE1FCIe2WAWUSoFcQ0RZE1pBFJeS9DR5l3f/93z/aUPfL5wd7yX557f
93XD7bnY33N5o1JqtPHiz3OlV+035mt0KJ2fVF5t6b1VrtF4NZt5M/WDFicG
2gtLNfr1+U7/h02LVO2ebR7+XaOuvV/GOu4uEM9Qqk5b7m8vfj9Tpp3TJ1cG
m+pUXB56faLyjFob01Zb6nS949KLm09G6GhhqTGxTur/6eFx3dJ96UgPNvFA
6dtpQekSrzchPc/jZqU/feQjXUkDpWv8uKvSab3C3/VO45qlD6Z7kj61wgOl
z/Pj9kpf5fUGpEd43LD0gyIf6XR909K5h3TuIZ17SOceer1zD+ncQzr30OCh
wUODhwYPDR4aPDR4aPDQ4KHBw4CHAQ8DHgY8DHgY8DDgYcDDgIcBDwMeBjws
eFjwsOBhwcOChwUPCx4WPCx4WPCw4GHBw4KHAw8HHg48HHg48HDg4cDDgYcD
DwceDjwceHjw8ODhwcODhwcPDx4ePDx4ePDw4OHBw4OHB48AHgE8AngE8Ajg
EcAjgEcAjwAeATwCeATwiOARwSOCRwSPCB4RPCJ4RPCI4BHBI4JHBA/pdP2b
VbbW6Xq3Saf72yU9yd+/T/opP/4B6Tnep036Ha9/XHqB1+uUTj+Hs9KJ+4J0
4rwinfa/Jr2B34akt/LAMekdfJ33VDZ37Fv1cOsk7eYHfqiy5fGuvqnKe9rP
1/FYZW1H6Hnp0VfqfPvy9J8Zla39v/gHXLhGjA==
               "]], 
              Line[CompressedData["
1:eJxF0S2sjnEYwOH39f1tM4JyMIWiKIoxhaAcgkJgQxAQFIqiKIpCsJnZpCMo
BIWgEKQzm2JMOYKCTfK852fPdYfn2VXu3f/99ly4euriislkcmM6mcz+n6aP
t33bPT16cHm+Hnl67fCGxb3To5P/8/z4l5vbD/CruTtL84f47a99Z+8d4w/v
hznJi0+GhWd42LZw/Dwvzb+cu3OFfw/r3tzg6exzmzfOFt7lHQvDgfd513De
y0e8f1j36xkvP/MFD699cu01n5gd+I5PD+ctfeRzw7p9n/nypWG+8/XZwp98
a3jul788O29u9YrRs3Vnt/LDB8Ps5HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD67FydD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD1Wja4H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H6tH14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1WDO6HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HmtH14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H12Pd6HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HqsH10P
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlyP
DaPrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrsXF0PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPTaNrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrsfm0fXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXYMroeXA+uB9eD68H14HpwPbge/GO5B/9Z7sH14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+ux9bR9eB6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB/wA6bqQn
               "]]}, "Charting`Private`Tag#3"]}}, <|
          "HighlightElements" -> <|
            "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
           "LayoutOptions" -> <|
            "PlotRange" -> {{-2., 2.}, {0., 0.6}}, 
             "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
             "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
             "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
             "DefaultStyle" -> {
               Directive[
                PointSize[
                 Rational[1, 180]], 
                RGBColor[0.560181, 0.691569, 0.194885], 
                AbsoluteThickness[2]], 
               Directive[
                PointSize[
                 Rational[1, 180]], 
                RGBColor[0.880722, 0.611041, 0.142051], 
                AbsoluteThickness[2]], 
               Directive[
                PointSize[
                 Rational[1, 180]], 
                RGBColor[0.368417, 0.506779, 0.709798], 
                AbsoluteThickness[2]]}, 
             "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                 Identity[
                  Part[#, 1]], 
                 Identity[
                  Part[#, 2]]}& ), 
               "ScalingFunctions" -> {{Identity, Identity}, {
                 Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
             False|>, 
           "Meta" -> <|
            "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, 
             "Function" -> ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PlotRange" -> {{-2., 2.}, {0., 0.6}}, 
            "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.560181, 0.691569, 0.194885], 
               AbsoluteThickness[2]], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.880722, 0.611041, 0.142051], 
               AbsoluteThickness[2]], 
              Directive[
               PointSize[
                Rational[1, 180]], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
                Identity[
                 Part[#, 1]], 
                Identity[
                 Part[#, 2]]}& ), 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLinePlot, "GroupHighlight" -> False|>|>]]}, 
      Annotation[{{{}, {}, 
         Annotation[{
           Hue[0.67, 0.6, 0.6], 
           Directive[
            PointSize[
             Rational[1, 180]], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJxF0VtIVFEUxvHB8qF9NKEGu2CGSGFQviiUt3aIYJAVGmoXS5M0yAcr8YK9
TKAEZQhhlCEaGKVUFmgRRbEqI1BLrXScwbLJCtIgExXRHjrnfAe/BcPwn4fF
2vOLKizNKgpyuVwN5sf6PufuSA8shInLmTMpyts6xS625ic7r/7VbMwoO+tJ
ZO3kIHt3oNrd8Za901x3+jk7zppO9hZrYRt7Y+1k5pNmtnVedQPbWpdykW2P
hz0XYy4sZ//ONA8sYVvnpR9nW+tULvtdnzkZbPO1efWpbOu5mTvY1nnuWPYt
c503mn2j0Zx1bOvvywtjW8+NDGbDY+VSw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PZ42PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PAIXWp4sOHBhgcb
Hmx4sFNsDzY82PBgw4MNDzY82PZ42PBgw4MNDzY82PBgw4MNDzY82PBgw4MN
DzY82PAIWWp4sOHBhgcbHmx4sOHBhgcbHmx4sOHBhgfbHg8bHmx4sOHBhgcb
Hmx4sOHBhgcbHmx4sOHBhgcbHsZSw4MNDzY82PBgw4MNDzY82PBgw4MNDzY8
DJnIv9LjLtul7R89hsx3J2a/ONmm4WFISXt71s3kbj1pexgye3V916mJAQ0P
Q/72b7yf1vlJw8OQptzCSz1lXg0PQ6Zr9nQN3vbp17aHIQ3nwzctVvs1PAxZ
lvaybstBv4aHIcaasZRtW/0aHoakPyo/+mPOp+FhSKCgtHD3e5+GhyH7qiLW
vbju0/AwZLAi4/PVoz4NDyX+Y/MdsW6fhoeSexGHTySNjWh4KPmesfpxS92I
hoeShNH41pDUEQ0PJU2PD/VH+7waHkqm9revKir1aniYvdB3qGV6WMNDSVnl
w5GEgmENDyV3rq3tnekd0vBQ0hmUEzV/dkjDQ8mzyPzsgfQhDQ8lT1cMxicV
DTkeShYflH0sjhh2PMz7uouCSlJ9joeShX8bKrcnjzoeSq4fCCpcFfvF8VDy
5W7O5n8fxhwPJWeC3RO/Wr86HkreXD7S17834HgomQkP+5MwFXA8lDQmV7ma
L3xzPJRUhIY2R6wd1zX1ictno5TY744b1/8Bjq+3rQ==
            "]], 
           Line[CompressedData["
1:eJxd3HdUFNcXB/Dtu1h+lliTWNHYEjVRE1t8zx57izEx1thjjUYTNUaNPcYW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            "]], 
           Line[CompressedData["
1:eJxF0UtIVVEUxvGb5aC9NaHMNMyQKBTKSUKZxl6IYJAVGtlL0yQVcqAmPqhJ
gRGUEYSShWgglVJpYEkPEiojUEut9HrFtNsL0iATLbEG7et38FtwOPwni7X5
ReYUpuX6uVyuavv5/pWXti2ZiVSyeX4+mxtF25V7nZKywMD68NDPpjXZezI4
RsnVhApX/blP5lHE2YnUrUqmQ4J+xk16zYuZqIxLiUpeXjzc07vLa1732ElR
UuwfPP698aNxN9qF+5WM3k7f8O/tmLHbWpKPKqnd65ezPGbUTKQ+jDhboGTu
35ryLQkj5rdd97xUSVxnrl9Boscssje6Tiv521ryLi980GjfwvNKHi/tj43P
HTArW+yB1UqeRGTt60seMGvteQ/rlbT5pUfOnhgw0XbdTJOSW1dCu6e7B8z8
M9uUlJTfG4rLHjT2tY1FT5VMzvUcbJgaNDt8B76yvad5eW6h2+y15030K6lr
P9i7zuM2mXZd1Ii9byS2MSBxyOTn2fmm5EvKivaGqiFT7Fs4qeRO+KFj8WND
5pR9rndOyfCR2ZaYYI/xnRfhr6W/LOVDTabH+NZlBGnZXREe1lHrMdeu2gnT
4s0uzNnxxuN4aEl+UJr59bfH8dCiV41t37Rx2PHQsjjpWVX0gWHHQ0v1mZD1
f08OOx5apip33u+/6XE8tNTtz7nQVeJ2PLT86l17N6ntveOhZaZm9f3j432O
h5aC5ua06wmdjoeW2c5t+zrymxwPLeNZl7uCS8Tx0OJyBh5seLDhwYYHGx5s
eLDhwYYHGx5seLDhEbDQ8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8GDD
gw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8AhcaHiw4cGGBxsebHiw4cGGBxse
bHiw4cGGBxsebHiw4cGGBxsebHiw4cGGBxsebHiw4cGGBxsebHgsW2h4sOHB
hgcbHmx4sOHBhgcbHmx4sH/Me7D/zHuw4cGGBxsebHiw4cGGBxsebHiw4cGG
BxsebHiw4cGGR9BCw4MNDzY82PBgw4MNDzY82PBgw4MNDzY82PBgw4MNDzY8
2PBgw4MNDzY82PBgw4MNDzY82PBg/wejhm3l
            "]]}, "Charting`Private`Tag#1"], 
         Annotation[{
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            PointSize[
             Rational[1, 180]], 
            RGBColor[0.880722, 0.611041, 0.142051], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJxF0S1sXlUAx+F3pOWjfEysE5gRghkJwcxguiZDFIGgNYSlBhJmEIDADHPN
DGZmZluyCRBTMwgWEpJmiBkQUwsJgmUJpggMCBTvPb/lPn9z85iTc+7v9U8+
P/j0mdVq9daJ1Wr+fr19d+/xfyePVk/35c7Wo2//5kvz/uTDq/f/Ofs7H9w7
c+X4Ib/3+PL23Qd8fn3cFz/xuXnf85vzgXf4tSvH+/du8Xy9y9d4Pm7nGx6b
+N+z6wO/4r/21xf8jOfr7X3M83FbH/Kvv6z3Pq9fe3j1As/P3X+H5+ttv83f
rY979AbfuL7eqzz/vsOTPD/3zCbX45XF9eB6cD24HlwPrgfXg+vB9eB6cD14
bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsfLi+vB9eB6cD24HrwzenA9uB5c
D64H14PHJq4H14PrwfXgenA9uB5cD64H14PrwfXgery0uB5cD64H14PrwfXg
enA9uB5cD64Hj01cD64H14PrwfXgenA9uB5cD64H14PrwfV4cXE9uB5cD64H
14PrwfXgenA9uB5cDx6buB58PHpwPbgeXA/+efTgenA9uB5cD64H14PrsbW4
HlwPrgfXg+vB9eB6cD24HlwPrgePTVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9XhhcT24HlwPrgfXg+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vx/OJ6cD24HlwPrgfXg+vB9eB6cD24Hjw2cT24HlwPrgfXg+vB9eB6
cD24HlwPrgfX47nF9eB6cD24HlwPrgfXg+vB9eDTowfXg8cmrgfXg+vB9eB6
cD24HlwPrgdfHz24HlwPrsezi+vB9eB6cD14b/TgenA9uB5cD64H14PHJq4H
14PrwfXgenA9uB5cD64H14PrwfXgemwurgfXg+vB9eB6cD24HlwPrgfXg+vB
YxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD02FteD68H14HpwPbgeXA+uB9eD
68H14LGJ68H14HpwPbgeXA+uB9eD68H12Di69dvNzQcHP+zWY+Po9sN3L36w
+cfuRxfO/3hqa+No/JdzT3b/B2diWms=
            "]], 
           Line[CompressedData["
1:eJxd1W9IU1EcxvHtSFESVKCmEAsRdBGUYImQ80RFRn8IJQ1iURb5Ql+4Fb5o
IUk1kwINNEKhpJYhyMQMZEVyTxb6QiUlcyWBLUkCJQqbgbXZvecpH+qAjA+y
3z33fOEs/XRV8Vlhs9kqzT/rc2rY9urtN6Fy9JqWXldiOPBVqOal3qSazo+y
3FozQk1VZ6SdTJ+S7sb+qPO9UCXz29zZBydlccjhnx0Tanyi/tRG94QsjPiS
ugaFKvN97riZ+lpa4zx9QuV5vjuOHhmV+jGPhXK12aPl40NyszWwQ6gufFFu
8s8Whe4KVT9WN3HH/lImW/9oFupS1q6s2++UtMa5rguVci3HaE14Jm3WqhWq
6sCF4NUvvXLBaQ6sFspRuW/lkxs90pzm8FcKtcPe0r0uOyitpxSWCeXudM35
xUNpjUs8Zs7bUvPz8M42OTJsrkNC3UtO7Xn6pkm+iJoDdwvlnU6ZP7/nirRe
tyhPqNL67RvavSVS73urULY/64E5LpxBt1grjbaOz72Wtl7XsYK+aG4vsmhf
NnrQ6EGjB40eNI6VRg8aPWj0oNGDRg8aPWj0oNGDRg8aPWj0oNGDRg8aPWj0
oNGDRg8aPWj0oNHDtmz0oNGDRg8aPWj0oNGDRg8aPWj0oNGDRg9ar1oaPWj0
oNGDRg8aPWj0oNGDRg8aPWj0oNGDRo//9h9dMv7Zb4Qe1ovW+wnR+vkBWj+v
kdbjfLTuW07rnkV0gT5wWvdy0npcEo1Fz1nnPxtftj7vMK2310/jnqRb9QHS
+rz8tH5dD62356b36wOk8TsQN0ZH1q9Z/FQn9fE54kZ17o+K4/kB3L+JcaMp
cyj3RP4j3LfRmFESPNeQVdWH+zUSM+I1A/6E9EGJHjHDWVEa2Js3hvszFDMa
Vg08bz8zKdEjZszPeIIL3R8kesSM1b5b9y9nT8tw7a/MAtN/f59+Ax4YGaI=

            "]], 
           Line[CompressedData["
1:eJw9mndcleUbxjEpVyn+REszR2pq5sy9LpyYmjMNrQQ0M83UzJUjcePIRa5y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            "]], 
           Line[CompressedData["
1:eJxF1W9Ik1EUx/HtStE/qEBNIRYiqBWUZImQei4VFf0htDSIWVlkoC+cxl60
kKSaSYEKGqFQUqIIYpmCpCSVhXuhlpJNk8BUkkCJwjSwNnvOPenvghufN8d7
7/fhWdSF/PRLymaz5Vl//D1S/DcmtTxACWZNUkX3XJzT8mrPvcc34iepwZWy
ZrguQLNTrub5li/U6fBOpz0PUNmqntf1F0fpXR+vAMXlZtYdSBqkCU/ok0Pj
AQoW9XhDonw0b03rngtQRnNhWWx+F1nDrIlBqozpTcxKfkZmnCNI7sTfuWeS
62iX2UeQBvo3rlv4WkKHx3lgkGz/19ly3iBcyNtzwSU8zgvXVPOCrc1ZA2Fz
3G7Yz9sbhmd43DSszOfissPNQHgbHzcOTjUHhtN5XBqcYxZsrs8DSw9YesDS
A5YesPSApQdsrn+FTS/ZXO962NxfJFzP/z8afsrH3wF38H6S4De8/X1wP2/v
GGweh9OwyZ0Nm5x5sNm/G7bzRzG8lgfegcP4OqvgLXzgh/BWvo5G2Dx+bbB5
vLpg8zz64JPccxDO4gv8DF/mvFNwAQ/8AV/jPAuw9LAvW3rA0gOWHrD0gKUH
LD1g6QFLD1h6wNIDlh6w9IClByw9YOkBSw9YesDSA5YesPSApQcsPWDpAUsP
WHqoZUsPWHrA0gOWHrD0UDqzdPem+oIMkh5KF0yGz17Zf5Okh9KPwiJaOz9W
kvRQOnx70Z/je2tJeijtbEqZ8aoGkh5K77FXt2yIb5b3rVtpR97BlR13W0l6
KJ1/5Grzre/tJD2sebcTXtaEvCDpofT1WB17/9Mrkh5Klw6W+B/Y35L0UFre
mz75nWhTOqXWPpcz1EvSQ+kk1y/HqRMD8r72KZ3t+dZYEfGBpIfSQ/7S85ud
fpIeSmfM7nTGHx0l6aH0mDs68lzUGEkPpasW20OLmiZorM/2fuSn0ku/T/8A
8FjkSg==
            "]], 
           Line[CompressedData["
1:eJxF0S1sVgcUgOGvpAVWfirGxEwJmRkJwcxgoA0TTCBGJ5aRTbAEEAhAYIbB
1GBqZgYJE2QJCsTEypKZTtSAQBGSCQgJphMYIEFxv77kPkfcm8ecnHvfQz9f
Xjm/YzKZHJmZTKbvH06e+PvT+dnlr7bn5dLaxpsvf1yYXf79yddnv517vnTr
t2E+n12+8+z23ObKX0t/XDk+//SL2eXJx3lw6sUvB47yw8XVrTPH+N9h3dpJ
fvxomNP89O6w8Hsett0/dY63zqwvrl7it8O6jWs8M33c4D3ThTf5s/vDgb/y
weG89Tt8eFj35h5v/4Y/efjau1f+4W+mB27yd8N5W0/4p+kP/I8vXhjmFV+d
LnzN14fPffGep+ctzs2NrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrsfO0fXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXYNboeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpwPbgeu0fXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX45PR9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9ZgfXQ+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXI89o+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxd3Q9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA99o2u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
x/7R9eB6cD24HlwPrgfXg+vB9eD/t3vwu+0eXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HosjK4H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD/4AHbLEzQ==
            "]]}, "Charting`Private`Tag#2"], 
         Annotation[{
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            PointSize[
             Rational[1, 180]], 
            RGBColor[0.560181, 0.691569, 0.194885], 
            AbsoluteThickness[2]], 
           Line[CompressedData["
1:eJxF0S+sV2UAx+Hf5Y/AFWVzl2ABnQULhUK5uFmugXIplFtkw0JQAwXKKRQL
hQLBjWkgUSgUN6aBosEEgcJklEuwSDDxO++Hnedbzp7y7n3P5/Mr31+6emC1
Wl3fWK3m782thzsv/z/xZPV+P25vPvvlX/5u3mveu/37f2de8KXHp27t/83f
vLyx9fApX1gf98NvfG7eI/5yPvABn761v/v4Z56vd+MOz8dt/8RjE789sz7w
Or/ZXV/wGs/X2/mW5+M2L/Nff653kdev3bv9Nc/P3T3P8/W2zvKv6+OefcH3
7q73Kc+/b+8Ez889dZjr8fHienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+OjxfXgenA9uB5cD94ePbgeXA+uB9eD68Fj
E9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4vrgfXg+vB9eB6cD24HlwPrgfX
g+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD0+XFwPrgfXg+vB9eB6cD24
HlwPrgfXg8cmrgfvjx5cD64H14P/GD24HlwPrgfXg+vB9eB6bC6uB9eD68H1
4HpwPbgeXA+uB9eD68FjE9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4trgfX
g+vB9eB6cD24HlwPrgfXg+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD2O
Lq4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXgenA9uB5cD64H14PrwfXg
enA9jiyuB9eD68H14HpwPbgeXA+uB58cPbgePDZxPbgeXA+uB9eD68H14Hpw
Pfju6MH14HpwPT5YXA+uB9eD68E7owfXg+vB9eB6cD24Hjw2cT24HlwPrgfX
g+vB9eB6cD24HlwPrgfX4/DienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+PQ4npwPbgeXA+uB9eD68H14HpwPbgePDZx
PbgeXA+uB9eD68H14HpwPbgeXA+uB9fj4OJ6cD24HlwPrgfXg+vB9eB6cD24
Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwPrgfX48DienA9uB5cD64H14PrwfXg
enA9uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H12NjcT24HlwPrgfXg+vB
9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24Hvx84/4nrz7beDLefe6fr94B
T9leJw==
            "]], 
           Line[CompressedData["
1:eJxd1j9oE2EYx/EX0cEsOsTBJaIu0cFFhILEV0WohVJoQV3ioGIXh3ZxCQ5d
olDEYhEhHSqlWqxDqCJaRbkjDiK0OGlEKJq6CAluufe/evcc+ujvhRC+cDz3
vu8nQ/ZenBi7vEUIcSP9ZN/D8bMzP1ZEfJjWN3mgOtPqPxTxwFH5ZOneJ7mn
3h1dnRfxxsLI+PLmW7mrOdip3RHxixOfe0cOPpCF9uJkZVrE4t81xZ2U04FX
udNppfoV7k6t2By8wJ2NK5zjXl9L1zD3m3468CR3Oq07OsCdba94iPt+Oq69
n7uRrd3c6WnL1R3c2XFL22D//V/Rf/vtcK/R4qb9rHLT+xe56X0z3DSuxj1O
i3uMBnIfowvnJq8yN40rcueLu5fdf/fn36b7bnPT9lrcNK7JPUcXyE33Veem
405y0/aq3KfpArnz3x03XV+Jm45b4M49AngE8AjgEcAjgEcAjwAeATy46bgV
btpeOYBHAI8AHh48PHh48PDg4cHDg4cHDw8eHjw8eHjw8ODhwMOBhwMPBx4O
PBx4OPBw4OHAw4GHAw8HHg48LHhY8LDgYcHDgocFDwseFjwseFjwsOBhwcOA
hwEPAx4GPAx4GPAw4GHAw4CHAQ8DHgY8DHho8NDgocFDg4cGDw0eGjw0eGjw
0OChwUODhwIPBR4KPBR4KPBQ4KHAQ4GHAg8FHiq6NnTp6a1H12XuoaLGxtSr
U5uPZf6Uirbf3dn4crYlc48kGtn3YXpodl3mHkn0/f3tiXdbP8rcI4kWesdX
Xi9/leeXnlduvkyiP/8vfgM9KYmy
            "]], 
           Line[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbX65g69l19f9xmDw2H6HXOvrwB1f98/aKjLh2/9H
9ksKbLmuL/66f96s07xtVg/t+w991Yjp/7pfdseHlZ3a9+2rRNa5P6z6ut/N
MM2im+WOfRoYfN0/OWtTJAfrTfsgsIFf98doxdR8N7lmDzKtwPbrfv7fWs94
5162BxoGNPHrfmGlz7df+Vy0Bxsn8nW/pq5nt8Luc/YMYPB1/27XhDX5Caft
3wSCDPyy/4Ls9Zmhm07Yg0zjuv5l/7bLL4MXTjlmD3beoS/7K6uW6jjLHLUH
G7fuy/7+hicb+KKO2M+aCQJf9nPVRDTN9z5iD/KtXOuX/Umhqwz5pI/ag71b
8GX/s9x6x6dFx+zBzov5sr84K33GraAT9h4g49y/7J/lHMStOvmUPSTcvuzP
dp39+I7aWXtw8Ml92d/IziZgJ3LBHuxdLqD+jIlva/ZftP8G9vDn/UeUP34q
WXfZHmzcw8/751Vavtn3+Kr9GTD4vP/Xpdvzu9tuQOPj836RYmX7r0p3oPHx
ef9ZzXepJ+QeQOPj8/6jVqH70p88tPedL+24qf4zPD4B/UD+Iw==
            "]], 
           Line[CompressedData["
1:eJxTTMoPSmViYGCQA2IQzdV/3ymn8dN+YzB4bF9gy3V9ccGn/duz9fuVZjyy
j+k/9FUj5tP+sqrTh46ceWjv8bBKZJ37p/0h7GlF4XMe2EP0fdp/K/KLH+ud
u/Zyra8Dd8h92i+2c1dZTd8te5Bptlyf9v/LTpOySr5u/00DZOLH/ZFfEi/I
5FyxBxv38OP+0AYmpg1TLtqfAYOP+9umzA/5XXLWfgfYwI/7t35aeoor4oj9
ErADP+63/ThHV2HLFnuw8/o/7t+yYbnsv1mb7MHGVX3cLxNj9cwmebN9Ghh8
3D/j767Lc9W32QeBDfy4/4jc20ne33bZg71r+3H/9sJ5R35JHrQHO0/j4/6m
ObLTPm86Zg82TuTjfmfZsB1Plc/aM4DBx/3CEjcCwp9ctH8TCDLww37Nm9eX
c3pctQd79/qH/cU671exn7lhD3beoQ/75++63xfbf9sebNy6D/unrGvbWBR6
137WTBD4sL+wa+F6Y4n79uDga/2w/xC3qaxI+gNofHzYn5Z09vZr84fQ+Piw
PyQtdtsGxkfQ+Piw38/SMszmxCP7pftKvmvafIDHJwDo5gA/
            "]], 
           Line[CompressedData["
1:eJxdmX9wVNUVxwOl/qSOgECACYVWJaWtOqUIUuiJMAUclEr4WQuYIli0A1gK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            "]], 
           Line[CompressedData["
1:eJxTTMoPSmViYGCQA2IQvWRfyXdNmw/2xmDw2N7jYZXIOvcP9n6WlmE2Jx7Z
x/Uf+qoR88E+JC122wbGR/ZFtlzXFxd8sE9LOnv7tflD+7bXgTvkWj/YH+I2
lRVJf2A/ayYIfLAv7Fq43ljivv06d5CBH+ynrGvbWBR61x5kWv+hD/bzd93v
i+2/bX9tcQHQxA/2xTrvV7GfuWH/BmTc6w/2mjevL+f0uGoPciMDw0d7YYkb
AeFPLtqLgQ38aO8sG7bjqfJZe60YkAM/2jfNkZ32edMxezuQ82w/2m8vnHfk
l+RB+yCQcYEf7Y/IvZ3k/W2XfRoYfLSf8XfX5bnq2+xBvn1Y9dFeJsbqmU3y
ZvsJYAd+tN+yYbnsv1mb7JeBnLf4o73txzm6Clu22O8CGbfjo/3WT0tPcUUc
sT93BgQ+2rdNmR/yu+Ss/SOwgR/tQxuYmDZMuWj/DeTdrx/tI78kXpDJuWIP
dh7XJ/t/2WlSVsnX7cHGyX2yF9u5q6ym75a9ETgePtnfivzix3rnLjQ+PtmH
sKcVhc95AI2PT/ZlVacPHTnzEBofn+y3Z+v3K814ZM/df98pp/ETPD4BLQTx
Rg==
            "]], 
           Line[CompressedData["
1:eJw9kV8o63EYxn+dOERGWW7YOoeIcS78uUDxJPkXLkwrtCQ1TpMIN9ZqnI5F
u5iTc8HEkiiStCJR1Nq0/Avr2Dm2YoZy/Am/75fiwvl9f63z1Nt79X56nvf5
3Nyh1HzgOE4uDNvV1vgim4FHtqgAhu00VW3m4cxXbbRe+DHbWRDhmeaxl3av
ccnPsCYfuKlZ5SHtTgJN9GF/l4nH65HXajL+xrlOuljm5zHZm3e7EfiFZ4Fm
pzwcSY9PPYtuCDCBSND99cedfvMQIk5O0B/2MaZQeoAs0QdBW8l4wJeyh3I/
AxJYipWRySPbaDQzg8K9tnX0ROlCF7PXSXDVbii67NqCkeEGCJpV85mSeCcs
Y0wEEfq6b9ZKBwRzApDA3HexJGlwQIxrJ+jVzWQUJzhxzOx5CFbc17VTP7dw
y3A3BAcyz5jK5gL7GcdRrJc0LXQ07SBOBFKkfakwfVrfh4LFTaWITeS9f6sO
USgGpoh+U1xFTbihZLgaCrVCrX/JOUaLKIoRra0+PPQPxPfpKEozW3JNIb5g
HxSy1Ye5ofTTYB8Uk5adKGO+P9gHhWVZOvz8fo4896Dk+xr93+c/VEbvPA==

            "]], 
           Line[CompressedData["
1:eJxd1j9I1HEYx/FvUUPXUIMFLUa1mENDEQhhz68IShBBoVosqMilQQlapMFF
BYn+EcE1FCIe2WAWUSoFcQ0RZE1pBFJeS9DR5l3f/93z/aUPfL5wd7yX557f
93XD7bnY33N5o1JqtPHiz3OlV+035mt0KJ2fVF5t6b1VrtF4NZt5M/WDFicG
2gtLNfr1+U7/h02LVO2ebR7+XaOuvV/GOu4uEM9Qqk5b7m8vfj9Tpp3TJ1cG
m+pUXB56faLyjFob01Zb6nS949KLm09G6GhhqTGxTur/6eFx3dJ96UgPNvFA
6dtpQekSrzchPc/jZqU/feQjXUkDpWv8uKvSab3C3/VO45qlD6Z7kj61wgOl
z/Pj9kpf5fUGpEd43LD0gyIf6XR909K5h3TuIZ17SOceer1zD+ncQzr30OCh
wUODhwYPDR4aPDR4aPDQ4KHBw4CHAQ8DHgY8DHgY8DDgYcDDgIcBDwMeBjws
eFjwsOBhwcOChwUPCx4WPCx4WPCw4GHBw4KHAw8HHg48HHg48HDg4cDDgYcD
DwceDjwceHjw8ODhwcODhwcPDx4ePDx4ePDw4OHBw4OHB48AHgE8AngE8Ajg
EcAjgEcAjwAeATwCeATwiOARwSOCRwSPCB4RPCJ4RPCI4BHBI4JHBA/pdP2b
VbbW6Xq3Saf72yU9yd+/T/opP/4B6Tnep036Ha9/XHqB1+uUTj+Hs9KJ+4J0
4rwinfa/Jr2B34akt/LAMekdfJ33VDZ37Fv1cOsk7eYHfqiy5fGuvqnKe9rP
1/FYZW1H6Hnp0VfqfPvy9J8Zla39v/gHXLhGjA==
            "]], 
           Line[CompressedData["
1:eJxF0S2sjnEYwOH39f1tM4JyMIWiKIoxhaAcgkJgQxAQFIqiKIpCsJnZpCMo
BIWgEKQzm2JMOYKCTfK852fPdYfn2VXu3f/99ly4euriislkcmM6mcz+n6aP
t33bPT16cHm+Hnl67fCGxb3To5P/8/z4l5vbD/CruTtL84f47a99Z+8d4w/v
hznJi0+GhWd42LZw/Dwvzb+cu3OFfw/r3tzg6exzmzfOFt7lHQvDgfd513De
y0e8f1j36xkvP/MFD699cu01n5gd+I5PD+ctfeRzw7p9n/nypWG+8/XZwp98
a3jul788O29u9YrRs3Vnt/LDB8Ps5HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD67FydD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD1Wja4H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H6tH14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1WDO6HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HmtH14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H12Pd6HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HqsH10P
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlyP
DaPrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrsXF0PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPTaNrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrsfm0fXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXYMroeXA+uB9eD68H14HpwPbge/GO5B/9Z7sH14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+ux9bR9eB6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB/wA6bqQn
            "]]}, "Charting`Private`Tag#3"]}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {{-2., 2.}, {0., 0.6}}, 
          "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
          "DefaultStyle" -> {
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.560181, 0.691569, 0.194885], 
             AbsoluteThickness[2]], 
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.880722, 0.611041, 0.142051], 
             AbsoluteThickness[2]], 
            Directive[
             PointSize[
              Rational[1, 180]], 
             RGBColor[0.368417, 0.506779, 0.709798], 
             AbsoluteThickness[2]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          ListLinePlot, "GroupHighlight" -> False|>|>, 
       "DynamicHighlight"]], {{}, {}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"Primitive cell (T2.2); k sampling: \
\\!\\(\\*SuperscriptBox[\\(10\\), \\(8\\)]\\)\"", TraditionalForm], 
     PlotRange -> {{-2., 2.}, {0., 0.6}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{0, 0}, {0, 0}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{"\"trivial\"", "\"critical\"", "\"nontrivial\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[2]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[2]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.368417, 0.506779, 0.709798]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.880722, 0.611041, 0.142051]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "180"], "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.560181, 0.691569, 0.194885]|>, 
                    "RGBColorSwatchTemplate"], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9101665701922455`*^9, 3.9101762776444693`*^9, {3.9101763232367353`*^9, 
   3.9101763491709766`*^9}, 3.9102387769094048`*^9, {3.910238815964269*^9, 
   3.910238842091621*^9}, 3.9102388766314473`*^9, 3.9102390116748486`*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"4a54b8d5-770f-4543-934e-9c83abf32228"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model on the supercells", "Subsection",
 CellChangeTimes->{{3.909113688151761*^9, 
  3.909113691600689*^9}},ExpressionUUID->"24550069-f0bd-4af7-a461-\
f59aa1a12f42"],

Cell["\<\
The model is extended to the supercells in the sequence by translation \
symmetry, which allows us to construct the Abelian Bloch Hamiltonians on the \
supercells\
\>", "Text",
 CellChangeTimes->{{3.909114061369022*^9, 
  3.9091140880436444`*^9}},ExpressionUUID->"5d455142-49a7-45ab-a522-\
3e46c5cdf0d7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Hscs", "=", 
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{
        RowBox[{"AbelianBlochHamiltonian", "[", 
         RowBox[{
          RowBox[{"scmodels", "[", "#", "]"}], ",", 
          RowBox[{"4", "&"}], ",", 
          RowBox[{"onsite", "[", "h0", "]"}], ",", 
          RowBox[{"hopping", "[", "h1", "]"}], ",", 
          RowBox[{"PCModel", "->", "pcmodel"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "&"}], "/@", "supercells"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9091140901054215`*^9, 3.9091140994598384`*^9}, {
   3.9091141535964785`*^9, 3.909114201440518*^9}, {3.9091142536091876`*^9, 
   3.9091142555260515`*^9}, {3.909114348523382*^9, 3.909114348909194*^9}, 
   3.909114658387212*^9, {3.9101543028388395`*^9, 3.9101543096639857`*^9}, {
   3.910166185826136*^9, 3.910166187276629*^9}, {3.910176380553774*^9, 
   3.9101764043273516`*^9}, {3.9102390536910253`*^9, 3.9102390721838813`*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"ba5ae0b9-bb63-4838-b531-682751d509f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<data\>\"", ",", "\"\<bloch\>\"", ",", 
         RowBox[{"ToString", "@", 
          RowBox[{"StringForm", "[", 
           RowBox[{
           "\"\<H_\!\(\*StyleBox[\"{\", \"Input\"]\)\!\(\*StyleBox[\"6\", \
\"Input\"]\)\!\(\*StyleBox[\",\", \"Input\"]\)\!\(\*StyleBox[\"4\", \
\"Input\"]\)\!\(\*StyleBox[\"}\", \"Input\"]\)\!\(\*StyleBox[\"-\", \
\"Input\"]\)\!\(\*StyleBox[\"BBH_T2\", \"Input\"]\)\!\(\*StyleBox[\".2\", \
\"Input\"]\)_sc-``.dat\>\"", ",", "#"}], "]"}]}]}], "}"}], "]"}], ",", 
      RowBox[{"Hscs", "[", "#", "]"}], ",", "\"\<Table\>\""}], "]"}], "&"}], "/@",
    "supercells"}], ";"}]], "Input",
 CellChangeTimes->{{3.9091142700197277`*^9, 3.9091143104477034`*^9}, {
   3.910154322749093*^9, 3.9101543310279417`*^9}, {3.91016160339386*^9, 
   3.910161605793605*^9}, {3.9101661483799353`*^9, 3.910166149293952*^9}, {
   3.9101763875940886`*^9, 3.910176390633175*^9}, 3.9102390844974265`*^9},
 CellLabel->"In[25]:=",ExpressionUUID->"d9b5c6a1-09fd-478f-85fc-8ed77e749d2f"],

Cell[CellGroupData[{

Cell["Density of states", "Subsubsection",
 CellChangeTimes->{{3.909114427990825*^9, 
  3.909114430083145*^9}},ExpressionUUID->"6823ddee-ce27-4ea8-ae79-\
b1d8c697cf3a"],

Cell[TextData[{
 "Increasingly better approximations of the true density of states in the \
thermodynamic limit are obtained by considering one-dimensional irreducible \
representations on increasingly larger supercells. To compute it, we would \
proceed analogously as above and thus jump directly to the precomputed \
results, which are stored as ",
 StyleBox["data/dos/dos_{6,4}-BBH_<quot>.dat", "Input"],
 ", where ",
 StyleBox["<quot>", "Input"],
 " is the corresponding quotient:"
}], "Text",
 CellChangeTimes->{{3.9091144367949524`*^9, 3.909114603985526*^9}, 
   3.91015441714965*^9, {3.910254634561754*^9, 
   3.9102546975997076`*^9}},ExpressionUUID->"17d4e983-f296-4265-9c48-\
751e58024efc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{6,4}-BBH_``_{1.5,1}.dat\>\"", ",", "#"}], 
              "]"}]}], "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.2\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<trivial; k sampling: \!\(\*SuperscriptBox[\(10\), \(8\)]\) \
(\!\(\*SuperscriptBox[\(10\), \(6\)]\))\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "5"}], "]"}], "/", "5."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9091263566114464`*^9, 3.909126393410284*^9}, {
  3.9091264603821816`*^9, 3.909126463017381*^9}, {3.9101544932422967`*^9, 
  3.910154495640236*^9}, {3.910155610950552*^9, 3.910155611196024*^9}, {
  3.9101562410776777`*^9, 3.910156285321762*^9}, {3.9101617452884254`*^9, 
  3.9101617608664107`*^9}, {3.910168721689234*^9, 3.910168728542076*^9}, {
  3.910168760533145*^9, 3.9101687649604893`*^9}, {3.9101775820379734`*^9, 
  3.910177584643213*^9}, {3.9101779037042403`*^9, 3.910177922324427*^9}, {
  3.9102393558673315`*^9, 3.9102394221311607`*^9}, {3.9102530653549595`*^9, 
  3.9102530784328337`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"0be1fcdd-ffa0-4093-8a3b-20a572f8f483"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8423264, 0.4188294]], 
         LineBox[CompressedData["
1:eJxF0V9Ik1EYx3FZdNE5lmDrj2GKSKFQ3iSU6TohwoSk0FAzNG00g7ywGmbY
zYK8KUEIJQvJwCilskATSZRTCYF/0lVze4dpQnWhXZikiHrR++439ntgjO8u
Hp6zT4qrtshti4mJaTY/1vcte49zfj1Ox0TmmkMEOpfY1db8Zpc3f1hJm2EX
DSQ1LvrY+fMN9p5P7BPmuqtD7CPW9LLTrYVd7OTGxcKBx2zrvIYWtrXOcZcd
Hi97Nc1cWMf+U2geWMO2znNeZFvrRCl7YtycArb52vLmXLb13MJjbOs8ewb7
qbkukMp+9NCcBLb195XHsa3nJm1lw2NHtOHBhgcbHmx4sOHBhgcbHmx4sOHB
hgcbHuzweNnwYMODDQ82PNjwYMODDQ82PNjwYMODDQ82PNjw2B5teLDhwYYH
Gx5seLAdYQ82PNjwYMODDQ82PNjh8bLhwYYHGx5seLDhwYYHGx5seLDhwYYH
Gx5seLDhERtteLDhwYYHGx5seLDhwYYHGx5seLDhwYYHOzxeNjzY8GDDgw0P
NjzY8GDDgw0PNjzY8GDDgw0PNjxktOHBhgcbHmx4sOHBhgcbHmx4sOHBhgcb
HlIvVN4ftXtOqvCPXqnXRo4XD1/uUvCQuqa7u+hJzohaDHtIvdK6r+/KwpSC
h9R/J5Nf5fV+U/CQur3UdW/UE1DwkHr5zqk+3zNDfQx7SN1ye/eBjYaQgofU
W/LeN6WfCyl4SC33zDkOHwopeEjtfFtX8WvVUPCQer6q1pX/2VDwkPr0zcSE
4TZDwUNq342C760VhoKH0KELaz0ZdkPBQ+iXiecvZc8FFTyE/lmws7+jKajg
IXTWTGZnbG5QwUPo9v6yyVQjoOAh9NKZ7nh3bUDBw+z18bKO5WkFD6E99W+C
WVXTCh5CP3+wd+zfmF/BQ+heW0nK2nW/gofQg0mVxVNOv4KH0O+2+TKz3f6I
h9Abrz1fqxOnIx7mfSNuW02uEfEQen1zf/3RnJmIh9BtZ22u+IzZiIfQsy9K
Dm5+mVNDuwaHJopFxP+H+g+sXpE+
          "]], 
         LineBox[CompressedData["
1:eJxd3Hd0FNUXB/Dtu6H8KFJVakCaAiooTd6jS28iivSOVEFQQASkizRBQLqU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          "]], 
         LineBox[CompressedData["
1:eJxF0U1IVFEYxvFpokXnWIKNlWGKSKFQbhLKTM5BhBGSQkXN0LShUciF1WCG
bQpyU4IQShaSgVRKpYEmlShUQuBHOtU4H5g2UC20hUmaqIvu9bnM88Ll8t+8
vPf+kly1BW67zWZrNh7zPRQ7ODRRJLRtc74rf+elLFEi9Oyz4oMbn+dUuMHR
4zwvdFuh3RWTNqsW8l8nNNYIvbaxv/7oiRm1klLW/L5O6IwRt70mO6i2mGtu
CL3e6/lSFT+tpLnwttBvt3vTM90+FdvjDDe0CD2YUFE05fSpxEZj40Oh++zF
SatXfCrVWLfcJfTTe3vH/o751BFz+oT21L8MZFROqyxhLBwSenFtvLRjaVrl
mgd+NPp0d4y71q8KjfMWvEK3D5ROJgf9qtxYlzJj3DeT3hmVHVDVVcb8EvpH
3q6BjqaAumwuXBT6efzZC5lzAXXd+NzwmtChc6s9aY6gMs9L2Ca192ret9by
oDLXlUVLfepafNxwW1A9uG9MnNThylpX7qegemz8Pn+y1M5XdeU/V4Kq1/hc
R5rUcs9c1uFDIfXGOC//mNRbc941pZ4JqQ/GuuZsqVtu7j6w3hBSE+PG5Em9
dOtkv/dJ0PKQur3EdWfU47c8pP4zmfgip++r5SH1cuu+/ovzU5aH1DXd3QWP
ToxYHlKvjhwvGq7usjyknq+4O+rwaMtDWv42GzzY8GDDgw0PNjzY8GDDgw0P
NjzY8GDDIyrS8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY
8GDDgw0PNjzY8GDDgw0PNjzY8NgRaXiw4cGGBxsebHiw4cGGBxsebHiw4cGG
BxsebHiw4cGGBxsebHiw4cGGBxsebHiw4cGGBxsebHjsjDQ82PBgw4MNDzY8
2PBgw4MNDzY82L83Pdj/Nj3Y8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY
8GDDIzrS8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8GDDgw0PNjzY8GDD
gw0PNjzY8GDDgw0PNjzY/wEuxknz
          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.9917508, 0.5901996, 0.09831576]], 
         LineBox[CompressedData["
1:eJxF0TFIVHEcwPFDyMGXHsgtBZ1Kiw4G1VLB+UQQHUI4MVxuSaglohoisOU5
uDR4FC6KtKQgDkLaIIj4cKglh6ZzcNAlgmuoIQeH6P3f1+77g8fjs/ze//++
fTPPJh+1FQqFV9kT3q9Lm2On58W0cDEvKh2ND7/04zDfda1+8Kf/WE/ulOeb
3/T46Wxp84seytY939O3w2zrgbBwXffMN6s773U43uyiDusqb3Q+iT7rzxa+
1D+r2QGf6HC8sYc6rOuY1odfs7mvs9vW6iM6XLd6R4fjlW7o1Wxd47peXsrm
ig6/r1bU4brlS5oeXS3TQ9ND00PTQ9ND00PTQ9ND00PTQ9ND55Noemh6aHpo
emh6aHpoemh6aHpoemh6aHpoenS2TA9ND00PTQ9ND13Je2h6aHpoemh6aHro
fBJND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9Nj8st00PTQ9ND00PTQ9ND00PT
Q9ND00PTQ+eTaHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpELdND00PTQ9ND
00PTQ9ND00PTQ9ND00Pnk0Tp26ftaw+u/h2iR5T+Xhns/VSeiJt5jyj9eHT3
5HBwLqZHlC6921/ontiI6RGlw7eu3asUP8f0iNK+m1NHPbuNeOpHfWNr9P/3
TuJ/5uHQSg==
          "]], 
         LineBox[{{-3.3828548797693148`, 0.5}, {-3.3825, 
          0.49646379166666665`}, {-3.3775, 0.47869008333333335`}, {-3.3725, 
          0.4999664375}, {-3.372496417544824, 0.5}}], 
         LineBox[{{-3.350836441063566, 0.5}, {-3.3475, 
          0.43143908333333336`}, {-3.3425, 0.3241203541666667}, {-3.3375, 
          0.26722002083333335`}, {-3.3325, 0.29076372916666665`}, {-3.3275, 
          0.3818833541666667}, {-3.322546525761373, 0.5}}], 
         LineBox[{{-3.3023680884200877`, 0.5}, {-3.2975, 
          0.41235027083333337`}, {-3.2925, 0.36110308333333335`}, {-3.2875, 
          0.3671998541666667}, {-3.2825, 
          0.42511710416666665`}, {-3.2778917213580296`, 0.5}}], 
         LineBox[{{-3.259648297721596, 0.5}, {-3.2575, 
          0.46103639583333333`}, {-3.2525, 0.35725972916666665`}, {-3.2475, 
          0.28250047916666665`}, {-3.2425, 0.26380577083333334`}, {-3.2375, 
          0.3068866041666667}, {-3.2325, 0.39431289583333334`}, {-3.2275, 
          0.49206591666666666`}, {-3.22693760866875, 0.5}}], 
         LineBox[{{-3.2083603704658077`, 0.5}, {-3.2075, 
          0.49119364583333336`}, {-3.2025, 
          0.47395789583333336`}, {-3.197644531280346, 0.5}}], 
         LineBox[{{-3.174044623699662, 0.5}, {-3.1725, 
          0.47445289583333333`}, {-3.1675, 0.38672427083333333`}, {-3.1625, 
          0.3336521666666667}, {-3.1575, 0.3339221041666667}, {-3.1525, 
          0.3752453125}, {-3.1475, 0.4295861458333333}, {-3.1425, 
          0.47096960416666667`}, {-3.1375, 0.48585791666666667`}, {-3.1325, 
          0.4764341458333333}, {-3.1275, 0.4521003125}, {-3.1225, 
          0.4258380625}, {-3.1175, 0.4079339791666667}, {-3.1125, 
          0.4083818125}, {-3.1075, 0.4328941041666667}, {-3.1025, 
          0.47980483333333335`}, {-3.099830528101429, 0.5}}], 
         LineBox[CompressedData["
1:eJxd3Hd0VNUTB/DtuzQB6UqRohRBAyjIT+FeQEClKSK9g1QVECkCIoogPVTp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          "]], 
         LineBox[{{3.099830528101429, 0.5}, {3.1025000000000005`, 
          0.47980483333333335`}, {3.1075000000000004`, 0.4328941041666667}, {
          3.1125000000000003`, 0.4083818125}, {3.1175, 0.4079339791666667}, {
          3.1225, 0.4258380625}, {3.1275, 0.4521003125}, {3.1325, 
          0.4764341458333333}, {3.1375, 0.48585791666666667`}, {
          3.1425000000000005`, 0.47096960416666667`}, {3.1475000000000004`, 
          0.4295861458333333}, {3.1525000000000003`, 0.3752453125}, {3.1575, 
          0.3339221041666667}, {3.1625, 0.3336521666666667}, {3.1675, 
          0.38672427083333333`}, {3.1725, 0.47445289583333333`}, {
          3.174044623699662, 0.5}}], 
         LineBox[{{3.1976445312803463`, 0.5}, {3.2025, 
          0.47395789583333336`}, {3.2075, 0.49119364583333336`}, {
          3.2083603704658077`, 0.5}}], 
         LineBox[{{3.2269376086687505`, 0.5}, {3.2275000000000005`, 
          0.49206591666666666`}, {3.2325000000000004`, 
          0.39431289583333334`}, {3.2375000000000003`, 0.3068866041666667}, {
          3.2425, 0.26380577083333334`}, {3.2475, 0.28250047916666665`}, {
          3.2525, 0.35725972916666665`}, {3.2575, 0.46103639583333333`}, {
          3.259648297721596, 0.5}}], 
         LineBox[{{3.27789172135803, 0.5}, {3.2825, 0.42511710416666665`}, {
          3.2875, 0.3671998541666667}, {3.2925, 0.36110308333333335`}, {
          3.2975, 0.41235027083333337`}, {3.3023680884200877`, 0.5}}], 
         LineBox[{{3.3225465257613735`, 0.5}, {3.3275, 0.3818833541666667}, {
          3.3325, 0.29076372916666665`}, {3.3375, 0.26722002083333335`}, {
          3.3425, 0.3241203541666667}, {3.3475, 0.43143908333333336`}, {
          3.350836441063566, 0.5}}], 
         LineBox[{{3.372496417544824, 0.5}, {3.3725, 0.4999664375}, {3.3775, 
          0.47869008333333335`}, {3.3825, 0.49646379166666665`}, {
          3.3828548797693148`, 0.5}}], 
         LineBox[CompressedData["
1:eJxF0TFIVWEYgOFjoIPHuhA6JHRVXGwwSBcTbucQhA0imEqLDQnWIKENEtiS
g4tDl8RFiZYQxMEoHQoRQUGXHJquQ4N3EcGGGipwCP9zX7rvB4fDs3zn/8/b
Njb5YPxSFEUvwpO9h0+La5/uxWlUmePk8GuY/jhtuzV81LJVSkrvpwr1D+M0
7breW8jtJ+WZxvW+x3G6tLDz+urAWnI2+Dk/NxGnH49uHx92ziZ/OkaLu9Nx
+uttZ+tmfiCpyda+itM3z+pWRpr/3YmzhfP/vxdFTet95ZlF3TIXNr7TN8K6
36u6O5sNXagPC7f1/eyAB3ooHO/sm34U1nV810+fhDnRz7OFP/XLcN3yuc6O
l69tqDpbN5rTy0thrumV8PtK7fpDuG7jTf0lHG+wR++FdcW7mh6aHpoemh6a
Hpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6Xq6aHpoemh6aHpoemh6aH
poemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6bHlarpoemh6aHp
oemh6aHpoemh6aF/VHrov5Uemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6a
Hrmq6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh
6aHpoemhLwDHn5T2
          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8647229999999999, 0.3364763999999999, 0.1829199600000001]], 
         LineBox[CompressedData["
1:eJxF0TFIVHEcwPFDFMSnJ8EtQpyIy7m0tDR4PmkxqOVchLjBE3RpsIZQFOEt
Lg66tBTZUpAQurjoEDxdBNHBGm4xyEWEc3CxIQh8//fN+/7gOD7Lj9//fYdm
5idnOwqFwkL2C//LpZ2Ji7/9aeH/vKn2ND/f6Lkwl7q+cXhbOdeTe+XV1pl+
drFU2jnSY9m619/14zC7eiQs3NKDq63a3icdzlt6p8O66prOJ9F/KtnCt/q6
lh34SofzJho6rOuZ0qcn2bzQ2WvrG091eG7tiQ7nlR7pL9m65rD+8D6bAR0+
X71fh+eWuzQ9im3TQ9ND00PTQ9ND00PTQ9ND00PTQ9ND55Noemh6aHpoemh6
aHpoemh6aHpoemh6aHpoevS1TQ9ND00PTQ9ND13Ne2h6aHpoemh6aHrofBJN
D00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9Nj9626aHpoemh6aHpoemh6aHpoemh
6aHpofNJND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND2itumh6aHpoemh6aHp
oemh6aHpoemh6aHzSTQ9ovTbyx+14tzPsVbeI0o342Twank8pkeUPrz9d7C9
tR7TI0q79xdnOxsHMT2i9GNnfWXm+Ff89cHozfTz+/2/4zvSMs36
          "]], 
         LineBox[{{-3.397823876449476, 0.5}, {-3.3975, 
          0.49336779166666667`}, {-3.3972165828913092`, 0.5}}], 
         LineBox[{{-3.3834967757064627`, 0.5}, {-3.3825, 
          0.47044054166666666`}, {-3.3775, 
          0.4494010729166667}, {-3.3754497617670243`, 0.5}}], 
         LineBox[{{-3.3648554166903595`, 0.5}, {-3.3625, 
          0.42871842708333335`}, {-3.3575, 
          0.37104680208333335`}, {-3.352670786589263, 0.5}}], 
         LineBox[{{-3.3438250529134206`, 0.5}, {-3.3425, 
          0.46712728125}, {-3.3375, 0.33294752083333334`}, {-3.3325, 
          0.40213292708333337`}, {-3.3290812341419875`, 0.5}}], 
         LineBox[{{-3.3211175977930933`, 0.5}, {-3.3175, 
          0.4105698020833333}, {-3.3125, 0.3788837916666667}, {-3.3075, 
          0.47507970833333335`}, {-3.305580805277082, 0.5}}], 
         LineBox[{{-3.2988364472055185`, 0.5}, {-3.2975, 
          0.48540689583333335`}, {-3.2925, 0.4152838020833333}, {-3.2875, 
          0.44151466666666667`}, {-3.2833795862290245`, 0.5}}], 
         LineBox[{{-3.2768651882711564`, 0.5}, {-3.2725, 
          0.4348466458333333}, {-3.2675, 0.39992428125}, {-3.2625, 
          0.45053566666666667`}, {-3.257748830811857, 0.5}}], 
         LineBox[{{-3.2570894936656622`, 0.5}, {-3.2525, 
          0.4710371875}, {-3.2475, 0.40074473958333334`}, {-3.2425, 
          0.4016916354166667}, {-3.2375, 
          0.4804118229166667}, {-3.2349950466139137`, 0.5}}], 
         LineBox[{{-3.2309361166978494`, 0.5}, {-3.2275, 
          0.45713166666666666`}, {-3.2225, 0.40095833333333336`}, {-3.2175, 
          0.46253457291666666`}, {-3.215297022819894, 0.5}}], 
         LineBox[{{-3.2075662124437994`, 0.5}, {-3.2075, 
          0.49936162500000003`}, {-3.2025, 0.39257955208333334`}, {-3.1975, 
          0.42043884375}, {-3.1941745195714226`, 0.5}}], 
         LineBox[{{-3.1855923587607635`, 0.5}, {-3.1825, 
          0.4307733229166667}, {-3.1774999999999998`, 
          0.40455398958333333`}, {-3.1726228270517693`, 0.5}}], 
         LineBox[{{-3.1644924451821788`, 0.5}, {-3.1625, 
          0.46733078125}, {-3.1575, 0.3937669166666667}, {-3.1525, 
          0.44165628125}, {-3.148911383551096, 0.5}}], 
         LineBox[{{-3.1419239927310465`, 0.5}, {-3.1375, 0.433874}, {-3.1325, 
          0.4221326458333333}, {-3.1275, 
          0.47920808333333337`}, {-3.1227823177438974`, 0.5}}], 
         LineBox[CompressedData["
1:eJxd3Hd0FNUXB/Dtu4LSRASkSVFBQJoICnkPRJEiHQQEDYhUFaRI70VpBpTQ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          "]], 
         LineBox[{{3.1227823177438974`, 0.5}, {3.1275, 
          0.47920808333333337`}, {3.1325, 0.4221326458333333}, {3.1375, 
          0.433874}, {3.141923992731047, 0.5}}], 
         LineBox[{{3.1489113835510962`, 0.5}, {3.1525000000000003`, 
          0.44165628125}, {3.1575, 0.3937669166666667}, {3.1625, 
          0.46733078125}, {3.1644924451821788`, 0.5}}], 
         LineBox[{{3.1726228270517693`, 0.5}, {3.1774999999999998`, 
          0.40455398958333333`}, {3.1825, 0.4307733229166667}, {
          3.185592358760764, 0.5}}], 
         LineBox[{{3.194174519571423, 0.5}, {3.1975000000000002`, 
          0.42043884375}, {3.2025, 0.39257955208333334`}, {3.2075, 
          0.49936162500000003`}, {3.2075662124437994`, 0.5}}], 
         LineBox[{{3.215297022819894, 0.5}, {3.2175, 0.46253457291666666`}, {
          3.2225, 0.40095833333333336`}, {3.2275000000000005`, 
          0.45713166666666666`}, {3.23093611669785, 0.5}}], 
         LineBox[{{3.234995046613914, 0.5}, {3.2375000000000003`, 
          0.4804118229166667}, {3.2425, 0.4016916354166667}, {3.2475, 
          0.40074473958333334`}, {3.2525, 0.4710371875}, {3.2570894936656622`,
           0.5}}], 
         LineBox[{{3.257748830811857, 0.5}, {3.2625, 0.45053566666666667`}, {
          3.2675000000000005`, 0.39992428125}, {3.2725000000000004`, 
          0.4348466458333333}, {3.276865188271157, 0.5}}], 
         LineBox[{{3.2833795862290245`, 0.5}, {3.2875, 
          0.44151466666666667`}, {3.2925, 0.4152838020833333}, {3.2975, 
          0.48540689583333335`}, {3.2988364472055185`, 0.5}}], 
         LineBox[{{3.305580804782784, 0.5}, {3.3075, 0.47507969791666665`}, {
          3.3125000000000004`, 0.37888380208333333`}, {3.3175000000000003`, 
          0.4105698020833333}, {3.321117597793094, 0.5}}], 
         LineBox[{{3.3290812341419875`, 0.5}, {3.3325, 
          0.40213292708333337`}, {3.3375, 0.33294752083333334`}, {3.3425, 
          0.46712728125}, {3.3438250529134206`, 0.5}}], 
         LineBox[{{3.3526707865892633`, 0.5}, {3.3575000000000004`, 
          0.37104680208333335`}, {3.3625000000000003`, 
          0.42871842708333335`}, {3.36485541669036, 0.5}}], 
         LineBox[{{3.3754497617670243`, 0.5}, {3.3775, 0.4494010729166667}, {
          3.3825, 0.47044054166666666`}, {3.3834967757064627`, 0.5}}], 
         LineBox[{{3.3972165828913097`, 0.5}, {3.3975000000000004`, 
          0.49336779166666667`}, {3.3978238764494764`, 0.5}}], 
         LineBox[CompressedData["
1:eJxF0TFIFXEAx/FLDMIzH4EOgijhoktLi4PPO1oMbHk6CPEEFdShoRzEeCK4
uDjo4pJoi0hCpIOLDg7WEEQO5eCi4FtEsOEtFgiC/3tfet8/HMdn+fG/+z4d
fzs4URdF0Wx4svenJ72V0YE4jarnIjn+Gc6rOF2vL86P/zhPTjff5RuG4/TR
wfuJ+rGjpFxq3ukfi9O2m7ujL9vLyXVhv33xTZxuJAsdV3Np8reruPJ1Jk4/
v/5daJo86XuQzS7834+iOBtc0i07/eXSqu5YDIsfdXeYu9nWz7Ozp/MNYfBQ
v8wu+F0Phetd/9IjYa7rTE9NhnOpp7PBip4Ln1u+1dn12h821pzNFXN67UM4
rXor/L7TTr0bPrf5mT4I1yv06G9hbuWFpoemh6aHpoemh6aHpoemh6aHpoem
h6aHpoemh6aHpoemh6aHpsfjmumh6aHpoemh6aHpoemh6aHpoemh6aHpoemh
6aHpoemh6aHpoemh6aHpoemh6aHpoenRVDM9ND00PTQ9ND00PTQ9ND00PfSf
ag/9r9pD00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTI1czPTQ9ND00PTQ9
ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND30PaNvkqY=

          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.4558917999999999, 0.16060319999999997`, 0.4593580000000001]], 
         LineBox[CompressedData["
1:eJxF0T8ohGEcwPFLWZw/pTNIkSwsFimGc7IwoM5iuYViMSAxnOUtWSwGFgYL
yaRksaiLZGFQ6hYDi8EZDBhM3uf9ct9fvb19hvfX87zfztnFqbmaVCq1Fj/h
vZ45HX35aSql/mY5W1c+/NDzYV51Yfvqq/tJT120b1Ye9NhLMXN6q4fidUuX
ui/Mue4JC090x2Ylf3Ggw/GKuzqsy27pZCL93R0vXNXv+fiACzocb3RGh3V1
0/r+Lp5xHd+2sD2iw3XzAzocL9Orj+J15S69vxdPqw6/r9Ckw3XbazU9Gqum
h6aHpoemh6aHpoemh6aHpoemh6aHTibS9ND00PTQ9ND00PTQ9ND00PTQ9ND0
0PTQ9Giomh6aHpoemh6aHjqb9ND00PTQ9ND00PTQyUSaHpoemh6aHpoemh6a
Hpoemh6aHpoemh6aHvVV00PTQ9ND00PTQ9ND00PTQ9ND00PTQycTaXpoemh6
aHpoemh6aHpoemh6aHpoemh6aHqkq6aHpoemh6aHpoemh6aHpoemh6aHpodO
JtL00JWkR7q0sfPx1l98GKJHujT8Odk217yYo0e6dP74uFI+u84NHi/ftEz8
f/+c+wUK6cLW
          "]], 
         LineBox[CompressedData["
1:eJxd3Hd4FNXXB/Dt2V1EpCtKl6oUadLvxQKKIB0BaQLSBEEQBaQJooD0JvwU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          "]], 
         LineBox[CompressedData["
1:eJxF0T8obnEcgPFDWRx/SgxSJAuLRcod3PdkYUC9DBYGCoPBle4d3rvcksVi
YGGwiEwkC4PFmywMSr2LwbsYMBj8KdP9nffJ+3zrnNNnON9+5zztM4tjs5VR
FP0JV/r8sb902TQSJ1FpHjKF3V/91RNxcnJ3t1w4zmeKucbDwek4Sd5GW2Yb
FjPP2dPW1YU4Wdl4ferN3f786Jxcv/j9/X4UVaS3fzpOF67ppsPBYm5Tt62G
jTu6K6x7P9A96Zzo/uqw8FwPpQe80uPheM+3eiqs67zX83NhHvVSuvBV/w2f
W/zS6fFaq2rKTtdN1uvtrTDNei/8vkKHPgqf29itz8Lxsn06H9atD+ib6zDD
mh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoetWXTQ9ND00PT
Q9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTo65s
emh6aHpoemh6aHpoemh6aHrol1IP/Vnqoemh6aHpoemh6aHpoemh6aHpoemh
6aHpoemh6VFfNj00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9
ND00PTQ9ND00PTQ99H/kV4gC
          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxF0T8ohGEcwPGLpO78WW4gRbKwWCwG52RhcHIWy6WoUzIgMZzlXZQsFguD
hcFksdyiLiULg8liYLGcwYDB5H3eL/f91dvbp95+Pc/77V9eny83pVKpnfgJ
793s5dTrT2ct9TebufTT2YdeCfOmS4c3X4PPer7au1d/1NOvlezlnR6P121c
65EwV3ooLLzQfXv1YvVUh+NVjnRYlzvQyUT6ezBeuK3fi/EB13Q43tSSDuvS
C/rhPp4ZHd+2dDipw3WLozocLzusz+N1TwP65Diebh1+X6lTh+v2tmh6dDRM
D00PTQ9ND00PTQ9ND00PTQ9ND00PnUyk6aHpoemh6aHpoemh6aHpoemh6aHp
oemh6dHeMD00PTQ9ND00PXQu6aHpoemh6aHpoemhk4k0PTQ9ND00PTQ9ND00
PTQ9ND00PTQ9ND00Pdoapoemh6aHpoemh6aHpoemh6aHpoemh04m0vTQ9ND0
0PTQ9ND00PTQ9ND00PTQ9ND00PTINEwPTQ9ND00PTQ9ND00PTQ9ND00PTQ+d
TKTpoetJD02PTK0r/znbUy7k6ZGp3U+0Lu7P3ebHVrcqzYX/71/yv9rju2s=

          "]], 
         LineBox[CompressedData["
1:eJxd3Hd4FNXXB/Dt2V1EUUIRpMNPmogUERTuBREEkVeaoALSBEWRohRFERQV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          "]], 
         LineBox[CompressedData["
1:eJxF0T0ohHEcwPEHSTkvC0XqJAuLxWKguywMyMtgOYpCMiAxnMWiZLnFwmCR
Mp3BwmAhWRhMtxjcYmEweCmT/3Pf3PdXz/P0qadf/+f5dsyvTi5URlG0Fa74
2b+8ka0aTaSj0rykCidrA7XTifRDumZ2b/wuVcw25YfmEumW1OdY28Jo6m3i
Mrm78v9+FH13ZXI3m7oivu3oRLxwXzfnh4rZA92+GzYe6+6w7utM98ZzoQdq
w8JrPRwf8F5PheO9PemZsK7rWS8thnnV6/HCD70dPrf4q+PjJavryo7XZRr1
0WGYVn0afl+hU5+Hz23q0VfheBN9+jasyw3qx4cwI5oemh6aHpoemh6aHpoe
mh6aHpoemh6aHpoemh6aHpoemh6aHvVl00PTQ9ND00PTQ9ND00PTQ9ND00PT
Q9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND06OhbHpoemh6aHpoemh6aHpo
emh66PdSD/1T6qHpoemh6aHpoemh6aHpoemh6aHpoemh6aHpoenRWDY9ND00
PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PTQ9ND00PfQf
fMSAlw==
          "]]}, 
        Annotation[#, "Charting`Private`Tag#5"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"trivial; k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(8\\)]\\) (\\!\\(\\*SuperscriptBox[\\(10\\), \\(6\\)]\\))\"", 
       TraditionalForm], PlotRange -> {{-2., 2.}, {0., 0.5}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 
        Scaled[0.02]}, {0, 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"T2.2\"", "\"T5.4\"", "\"T9.3\"", "\"T33.11\"", "\"T65.9\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.8423264, 0.4188294]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.9917508, 0.5901996, 0.09831576]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.9091264714520893`*^9, 3.9101545008181863`*^9, 3.910155616253199*^9, {
   3.9101562517976747`*^9, 3.9101562871700735`*^9}, 3.910162253949086*^9, {
   3.910168716292123*^9, 3.9101687292935357`*^9}, {3.9101687617626452`*^9, 
   3.9101687658955555`*^9}, {3.9101778893722553`*^9, 
   3.9101779231383815`*^9}, {3.9102519014488955`*^9, 
   3.9102519258906603`*^9}, {3.910252989625407*^9, 3.9102530153394637`*^9}, 
   3.910253079389468*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"dc004d46-0da0-47d1-914a-8ec5ac5c7400"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{6,4}-BBH_``_{0.77,1}.dat\>\"", ",", "#"}], 
              "]"}]}], "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.2\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<critical; k sampling: \!\(\*SuperscriptBox[\(10\), \(8\)]\) \
(\!\(\*SuperscriptBox[\(10\), \(6\)]\))\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "5"}], "]"}], "/", "5."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.910239429307313*^9, 3.9102394352050447`*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"27f4e9eb-54e9-4a2d-840d-6b6965753dde"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8423264, 0.4188294]], 
         LineBox[CompressedData["
1:eJxF1SGMl2UAx/G/7k7xUBnbGSg4RjnnZrFYTjbLESx3hXJFNzQQ0GCB8haK
hWI53SgaLFIMUNhuECgaTIzNIMVyBgsEk//3+bL38yv/fcqz5/l/w3vh8+sH
V19drVbvv7Jazb83t+/uPfvvzPHq5b7e3Xry47/8xby/+fD2w+c7f/LB/fO3
Tv7gy89ubN99zB+vj/vqAX8471d+bz7wZ3731sn+/Ts8X+/Gdzwft/stj038
Ymd94Df8z/76gtd4vt7eZzwft3WFf/9tvU95/drD25/w/Nz9j3i+3vYH/NP6
uCcX+fuj9c7x/PcdnuH5uec3uR5vL64H14PrwfXgenA9uB5cD64H14PrwWMT
14PrwfXgenA9uB5cD64H14PrwfXgenA93lpcD64H14PrwfXg3dGD68H14Hpw
PbgePDZxPbgeXA+uB9eD68H14HpwPbgeXA+uB9fjzcX14HpwPbgeXA+uB9eD
68H14HpwPXhs4npwPbgeXA+uB9eD68H14HpwPbgeXA+ux+nF9eB6cD24HlwP
rgfXg+vB9eB6cD14bOJ68MnowfXgenA9+NHowfXgenA9uB5cD64H12NrcT24
HlwPrgfXg+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vx
xuJ6cD24HlwPrgfXg+vB9eB6cD24Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwP
rgfX49TienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5cD64H14PrwfXgenA9
uB5cD64H1+P1xfXgenA9uB5cD64H14PrwfXgd0YPrgePTVwPrgfXg+vB9eB6
cD24HlwPPho9uB5cD67Ha4vrwfXgenA9eG/04HpwPbgeXA+uB9eDxyauB9eD
68H14HpwPbgeXA+uB9eD68H14HpsLq4H14PrwfXgenA9uB5cD64H14PrwWMT
14PrwfXgenA9uB5cD64H14PrwfXgenA9NhbXg+vB9eB6cD24HlwPrgfXg+vB
9eCxievB9eB6cD24HlwPrgfXg+vB9dg4vvP0h83HB/cu/XJq58u/zm4cj+/K
0dNL/wPMqFYs
          "]], 
         LineBox[CompressedData["
1:eJxd1VFIU1Ecx/G7I/UwggrUDGIhQVsEUaxEyHWiIiWKmKSBLMjAPeiDWviQ
Igk1GwUZGIRCSaxCCCUNYklyDxYNUsGhbRi9jCiCSQS1AmOre86v9qMOiHyQ
nXvu/zuOlefa61uEZVktzo/+najrmWh6K9TwkF7Lsj7uiWSTQi2lome3hFKy
NtNdOp4Qqrn70+jNikUZcKdjHdNCVXd885w6uSD9ej0RKjDiyoWXZuWO0MBM
blSocXxQbo1kg/G7QkWT/ak7rpeyTP/hllCXvAe9t5eV1NsFrglVftVvD5c8
l5ZefUK1H7s4duXzU/nd52zYJZSn7ejaZ9cnpbObJ9Im1D7X0OMNu8ekfkpt
s1ChR4GViHgo9Xbu085+O3t/ntg/IufnnHVcqHtlFZNTbwbli5yz4SGhOt+X
f71w+LLUrxusFqoxunfTg84Gac69Syjrz7rvbJfeRpsxbaadt/WF1tP6dT1r
6B7neJlVV9GdeoBf6LBeH2k9Pt87Gj1ojJVGDxo9aPSg0YNGDxo9aPSg0YNG
Dxo9aPSg0YNGDxo9aPSg0YNGDxo9aPSg0cMqGj1o9KDRg0YPGj1o9KDRg0YP
Gj1o9KDRgzarj0YPGj1o9KDRg0YPGj1o9KDRg0YPGj1o9KDR47/z537Z/5w3
Q8+ZRZvzxGnz/BhtnjdAm+26adM3TJueQfqAGThtevlos10pjUWv6PlnC0Wb
eadpc7wZGvckjXuYNvOK0OZ1O2hzvBBdZwZIm++fv2AvzG9ct/qhX5rxeQp2
V9WP1qaaGO5fd8Ee3D5bdaZmAvdtLm83jJ2/4W2fxv2ayduF3leRksqERI+8
7WttjB2pTkrf6+E9ZVN5++//j9/1eulQ
          "]], 
         LineBox[CompressedData["
1:eJw9km1IU1EYx68FIiNSaUEvMhhRK8qbEBgU8+nFmkhUu0YJyhrihL7YgoTQ
BeayN0fLL7ElQWiBg5qla1wV96RtlWIrp2sZK9IikCQiqDznBGv3dOgPh8P5
8uP5P79jrDutOJZJkmTKHu32L5YqMwsMb/m1zMJcsz5omWNYGcm4KhxvYZKH
YdFS2b6hWBJUQ/tXq8qwZGBeTp6chrtOsy7Vw/Cz57DbK0+Bd+zn5lovw77q
NwXb6+LAcc0Md0rrC4zBCWjgYVj+PWEvtj4HhQMZevwnrhgPRUGjOc0M447z
7//4RyELyxIZFm4443oXjwDH6Rm+rN84fT1vGCQehmzeYf9dosKiVQNSfEhL
U/tXhkGj6VIUP+WeGkj1hoCPN0axi1aN5K8LAccFKY7nt7V0nA3Bvz1QXN6j
vm4zPwatraGd4u6OD4HWljDwuk6KB12mhpE1KvDxainaFa/F/W0QKvgCKeZG
umv6FoZhBw/Fc0VrI749EeDrM1A0Xkt/uWN7AryujqJt7wNXoH8UfvHCBAdv
hu+xTU+Fj+y7cMvHR/1R4YOg6fKRXZ32Z8IHQUuwS7FtfSF8EDxuDWT88oTw
QfD2/bLyG85J4YNgq+VYb6P8SvgguCIaq79YOSV8ELy6ukbOSySED4JNF1Sf
5+iM8EHQnT7g604nhQ+COTnVusbOlPBB8EfTtnH9pVmIrTJXFWeW/v+vvwz5
ThE=
          "]], 
         LineBox[CompressedData["
1:eJw9mndc1tUXx0nx5yqlREtzpznKmQvXBzXFFAf409BURDPTLM0daqGh4shF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          "]], 
         LineBox[CompressedData["
1:eJw9km1I00Ecx/8WiIxIpRU9iDCiZg8uKTAotm8P1kSi2owSHGuIE3pjKxJC
F5hLe3A0fRObEoRSOKhZusZfxZE2M8VWTucyVuSKQJSIoPLugrUbR184jrsX
H76/+5yq6qLRukqSJHVq8X18nba8MLmCDg/PPPidJBH8rNs9oWyZxwaffqFe
SZCRUaGobY9hp8k1+quAwBE/5u6KR6FTxLptWoK667LbeXoWRjm/eclAcHt9
pSYrEkFNOgRrQmPVN8qmUa/kQIJG/ZmeWs1btKVoJhfB/ce6kjbbFB7ZtCki
wVmDN+nRTGKQ42QCva/TaN71GuEpHgL1zVMH2i2vkEgDCQZyd3x+1hfC7wJe
MHW+F3jItr9Eup6Cwnz4id3bN4I0Lp9CdSf+7YH5Bfbu46G4mrcp6D4UROkC
B1JkBrsqexeHYObjmigsRpfe8X0Al3k9G8Vxu7pmeKOMFo5rpjjY+snb2BAQ
70ixult+16R9jvTz+SgmspsaWq/4kR53lKKTlg9nb/ZjjteLUXzJvNAf6/Fj
meOWKJ7S4tjRtQHhg4ElrJY/RbLwwfCmetvM3awh4YMhd+sl+4dwUPhgCFuv
ffzrGRE+GJyec7dUJ0LCB0PJj4il0DAufDDsl7bkqHyTwgdDb8Vczp6qsPDB
8NV50uHSTAsfDEX9CU30/IzwwZC3ojsyOBYVPhjKgkl7qfU9OpaLjbOL7P//
+ge0kTq1
          "]], 
         LineBox[CompressedData["
1:eJxF1V9Ik1EYx/HtSF1YUEGaQSwkyGUQlSVCrudQURJFaGkgMzLQQC/8E16k
SEHNpCAFg1AoiaEIYaVBpCSFSYvMULKJ0Y1FESgRlAXGVnvOL/0d2Ds+N8/O
e74v79LPVBWUGY/HU5b46Hfmq44dKYMx6WjXNS1vXuuKib+iKHwgZ0I+1q+9
d2gmJvHGF6Gk9Ij88gdbhudjUthbez2jakiSp8LVgeS4tG0ezS7J7RNfaDb/
sS8uddm/K4pzw7IzS1dcxsfWrFz43CR5MzowLp7/61Rimj9I1wZ0It2k40I0
9kknNpcYSOu0lmE6qtuboud03Cxt3PXvklPdQDpTb9dP73U3TBfouHy63C3a
HV893eo2SHfr9sL0oDtAGj1o9KDRg3bHv8xjF+2OdxXtzm893aW/v4m+r7e/
jR7Q/eTQz3X7++gx3d4R2j0OJ2mXu5R2OStpt/862quXi/QKHXiVTtHjvEFv
1Bu+TW/R4+ih3eP3kHaP1xDtnscIfVx7TtAleoAf6LOa9wtdowO/0w2aZ4FG
D++S0YNGDxo9aPSg0YNGDxo9aPSg0YNGDxo9aPSg0YNGDxo9aPSg0YNGDxo9
aPSg0YNGDxo9aPSg0cMsGT1o9KDRg0YPGj2MLWreta6rplDQw9iaT6k/zu2/
JOhh7J2UtP7Bd22CHsambm38c3RPp6CHscG7gbmQ6Rb0MHa3t/3B6u29eN/W
GeurPLh84Fq/oIexVYfP917+9kjQIzHvStbTjqQngh7GXsiwGTennwl6GNs8
0RS95R0R9DAW782IoIexgU7vfPnkqKCHsTnVP30njo3jfR0xtrT+a09r2ltB
D2Mno82nNwSj8jKvoa/4vbGL/x//AM+1twI=
          "]], 
         LineBox[CompressedData["
1:eJxF0S+sj3scwPEfO8f/P7O54ZZjphyzKYpy5+wWgnLcoBDYEAQEhaIoiqJw
N8VsyiUIjqC4QSFIZhMoyhEUbJLnOW97Xp/wPHuVzz7fvfeevXTi3PrZbHZg
3Ww2/v/btHjh4665pXt3x3l/ZO3/59zS/ff/zr868ezIw8t/bXm3b25p9nue
HP10bfdBfr5wc3X5MP//bfHU7b/5zethjvO7B8PCkzxse3z0DK8uryzcvMjf
h3Uvr/K68XODt44Lb/Efj4cD7/Ce4byV+7x/WPftER8a5ykPr31w+QUfGw98
xf8M562+5dPDusUPfOH8MJ/5yrjwK18fnvvpJ4/nLczPTx7XndrJ9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxYXI9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9Nk6u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
x6bJ9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9dg8uR5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5bJteD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9dj6+R6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6bJtcD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cj+2T68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD67Fjcj24HlwPrgfXg+vB9eB6cD34y1oP
/rHWg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlyPnZPrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14N/AcjpwQ4=
          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.9917508, 0.5901996, 0.09831576]], 
         LineBox[CompressedData["
1:eJxF1S+I32UAx/GfcnN6/pnhFiwbw7KBiCCC5Tyw3MLKbeLKFYVZDGoQZJZv
WbEsaDmDClswLbiyMjlcWNGwNATLQIRxBosGk7/v85bv61N+vMrD8/ze4Xvm
/Y8uXnlytVq98sRqNf9+vnVr99G/Jw5X/++T7c2HN/7iD+b9wfvXf/r77G98
8c6pa0cP+Pyjq1u37vNb6+M+vsuvz7vN5+YDv+fT14727nzD8/WufsXzcdtf
8NjE/5xdH/gp/7m3vuCHPF9v9z2ej9u8zL/8vN4FXr92//rbPD93702er7f1
Kt9cH/fwZf76YL2XeP779k/w/NxTx7geLyyuB9eD68H14HpwPbgeXA+uB9eD
68FjE9eD68H14HpwPbgeXA+uB9eD68H14HpwPZ5fXA+uB9eD68H14O3Rg+vB
9eB6cD24Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwPrgfX47nF9eB6cD24HlwP
rgfXg+vB9eB6cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwPrsezi+vB9eB6
cD24HlwPrgfXg+vB9eB68NjE9eCj0YPrwfXgevC90YPrwfXgenA9uB5cD67H
5uJ6cD24HlwPrgfXg+vB9eB6cD24Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwP
rgfX45nF9eB6cD24HlwPrgfXg+vB9eB6cD14bOJ6cD24HlwPrgfXg+vB9eB6
cD24HlwPrsfTi+vB9eB6cD24HlwPrgfXg+vB9eB68NjE9eB6cD24HlwPrgfX
g+vB9eB6cD24HlyP44vrwfXgenA9uB5cD64H14PrwSdHD64Hj01cD64H14Pr
wfXgenA9uB5cDz4YPbgeXA+ux1OL68H14HpwPXh39OB6cD24HlwPrgfXg8cm
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6HFtcD64H14PrwfXgenA9uB5cD64H
14PHJq4H14PrwfXgenA9uB5cD64H14PrwfXgemwsrgfXg+vB9eB6cD24HlwP
rgfXg+vBYxPXg+vB9eB6cD24HlwPrgfXg+uxcXjpjXe+/fGzczv12Di88vi1
C1/ufLfzw7vT7y8e3zgc35mDX3f+A1fBXIY=
          "]], 
         LineBox[CompressedData["
1:eJxFm2dYlFcThlc0tthjixq7EQtqLNFYmFVjNPaCRmODiOWTGEs0dsUuNuyx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          "]], 
         LineBox[CompressedData["
1:eJxF0S+oVgcYwOHvjnvV+WcaXFi5QywKIoMxWJF7WXHB4hQtGhTUYJgGQbZi
sawYtGjYBiKYHMyiQYMLFg2my8AiiCDXYLkOTJ5zf+M8bziH5wsv7/l+u07/
/NOZz2az2b652Wx8/33syusdG+eXb90c59+la0/W9pzYPr985u03h64v/bm0
/vtX88tHvjv6x+PLe5fuXDiweWX3/PLs//nr4Ktfdu7nh4tXVw9/z/8M6679
wM+fDXOIV24PC4/zsO3ewVO8evjB4tXz/GFY9+QSz42PK7xlXPgbf3lvOPAG
fz2c9+B33jusW7vL345zn4evvX3hEf84HviUjwznrb7gk+Mf+JLPnR3mDV8c
F77nX4fPffWRx/MWFxYm14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H12PD5HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpsnFwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlyPTZPrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14Pr8fnkenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgemyeXA+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXI8tk+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxdXI9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9tk2u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
xxeT68H14HpwPbgeXA+uB9eD68Hv1nvwf+s9uB5cD64H14PrwfXgenA9uB5c
D64H14PrwfXYPrkeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPfgTrOrG6A==
          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8647229999999999, 0.3364763999999999, 0.1829199600000001]], 
         LineBox[CompressedData["
1:eJxF1S+I32UAx/Gf4+bpqVs5g2VDLBPEYrHcBpYzGLwVDbewwSwGNQgyy7es
CLKFlRvD4oLpDJYV4dAg+Ce4MgYrK5YzGNQgCP6+z1u+r0/58SoPz/N7h++L
Vz64ePXEarV65YnVav79dPtw9/E/p49W/++jna0HX/7B7837jfdvfPfXuUd8
8d6Z68e/8puPr20f/sDn18d9+C2/Nu8bfnk+8Cs+e/14794XPF/v2i2ej9v5
jMcm/vvc+sCP+fe99QXf5/l6u5d5Pm7rHf7l5/Xe4vVr92+8wfNz917n+Xrb
r/Ld9XEPXuLbB+u9wPPft3+a5+eeOcn1OLW4HlwPrgfXg+vB9eB6cD24HlwP
rgePTVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9XhucT24HlwPrgfXg3dGD64H
14PrwfXgevDYxPXgenA9uB5cD64H14PrwfXgenA9uB5cj2cX14PrwfXgenA9
uB5cD64H14PrwfXgsYnrwfXgenA9uB5cD64H14PrwfXgenA9uB7PLK4H14Pr
wfXgenA9uB5cD64H14PrwWMT14OPRw+uB9eD68Hfjx5cD64H14PrwfXgenA9
thbXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6cD24HlwPrgfXg+vB9eB6
cD24Hk8vrgfXg+vB9eB6cD24HlwPrgfXg+vBYxPXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD2eWlwPrgfXg+vB9eB6cD24HlwPrgfXg8cmrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6bC6uB9eD68H14HpwPbgeXA+uBz8/enA9eGzienA9uB5c
D64H14PrwfXgevDB6MH14HpwPZ5cXA+uB9eD68G7owfXg+vB9eB6cD24Hjw2
cT24HlwPrgfXg+vB9eB6cD24HlwPrgfX4+TienA9uB5cD64H14PrwfXgenA9
uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H12NjcT24HlwPrgfXg+vB9eB6
cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlyPjaN/3z28e2L75vl6bBxd2vzz
6/s/fnLh4POf3r6zuXE0vjMHDy/8B4BRXjg=
          "]], 
         LineBox[CompressedData["
1:eJxFm3dUVGcTh1eMxt6xG42JscQWe4nMxmg0Fuy9RE3sGjH2jlhj4qfG3rFR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          "]], 
         LineBox[CompressedData["
1:eJxF0S+IlwcYwPGfcnp6Ti0aVk7E4kBWLJbNw3KGhemChhkcqGHBMwxEy4pl
MFxYcYjlFJbOsOKCRcNgf4Irh2CxWG7B4E0YDHzf+8r7ecL78vmFh+f9fQ9/
dfXspe2z2ezYttlsfN/5/o/P787PLf10Z5znJ28/2Tz65f65pQvzbx7+/fv1
k1u/fzi39P/5tfvbD/zw6YOVTxbWj8wtzd7Pw+WXNw58zL8u3to4c4KfDutu
n+K//hzmM15fHRae42Hb2vJF3jjzaPHW1/zvsO7JN7xtfHzLe8aF3/HBteHA
H/nQcN6je/zRsG7zZz4+zi88fO3qymM+PR74G38xnLfxjC+Mf+ALvnJ5mFd8
bVz4mm8On/vyPx7PW9yxY3I9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9dk6uB9eD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+ux/zkenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfXgeuyaXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXI/dk+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+uxMLkeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeeybXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX44PJ9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9dg7
uR5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9
uB77JteD68H14HpwPbgeXA+uB9eD/9nqwW+3enA9uB5cD64H14PrwfXgenA9
uB5cD64H14PrsX9yPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HrwO01ayJo=
          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.4558917999999999, 0.16060319999999997`, 0.4593580000000001]], 
         LineBox[CompressedData["
1:eJxF1SGMl2UAx/E/7lA4VMoZLDhmwc1RLJaTTcMZNBwByhXYpBCUTQuUt+Cc
5YrlDBQNJooGittNgwUCCdgsFDd2BooGkv/3+br38yv/fcqz5/l/w3v26ucX
P3tptVq9e2y1mn9vbd3defri9OHq/93Y3nz0w3O+Nu8v3tv/7Z9zf/LFe2du
Hz3kj5/e3Lr7B3+wPu6LX/m9eT/zO/OBP/Fbt492793h+Xo3v+P5uO1veWzi
f8+tD/yK/95dX/A6z9fbucLzcZuX+cH99T7h9Wv39j/k+bm77/N8va3z/OP6
uEdv8/cH673J89+3d5rn5545zvV4fXE9uB5cD64H14PrwfXgenA9uB5cDx6b
uB5cD64H14PrwfXgenA9uB5cD64H14Pr8drienA9uB5cD64Hb48eXA+uB9eD
68H14LGJ68H14HpwPbgeXA+uB9eD68H14HpwPbgery6uB9eD68H14HpwPbge
XA+uB9eD68FjE9eD68H14HpwPbgeXA+uB9eD68H14HpwPU4trgfXg+vB9eB6
cD24HlwPrgfXg+vBYxPXg49GD64H14Prwb+PHlwPrgfXg+vB9eB6cD02F9eD
68H14HpwPbgeXA+uB9eD68H14LGJ68H14HpwPbgeXA+uB9eD68H14HpwPbge
JxfXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6cD24HlwPrgfXg+vB9eB6
cD24HicW14PrwfXgenA9uB5cD64H14PrwfXgsYnrwfXgenA9uB5cD64H14Pr
wfXgenA9uB6vLK4H14PrwfXgenA9uB5cD64HvzF6cD14bOJ6cD24HlwPrgfX
g+vB9eB68MHowfXgenA9Xl5cD64H14PrwTujB9eD68H14HpwPbgePDZxPbge
XA+uB9eD68H14HpwPbgeXA+uB9fj+OJ6cD24HlwPrgfXg+vB9eB6cD24Hjw2
cT24HlwPrgfXg+vB9eB6cD24HlwPrgfXY2NxPbgeXA+uB9eD68H14HpwPbge
XA8em7geXA+uB9eD68H14HpwPbgeXA+ux8bhly9++Xrn2acXHn90af+bExuH
4ztz8OTCf/q1WmM=
          "]], 
         LineBox[CompressedData["
1:eJxdm3l8zdfz/4naldIQaqf2jzWl9olqLbWUFrXWHluKqqoqbWyl1F4EQeyR
kIhsgpgkxJIgd1Gyy76vN7m52fO9ec/MfT9+v/tH+3g9mr7vued53ufMmXlN
12Ubvl1pVadOHdd6derU/jvuYuruaW5WQWfP1H6ioM/CIyFGV6ugweNS9l9a
/Q46782eee+CVVDAotZj1pvOQmuPiYnb/rUKMmgaTB3t0weavLuyccwBq6Dd
Jwqyhm67NLZO7cfRKqgOf0p6mx/4i6rNT+u0d52qE7dZe0xcquraxzX5XtWv
Xpo/U1X92Gh+4BeqNj8te+ZwVdcOz3qAqq+aH/euu6qVn9lO1eZf23thC1XX
/txO9VX9u3l4ieV1Lfon8+OuFKjavvaTpura6esdq+pvaweoVXXt8Dyeqbr2
cRsDVW1b+/FWNfFQNfFQNfFQNfFQtfJxVDXxUDXxUDXxUDXxUDXxUDXxUDXx
UDXxUDXxUDXxUDXxUDXxUDXxqGPRxEPVxEPVxEPVxEPVxEPVxEPVxEPVxEPV
xEPVxEPVxEPVysdR1cRD1cRD1cRD1cRD1cRD1cRD1cRD1cRD1cRD1cRD1cRD
1cTj/xu/sQb/n/Em1iDtB8fGvlQ+or3GKuO5V4Ppzc+MWpGXMFb5/is12L39
sUPPJ1iD8n1HarDDB1sGL3xrB8rjttXg5gUz/9i30x4UvvY1aBif7zNzwt+g
8JxZgysaBaW3Lb8KY5UJr8HKyE59/z0dQPtZ7xoMHd9+UOHRUFAeZ12DOHbq
V/Otw4BGXYP78g1tP6/3EnJq5z+7Gvc3Sf3C1O4VKPP9rhoPO4c/2erzCpTh
hVRjnT0/xddYa0B5nEc1pt0aMWlE9wigfbQaSw5d+2mHTgPKfO2txkV2xpY2
bSJA+bkbq/Hrc2F1dxzVgjK8hdV4JWpEh0fjNDBJmcBqdKqMSuzxgQ6U9Wdb
jdFn7/k2ddKAMn2dqrFZ6cwVc611tP82qcbZW/uObv1cA8SjCgvMP6dlhhaI
RxXuOvD1kCnm8RCPKlz4xL6gzW0tEI8q3BDWv7QgRgPEowoXRxx3eeegZR5V
+O9y/YUjORrmUYXTdncN3zFeyzyqMMWnQ/0R9bTMowpn28eHQVctKD93TBWu
PHV2W15TLSjD612FHz39rWb3B1rmUYW/TX9jmtRKyzzM451q/oIiDfOoRJeO
PxhWtdQyj0oss14yfmyqhnlUYit7l3oDG2uZRyU6LdoStTJWwzwq0X1yc++1
TbTMoxJPhg45fj9Bwzwq0XWpf+aaZsKjErukZI5ZlCI8KrHnOwf/Tp21zKMS
B7dek1lSIDwqcV6jg0+DPtcyj0q8/KHT1tU1wqMCl9+7tfLxfOFRgfsad5vY
rLmWeVSgzYwdT+rvEB4VaHI9fW6Mef6IRwV+Eex9/5q78KjAl0+2jt4/QMs8
KnBd0eKr0VHCowJThh9OHj5BeFRgL9/5LydXCo8KnLLK4ZputfCowPNjbyfO
bKBjHhW4dsqc5IFnhUcF5hfOHtWzVMs8yvFlhw2/x2UIj3J8HNh9fnutlnmU
Y7ef973s+JWOeZTjtOCMmKoLWuZRjqcuL3IvP6ljHuUYHfnn04N/a5mH+b9v
SWo6I0THPMpx9WRN9rxLWuZRjqUuPvFjguX9KMe8DM9do9K0zKMcvU03558+
Lu9HOQ4ePlbjt0DHPMqw31cP5hi/1TGPMmwS7GadG65jHmWYmTt56rbOOuZR
hhfWZW9P76VnHmXY9Ju9N0IG6phHGd7Vt9ya00/PPMqwsa1mp80+HfMow6Ml
EyuulOuYRxkWFsUMqaynZx5laN324988zb+HeJShbs7iR43n6ZlHGZq2d6g8
/kTHPMow8ug3dYet0zOPUmzccHaSQ7WOeZRiydw97TK+1DOPUhy9ZaTVEfPz
iEcpZnggtGinZx6luL8uHGh2RM88SvHzz1ZZLe+hZx6lOG70nwn39+qZRykO
Huhk83KhnnmU4jz9mvX9FuuZRyk6n0z49KGTnnmU4vztw/oFj9czj1J8/fXG
Vj/c1DMPEz6zne1XOFfPPEzof2bOnLYH9MzDhG/jYw/6HtIzDxM+Sj3e5JOF
wsOEmatbbzrioWceJoyPeR4wdZrwMP99gM26DZf0zMOEkQ/DXBI26pmHCf+1
q/aPWCM8TLjsxdCY2+f0zMOEC181u1l3mPAw4bjV5X+uvKpnHibsVfHB2Rfj
hEcJtkoa0GOg+XnEowRLN4+AE2uFRwk2xE872nQSHiW4bUmXNZ0OC48SPNwn
ecHydHk/SjBwt61NvqPwKMF2HTqvXlAt70cJbvF95XP3E+FRggWZm/7oOU14
lGDreyN2zP9XxzxKcE7xvUWt/xEeJWgT9++Cgunyfhhx0ENPDz974WHETubt
d99aeT+MGGynGz1IL++HET923vO9p07HPIzY9QJsjBsn74eR9utPhYcR7+Ts
cHtbKPuVEX++VDGloY3wYJ0t+5UR/3Q/03Wo5f0wYoJr/3mHrGS/MmLPZodb
+EyW98OI1kEdRs7vomMexRhbFX21a7TsV8U4e8Oe3X3765hHMbauPcDWy/lR
jJFN2/ea0kzHPIrR7a9Wz2v6yvlRjE3GjBiWGyX7VTEaNqydVWk+j4hHMRqX
rHqbflX2q2JcEbBhqcc5DfMoRufYaXk9l8t+VYz+W3ZumLtIwzyK8eKR3YuP
22iZRxFOD3F/l2GjYR5FqFvtPvB9lJznRdhVv+T5pksRzKMIP3ww7ZvHJ+U8
L8JB1tdzm7aMYB5F2K9h8Ve/TJfzvAg7Lhro4HzqNfMoQnfr3Pn/JUcwjyJ8
OPrptD3TXzOPIlzksNEruH0E8zA/v/YF7fyaeRThQXO4Ma3ja+ZRhJ096mfF
fvqaeRgwxtftfbiVxFcGfJ86eH23nq+ZhwEvD/pxce8BL5mHAdedW7Ny78VX
zMOAF/IXLkjPDGceBrRvHzEr6vhL5mHAYvNxWNnrJfMw4P/uBFk1HR3OPAyo
zZ7Xqnj6S+ZhwHS/y5XNfwljHgZMXj5hX6lzOPMw4Bv9nZjiA2HMoxAnjZse
PvPTMOZRiBnaf3tGGMOYRyEuedS4X+7IF8yjEEPPtdwwYWoY8yjE2KSMbUsP
vWAehXhFc2K53uM58yjEzL7Tl7aIf8E8CjHg+LCT9UY+Zx6F+PnJeuWX9z9n
HoX4Xp9aOTXvOfMoRI1mVYbtjGfMoxCX7qzfZu63z5lHIebE7dZty3zGPArQ
atKg0NmXnjKPAgxc8sOggYZnzKMA+5869mZo82fMowAfHTIHxM2eMo8C7PpZ
Fd796RnzKMCYc797lXz9lHkU4Ljz7SPLd4QyjwLssSD+ZKfop8yjAFctr2k3
0C+UeRTgTIdRR9e8fsI8CvDMDyP+m/HlU+ZRgH/lDew4dU4ojz8fB9Q97Til
5xMebz461u4Xp0LBSRlfPpr/a1CPDqE8nnxs/ZF5h3N8zN+fj6kRzQeWXZHv
y8ciZ9f8Y81DoViZ0Dzaz7o9Zr552KQk3GHXb4+ZZx6ObLJp/uHoJ8wvD3GG
k9/AQY9hhsIrD2vDi/nfhTCfPLQ51ev43oZPmEce2l5tsNXf8zG8VeY/F4/4
B+YN9w2GW8p852Krq6usPX8NgT3K/ObipMDYnJn6xzyfudjgb7sXp4aGwGfK
/OXS+9ogmOcrF0/AqIcpXiGQoAwwh+K5po95feZQPJgdBEeVCcxB1zrtDX2u
BvH6y8GXAx7k3P07BEYrD8xBh+JuLqH9Q3h95eD57ZsN2sZBzCMbd/S4PGXx
4iDmkY0ejr5Wb61DmEc2Rg/aUj9xWTDzyEbvvHqXb6U/Yh7ZGJD4V/v195B5
ZOMvBu2Lib8FM48s3NPQ+ZthyUHMIwtHmMO74dWBzCMLPylvtuOv6Y+YRxb+
/LbDVefAIOaRhcO7x/+z9UwQ88jCsHCnKueTgcwjC7svq55jG/GQeWTi/LEb
Phl3FplHJsUjo4KYRyZO+/56P31gIPPIxImXs0KO3XvAPDLRYP/kXMtRgcwj
E90e2HY5OQKZRwbG5cwc+Dk8Yh4ZWBtefrfjAfPIwD9euTdr0uoB88jAys7/
FFU3DWQeGbhmS/N9+W0eMY8MHNMr6/dPxz9kHuno4ft2/rrW95lHOiZ9bFv/
yr77zCMdO0YFHnJe/JB5pOM/s87VdAt+yDzM+teNaUlR95lHOq4cWr3Lo1sA
80jD7v+l4aRrAcwjDX9s0Tps74QHzCMNcw7bTv3o0APmkYYjh+WWDS8OYB5p
uHWVXV/b7+8xjzS0GTv4u0Hb7jGPNNw39HyaX0kA80hFL2P35cG77jOPVHyc
UGoXsyyAeaSiz2nND1+4+zOPVOzh/ebNzzb+zCMVQ+vP6vzT7HvMIxULP2y6
VLsxgHmkYESbVn7eZfeYRwq6u5k/0/2ZRwrCTvu733TxYx4pGDaxV+fz2/2Y
Rwr6NwPs7+3PPFLwRH6vkUc23WMeyZgLyaHXjvszj2RcopntHBLtyzyScXbz
jINZKT7MIxkjrvSZduFPX+aRjNs2OUQXaf2YRzIO3eja/sON/swjCUvjf88P
3OfHPJLw/MXJUcee+jCPJLy1ok5cXy9v5pGEFzYfG6qz9WEeSdh2XvcdBa6+
zCMJZ93a74Rn/JhHEq5s1cc5z+jLPBIx4u/yTi/Ah3kk4i6/UK3x7l3mkYhN
TYdX/7j/LvNIxFF2czyaZ3gzj0TUN2wx/KKDL/NIxLxvDUPsw32ZRwLm9D89
S+PowzwS0OX9qcT0X+8yjwQc2sB+XdIQL+aRgA03tDwXfNCLeSRg6Mhffm1g
5808EvCR+bp6NtkHIpXxv8dZs47PW1vtw+N9j61L6hyOvuANg5TxvcfJka/b
tLL34vHE4+4ujXZ1KfXk749H15/rLYBhd/j74tFm7S1DdIwXZCi843BYu18i
L/t7M984PGXY2H/Gzz7MMw5ttpcuv7PIm/nFIs4zbzhDvcBF4RWLX5uvv63+
8WA+sdjcoer5XMfbzCOW8hl/efL8x6DzZ1/2367zgrnKfMdgI49zN/433Rsa
KfMbg32yx3YJ2+bN8xmN7RyGZN3J9YLVyvxF49oPj+g8HT15vqLxl/1H2nUc
eQuClPUahV+OrR95dJU7r88o/P7Ll+/X+t2GLsp6jMKhxlijyfsOr79I7H8o
u/0U27uwVXlgJO4yvz4uK+/y+orE83NjW/T61ot5vMMDK5b+1q3Mg3m8wxnL
dDEnNrozj3dYmz76qY0b83iLHZ56dIlt4M483uKOHU4HfFJuM4+36Dd5/JuQ
VXeYx3+42adJwLNvvJjHf7h+d9CAv7LvMI//0OfxlOoc8+8nHm/wfcvbH75a
c4t5vMEWCzZ/tz7xJvN4Q/tX55vM4w29zz3dmIceB192dEwceot56PG8Cdqm
n/RgHnp8kvhg9NM4T+ahw+Nzb+S9dvFkHjoM/Cz56J7y28xDhz3dC202X3Nn
HlqMO+j7uenATeahxXCXhHlx37oyDy1O6HHm2vX1rsxDg/n7Pj5Y4XWTeWhw
8bHwI9/vcWceGvygsHJndvwtuKOMPwLXnr2+5uyp2zzeCOz6+9q/Oza7DUuU
8b3G2Y/eND55UcbzCnPyI8bPqOvG3/8KD2n6dO2+wpW/7yWOWt7v5OutN0Cj
8A7H3HU/rJzhdIP5hmPRqn2nK5e6Ms8wyqdE32R+LzDW78cYv1Q3sFN4vcBm
F536tI1zZz7PsXuTRm3jT7szj+fYr3raoQOebjz/z2g//+Im3FHm+ynWpt9m
vbsBHynz+5Ti/TfXeT5D8WRtfuDyddAo8/cE34/pfftX03Werye4OHL4vJCC
G+CorNfHeHH+soZVtjd5fYZga/P1t76debzKegzBW0d/3/7fIzdef8E4qfb4
2OwGBcoDg3DyhwXrbzjJ+grCgMqtXw343BWWKONH7LN1jr9PIxnvIxx3MMK+
R8E1CFLG9xB9JzlGvrt6jcfzAO/brNuQ1/86f/99XPyBT6nDgBv8ffdw4uuV
y0ZfcAUXhbc/bmvUt++L4pvM1w8bL57SNeSG8PTF0Obl7xZcd2N+3tjJZu+F
DudugqPC6y6euLnDoYXxBvPxwi/3brpUMf4687iDLubjqNWrq7BEmd/buCx5
RePdH1+FIGW+3LDN3CU761+/CnbK73fF2nTikH3XeX1dw19vZ5nuDr8JXZT1
cgXXjjAH4Pa3wFEB5oIHAz/xWQaeQAUgZ3Q6fnpwxaI7QAWU07hVuyt6URez
Vi5Ux3DDhbtzJxjM/7/C42+0Sj/xqnVD83iV9fEH7uxt3jDPnoA6yvpdgWFx
Kes3+a8UDRZNfw+Wv6fngeV59H1g+T4aD8h4HGm8IOMNot8D8nvs6PeC/F6e
D5D54PkCy3zRfILMpyPNN8h8dyEeYOFBvEB4uRBPEJ4JxBuEN68HkPXA6wVk
vfB6AllPCbTeQNYbr0eQ9ehC6xVkvSbQegZZz11ovYOsd34fQN4Hfl9A3hd+
n0Dep6P0voG8b/w+gryPBfS+gryvR+l9BnmfB9H7DvK+834Ash/wfgGyX/B+
ArKf8H4Dst/Q+J+B7Ecf0X4Fsl/dof0MZD+bQfsdyH5XQPshyH7I+yXIfsn7
Kch+yvstyH67kfZjkP2Y92uQ/VpD+znIfr6R9nuQ/f4jOg9AzgM+L0DOCz5P
QM4TPm9AzpvndB6BnEd8XoGcV1vpPAM5z57TeQdy3rWl8xDkPOTzEuS85PMU
5Dzl8xbkvOXzGOQ8pvHrQc7rRnSeg5znc+m8BznvXSkeAIkHSileAIkXOJ4A
iSc43gCJNzgeAYlHaD2+BYlXnCieAYlnMijeAYl3hlM8BBIP7ad4CSRe4ngK
JJ7ieAsk3uJ4DCQeIx6RIPEax3Mg8RzxiAKJ94hHFEg8SDyiQeJFjidB4kmO
N0HiTY5HQeJRjldB4lXiEQMSzxKPWJB4l3jEgsTDxCMWJF4mHrEg8TTH2yDx
NsfjIPE4x+sg8TrxiAeJ54lHPEi8TzziQe4DxOM9yH2BeLwHuU/wfQPkvsH3
EZD7CN9XQO4rK+g+A3Kf4fsOyH3nId2HQO5DKXRfArkvNaP7FMh9iu9bIPct
vo+B3Mf4vgZyX+P7HMh9jsafCHLf+4DugyD3wf/RfRHkvjiL7pMg98ntdN8E
uW/yfRTkPsr3VZD7Kt9nQe6ztB6TQe67U+k+DHIf3kz3ZZD7sjPdp0Hu00/o
vg1y3+b7OMh9nO/rIPd1vs+D3OeJRwrIfZ/zASD5AOKRApIvIB4pIPkE4pEK
km/gfARIPoLzFSD5Cs5ngOQzON8Bku8gHqkg+RDikQaSLyEeaSD5FOKRBpJv
IR5pIPkYzteA5Gs4nwOSz+F8D0i+h3ikg+SDiEc6SL6IeJg155OIRzpIvol4
pIPkozhfBZKv4nwWSD6L810g+S7ikQGSD+N8GUi+jHhkgOTTiEcGSL6NeGSC
5OM4XweSr+N8Hkg+j/N9IPk+zgeC5AOJRyZIvpB4ZIHkE4lHFki+kXhkgeQj
iUcWSL6S85kg+UzOd4LkOzkfCpIPJR7ZIPlS4pENkk8lHtkg+VbikQ2SjyUe
2SD5Ws7nguRzOd8Lku/lfDBIPph45IDkizmfDJJPJh45IPlm4pEDko8mHrkg
+WrOZ4PksznfDZLv5nw4SD6c8+Ug+XLikQuSTyceeSD5duKRB5KPJx55IPl6
4pEHks/nfD9Ivp/rASD1AK4XgNQLiEc+SD2BeOSD1BuIRz5IPYJ45IPUK4hH
Pkg9g+sdIPUOroeA1EO4XgJSLxlC9RSQegrXW0DqLT9QPQakHrOJ6jUg9Zq/
qJ4DUs/heg9IvYfrQSD1IK4XgdSLKD9YAFJP4noTSL3JiupRIPWoNlSvAqlX
9aV6Fkg9i/xdhSD1Lq6HgdTDuF4GUi/jehpIPY3WYyFIve061eNA6nH3qV4H
Uq97TfU8kHpeEtX7QOp9XA8EqQdyvRCkXsj1RJB6IvEwgNQbuR4JUo8kHgaQ
eiXxMIDUM4mHAaTeyfVQkHoo10tB6qVcTwWppxIPA0i9leuxIPVY4lEEUq8l
HkUg9VziUQRS7yUeRSD1YK4Xg9SLuZ4MUk/mejNIvZl4FIHUo4mH+flcryYe
RSD1bOJRBFLvJh5FIPVwrpeD1Mu5ng5ST+d6O0i9nXgUg9TjuV4PUq8nHsUg
9XziUQxS7ycexSB+APYLgPgF2E8A4idgvwGI34B4FIP4EdivAOJXIB5GED8D
8TCC+B2IhxHED0E8jCB+CfZTgPgp2G8B4rdgPwaIH4N4GEH8GsTDCOLnIB5G
EL8H8TCC+EGIhxHEL8J+EhA/CftNQPwm7EcB8aMQjxIQvwr7WUD8LMSjBMTv
QjxKQPwwxKMExC/DfhoQPw37bUD8NuzHAfHjEI8SEL8O+3lA/DzEwwTi9yEe
JhA/EPEwgfiFiIcJxE/EfiMQvxH7kUD8SOxXAvErEQ8TiJ+JeJhA/E7Ew/z3
7IciHiYQvxTxMIH4qdhvBeK3Yj8WiB+L/Vogfi3iUQri52K/F4jfi3iUgvjB
iEcpiF+MeJSC+MnYbwbiN2M/Gogfjf1qIH414lEK4mdjvxuI3414lIH44YhH
GYhfjniUgfjpiEcZiN+O/Xggfjz264H49djPB+LnIx5lIH4/4lEG4gckHmUg
fkHiUQbiJyQeZSB+Q/YjgvgR2a8I4ldkPyOIn5F4lIP4HdkPCeKHJB7lIH5J
4lEO4qckHuUgfkv2Y4L4MdmvCeLXZD8niJ+TeJSD+D3ZDwriByUeFSB+UeJR
AeInJR4VIH5T4lEB4kdlvyqIX5X9rCB+Vva7gvhdiUcFiB+WeFSA+GWJRwWI
n5Z4VID4bYlHBYgfl/26IH5d9vOC+HnZ7wvi9yUelSB+YPYLg/iFiUcliJ+Y
eFSC+I2JRyWIH5n9yiB+ZfYzg/iZ2e8M4ncmHpUgfmj2S4P4pYlHFYifmnhU
gfitiUcViB+beFSB+LXZzw3i52a/N4jfm/3gIH5w4lEF4hcnHlUgfnLiUQXi
NyceVSB+dOJhHi/71dnPDuJnZ787iN+d/fAgfnjiUQ3il2c/PYifnnhUg/jt
iUc1iB+feFSD+PXZzw/i52e/P4jfn/sBQPoBiEc1SL8A9xOA9BMQjxqQfgPi
UQPSj0A8akD6FbifAaSfgfsdQPoduB8CpB+C+yVA+iWIRw1IPwXxqAHptyAe
NSD9GMSjBqRfg3iIPjaW+z1A+j24H8RONPeLWPRZ6iex6GvUb2LRntSPYtEB
1K9i0dzPYtHc72LR3A9j0dwvY9HcT2PR3G9j0XVr/+Go6qbUr2PR3M9j0dzv
Y9HcD2TR3C9k0dxPZNGTqN/Ior+jfiSLXkT9Sha9ivqZLJr7nSya+6Esmvul
LJr7qSyaeKiaeKiaeKiaeKia+70smvvBLJr7xSya+8ksmvvNLJr70SyaeKia
eKia+90smvvhLJr75Sya++ksmvvtLJp4qJp4qJp4qJp4qJr7AS2a+wUtmvsJ
LZr7DS2aeKiaeKiaeKiaeKia+yEtmvslLZr7KS2a+y0tmvsxLZr7NS2aeKia
eFjZSb8n94PaST8o94vaSb8o95PaST8p95vaSb/p/wE60ry+
          "]], 
         LineBox[CompressedData["
1:eJxF0T+sTgcYwOGPXPW3LDpYbiMWErF0sYgbhmvQ4ZKwMJBgMCBhYbGQpstd
utRgEYlJBx0YutwOFgaTSiwWiVyDBYmp59yfnOcdzsnzDW/e8/12n79y4sL6
2Wy2f91sNr7/O3pq+bdNcwv3/hznzeHllc97z+yYW7j+7e+7ix9+Pbz2+665
hdn3eXj10JbXe/ivxXc3dx7gZ/N3VpcO8r/DuuUj/PLFMMf59YNh4Wketj1e
PMerS0/n71zmL8O6lRu8bnzc5q3jwt/5p8fDgX/wz8N5T+/zvmHd50f8yzhP
ePjaB1f/4WPjgc/55HDe6is+O/6Bb/nSxWHe87Vx4Se+NXzuu288nje/YcPk
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
evwwuR5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB4bJ9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+uB9dj0+R6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6bJ5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5c
D64H14PrwfXgenA9uB5cjy2T68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD67F1cj24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD22Ta4H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD67Hj5PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrsX1yPbgeXA+uB9eD68H1
4HpwPfjjWg/+utaD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXI8dk+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg/8HCLTE
xQ==
          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxF1SGMl2UAx/E/7kA8QMoRKDBnwc1R2JzlZKMcwXIUyhXctBiUYMHyFoqF
YjkDRTfd2CgUittNAgXZCIyxWSiUI1g0kPy/z9e9n1/571OePc//G94Pvvjm
2pfvrFarj4+sVvPv91v3d169PX2w+n83tzdf/Pw3fzXvNe/d+eOfC3/xtYfn
bh8+46uvbm3df8yfrY/79ne+NO8BfzQf+Bufv324+/Auz9e79SPPx23/wGMT
/3thfeB3/GZ3fcGveb7ezg2ej9u8zn8+We9zXr92784Vnp+7+ynP19u6yL+s
j3vxIf+0v95Znv++vdM8P/fcUa7H+4vrwfXgenA9uB5cD64H14PrwfXgevDY
xPXgenA9uB5cD64H14PrwfXgenA9uB5cj1OL68H14HpwPbgevD16cD24HlwP
rgfXg8cmrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6nFxcD64H14PrwfXgenA9
uB5cD64H14PHJq4H14PrwfXgenA9uB5cD64H14PrwfXgepxYXA+uB9eD68H1
4HpwPbgeXA+uB9eDxyauBx+OHlwPrgfXgx+NHlwPrgfXg+vB9eB6cD02F9eD
68H14HpwPbgeXA+uB9eD68H14LGJ68H14HpwPbgeXA+uB9eD68H14HpwPbge
7y2uB9eD68H14HpwPbgeXA+uB9eD68FjE9eD68H14HpwPbgeXA+uB9eD68H1
4HpwPY4vrgfXg+vB9eB6cD24HlwPrgfXg+vBYxPXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD3eXVwPrgfXg+vB9eB6cD24HlwPPjN6cD14bOJ6cD24HlwPrgfX
g+vB9eB68P7owfXgenA9ji2uB9eD68H14J3Rg+vB9eB6cD24HlwPHpu4HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+txdHE9uB5cD64H14PrwfXgenA9uB5cDx6b
uB5cD64H14PrwfXgenA9uB5cD64H14PrsbG4HlwPrgfXg+vB9eB6cD24HlwP
rgePTVwPrgfXg+vB9eB6cD24HlwPrgfXY+Pg6b2Tm3efn7r8yY1HB78e3zgY
35n9l5f/A+XJWYY=
          "]], 
         LineBox[CompressedData["
1:eJxdm3dYlFfTxhEVS4zYY08wxpIYX1tEYxlEo9hiTcQWjYklGiIaNVETxW6M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          "]], 
         LineBox[CompressedData["
1:eJxF0SFsVQcUgOHXpWWlhdUwgSkhmC1ZZkjIzEKD6cQMIGZAlIQhECtiZjMz
GEzNzCZqGgIJSREzTCwhrcBsSyYWQoLBYDqBAZIp7u1P7nfEvfmeODn3/aev
fXfp+gez2eyzudlsfJ/b2H98b3F+7ddfxnl2fmvv9SdXVubX/n5wbGn73+Pn
D38/Ob82ez93N79cenqGH66/+OHE5/z76u2Di1/w/rBu6wL/9ecwX/PTnWHh
Nzxs213f4IOLj1Zv3+Q3w7q973lufPzEy+PCO/zx7nDgz3xqOO/RNn86rHt9
n8+O8xsPX7uz+Qd/NR74hC8P5x38w1fHP/A53/h2mJd8a1z4in8cPvfF/zye
t7qwMLkeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1
4HpwPbgeRybXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfX48PJ9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9VicXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXI+jk+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+uxNLkeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpwPbgey5PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrcWxyPbgeXA+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPY5PrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrsdHk+vB9eB6cD24
HlwPrgfXg+vB/x324LeHPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1WJlc
D64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB78
DvOZw+g=
          "]]}, 
        Annotation[#, "Charting`Private`Tag#5"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"critical; k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(8\\)]\\) (\\!\\(\\*SuperscriptBox[\\(10\\), \\(6\\)]\\))\"", 
       TraditionalForm], PlotRange -> {{-2., 2.}, {0., 0.4}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 
        Scaled[0.02]}, {0, 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"T2.2\"", "\"T5.4\"", "\"T9.3\"", "\"T33.11\"", "\"T65.9\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.8423264, 0.4188294]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.9917508, 0.5901996, 0.09831576]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.910253083599592*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"159895ea-b2a9-4791-a235-7acb41be3925"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"Association", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"#", "->", 
       RowBox[{"Import", "[", 
        RowBox[{"FileNameJoin", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<data\>\"", 
           StyleBox[",", "Input"], 
           StyleBox["\"\<dos\>\"", "Input"], 
           StyleBox[",", "Input"], 
           StyleBox[
            RowBox[{"ToString", "@", 
             RowBox[{"StringForm", "[", 
              RowBox[{"\"\<dos_{6,4}-BBH_``_{0.38,1}.dat\>\"", ",", "#"}], 
              "]"}]}], "Input"]}], "}"}], "]"}], "]"}]}], "&"}], "/@", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "\"\<T2.2\>\"", "}"}], ",", "supercells"}], "]"}]}], 
    "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", "Black"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Energy \!\(\*StyleBox[\"E\",FontSlant->\"Italic\"]\)\>\"", ",", 
      "\"\<Density of states\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.6"}], "}"}]}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<nontrivial; k sampling: \!\(\*SuperscriptBox[\(10\), \(8\)]\) \
(\!\(\*SuperscriptBox[\(10\), \(6\)]\))\>\""}], ",", 
   RowBox[{"PlotStyle", "->", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ColorData", "[", 
       RowBox[{"\"\<SunsetColors\>\"", ",", "\"\<ColorFunction\>\""}], "]"}], 
      "/@", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"1", ",", "5"}], "]"}], "/", "5."}]}], ")"}]}], ")"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9102394371705465`*^9, 3.9102394422011757`*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"1099a1c1-b7e4-4327-b2fc-e20e07831e0c"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{}, {{{}, {}, 
       TagBox[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[1., 0.8423264, 0.4188294]], 
         LineBox[CompressedData["
1:eJxF0S+sV2UAx+Hf5Y/AFWVzl2ABnQULhUK5uFmugXIplFtkw0JQAwXKKRQL
hQLBjWkgUSgUN6aBosEEgcJklEuwSDDxO++Hnedbzp7y7n3P5/Mr31+6emC1
Wl3fWK3m782thzsv/z/xZPV+P25vPvvlX/5u3mveu/37f2de8KXHp27t/83f
vLyx9fApX1gf98NvfG7eI/5yPvABn761v/v4Z56vd+MOz8dt/8RjE789sz7w
Or/ZXV/wGs/X2/mW5+M2L/Nff653kdev3bv9Nc/P3T3P8/W2zvKv6+OefcH3
7q73Kc+/b+8Ez889dZjr8fHienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+OjxfXgenA9uB5cD94ePbgeXA+uB9eD68Fj
E9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4vrgfXg+vB9eB6cD24HlwPrgfX
g+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD0+XFwPrgfXg+vB9eB6cD24
HlwPrgfXg8cmrgfvjx5cD64H14P/GD24HlwPrgfXg+vB9eB6bC6uB9eD68H1
4HpwPbgeXA+uB9eD68FjE9eD68H14HpwPbgeXA+uB9eD68H14HpwPY4trgfX
g+vB9eB6cD24HlwPrgfXg+vBYxPXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD2O
Lq4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXgenA9uB5cD64H14PrwfXg
enA9jiyuB9eD68H14HpwPbgeXA+uB58cPbgePDZxPbgeXA+uB9eD68H14Hpw
Pfju6MH14HpwPT5YXA+uB9eD68E7owfXg+vB9eB6cD24Hjw2cT24HlwPrgfX
g+vB9eB6cD24HlwPrgfX4/DienA9uB5cD64H14PrwfXgenA9uB48NnE9uB5c
D64H14PrwfXgenA9uB5cD64H1+PQ4npwPbgeXA+uB9eD68H14HpwPbgePDZx
PbgeXA+uB9eD68H14HpwPbgeXA+uB9fj4OJ6cD24HlwPrgfXg+vB9eB6cD24
Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwPrgfX48DienA9uB5cD64H14PrwfXg
enA9uB48NnE9uB5cD64H14PrwfXgenA9uB5cD64H12NjcT24HlwPrgfXg+vB
9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24Hvx84/4nrz7beDLefe6fr94B
T9leJw==
          "]], 
         LineBox[CompressedData["
1:eJxd1j9oE2EYx/EX0cEsOsTBJaIu0cFFhILEV0WohVJoQV3ioGIXh3ZxCQ5d
olDEYhEhHSqlWqxDqCJaRbkjDiK0OGlEKJq6CAluufe/evcc+ujvhRC+cDz3
vu8nQ/ZenBi7vEUIcSP9ZN/D8bMzP1ZEfJjWN3mgOtPqPxTxwFH5ZOneJ7mn
3h1dnRfxxsLI+PLmW7mrOdip3RHxixOfe0cOPpCF9uJkZVrE4t81xZ2U04FX
udNppfoV7k6t2By8wJ2NK5zjXl9L1zD3m3468CR3Oq07OsCdba94iPt+Oq69
n7uRrd3c6WnL1R3c2XFL22D//V/Rf/vtcK/R4qb9rHLT+xe56X0z3DSuxj1O
i3uMBnIfowvnJq8yN40rcueLu5fdf/fn36b7bnPT9lrcNK7JPUcXyE33Veem
405y0/aq3KfpArnz3x03XV+Jm45b4M49AngE8AjgEcAjgEcAjwAeATy46bgV
btpeOYBHAI8AHh48PHh48PDg4cHDg4cHDw8eHjw8eHjw8ODhwMOBhwMPBx4O
PBx4OPBw4OHAw4GHAw8HHg48LHhY8LDgYcHDgocFDwseFjwseFjwsOBhwcOA
hwEPAx4GPAx4GPAw4GHAw4CHAQ8DHgY8DHho8NDgocFDg4cGDw0eGjw0eGjw
0OChwUODhwIPBR4KPBR4KPBQ4KHAQ4GHAg8FHiq6NnTp6a1H12XuoaLGxtSr
U5uPZf6Uirbf3dn4crYlc48kGtn3YXpodl3mHkn0/f3tiXdbP8rcI4kWesdX
Xi9/leeXnlduvkyiP/8vfgM9KYmy
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbX65g69l19f9xmDw2H6HXOvrwB1f98/aKjLh2/9H
9ksKbLmuL/66f96s07xtVg/t+w991Yjp/7pfdseHlZ3a9+2rRNa5P6z6ut/N
MM2im+WOfRoYfN0/OWtTJAfrTfsgsIFf98doxdR8N7lmDzKtwPbrfv7fWs94
5162BxoGNPHrfmGlz7df+Vy0Bxsn8nW/pq5nt8Luc/YMYPB1/27XhDX5Caft
3wSCDPyy/4Ls9Zmhm07Yg0zjuv5l/7bLL4MXTjlmD3beoS/7K6uW6jjLHLUH
G7fuy/7+hicb+KKO2M+aCQJf9nPVRDTN9z5iD/KtXOuX/Umhqwz5pI/ag71b
8GX/s9x6x6dFx+zBzov5sr84K33GraAT9h4g49y/7J/lHMStOvmUPSTcvuzP
dp39+I7aWXtw8Ml92d/IziZgJ3LBHuxdLqD+jIlva/ZftP8G9vDn/UeUP34q
WXfZHmzcw8/751Vavtn3+Kr9GTD4vP/Xpdvzu9tuQOPj836RYmX7r0p3oPHx
ef9ZzXepJ+QeQOPj8/6jVqH70p88tPedL+24qf4zPD4B/UD+Iw==
          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQzdV/3ymn8dN+YzB4bF9gy3V9ccGn/duz9fuVZjyy
j+k/9FUj5tP+sqrTh46ceWjv8bBKZJ37p/0h7GlF4XMe2EP0fdp/K/KLH+ud
u/Zyra8Dd8h92i+2c1dZTd8te5Bptlyf9v/LTpOySr5u/00DZOLH/ZFfEi/I
5FyxBxv38OP+0AYmpg1TLtqfAYOP+9umzA/5XXLWfgfYwI/7t35aeoor4oj9
ErADP+63/ThHV2HLFnuw8/o/7t+yYbnsv1mb7MHGVX3cLxNj9cwmebN9Ghh8
3D/j767Lc9W32QeBDfy4/4jc20ne33bZg71r+3H/9sJ5R35JHrQHO0/j4/6m
ObLTPm86Zg82TuTjfmfZsB1Plc/aM4DBx/3CEjcCwp9ctH8TCDLww37Nm9eX
c3pctQd79/qH/cU671exn7lhD3beoQ/75++63xfbf9sebNy6D/unrGvbWBR6
137WTBD4sL+wa+F6Y4n79uDga/2w/xC3qaxI+gNofHzYn5Z09vZr84fQ+Piw
PyQtdtsGxkfQ+Piw38/SMszmxCP7pftKvmvafIDHJwDo5gA/
          "]], 
         LineBox[CompressedData["
1:eJxdmX9wVNUVxwOl/qSOgECACYVWJaWtOqUIUuiJMAUclEr4WQuYIli0A1gK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          "]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQvWRfyXdNmw/2xmDw2N7jYZXIOvcP9n6WlmE2Jx7Z
x/Uf+qoR88E+JC122wbGR/ZFtlzXFxd8sE9LOnv7tflD+7bXgTvkWj/YH+I2
lRVJf2A/ayYIfLAv7Fq43ljivv06d5CBH+ynrGvbWBR61x5kWv+hD/bzd93v
i+2/bX9tcQHQxA/2xTrvV7GfuWH/BmTc6w/2mjevL+f0uGoPciMDw0d7YYkb
AeFPLtqLgQ38aO8sG7bjqfJZe60YkAM/2jfNkZ32edMxezuQ82w/2m8vnHfk
l+RB+yCQcYEf7Y/IvZ3k/W2XfRoYfLSf8XfX5bnq2+xBvn1Y9dFeJsbqmU3y
ZvsJYAd+tN+yYbnsv1mb7JeBnLf4o73txzm6Clu22O8CGbfjo/3WT0tPcUUc
sT93BgQ+2rdNmR/yu+Ss/SOwgR/tQxuYmDZMuWj/DeTdrx/tI78kXpDJuWIP
dh7XJ/t/2WlSVsnX7cHGyX2yF9u5q6ym75a9ETgePtnfivzix3rnLjQ+PtmH
sKcVhc95AI2PT/ZlVacPHTnzEBofn+y3Z+v3K814ZM/df98pp/ETPD4BLQTx
Rg==
          "]], 
         LineBox[CompressedData["
1:eJw9kV8o63EYxn+dOERGWW7YOoeIcS78uUDxJPkXLkwrtCQ1TpMIN9ZqnI5F
u5iTc8HEkiiStCJR1Nq0/Avr2Dm2YoZy/Am/75fiwvl9f63z1Nt79X56nvf5
3Nyh1HzgOE4uDNvV1vgim4FHtqgAhu00VW3m4cxXbbRe+DHbWRDhmeaxl3av
ccnPsCYfuKlZ5SHtTgJN9GF/l4nH65HXajL+xrlOuljm5zHZm3e7EfiFZ4Fm
pzwcSY9PPYtuCDCBSND99cedfvMQIk5O0B/2MaZQeoAs0QdBW8l4wJeyh3I/
AxJYipWRySPbaDQzg8K9tnX0ROlCF7PXSXDVbii67NqCkeEGCJpV85mSeCcs
Y0wEEfq6b9ZKBwRzApDA3HexJGlwQIxrJ+jVzWQUJzhxzOx5CFbc17VTP7dw
y3A3BAcyz5jK5gL7GcdRrJc0LXQ07SBOBFKkfakwfVrfh4LFTaWITeS9f6sO
USgGpoh+U1xFTbihZLgaCrVCrX/JOUaLKIoRra0+PPQPxPfpKEozW3JNIb5g
HxSy1Ye5ofTTYB8Uk5adKGO+P9gHhWVZOvz8fo4896Dk+xr93+c/VEbvPA==

          "]], 
         LineBox[CompressedData["
1:eJxd1j9I1HEYx/FvUUPXUIMFLUa1mENDEQhhz68IShBBoVosqMilQQlapMFF
BYn+EcE1FCIe2WAWUSoFcQ0RZE1pBFJeS9DR5l3f/93z/aUPfL5wd7yX557f
93XD7bnY33N5o1JqtPHiz3OlV+035mt0KJ2fVF5t6b1VrtF4NZt5M/WDFicG
2gtLNfr1+U7/h02LVO2ebR7+XaOuvV/GOu4uEM9Qqk5b7m8vfj9Tpp3TJ1cG
m+pUXB56faLyjFob01Zb6nS949KLm09G6GhhqTGxTur/6eFx3dJ96UgPNvFA
6dtpQekSrzchPc/jZqU/feQjXUkDpWv8uKvSab3C3/VO45qlD6Z7kj61wgOl
z/Pj9kpf5fUGpEd43LD0gyIf6XR909K5h3TuIZ17SOceer1zD+ncQzr30OCh
wUODhwYPDR4aPDR4aPDQ4KHBw4CHAQ8DHgY8DHgY8DDgYcDDgIcBDwMeBjws
eFjwsOBhwcOChwUPCx4WPCx4WPCw4GHBw4KHAw8HHg48HHg48HDg4cDDgYcD
DwceDjwceHjw8ODhwcODhwcPDx4ePDx4ePDw4OHBw4OHB48AHgE8AngE8Ajg
EcAjgEcAjwAeATwCeATwiOARwSOCRwSPCB4RPCJ4RPCI4BHBI4JHBA/pdP2b
VbbW6Xq3Saf72yU9yd+/T/opP/4B6Tnep036Ha9/XHqB1+uUTj+Hs9KJ+4J0
4rwinfa/Jr2B34akt/LAMekdfJ33VDZ37Fv1cOsk7eYHfqiy5fGuvqnKe9rP
1/FYZW1H6Hnp0VfqfPvy9J8Zla39v/gHXLhGjA==
          "]], 
         LineBox[CompressedData["
1:eJxF0S2sjnEYwOH39f1tM4JyMIWiKIoxhaAcgkJgQxAQFIqiKIpCsJnZpCMo
BIWgEKQzm2JMOYKCTfK852fPdYfn2VXu3f/99ly4euriislkcmM6mcz+n6aP
t33bPT16cHm+Hnl67fCGxb3To5P/8/z4l5vbD/CruTtL84f47a99Z+8d4w/v
hznJi0+GhWd42LZw/Dwvzb+cu3OFfw/r3tzg6exzmzfOFt7lHQvDgfd513De
y0e8f1j36xkvP/MFD699cu01n5gd+I5PD+ctfeRzw7p9n/nypWG+8/XZwp98
a3jul788O29u9YrRs3Vnt/LDB8Ps5HpwPbgeXA+uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD67FydD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD1Wja4H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H6tH14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1WDO6HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HmtH14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H12Pd6HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HqsH10P
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlyP
DaPrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrsXF0PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD
68H14HpwPTaNrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrsfm0fXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXYMroeXA+uB9eD68H14HpwPbge/GO5B/9Z7sH14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+ux9bR9eB6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB/wA6bqQn
          "]]}, Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[{
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0.9917508, 0.5901996, 0.09831576]], 
         LineBox[CompressedData["
1:eJxF0SGsVmUAx+HvIqBeEMolWGBIgWKhUC5uzO0aKJdiuUU2KQQhULCccouF
QoFg0UCiWCC4MQ0WDSY2Z2FslGugQDDxnffHzvMvZ095977nd/b6d9e+PbRa
re5srFbz9/utxzsv/j/5bPV+t7c3n//0mm/Me8V79357c/5fvvbk9P7B3/zV
i7tbj//gy+vjbv3KF+f9whfmAx/xmf2D3Sc/8ny9u/d5Pm77Bx6b+O359YF3
+L/d9QVv8ny9nW94Pm7za/7rz/Wu8vq1e/eu8Pzc3Us8X2/rc/55fdzzc/zw
wXqf8vz79k7y/NzTR7geJxbXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6
cD24HlwPrgfXg+vB9eB6cD24Hp8srgfXg+vB9eB68PbowfXgenA9uB5cDx6b
uB5cD64H14PrwfXgenA9uB5cD64H14PrcXxxPbgeXA+uB9eD68H14HpwPbge
XA8em7geXA+uB9eD68H14HpwPbgeXA+uB9eD63FscT24HlwPrgfXg+vB9eB6
cD24HlwPHpu4HnwwenA9uB5cD/599OB6cD24HlwPrgfXg+uxubgeXA+uB9eD
68H14HpwPbgeXA+uB49NXA+uB9eD68H14HpwPbgeXA+uB9eD68H1+HhxPbge
XA+uB9eD68H14HpwPbgeXA8em7geXA+uB9eD68H14HpwPbgeXA+uB9eD6/HR
4npwPbgeXA+uB9eD68H14HpwPbgePDZxPbgeXA+uB9eD68H14HpwPbgeXA+u
B9fjw8X14HpwPbgeXA+uB9eD68H14FOjB9eDxyauB9eD68H14HpwPbgeXA+u
Bz8YPbgeXA+ux9HF9eB6cD24HrwzenA9uB5cD64H14PrwWMT14PrwfXgenA9
uB5cD64H14PrwfXgenA9jiyuB9eD68H14HpwPbgeXA+uB9eD68FjE9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPQ4vrgfXg+vB9eB6cD24HlwPrgfXg+vBYxPX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD0+WFwPrgfXg+vB9eB6cD24HlwPrgfX
g8cmrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6HFpcD64H14PrwfXgenA9uB5c
D64H14PHJq4H14PrwfXgenA9uB5cD64H14PrwfXgemwsrgfXg+vB9eB6cD24
HlwPrgfXg+vBYxPXg+vB9eB6cD24HlwPrgfXg/95ur/68rONZ+PdF19+8Q5Q
5V4V
          "]], 
         LineBox[CompressedData["
1:eJxd1w1M1GUcwPHTZAUrCoM5pqDIAhQVPVraCB5fQgqzpQ0toJFvOEIUIm3C
Mgxw01JefI2UUjPkRLQy01B/N9RMFJmp0CF33Ilmemp693+5+9//pOP/PNdT
v2e73b7b7XfP83zudruohSvmLhms0+lO+x4Dz8frquX0Zp0xUVt9ZEx2Vau4
X2f8XWcZHJj+ExlZaZ9zrF5nNIz+O2FrTQEJa06zlWzRGdv19cMPfjKEBHXt
LUzeoDPq/rvKeEtxvoErefumRVbm87aVhDanLeA9MC5oPu/2i771Bu/Tom/g
dN6+afY5U3gPbC90Au9vfeO6onl/ObDCeftOG5f9LO+B40YGoP2L/fC//dp4
X9QWb20/x3hr77+Xt/Z+Vby1cSW8c7XFe642kHeKduG8Na843tq4UN508b43
cP/2x/+2dt9dvLXttfLWxjXzrtMukLd2X5W8teMW8ta2l837Ne0CedPPHW/t
+iJ5a8cN4k09vMjDizy8yMOLPLzIw4s8vMjDizx4a8dN5q1tL86LPLzIw4s8
VOShIg8VeajIQ0UeKvJQkYeKPFTkoSIPFXmoyMODPDzIw4M8PMjDgzw8yMOD
PDzIw4M8PMjDgzw8yMODPBTkoSAPBXkoyENBHgryUJCHgjwU5KEgDwV5KMjD
jTzcyMONPNzIw4083MjDjTzcyMONPNzIw4083MjDjTxcyMOFPFzIw4U8XMjD
BYktg1avP9OQQj1c8E34mSdXqbdTqIcLik8WfDf9laGEerjgbk5tW2jxREI9
XHDBaX3QZJ5JqIcLGg/Ezaobl0V/D4NcMGrGueCxRQWEeshwaxA5OU5XRqiH
DIay0npSUEOohwwTyl+9X2PdTaiHDNOi7eVk22FCPWTIPD5sR1hbC6EeMoRN
6vfkZpwl1EOGorB6Q8byS4R6yFAXHQ9Pr7pKqIcMltA88a/nugn1kOGtW0ca
bn7RS6iHDMN/bcsIt9sI9ZChrXHXgg8+v0HorclwtWnm+sJcG6EeEiR2TK46
fMtCqIcEIzdO1D8ovk6ohwT3y+wbwi+bCPWQQGnvIguXdxPqIcHJwZc36xt7
CPWQYLzQvFSM7yXUQ4JlWVtMo4ZbCfWQYPnO2O/XrLMwDwnMD1vubPOamIcE
a8dNOvHp8SvMQ4L3q4W8sOQLzEOC/La4xpik08xDhNENh27nv9TKPEQokmyJ
94LOMw8RQmPlpNCwK8xDhHrdruzcC93MQwR99dLtK3ZZmYcIfR3mry4m32Ae
IrwdsuW3+Gs25iFCoKV6ZsCmXuYhQt5Uw5tCjN9DhI7ylh9XXb/GPETYHbIs
u3/TVeYhQubYFWlTCjqZhwg7jtZO/DOqm3kI4Dw1ZO3+S2bmIcDsounBkwOs
zEOA2v4ew+NoK/MQIDY1pXVGi4V5CKDMe1wVE+X3ECD+YFMm5JqYhwBH9bbt
Sl4X8xDAcUQ1ZpzqZB4CFFboS7LWdTEPASIPjR+z+CMT8xBg48jkd0yXrzMP
AaKSU4NDGszMwwkH1NS+RZkW5uGElcWPfk4OsTAPJ1QE/1IxI8fMPJywZv6Q
/ixTD/Nwwmf72mf9YethHk7oOzM/aUO5mXk4Yee+xS8HVlqYhxNi5yS4XvzY
7+GExHTD+VxbL/NwQunkJ14/u8z//XDCHsOIgoQRFubhBJc9qem9qT3Mw/f6
sPCI6gq/hwMmPHPHnHrWxDwcEJTz4dHNpd3MwwHEdq9Tv7qHeTigNJgMDTT5
PRzQERvwcMwiK/NwQHXEtGFKu5V5OGBpbX5EQoP/++GAczeVxT+8YGUeDpAe
Ltnz1Lu9zMMBO7Y+352T2Ms8HJA6Om32Jd/ngXo4ICA9QjZOszGPRzDvRM3q
m1/fIFPjuzvh7iPw/z/4B7iwyXg=
          "]], 
         LineBox[{{-1.1114603509355774`, 0.6}, {-1.1075, 
          0.5453574375}, {-1.1025, 0.3969878333333333}, {-1.0975, 
          0.2392251875}, {-1.0924999999999998`, 
          0.20491616666666668`}, {-1.0875, 0.34101702083333335`}, {-1.0825, 
          0.4987900416666667}, {-1.0775, 
          0.5869208333333333}, {-1.073000048024336, 0.6}}], 
         LineBox[CompressedData["
1:eJxdmXlUVdcVxnFIa1ytGpWoSZbLaJaxKVqKSWqdtjFaJ+KAGie0aJynpEZw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          "]], 
         LineBox[{{1.0730000480243365`, 0.6}, {1.0775000000000001`, 
          0.5869208333333333}, {1.0825, 0.4987900416666667}, {1.0875, 
          0.34101702083333335`}, {1.0924999999999998`, 
          0.20491616666666668`}, {1.0975000000000001`, 0.2392251875}, {
          1.1025000000000005`, 0.3969878333333333}, {1.1075000000000004`, 
          0.5453574375}, {1.1114603509355778`, 0.6}}], 
         LineBox[CompressedData["
1:eJxd131QVFUYx/HVZAoqCoMcRlGRSVBUdGnShuAHGlKYTdqgBRT5hkOIiqSN
MhkGOqOlvPgaKaWOIohoZRbi2/iSiQJjKrTILrugmaKmu3v3brt398a996xn
5jkzsPOdgWfPOZ+7f2z43CUzF/TX6XTn+n6U16TojrbT9x4jVl09cERllp4V
HmPWifKVt77vRkD73qXxAVb4pYaJZ5IsGLq2d8ZvQ61IHpEyvSXCDL36f1bs
2PpSR1ZsF96yrAquT7HC8WjBnmc+7MLHfdOiMq24eMs1/6dXzFgWr0y0YmFF
blhMtRnrlHFrrSgLSxrkajaj8ltlWdEa6fdo1Dwz6lOUgVYUBmKgv8EEZVrp
WStgud+mX9mJNmV77VYEZC07trmwA/eVcb1WjHv+rjH5ggHKGXU6GwpDQsPK
SjrwsjrQBmdvXN1HiZ0YrRw3yoY9tUPyYoaYkKAeuO/vJz719oVFXZipjJth
Q2xq7aVsSxey1WVD5IwY56ufd0E5rWWVDTv3zX/df60JZeoGbeg5PztuQ7ER
+5Xt7bXhq33N0/6ydOK4eoE2rJ49QM4wdKLlirJsKAk8XjIly4hudaANywse
/xofZGIeNhyUknvmpZuYhx3h8cmBQdVG5mHHxmHxHxiu3mQedgw9PHbU/M8M
zMOOpSX6VRnr2pmHHdaj0pm0U23Mw45jest2V04787Aj+lBd+ulsA/OwwzXL
WzoyvJN52BGZnHB2SqPPw44KubPW2/c8aB52TM+fHDjRz8w87LCdGrDmQIuR
eQjYcaxi/N/hPg8B6aOXpEzKa2MeAnYHLcqUN11nHgJaixt/XnHzBvMQkJNY
+659ZAfzEOBvKpvqt8nnIeD9oC1/RN+wMA8BPa3G767EdzMPAfqyhduX7DIz
DwFVul2Z2Zc7mIeA4EgxLjjkGvMQkO+wxN4PuMQ8BIyoPnwn97WzzMOB3Kao
mpFx55iHA5+U2XNC4i8zDwfWjJlw4suGa8zDAeOjxrvbPAbm4cDinZE/rl5n
Yh4OLMrYYhg+2Pf5cGCsvX6hEN3FPBw42f/qZn2Nz8MBV3M75i7uYB4OPCjq
3RB61cA8HBi2cbz+YcFN5uFAbOvE0iO3TcxDxPW6qeuXZluYh4imml1zPv26
m3mIGPx7U1por4V5iHjv9tHqW9/4Ph8iTME5wj8v+jxEVEZEn35uxXXmISI/
pKo2bXEL8xARMkF2Z6ddYB4i0hsG7QhpamQeIpIieoux7QjzEDGu+M0H5ebd
zENEbVFhFfLKmYeI2/1wcoyuiHk4MXzKxcDR+XnMw4mag1HTKsdkMA8nLtvM
D+uMU5mHE/eyKpqCC8YzDycKTubtn/zGQObhxA+h559eId1J0DyciG3st3L9
+eoEzcMJHVuaB2/Ng7fmwVvz4K15/PekNQ/emgdvzYO35sFb8+CtefDWPHhr
Hrw1D96aB2/Ng7fmwVvzcD1pzYO35sFb8+CtefDWPHhrHrw1DxfxcBEPF/Fw
EQ8X8XATDzfxcBMPN/FwEw838XATDzfxcBMPN/FwEw838XATD4l4SMRDIh4S
8ZCIh0Q8JOIhEQ+JeEjEQyIeEvHwEA8P8fAQDw/x8BAPD/HwEA8P8fAQDw/x
8BAPD/HwEA8v8fASDy/x8BIPL/HwEg8v8fASDy/x8BIPL/HwEg+ZeMjEQyYe
MvGQiYdMPGTiIRMPmXjIxEMmHjLx4K1ev58u0dfq9b7AW72/UN77lPeP4H1Y
Of443g3KfibxPqdsfzLvZmV77/BWH4fZvFXuObxVzlze6v6X8+6n/Cri/awy
cAPvEOU6t+gSm/VVgw99MQDDlANX6RJrR/wbs7U8D6OU6zigS/xTZ+rvn/oL
GirLxNR6XaLv+8H/fYxoew==
          "]], 
         LineBox[CompressedData["
1:eJxF0S+Mj3EcwPHf+e/8KwTlDIWiKIoxs52gICgnsCEICApFuaIoCkExm0RQ
XFAICkESKDebcoJybJLnd297Xp/wPHuVzz7fvfdfuXn+6rrJZHJnZjKZ/r8u
LU5OH5g5eXRtvp94fuv47JeDMycn/+fV/PLd3Ud4aW5x5dwxfr96aOHhKf70
cZiz/OXZsPAiD9tezl/mlXNv5hZv8O9h3bs7PDP93Odt04UPeM/L4cBHvG84
781TPjysW33Ba898zcNrn916y2emB37gC8N5K5/50rDu0De+fm2YH3x7uvAX
3xueu/yXp+fNbVw3erpuYRc/eTzMXq4H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB7rR9eD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9djw+h6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6bBxdD64H14PrwfXgenA9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cj02j68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD67F5dD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD22jK4H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H1tH1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1
mB1dD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9
uB5cj22j68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD67F9dD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD12jK4H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD67HztH14HpwPbgeXA+uB9eD68H14J9rPfjPWg+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpwPXaNrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP/geY3KQV
          "]]}, Annotation[#, "Charting`Private`Tag#2"]& ], 
       TagBox[{
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.8647229999999999, 0.3364763999999999, 0.1829199600000001]], 
         LineBox[CompressedData["
1:eJxN0SGsllUAx+HvIoheVAjXQIEhBYuFQrmyUS7B4KVQbtENCgENFChvoVgo
FgwWDCYKhcLGNFgkmCgU5ma5sFEgWOR7z4+9j//y7dm+nZ3z/k59e/3SlQOr
1erGxmo1/97aur/z/N+jj1fv9v325tN7r/jqvH94785vr88840sPT9ze/4sv
Pr+5df8P/nJ93HeP+Oy8B/z5fOCvfPL2/u7Dn3m+3s0feT5u+wcem/jNmfWB
N/jF7vqC13i+3s43PB+3eZmf/LneV7x+7d6dCzw/d/ccz9fb+oJ/WR/39DT/
dHe94zx/vr2jPD/3xCGuxyeL68H14HpwPbgeXA+uB9eD68H14Hrw2MT14Hpw
PbgeXA+uB9eD68H14HpwPbgeXI+PF9eD68H14HpwPXh79OB6cD24HlwPrgeP
TVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9fhocT24HlwPrgfXg+vB9eB6cD24
HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwPrgfXg+txZHE9uB5cD64H14PrwfXg
enA9uB5cDx6buB68P3pwPbgeXA/+ffTgenA9uB5cD64H14Prsbm4HlwPrgfX
g+vB9eB6cD24HlwPrgePTVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9fhwcT24
HlwPrgfXg+vB9eB6cD24HlwPHpu4HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vx
weJ6cD24HlwPrgfXg+vB9eB6cD24Hjw2cT24HlwPrgfXg+vB9eB6cD24HlwP
rgfX4/DienA9uB5cD64H14PrwfXgevCnowfXg8cmrgfXg+vB9eB6cD24HlwP
rgffHT24HlwPrsf7i+vB9eB6cD14Z/TgenA9uB5cD64H14PHJq4H14PrwfXg
enA9uB5cD64H14PrwfXgehxaXA+uB9eD68H14HpwPbgeXA+uB9eDxyauB9eD
68H14HpwPbgeXA+uB9eD68H14HocXFwPrgfXg+vB9eB6cD24HlwPrgfXg8cm
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6vLe4HlwPrgfXg+vB9eB6cD24HlwP
rgePTVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9TiwuB5cD64H14PrwfXgenA9
uB5cD64Hj01cD64H14PrwfXgenA9uB5cD64H14PrwfXYWFwPrgfXg+vB9eB6
cD24HlwPrgfXg8cmrgfXg+vB9eB6cD24HlwPrsf//n/s5X9ff7bxeLz77N/n
3wJYEV69
          "]], 
         LineBox[CompressedData["
1:eJxd131M1VUYwPGr+VJoGQ7FlyIZrJGI4ls6Q04mqSQj0aQ/JJ2hlOnUVEjB
Sp20NBlq6ECHifhCWSSJigp7AINQ8CUE7uVyX9OVC4u4v/d7f1e7/M6xs56z
Mfb957nnPJ87NsLf37B4dX+TydQQ+On7PTZ43OdTfzDVTjXOPfJKWn69VGaq
lR+Mq2+9W0Jeyu1OqTpmqn3reHlXXvQQMqJ8vju7wFRrYifIXLpx9l7extnB
W44KDMzkHZgWlruWtzs7pHz+St5944Le5X2zJXCSeF+TAgPf4B2Y1p0yk3ff
9UIm8j4ZGGeO4F3Ud0bzDrw2Km0Y777nhg1E95cew//u6+bdYhzexn2qeBuf
X8rb+Lx83sa4bN4ZxuG92BjIO95YOG/DK4q3MS6ENz28H/btv/vRf23s28zb
uF49b2NcOe8jxgJ5G/vK5W08dyNv43ppvBcYC+RNv3e8jfWF8TaeG8SbeviR
hx95+JGHH3n4kYcfefiRhx958DaeO5u3cb0oP/LwIw8/8tCRh448dOShIw8d
eejIQ0ceOvLQkYeOPHTkoSMPH/LwIQ8f8vAhDx/y8CEPH/LwIQ8f8vAhDx/y
8CEPH/LwIg8v8vAiDy/y8CIPL/LwIg8v8vAiDy/y8CIPL/LQkIeGPDTkoSEP
DXloyENDHhry0JCHhjw05KEhDw15qMhDRR4q8lCRh4o8VOShIg8VeahQPrKh
0D3hRDz1UGGwqeTp6tM34qmHCst/ORV6Ilaif56DVLjvHh+39OwLhHooEPH9
+fmHkucQ6qHAtrWbs958Kp1QDwW88tGssP67CPVQ4PqBW7VNC4sJ9VAgs+xy
T/SeSkI9FBAuvNN8jTQR6qHAXXvmq/edHYR6KFC5tSI2YYqLUA8F6vIKYg6O
cRPqocDF8/WD95xxEOqhwKl/zp+8mG8n1EOB1pltPfUvOwndggK1Sf1Sp12z
E+ohw97SXIe0z0Kohww/LXNM2pbcTqiHDAndt0wD1lgI9ZDhyDNfbH423UGo
hwypmWs6JkxxEuohQ03jxJSaTAuhHjI8kA82fjiilVAPGVZmxS1pL2oj1EOG
O4k9Y1cINkI9ZBCKOtsygl2EesiwuqlCGtrPSqiHDHNPXo7Km9rKPCS4sq3m
uR8P/8o8JBh4dcvpe21m5iFB/Hv2CkuqnXlI8NI3+4sv1dmYhwQJv19qL3rd
wjwkuBV++EpKZzvzkEBZF/vHhFQL85Ag8XphWfMHNuYhQXn85IZJw+zMQ4Kh
i2KmL73RyTwkWHJ71yLHMDPzkOCryuwtz++0MA8JRpG8HCHCxjxESKyOK44e
bmceIoRV2R0Loq3MQ4TvSLvv+E4z8xChZNbc5fqfFuYhwpiKuOm7q2zMQ4Ti
faHqJ8125iFCzrcNNw9/bGUeIsye9eU5MdLMPET4LVFtDrFYmIcI5rRlq7/u
tTMPEXrmSHpqlZN5iNA7c8r2yRVdzEOAHaVB667KZuYhwMOzhTO23LEyDwFG
724pG5rsYh4COJd9dnPFeBfzEGC90BlyYpCVeQgQsb3/a8FgZh4CRP5dIZaU
2pmHAGML5h6bkeRmHgJUV7rPTTM5mYcAj9afOTJv/xMPAdo0+0pTRxfzEMC6
aWLD0oFu5iHA1o71V++Y3MzDA58WBIfuaLQxDw+sKg4NEcJtzMMDyeeGD9qa
52IeHhjeGpOcv87NPDywO/ZSzuXbDubhAYuctXBTk415eMC59+cB06e5mIcH
mhMiX1Q3uJmHByILP8qIOeRkHh6ouz/vwIUsG/PwQHpOzIOalCceHhjZKj5s
OepmHr2w6u0RGZVJLubRC9a/jj8eEt7FPHohY1x1+rFNdpIePKqusaoXnvz/
8C/Yidk6
          "]], 
         LineBox[CompressedData["
1:eJxdmXl01NUVxwekIAgcqyxBIQ21aosgyFIMSm4QFAU8LJYKFGxUBFpjQZBK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          "]], 
         LineBox[CompressedData["
1:eJxd13tQVGUYx/GjeSm1DAfFS6EMTEMiiqjpGPLDxAvJkGjSH5qOIZTpaKGQ
ipU66qTJoIYO6GAiXigLJVFBYRIMQlE0BHaBXZZVp5y0iD2XXfca55wX35nn
ndnd+f7z7HPez/IHQR9tWJzSVxCEmp6X+pniN7KqtqwbU7TzEA231dON1HEV
ycfTzHiw1b94vrUbbf+c8A0OaocSujy7Wu7G6veGp5bGd2KQofCzWYNsGNEo
Pb19zIrA3U8SywJtSM4Mf1yZaEGkNteGqkfzDl7KMGGBVR1oQ0jup6nhhy1Y
0TMtdLkN9bEhrzs2WJE2S51og2Xfb/2mTe3EHnXcbhuMSsbCtDoTjuapx4Zd
EVcyy+92oGe5noE2DGsMT8heZ4U6LbvahoQLwwZszupEi7qewYbV+QH+YpAJ
T9VxT2z4MscvYHutCeodCIKIzS3rr90TrBihDRTRljaxZml/K8arjxsqoumZ
eZXQ0o5o7YFFeNefPTrvQCsWq+MSRVSUWi9MFSxI1Y6IMTlzjk+Pt0K7vq0i
Qv4tkQoKzTigLSgieFvft/1+NeCMul6hiPViq//JAW24ql2gCMuyr+6sHN/J
PESM2nW7aEhCJ/MQ8fRc7vRN99qYh4jthYPWXVMMzENC94zIbZNL2pmHhK7Z
sjuprNdDgmH5spTvus3MQ8KDOEe9v9HIPCTMmvnNBSnEwDwkZP5Qc+fI523M
Q0L+/gDHF/Vm5iFhdEnUtF1lJuYhoWDmnBXuv43MQ8KPaHad2GFgHhICy8wd
C8LamIeEuIqo/LBhZuYhYySyMsVgE/OQ8W3p1k2v7jAyDxlL7u5c1DHUwDxk
DFkUPm3prV4PGcXRk2smDTUzDxlxN3OL6j82MQ8Z9nURf01IMjIPGQ1BR64m
tjYzDxmxf15pzosxMg8ZY78/kH+lysQ8ZER/aC4xJvX+fcjof23TmYdNBuYh
4+qWylfOH/mDeSiYc6o8NGtKI/NQkFJXIg/p08Y8FIh5rU2pfp3MQ8G9uK4x
K0UT81CwKiNqSXNeE/NQ8Fg5VPvJ8EbmoaCydmJiZbqReShISl/TMiHSwjwU
HH1pz8aXkzuYh4LYJw1CvzVG5qHgl2Udk7YkNDMPBfsKd3fI+43Mw47r8X2S
pt4wMw87Gmc0dVW/YWEedpz+7+Kpy9lm5mHH5YvVA/ee7WAedlRl5YQfGm1l
HnaUbi6JiI3sZB523Denv/XI0sI87BAvvV9/A3XMw470ovKusL2lzMOOmwcb
rtctzGcedjiVYxmBfXcyDzu2rN2YMfeFZOZhR/BPF+cfTpjNPBx4ZB0ftfTc
a8zDgRW/nw44GSFH6x4ODBQKXqw4cyta93CgeERNrnXCyWjdwwGBHd2Dt+7B
W/fgrXvw1j146x68dQ/eusez56178NY9eOsevHUP3roHb92Dt+7BW/fgrXvw
1j146x68dQ/euofzeesevHUP3roHb93DSTycxMNJPJzEw0k8nMTDSTycxMNF
PFzEw0U8XMTDRTxcxMNFPFzEw0U8XMTDRTxcxMNFPNzEw0083MTDTTzcxMNN
PNzEw0083MTDTTzcxMNNPDzEw0M8PMTDQzw8xMNDPDzEw0M8PMTDQzw8xMND
PDzEw0s8vMTDSzy8xMNLPLzEw0s8vMTDSzy8xMNLPLzEw0c8fMTDRzx8xMNH
PHzEw0c8fMTDRzx8xMNHPHzEg7d2/f2FmN7Wrncob+3+RvE+rX5/MO/z6uNP
5F2u7jOD9w11/Xd431HXi+et/Rw+4K1xr+Ktca7lre2fzruP+rad92B14D7e
w9XrzOE9Vn3g40LMuyeK27PCBuNN9TqKhBjl8bjqxvsFGOM37uspPwsxvf8/
/A87uXdB
          "]], 
         LineBox[CompressedData["
1:eJxF0S2sjnEYwOH3+Ob4CgTlGApFURRjCkHwERQCG4KAoFAURVEUgnJmk46g
HEEhKARJUcymHDblsCk87/nZc93heXaVe/d/vz2Xb5y9smoymdyemUym/1fb
f/w9vXfm2KGV+Xr02c0jmz7tmzk2+T8vTny5s+Mgv5q7v3TmML9d3n/h4XH+
8H6YU/xpflh4nodtCycu8dKZxbn71/nXsO7NbZ6Zfu7x7HThA965MBz4iHcP
5y0+5QPDuuXnvPLMlzy8dv7maz45PfAdnxvOW/rIF4d1+z/ztavDfONb04U/
+e7w3C9/eHre3NpVo6frLmzjJ4+H2cX14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9dj9eh6cD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6rBldD64H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cj7Wj68H14HpwPbgeXA+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD67FudD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD3Wj64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD67HhtH14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H12Di6
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24
HptG14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5c
D64H12N2dD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD02j64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD67HltH14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H12Dq6HlwPrgfXg+vB9eB6cD24Hvx9pQf/XunB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrse20fXgenA9uB5cD64H14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14Prwf8A4umkvQ==
          "]]}, Annotation[#, "Charting`Private`Tag#3"]& ], 
       TagBox[{
         Hue[0.37820393249936934`, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[
          0.4558917999999999, 0.16060319999999997`, 0.4593580000000001]], 
         LineBox[CompressedData["
1:eJxF0S+sV2UAx+Hf5Z9wFSjXMQpOLVgsFMuVjXIJlEuh3CKbFoIQKLC5Y6BY
KBQMFg0mioXCBhIsEkwUCnOjXAIFg4nfeT/sPN9y9pR373s+n179/vK3B1ar
1c2N1Wr+3t56sPPy/5OPV+93Y3vz+a9v+Lt5r3jv7p9vz77gyw/P3Nn/hy++
vLX14C/+en3c9Ud8bt4f/MV84O/8yZ393Ye/8Hy9W/d4Pm77Jx6b+L+z6wNv
8uvd9QWv8Xy9nW94Pm7zCj/7e71LvH7t3t0LPD939yuer7f1Jf+2Pu755/zz
/fVO8/z79k7y/Nwzh7keJxbXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6
cD24HlwPrgfXg+vB9eB6cD24HscX14PrwfXgenA9eHv04HpwPbgeXA+uB49N
XA+uB9eD68H14HpwPbgeXA+uB9eD68H1+GhxPbgeXA+uB9eD68H14HpwPbge
XA8em7geXA+uB9eD68H14HpwPbgeXA+uB9eD6/Hh4npwPbgeXA+uB9eD68H1
4HpwPbgePDZxPXh/9OB6cD24Hvx09OB6cD24HlwPrgfXg+uxubgeXA+uB9eD
68H14HpwPbgeXA+uB49NXA+uB9eD68H14HpwPbgeXA+uB9eD68H1OLa4HlwP
rgfXg+vB9eB6cD24HlwPrgePTVwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9Ti6
uB5cD64H14PrwfXgenA9uB5cD64Hj01cD64H14PrwfXgenA9uB5cD64H14Pr
wfX4YHE9uB5cD64H14PrwfXgenA9+OPRg+vBYxPXg+vB9eB6cD24HlwPrgfX
g++PHlwPrgfX48jienA9uB5cD94ZPbgeXA+uB9eD68H14LGJ68H14HpwPbge
XA+uB9eD68H14HpwPbgehxfXg+vB9eB6cD24HlwPrgfXg+vB9eCxievB9eB6
cD24HlwPrgfXg+vB9eB6cD24HocW14PrwfXgenA9uB5cD64H14PrwfXgsYnr
wfXgenA9uB5cD64H14PrwfXgenA9uB4HF9eD68H14HpwPbgeXA+uB9eD68H1
4LGJ68H14HpwPbgeXA+uB9eD68H14HpwPbgeBxbXg+vB9eB6cD24HlwPrgfX
g+vB9eCxievB9eB6cD24HlwPrgfXg+vB9eB6cD24HhuL68H14HpwPbgeXA+u
B9eD68H14Hrw2MT14HpwPbgeXA+uB9eD68H14B9PPfnh0mcbj8e7z/17/h1L
5V3c
          "]], 
         LineBox[CompressedData["
1:eJxd23l8VOXVB/CwimCBF1lVIigKVYtIi4DbidSPgGIVqEoBKSoqFqxgEQFR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          "]], 
         LineBox[CompressedData["
1:eJxF0S2sjnEYwOH3+HZ8nMJMOYZCURTFnCkEBUEhsCEICAqbmU1RFIWgmE06
gkIQEBSCpChnNuUICjbJ856fPdcdnmdXuXf/99t94eqpi6smk8mNmclk+r+7
4+3tE3tmFg6uzLcjz64dnv2yd2Zh8n9eHFu6ue0Av56/t3zyEL//te/sg6P8
6eMwJ/jL02HhGR62LR47z8snX83fu8K/h3XvbvDM9HOHN00X3ufti8OBD3nX
cN6rJ7x/WPfrOa888yUPr3167Q0fnx74gU8P5y1/5nPDun1f+fKlYb7z9enC
n3xreO7SX56eN7921ejpurNz/PjRMDu5HlwPrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6rB5dD64H14PrwfXgenA9uB5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cjzWj68H14HpwPbgeXA+uB9eD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD67F2dD24HlwPrgfXg+vB9eB6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD3Wja4H14PrwfXgenA9
uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD67H+tH14HpwPbge
XA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H12DC6HlwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HhtH
14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
12N2dD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD02ja4H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD67H5tH14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+uB9eD68H12DK6HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HltH14PrwfXgenA9uB5cD64H14N/rPTgPys9uB5c
D64H14PrwfXgenA9uB5cD64H14PrwfWYG10PrgfXg+vB9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HvwPZlGj3A==
          "]]}, Annotation[#, "Charting`Private`Tag#4"]& ], 
       TagBox[{
         Hue[0.6142719099991583, 0.6, 0.6], 
         Directive[
          PointSize[
           NCache[
            Rational[1, 360], 0.002777777777777778]], 
          AbsoluteThickness[2], 
          RGBColor[0., 0., 0.]], 
         LineBox[CompressedData["
1:eJxF0S+QVlUAh+Fv+SesCmUNFBi0YNBCoSzOWJZAWQplDTIDxYAGCpZbKBaK
BQMFnDFtoVCcYTRQIJgoFIYZyhIsGkx+97zMfX7lzlPOnHPfc9dvXb1xaLVa
3d5Yrebvj1v7O6//O/V09X4/bG++fPg335z3lvfu/fHP+Vd89cmZuwd/8eXX
d7b2n/Gl9XHf/84X5j3mz+cDf+Ozdw92nzzg+Xp3fub5uO2feGzif8+vD7zN
73bXF/yO5+vtfMvzcZvX+MXz9a7w+rV7977m+bm7F3m+3taX/Gh93MvP+Jf7
653m+fftneL5uWeOcj1OLq4H14PrwfXgenA9uB5cD64H14PrwWMT14PrwfXg
enA9uB5cD64H14PrwfXgenA9Pl5cD64H14PrwfXg7dGD68H14HpwPbgePDZx
PbgeXA+uB9eD68H14HpwPbgeXA+uB9fjo8X14HpwPbgeXA+uB9eD68H14Hpw
PXhs4npwPbgeXA+uB9eD68H14HpwPbgeXA+ux4eL68H14HpwPbgeXA+uB9eD
68H14Hrw2MT14IPRg+vB9eB68J+jB9eD68H14HpwPbgeXI/NxfXgenA9uB5c
D64H14PrwfXgenA9eGzienA9uB5cD64H14PrwfXgenA9uB5cD67HicX14Hpw
PbgeXA+uB9eD68H14HpwPXhs4npwPbgeXA+uB9eD68H14HpwPbgeXA+ux/HF
9eB6cD24HlwPrgfXg+vB9eB6cD14bOJ6cD24HlwPrgfXg+vB9eB6cD24HlwP
rscHi+vB9eB6cD24HlwPrgfXg+vBn4weXA8em7geXA+uB9eD68H14HpwPbge
fH/04HpwPbgexxbXg+vB9eB68M7owfXgenA9uB5cD64Hj01cD64H14PrwfXg
enA9uB5cD64H14PrwfU4urgeXA+uB9eD68H14HpwPbgeXA+uB49NXA+uB9eD
68H14HpwPbgeXA+uB9eD68H1OLK4HlwPrgfXg+vB9eB6cD24HlwPrgePTVwP
rgfXg+vB9eB6cD24HlwPrgfXg+vB9Ti8uB5cD64H14PrwfXgenA9uB5cD64H
j01cD64H14PrwfXgenA9uB5cD64H14PrwfU4tLgeXA+uB9eD68H14HpwPbge
XA+uB49NXA+uB9eD68H14HpwPbgeXA+uB9eD68H12FhcD64H14PrwfXgenA9
uB5cD64H14PHJq4H14PrwfXgenA9uB5cD64Hf/Hm12+ufLrxdLz7wpuv/gdP
ZF4X
          "]], 
         LineBox[CompressedData["
1:eJxd23l8VOXVB/AUpI2gBS2i+FoWNyiCRYpKUTgRqShLpUJVWiqLgr5gP7IJ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          "]], 
         LineBox[CompressedData["
1:eJxF0S+Mj3EcwPHfHef/n0JQzlAoVxTF3BSCgqAQ2BAEhCsURVEUhaDcbBJB
ISgEhSBdUW425QTl2CTP7972vD7hefYqn32+ex+6dvvC9dnJZLI0M5lM/wvf
X1w5d3hm8fjGfD/14s7JHStHZhYn/+f1mdV7+xb43fzDtfMn+OP60cuPT/OX
z8Oc45XlYeElHra9OnOV186/nX94i38P6z4s8cz084B3Thc+4v2vhgOf8MHh
vLfP+diwbv0lbzzzDQ+vXb7zns9OD/zEF4fz1r7ylWHd0W9888YwP/judOEv
vj88d/UvT8+bn5sdPV13eS8/ezrMAa4H14PrwfXgenA9uB5cD64H14PrwfXg
enA9uB5cD64H14PrwfXgenA9uB6bRteD68H14HpwPbgeXA+uB9eD68H14Hpw
PbgeXA+uB9eD68H14HpwPbgeXA+uB9dj8+h6cD24HlwPrgfXg+vB9eB6cD24
HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6zI2uB9eD68H14HpwPbgeXA+u
B9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+ux5bR9eB6cD24HlwPrgfX
g+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9dg6uh5cD64H14Pr
wfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB7bRteD68H1
4HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9dj++h6
cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6
7BhdD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H14PrwfXgenA9
uB5cj52j68H14HpwPbgeXA+uB9eD68H14HpwPbgeXA+uB9eD68H14HpwPbge
XA+uB9eD67FrdD24HlwPrgfXg+vB9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP
rgfXg+vB9eB6cD12j64H14PrwfXgenA9uB5cD64H14PrwfXgenA9uB5cD64H
14PrwfXgenA9uB5cD67HntH14HpwPbgeXA+uB9eD68H14J8bPfjPRg+uB9eD
68H14HpwPbgeXA+uB9eD68H14HpwPfaOrgfXg+vB9eB6cD24HlwPrgfXg+vB
9eB6cD24HlwPrgfXg+vB9eB6cD24HlwP/gfF26QX
          "]]}, 
        Annotation[#, "Charting`Private`Tag#5"]& ]}}, {{}, {{}, {}}}}, {
    DisplayFunction -> Identity, DisplayFunction -> Identity, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{
        FormBox[
         TagBox["\"Density of states\"", HoldForm], TraditionalForm], None}, {
        FormBox[
         TagBox[
         "\"Energy \
\\!\\(\\*StyleBox[\\\"E\\\",FontSlant->\\\"Italic\\\"]\\)\"", HoldForm], 
         TraditionalForm], None}}, FrameStyle -> GrayLevel[0], 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "DefaultPlotStyle" -> {
         Directive[
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.363898, 0.618501, 0.782349], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[1, 0.75, 0], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.647624, 0.37816, 0.614037], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.571589, 0.586483, 0.], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.915, 0.3325, 0.2125], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[
          0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
          AbsoluteThickness[2]], 
         Directive[
          RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
          AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
       "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
       "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
       "OptimizePlotMarkers" -> True, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"nontrivial; k sampling: \\!\\(\\*SuperscriptBox[\\(10\\), \
\\(8\\)]\\) (\\!\\(\\*SuperscriptBox[\\(10\\), \\(6\\)]\\))\"", 
       TraditionalForm], PlotRange -> {{-2., 2.}, {0., 0.6}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{0, 
        Scaled[0.02]}, {0, 
        Scaled[0.08090169943749476]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"T2.2\"", "\"T5.4\"", "\"T9.3\"", "\"T33.11\"", "\"T65.9\""}, 
      "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[1., 0.8423264, 0.4188294]], {}}}, AspectRatio -> 
                    Full, ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0.9917508, 0.5901996, 0.09831576]], {}}}, 
                    AspectRatio -> Full, ImageSize -> {20, 12.5}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {
                    LineBox[{{0, 12.5}, {20, 12.5}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[2], 
                    RGBColor[0., 0., 0.]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 12.5}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.18000000000000002`] -> 
                    Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[1., 0.8423264, 0.4188294]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> RGBColor[0.9917508, 0.5901996, 0.09831576]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.8647229999999999, 0.3364763999999999, 
                    0.1829199600000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|
                    "color" -> 
                    RGBColor[
                    0.4558917999999999, 0.16060319999999997`, 
                    0.4593580000000001]|>, "RGBColorSwatchTemplate"]}], "]"}],
                ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", 
                    FractionBox["1", "360"], "]"}], ",", 
                   RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
                   
                   TemplateBox[<|"color" -> RGBColor[0., 0., 0.]|>, 
                    "RGBColorSwatchTemplate"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm], ",", 
               TagBox[#3, HoldForm], ",", 
               TagBox[#4, HoldForm], ",", 
               TagBox[#5, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               
               RowBox[{
                "True", ",", "True", ",", "True", ",", "True", ",", "True"}], 
               "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.9102530869967065`*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"0523958d-34a5-43d4-8a89-0d29085243c2"]
}, Open  ]],

Cell["\<\
We observe convergence of the density of states with increasing size of the \
supercell.\
\>", "Text",
 CellChangeTimes->{{3.909125877711278*^9, 3.909126045253215*^9}, {
  3.9101545181845226`*^9, 
  3.9101545262977867`*^9}},ExpressionUUID->"1b53b35b-3523-4a1c-8eb7-\
4bba244b9dff"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1428, 825.75},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>1. Inherited,
FrontEndVersion->"13.3 for Microsoft Windows (64-bit) (July 24, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"86261373-b400-4f6a-92d1-96a6315a50c9"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 303, 7, 35, "Text",ExpressionUUID->"25e347e7-d5f6-499d-95a7-78e4f26e23c4"],
Cell[CellGroupData[{
Cell[886, 31, 161, 3, 67, "Section",ExpressionUUID->"2e5cf166-0f8d-4a79-9131-7743a7213544"],
Cell[1050, 36, 363, 7, 35, "Text",ExpressionUUID->"5e46b4de-4782-4109-aabf-ab09980bd127"],
Cell[1416, 45, 247, 5, 44, "Input",ExpressionUUID->"1a6e7216-2d05-4afb-bde5-8f1765bb7aba",
 InitializationCell->True],
Cell[1666, 52, 297, 6, 44, "Input",ExpressionUUID->"734cb0e3-96ac-4020-b0f3-2ab2eb1c581b",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2000, 63, 302, 4, 67, "Section",ExpressionUUID->"5c8fe938-4a81-4d15-b4c6-d17ad1f32d3f"],
Cell[CellGroupData[{
Cell[2327, 71, 211, 4, 54, "Subsection",ExpressionUUID->"0aa1239d-4d07-4b4a-a942-f7e95e4123cb"],
Cell[2541, 77, 390, 9, 35, "Text",ExpressionUUID->"89c60f61-ecd2-4ee9-ab1a-cf8bcfab8422"],
Cell[2934, 88, 583, 14, 28, "Input",ExpressionUUID->"48113e68-9341-4006-9c86-c6c9e6fff331"],
Cell[3520, 104, 629, 14, 28, "Input",ExpressionUUID->"d928ec5c-db9e-4c18-8b7e-b50ba50f1a71"],
Cell[4152, 120, 330, 8, 35, "Text",ExpressionUUID->"00495ca5-cb98-4b4a-9d1f-156d8cf17d98"],
Cell[4485, 130, 559, 11, 28, "Input",ExpressionUUID->"80851ff6-620b-4dad-b4e6-d9efccfe3f3c"],
Cell[5047, 143, 817, 19, 28, "Input",ExpressionUUID->"678328f8-6dfb-41e5-b97a-d97cc7cc6387"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5901, 167, 181, 3, 54, "Subsection",ExpressionUUID->"2e46cb30-aab4-4ca6-84e9-be7dc3526191"],
Cell[6085, 172, 476, 8, 58, "Text",ExpressionUUID->"341dd1bd-e500-4566-8ca2-7e964d21b4c8"],
Cell[CellGroupData[{
Cell[6586, 184, 933, 18, 162, "Input",ExpressionUUID->"6d2b05f0-47f9-4b24-89ab-81a2e9ebdbb4"],
Cell[7522, 204, 129351, 2144, 317, "Output",ExpressionUUID->"2b7f5c4c-3604-4cd1-8985-700ccfcb41be"]
}, Open  ]],
Cell[136888, 2351, 396, 8, 35, "Text",ExpressionUUID->"c772f7df-d25d-489a-b114-9df4ad308a69"],
Cell[CellGroupData[{
Cell[137309, 2363, 686, 16, 28, "Input",ExpressionUUID->"27ff0637-f797-47c1-9726-11d490f8ca1d"],
Cell[137998, 2381, 971, 27, 46, "Output",ExpressionUUID->"90b5f9db-c6a7-41c8-b149-37d5817d2f61"]
}, Open  ]],
Cell[138984, 2411, 163, 3, 35, "Text",ExpressionUUID->"6f1fa75b-44b5-476e-989d-15b68100359b"],
Cell[139150, 2416, 599, 13, 28, "Input",ExpressionUUID->"8ef56728-4aa6-4c54-b5f0-9af549df0f1c"],
Cell[CellGroupData[{
Cell[139774, 2433, 168, 3, 45, "Subsubsection",ExpressionUUID->"ab3c7313-84ab-4903-817f-0cda254dbc01"],
Cell[139945, 2438, 462, 9, 58, "Text",ExpressionUUID->"123d0899-b6f2-408b-a9ed-0cd524724576"],
Cell[CellGroupData[{
Cell[140432, 2451, 488, 10, 28, "Input",ExpressionUUID->"3ff975b3-8c4f-4dcc-b819-e3562f86870c"],
Cell[140923, 2463, 18612, 356, 62, "Output",ExpressionUUID->"62a83bda-ee71-41fa-8301-c889a62a4160"]
}, Open  ]],
Cell[159550, 2822, 302, 6, 35, "Text",ExpressionUUID->"f12bb32d-9e00-4dac-9f8b-9a3ef0b45887"],
Cell[159855, 2830, 2597, 69, 178, "Input",ExpressionUUID->"365c03fd-f61f-4032-9bcf-5f728c146577",
 InitializationCell->True],
Cell[162455, 2901, 651, 18, 35, "Text",ExpressionUUID->"1bbd633c-157f-46a0-a45d-7b39a32bcebb"],
Cell[163109, 2921, 513, 13, 28, "Input",ExpressionUUID->"d553c574-e670-4b75-b2de-cad7dd597255"],
Cell[CellGroupData[{
Cell[163647, 2938, 857, 18, 31, "Input",ExpressionUUID->"2f2de91f-e136-4ae2-8a04-14311f78bbf2"],
Cell[164507, 2958, 78519, 1361, 262, "Output",ExpressionUUID->"c34cfb51-d425-4333-95f6-5c4d3fa082c7"]
}, Open  ]],
Cell[243041, 4322, 503, 10, 35, "Text",ExpressionUUID->"1f122f01-94f2-4fab-839e-c603454b0f31"],
Cell[CellGroupData[{
Cell[243569, 4336, 1180, 28, 53, "Input",ExpressionUUID->"1c687741-654e-42b0-b299-3a6db4f577d4"],
Cell[244752, 4366, 145867, 2462, 262, "Output",ExpressionUUID->"8e36ac29-00c3-4f32-a9db-8e0cc8ec4a55"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[390680, 6835, 171, 3, 54, "Subsection",ExpressionUUID->"03e8e79c-cffb-4f64-b870-a5b0c19cb800"],
Cell[390854, 6840, 314, 7, 35, "Text",ExpressionUUID->"0fc91d85-0956-4c4c-b117-6bb43e0a84ea"],
Cell[391171, 6849, 968, 22, 28, "Input",ExpressionUUID->"7b62a3bf-6668-41bf-a804-54392f6274fa"],
Cell[392142, 6873, 711, 17, 28, "Input",ExpressionUUID->"f6d2b461-3919-4b7d-a29f-efceb258919a"],
Cell[CellGroupData[{
Cell[392878, 6894, 164, 3, 45, "Subsubsection",ExpressionUUID->"8281bd5b-57f4-4f14-8c01-6406fab36a79"],
Cell[393045, 6899, 322, 6, 35, "Text",ExpressionUUID->"6d38ecac-6b75-4d4a-9a72-9cf3638e9ac8"],
Cell[CellGroupData[{
Cell[393392, 6909, 292, 6, 28, "Input",ExpressionUUID->"a07f4cec-2ae7-4987-9e3c-968888734acb"],
Cell[393687, 6917, 3369, 90, 71, "Output",ExpressionUUID->"af6d6038-05fe-4cfe-80d0-63ff2287a109"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[397105, 7013, 168, 3, 45, "Subsubsection",ExpressionUUID->"5a8125a9-906f-49ba-9388-06fadfc45e2e"],
Cell[397276, 7018, 481, 8, 58, "Text",ExpressionUUID->"d01eb045-6be8-4225-8b95-b0bd44723d24"],
Cell[397760, 7028, 787, 20, 28, "Input",ExpressionUUID->"9a419784-bd59-45c9-bdf3-199c64448a76"],
Cell[398550, 7050, 436, 12, 35, "Text",ExpressionUUID->"2b1c8500-dfcc-498f-b96b-390b3cf3ffc6"],
Cell[398989, 7064, 761, 20, 28, "Input",ExpressionUUID->"e9f06fc8-fdde-49e0-b51c-d473777b09d2"],
Cell[399753, 7086, 340, 7, 35, "Text",ExpressionUUID->"90089e1d-6a12-4649-b7d8-9d0249e27781"],
Cell[CellGroupData[{
Cell[400118, 7097, 1479, 37, 53, "Input",ExpressionUUID->"a4530974-f78b-4741-9abe-c0ff20504da3"],
Cell[401600, 7136, 149068, 2601, 268, "Output",ExpressionUUID->"5c943cb8-bc47-47b3-b1e5-2f9098c7ebac"]
}, Open  ]],
Cell[550683, 9740, 581, 13, 35, "Text",ExpressionUUID->"a8eef5b2-fa3f-4efa-9b0e-83e472e2a2ca"],
Cell[CellGroupData[{
Cell[551289, 9757, 1936, 50, 72, "Input",ExpressionUUID->"0c167561-a667-494a-9983-facef3c816b3"],
Cell[553228, 9809, 280442, 4755, 264, "Output",ExpressionUUID->"8f51d0c5-b390-445b-994a-a99bcb07a01e"]
}, Open  ]],
Cell[833685, 14567, 291, 7, 35, "Text",ExpressionUUID->"ae7108a1-7632-46b1-8b5a-b1df6e84a0a4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[834025, 14580, 184, 3, 54, "Subsection",ExpressionUUID->"38c8a010-1f34-4695-b901-623f646a4b37"],
Cell[834212, 14585, 995, 27, 58, "Text",ExpressionUUID->"a38eb184-837a-42a3-bd8b-d4d62527deac"],
Cell[CellGroupData[{
Cell[835232, 14616, 1144, 27, 48, "Input",ExpressionUUID->"df1e17a4-24b1-4751-838d-b11d96db12a7"],
Cell[836379, 14645, 142902, 2455, 268, "Output",ExpressionUUID->"b8f815d7-aba7-4296-b0b2-83c2ef0d1789"]
}, Open  ]],
Cell[CellGroupData[{
Cell[979318, 17105, 2443, 64, 74, "Input",ExpressionUUID->"ab533ebd-9df3-428e-83e4-f4760fcc719d"],
Cell[981764, 17171, 198277, 3384, 262, "Output",ExpressionUUID->"b1c53614-aec9-4e72-b957-7cef649e89f1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1180090, 20561, 183, 3, 54, "Subsection",ExpressionUUID->"0c79cecf-b3aa-46a9-9d9c-7e118e6bc6f7"],
Cell[1180276, 20566, 294, 6, 35, "Text",ExpressionUUID->"46376d33-5fae-4488-ab9e-c08feb80edc0"],
Cell[CellGroupData[{
Cell[1180595, 20576, 175, 3, 45, "Subsubsection",ExpressionUUID->"fc354d59-7ef2-4dfe-961d-d0d379a59417"],
Cell[1180773, 20581, 178, 3, 35, "Text",ExpressionUUID->"327c9d3a-d54a-488a-a38b-a5cac7e5834f"],
Cell[1180954, 20586, 610, 12, 28, "Input",ExpressionUUID->"1340367b-a1ce-41d1-bbba-46cba7dcfcce"],
Cell[1181567, 20600, 817, 19, 28, "Input",ExpressionUUID->"4afa58e7-e9cf-44cc-832d-cebe051ffb42"],
Cell[1182387, 20621, 200, 3, 35, "Text",ExpressionUUID->"75e9326b-87c7-4575-a6cd-dcd82c933f5d"],
Cell[1182590, 20626, 968, 22, 28, "Input",ExpressionUUID->"eeed950c-a368-4845-8ad4-e49e5f315fd9"],
Cell[1183561, 20650, 711, 17, 28, "Input",ExpressionUUID->"6b391cae-718b-4c0f-a58b-15203a9643a1"],
Cell[1184275, 20669, 169, 3, 35, "Text",ExpressionUUID->"9f16f854-df8d-43fc-bfd1-45682e021184"],
Cell[1184447, 20674, 787, 20, 28, "Input",ExpressionUUID->"3722dad1-0047-410a-bef6-bd4ff62b68f7"],
Cell[1185237, 20696, 424, 11, 35, "Text",ExpressionUUID->"6950afae-9e13-494f-aaa9-5f07ae62525b"],
Cell[1185664, 20709, 761, 20, 28, "Input",ExpressionUUID->"5a91d423-30a4-40d9-84e0-a02aeab08cce"],
Cell[1186428, 20731, 297, 4, 35, "Text",ExpressionUUID->"c7997f03-ca8b-4d0e-8c49-243a48e2a12b"],
Cell[CellGroupData[{
Cell[1186750, 20739, 1478, 37, 53, "Input",ExpressionUUID->"d296bc34-ca04-49a5-9284-337c52672829"],
Cell[1188231, 20778, 149194, 2603, 264, "Output",ExpressionUUID->"48b5ca4d-f0c9-4b71-b97e-7c77c6c8baa8"]
}, Open  ]],
Cell[1337440, 23384, 650, 12, 35, "Text",ExpressionUUID->"a788d98f-d62c-4fe2-9b18-a235cebbec81"],
Cell[CellGroupData[{
Cell[1338115, 23400, 1711, 47, 72, "Input",ExpressionUUID->"5202b7b0-c17e-4fa9-861e-2573dd28c8ff"],
Cell[1339829, 23449, 263781, 4482, 264, "Output",ExpressionUUID->"8d675a63-e53e-400b-8224-c92b1d42a02c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1603659, 27937, 198, 3, 45, "Subsubsection",ExpressionUUID->"85eb5c05-a459-4dd8-90d1-03ad6cc738d7"],
Cell[1603860, 27942, 232, 4, 35, "Text",ExpressionUUID->"8c377bcb-d060-434e-a0d3-1e2b20b615ec"],
Cell[1604095, 27948, 586, 11, 28, "Input",ExpressionUUID->"fd0aec85-f518-47e8-81b5-0b475e1f24da"],
Cell[1604684, 27961, 817, 19, 28, "Input",ExpressionUUID->"164b9b72-1a98-43c4-8a55-72bda0b9730c"],
Cell[1605504, 27982, 200, 3, 35, "Text",ExpressionUUID->"c687b6ce-dee9-4d50-95e0-c348caec9abf"],
Cell[1605707, 27987, 968, 22, 28, "Input",ExpressionUUID->"d936ec5c-9029-40f0-8659-c0f87f454fb3"],
Cell[1606678, 28011, 711, 17, 28, "Input",ExpressionUUID->"d68def57-80b7-4cf6-9cf2-a13fd3ed5406"],
Cell[1607392, 28030, 169, 3, 35, "Text",ExpressionUUID->"5c5d7114-d701-4e7f-a8be-17c53bdedcbd"],
Cell[1607564, 28035, 787, 20, 28, "Input",ExpressionUUID->"db074c64-429b-4f8f-bfbd-9637d623c1b8"],
Cell[1608354, 28057, 424, 11, 35, "Text",ExpressionUUID->"7d08cf4d-b02f-41df-b3b2-5f8cec46cf47"],
Cell[1608781, 28070, 761, 20, 28, "Input",ExpressionUUID->"05079843-3a04-4fc6-a548-681b0294baa7"],
Cell[1609545, 28092, 297, 4, 35, "Text",ExpressionUUID->"683ede2c-0421-41cf-b250-b8addca7c6f8"],
Cell[CellGroupData[{
Cell[1609867, 28100, 1507, 37, 53, "Input",ExpressionUUID->"922a33d0-a655-4267-afc5-8a8ce2e391e6"],
Cell[1611377, 28139, 94469, 1651, 268, "Output",ExpressionUUID->"a9c6624d-2a45-400f-b36d-2783cc35c172"]
}, Open  ]],
Cell[1705861, 29793, 650, 12, 35, "Text",ExpressionUUID->"c399c57a-4114-4e62-862f-4eebf1e0623b"],
Cell[CellGroupData[{
Cell[1706536, 29809, 1763, 48, 72, "Input",ExpressionUUID->"4d17b6dc-e479-45f4-84e6-62890e91ed68"],
Cell[1708302, 29859, 160005, 2727, 264, "Output",ExpressionUUID->"0c343022-39e4-42fe-8244-6b14013f8b84"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1868380, 32594, 353, 5, 53, "Section",ExpressionUUID->"a418547a-0b1f-458c-8af5-495ebe9a3d66"],
Cell[CellGroupData[{
Cell[1868758, 32603, 211, 4, 54, "Subsection",ExpressionUUID->"5ab80389-8a61-4228-87da-25573989ad0f"],
Cell[1868972, 32609, 390, 9, 35, "Text",ExpressionUUID->"e31838ec-b122-4e26-b20d-d0e7b3f04e1e"],
Cell[1869365, 32620, 628, 14, 28, "Input",ExpressionUUID->"aeed050f-e253-4109-a2b2-61acd4c5f6c6"],
Cell[1869996, 32636, 681, 15, 28, "Input",ExpressionUUID->"2d8fdcce-2a72-403c-8a63-d9f8107654d0"],
Cell[1870680, 32653, 330, 8, 35, "Text",ExpressionUUID->"1e62225f-f3ae-411f-8798-f1e688bb4be5"],
Cell[1871013, 32663, 529, 10, 28, "Input",ExpressionUUID->"028c58da-dcb5-485e-a800-fe3d0c8c4068"],
Cell[1871545, 32675, 868, 20, 28, "Input",ExpressionUUID->"20078e31-eb53-4fa0-9ee3-a3f7d9b41076"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1872450, 32700, 206, 3, 54, "Subsection",ExpressionUUID->"fc1ad04f-0452-43a1-8d35-89b14203b5af"],
Cell[1872659, 32705, 504, 9, 58, "Text",ExpressionUUID->"98e3dbae-71e3-4850-88b6-fa213937fe05"],
Cell[CellGroupData[{
Cell[1873188, 32718, 987, 19, 162, "Input",ExpressionUUID->"03e42d22-45fc-4d64-94ef-c177fcf821fe"],
Cell[1874178, 32739, 278677, 4641, 317, 201967, 3382, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"7ee16426-f490-4dcf-ae5a-abb143537df5"]
}, Open  ]],
Cell[2152870, 37383, 396, 8, 35, "Text",ExpressionUUID->"0a1e40eb-b992-4711-9e3c-48b30f41c3f6"],
Cell[CellGroupData[{
Cell[2153291, 37395, 686, 16, 28, "Input",ExpressionUUID->"38c40d56-e0c2-4481-806c-40558f39dfbe"],
Cell[2153980, 37413, 4748, 128, 316, "Output",ExpressionUUID->"ddca14ab-9bbf-4bf2-a25b-d05048d25c08"]
}, Open  ]],
Cell[2158743, 37544, 163, 3, 35, "Text",ExpressionUUID->"eb6f2ed8-b3bb-496d-89ea-ea805068d26c"],
Cell[2158909, 37549, 650, 14, 28, "Input",ExpressionUUID->"493ddf19-00d7-49cf-acc4-8a1c9ca3b79b"],
Cell[CellGroupData[{
Cell[2159584, 37567, 168, 3, 45, "Subsubsection",ExpressionUUID->"1606f219-d378-4d2b-9043-2f2ad2be2a2f"],
Cell[2159755, 37572, 462, 9, 58, "Text",ExpressionUUID->"08060aaf-6252-45ac-9e04-d3a80c9c83ec"],
Cell[CellGroupData[{
Cell[2160242, 37585, 488, 10, 28, "Input",ExpressionUUID->"27569130-23e9-4fd3-aef2-43d81f33b05b"],
Cell[2160733, 37597, 38374, 671, 62, "Output",ExpressionUUID->"9a0b9b92-dfad-4dc6-b529-ba341c021fdf"]
}, Open  ]],
Cell[2199122, 38271, 688, 17, 35, "Text",ExpressionUUID->"4b4f3a38-c50a-4b93-aba7-b03f2b15e9bd"],
Cell[2199813, 38290, 562, 14, 28, "Input",ExpressionUUID->"afdd53c3-797e-4619-aae6-18a044d2efe4"],
Cell[CellGroupData[{
Cell[2200400, 38308, 957, 20, 31, "Input",ExpressionUUID->"961292a7-59d7-40a3-b4ad-df480a357ba9"],
Cell[2201360, 38330, 38480, 697, 265, "Output",ExpressionUUID->"8c94fba0-fd77-4e4f-8ed2-e61ecb23194a"]
}, Open  ]],
Cell[2239855, 39030, 551, 10, 35, "Text",ExpressionUUID->"cd608bbd-1693-4fb3-af8e-7fa1f7341a85"],
Cell[CellGroupData[{
Cell[2240431, 39044, 1280, 29, 53, "Input",ExpressionUUID->"e666d09d-03f0-4c90-aca2-eed95ae84ed8"],
Cell[2241714, 39075, 49746, 883, 265, "Output",ExpressionUUID->"79325e11-91c0-4ece-a286-e7e9f23af1ce"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2291521, 39965, 171, 3, 54, "Subsection",ExpressionUUID->"da606e6b-2fd5-4c23-85f6-d56308944516"],
Cell[2291695, 39970, 314, 7, 35, "Text",ExpressionUUID->"aaa6298d-ea83-435e-b7e2-fdc67d8d4835"],
Cell[2292012, 39979, 968, 22, 28, "Input",ExpressionUUID->"2b90c46e-f644-45f9-ac38-b4699b316829"],
Cell[2292983, 40003, 759, 18, 28, "Input",ExpressionUUID->"a3967646-49e6-4f6e-989b-7dab6ee4bc75"],
Cell[CellGroupData[{
Cell[2293767, 40025, 168, 3, 45, "Subsubsection",ExpressionUUID->"6b3832b2-1739-4102-b71c-e80fc0bfe94f"],
Cell[2293938, 40030, 481, 8, 58, "Text",ExpressionUUID->"4571d201-c92b-4feb-a7fc-f385687f1001"],
Cell[2294422, 40040, 787, 20, 28, "Input",ExpressionUUID->"e3ece56f-79b5-4591-87f5-619f5114ea74"],
Cell[2295212, 40062, 537, 13, 35, "Text",ExpressionUUID->"6d21be8a-b730-442d-b0a0-f9d4c09742ec"],
Cell[2295752, 40077, 811, 20, 28, "Input",ExpressionUUID->"4d95add6-4807-4100-86ec-a027e9d7cd1e"],
Cell[2296566, 40099, 340, 7, 35, "Text",ExpressionUUID->"eb247454-3d8b-4b43-aada-f6c7a26450a4"],
Cell[CellGroupData[{
Cell[2296931, 40110, 1557, 38, 53, "Input",ExpressionUUID->"0a04cab2-7240-4349-b830-d2b054f1f632"],
Cell[2298491, 40150, 44997, 839, 267, "Output",ExpressionUUID->"94f26d6f-6f82-4221-9db5-796b7b7e6b25"]
}, Open  ]],
Cell[2343503, 40992, 607, 13, 35, "Text",ExpressionUUID->"1f14f433-7718-478f-ad9c-2070915719e8"],
Cell[CellGroupData[{
Cell[2344135, 41009, 1989, 51, 72, "Input",ExpressionUUID->"68751a8c-af9d-49c1-91f0-c2a6834ba4c9"],
Cell[2346127, 41062, 69123, 1236, 267, "Output",ExpressionUUID->"8a43727d-52c2-4cad-b9d8-c0cb854202ea"]
}, Open  ]],
Cell[2415265, 42301, 291, 7, 35, "Text",ExpressionUUID->"e1e2ff00-1957-4574-a036-ecdd92acc227"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2415605, 42314, 184, 3, 54, "Subsection",ExpressionUUID->"78a67eaa-0fe9-48d0-b304-632e1ccbb3c3"],
Cell[2415792, 42319, 1090, 28, 58, "Text",ExpressionUUID->"eafeb38b-e329-4813-b34f-88ebcee0afc0"],
Cell[CellGroupData[{
Cell[2416907, 42351, 1239, 29, 48, "Input",ExpressionUUID->"3dddf41e-4444-4c10-82f7-572671e12626"],
Cell[2418149, 42382, 99549, 1772, 263, "Output",ExpressionUUID->"ff7138f1-e83b-4a7f-a2b6-aedae5de7631"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2517735, 44159, 2291, 57, 72, "Input",ExpressionUUID->"146d2cdb-d151-4100-9344-5de2e0530a98"],
Cell[2520029, 44218, 46423, 864, 266, "Output",ExpressionUUID->"d6736b00-294f-4655-aac4-17e863abe7e3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2566501, 45088, 183, 3, 54, "Subsection",ExpressionUUID->"80185b0e-ff22-4cb5-a965-dd73fec4c933"],
Cell[2566687, 45093, 294, 6, 35, "Text",ExpressionUUID->"87f2b983-e1bf-4213-99c2-d4489859c498"],
Cell[CellGroupData[{
Cell[2567006, 45103, 175, 3, 45, "Subsubsection",ExpressionUUID->"f8209134-808f-4b0f-bdb4-6928aa33cc08"],
Cell[2567184, 45108, 178, 3, 35, "Text",ExpressionUUID->"25bf66c2-579b-4808-a98f-33a8eaec8b83"],
Cell[2567365, 45113, 578, 11, 28, "Input",ExpressionUUID->"951767d9-5381-44c4-997f-22260b82b591"],
Cell[2567946, 45126, 917, 20, 28, "Input",ExpressionUUID->"332f41d1-15d4-4e3d-b6dd-5203270587fa"],
Cell[2568866, 45148, 641, 13, 58, "Text",ExpressionUUID->"0ca4682f-bd47-4246-b420-11eba0529119"],
Cell[CellGroupData[{
Cell[2569532, 45165, 1761, 48, 72, "Input",ExpressionUUID->"c5aeea6f-e37b-4ccd-872e-ff146d28331f"],
Cell[2571296, 45215, 68675, 1228, 267, "Output",ExpressionUUID->"e09b25e1-aa05-400f-963c-dce0eaeff21b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2640020, 46449, 198, 3, 45, "Subsubsection",ExpressionUUID->"28460305-97c8-48d4-94a8-4e43fe32a594"],
Cell[2640221, 46454, 232, 4, 35, "Text",ExpressionUUID->"b94218fb-7d59-46b8-b84a-6b469c71c85c"],
Cell[2640456, 46460, 661, 12, 28, "Input",ExpressionUUID->"e393cbc3-2a2b-42e7-85ec-4cc2c0f6f856"],
Cell[2641120, 46474, 868, 20, 28, "Input",ExpressionUUID->"27afd63b-22ed-4e39-818a-146089ab2398"],
Cell[2641991, 46496, 330, 7, 35, "Text",ExpressionUUID->"562024e6-60c7-4c3d-8d45-ed7268a3d382"],
Cell[2642324, 46505, 1097, 25, 28, "Input",ExpressionUUID->"fd960593-b340-4ac6-aaf5-50910e92335f"],
Cell[2643424, 46532, 834, 20, 28, "Input",ExpressionUUID->"89106dea-d119-48a2-8f9b-5e9d6c821c13"],
Cell[2644261, 46554, 169, 3, 35, "Text",ExpressionUUID->"bdf68d73-440e-440a-ab59-a6c7408fc2fc"],
Cell[2644433, 46559, 905, 21, 28, "Input",ExpressionUUID->"32470280-4dee-4a31-8c50-4fd5579ef4c0"],
Cell[2645341, 46582, 470, 11, 35, "Text",ExpressionUUID->"3b43be3d-364b-4277-b040-d80426c19156"],
Cell[2645814, 46595, 939, 23, 28, "Input",ExpressionUUID->"dd6860cb-56d5-4eec-91eb-9a6eb3a3d441"],
Cell[2646756, 46620, 297, 4, 35, "Text",ExpressionUUID->"b86d8a84-14b0-4941-bc25-4c9914bca2ec"],
Cell[CellGroupData[{
Cell[2647078, 46628, 1559, 38, 53, "Input",ExpressionUUID->"2d31482e-46a7-4962-8a0f-e6b58c9152a3"],
Cell[2648640, 46668, 36929, 694, 290, "Output",ExpressionUUID->"cbdbb545-887d-4ebb-8b9a-5e33a137385d"]
}, Open  ]],
Cell[2685584, 47365, 680, 13, 35, "Text",ExpressionUUID->"c2ff081f-e50b-4856-8981-0c0d3abb07bb"],
Cell[CellGroupData[{
Cell[2686289, 47382, 1813, 48, 72, "Input",ExpressionUUID->"301ae744-bdaa-49ed-9d77-45cfd0791b45"],
Cell[2688105, 47432, 69065, 1235, 267, "Output",ExpressionUUID->"cd0f655a-0347-4274-a20b-5b9f6bfdb4b3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2757243, 48675, 469, 8, 53, "Section",ExpressionUUID->"49f37b0d-197a-458f-a522-4d493dec4b0a"],
Cell[CellGroupData[{
Cell[2757737, 48687, 211, 4, 54, "Subsection",ExpressionUUID->"2809b34e-b1f7-4c38-b3a2-8e1e5c8a5f4a"],
Cell[2757951, 48693, 390, 9, 35, "Text",ExpressionUUID->"cb23dc52-960f-44c5-8d0b-cd9ec821af3e"],
Cell[2758344, 48704, 628, 14, 28, "Input",ExpressionUUID->"99b5509f-cde8-4248-9706-f881ea19edd4"],
Cell[2758975, 48720, 730, 16, 28, "Input",ExpressionUUID->"2f679673-cc5f-4860-80aa-a8d0a9d463e8"],
Cell[2759708, 48738, 330, 8, 35, "Text",ExpressionUUID->"9bf13767-43f8-4181-84d2-903972d5d14e"],
Cell[2760041, 48748, 528, 10, 28, "Input",ExpressionUUID->"c5c1f1b2-797f-4bf0-93f6-908b636f82cb"],
Cell[2760572, 48760, 913, 20, 28, "Input",ExpressionUUID->"4d58570a-87ec-4e4e-97c8-3d82e549509a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2761522, 48785, 206, 3, 54, "Subsection",ExpressionUUID->"b39e346f-ee02-4116-b1f3-23549377c887"],
Cell[2761731, 48790, 504, 9, 58, "Text",ExpressionUUID->"d5e207c8-6314-432b-8475-7f0a17ed19d0"],
Cell[CellGroupData[{
Cell[2762260, 48803, 986, 19, 162, "Input",ExpressionUUID->"d9d1f6e3-b0d6-4fd6-b0a4-01448f3969fc"],
Cell[2763249, 48824, 321739, 5382, 317, 231980, 3909, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"0969c375-5bbe-41e8-aae0-c6373f13443b"]
}, Open  ]],
Cell[3085003, 54209, 396, 8, 35, "Text",ExpressionUUID->"679d70a2-5930-47f3-bcdb-beccdf68d04c"],
Cell[CellGroupData[{
Cell[3085424, 54221, 686, 16, 28, "Input",ExpressionUUID->"76a9f185-88e4-43cf-9074-24465b29b912"],
Cell[3086113, 54239, 9079, 229, 471, "Output",ExpressionUUID->"7c25eaee-6e71-48ba-9ac4-3437448d7e4f"]
}, Open  ]],
Cell[3095207, 54471, 163, 3, 35, "Text",ExpressionUUID->"e88406aa-0530-4485-ba3d-29648e177a84"],
Cell[3095373, 54476, 701, 15, 28, "Input",ExpressionUUID->"a1acb124-c6f7-41a4-8b0b-1c1f0bb7a74e"],
Cell[CellGroupData[{
Cell[3096099, 54495, 168, 3, 45, "Subsubsection",ExpressionUUID->"0c6113f1-0b03-44e2-9546-c3eaf63debf1"],
Cell[3096270, 54500, 462, 9, 58, "Text",ExpressionUUID->"d1b06afd-a354-469e-97aa-73f4e5895479"],
Cell[CellGroupData[{
Cell[3096757, 54513, 487, 10, 28, "Input",ExpressionUUID->"c006109b-5ac4-4e84-b8b0-36b4037da23c"],
Cell[3097247, 54525, 57279, 945, 62, "Output",ExpressionUUID->"2dd6e1eb-2516-4e7f-aa9b-1ee5b6abc051"]
}, Open  ]],
Cell[3154541, 55473, 688, 17, 35, "Text",ExpressionUUID->"a82f339f-fef6-4bb2-9b25-b2b09da625b2"],
Cell[3155232, 55492, 614, 14, 28, "Input",ExpressionUUID->"8c71c0a2-bf16-43d9-96b0-8b527dfc7726"],
Cell[CellGroupData[{
Cell[3155871, 55510, 1143, 25, 53, "Input",ExpressionUUID->"a21ecc2f-90ce-4a0e-81c0-f244c9b9ba69"],
Cell[3157017, 55537, 41132, 742, 266, "Output",ExpressionUUID->"0645e163-d9af-45b9-b736-921435290170"]
}, Open  ]],
Cell[3198164, 56282, 597, 11, 35, "Text",ExpressionUUID->"4d1e2b78-2536-4a0d-8d76-55b3a379b4de"],
Cell[CellGroupData[{
Cell[3198786, 56297, 1518, 35, 53, "Input",ExpressionUUID->"dfeea4c9-d523-434f-83fd-fe8841a5b024"],
Cell[3200307, 56334, 49528, 880, 266, "Output",ExpressionUUID->"8804f3e7-a41e-4018-8994-0a2ff9541062"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3249896, 57221, 171, 3, 54, "Subsection",ExpressionUUID->"f69101ea-69ad-417a-b569-e82b10379938"],
Cell[3250070, 57226, 314, 7, 35, "Text",ExpressionUUID->"a256d9a9-32f5-42cc-941e-a866bfa9cae6"],
Cell[3250387, 57235, 969, 22, 28, "Input",ExpressionUUID->"6b7c8950-cf63-4ebe-9475-ebcb0b888d98"],
Cell[3251359, 57259, 802, 18, 28, "Input",ExpressionUUID->"0db6c4a8-0acc-4207-815a-72e1dba3cba1"],
Cell[CellGroupData[{
Cell[3252186, 57281, 168, 3, 45, "Subsubsection",ExpressionUUID->"78cb7662-4405-462e-90fb-9648ea721abb"],
Cell[3252357, 57286, 481, 8, 58, "Text",ExpressionUUID->"8f1abd0f-29fb-46cc-9013-cbc11b890705"],
Cell[3252841, 57296, 805, 19, 28, "Input",ExpressionUUID->"8005e28c-1c5f-464b-857e-b5fb53204377"],
Cell[3253649, 57317, 537, 13, 35, "Text",ExpressionUUID->"aa4949b9-061f-4cb2-b2c6-7fd6a89e3f7c"],
Cell[3254189, 57332, 893, 21, 28, "Input",ExpressionUUID->"237a1314-4308-40b2-8466-dfb379ff8d6e"],
Cell[3255085, 57355, 340, 7, 35, "Text",ExpressionUUID->"d875982f-f8a4-42a2-bb90-3c3cf39b45a4"],
Cell[CellGroupData[{
Cell[3255450, 57366, 1871, 47, 53, "Input",ExpressionUUID->"67cd92ae-b6f7-4ad1-adaa-47a587a251f4"],
Cell[3257324, 57415, 52928, 974, 267, "Output",ExpressionUUID->"14c6487f-935a-43d0-9e2c-90201a5ce8d2"]
}, Open  ]],
Cell[3310267, 58392, 659, 14, 35, "Text",ExpressionUUID->"53addfa9-a828-402d-a987-6e5715e051f1"],
Cell[CellGroupData[{
Cell[3310951, 58410, 2300, 60, 72, "Input",ExpressionUUID->"b92303ef-646d-4f10-97d6-d1b1d69c3ccd"],
Cell[3313254, 58472, 69044, 1240, 267, "Output",ExpressionUUID->"ed351f82-ae45-4a0c-a0c3-0e82371407f4"]
}, Open  ]],
Cell[3382313, 59715, 291, 7, 35, "Text",ExpressionUUID->"d506a133-49ba-43d8-863f-f420b1ad99c7"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3382665, 59729, 483, 7, 53, "Section",ExpressionUUID->"e56a93af-a87f-4a35-968a-8467cfa0ee48"],
Cell[CellGroupData[{
Cell[3383173, 59740, 211, 4, 54, "Subsection",ExpressionUUID->"ae46e953-10ad-4797-b4e0-8260e3aee7ea"],
Cell[3383387, 59746, 390, 9, 35, "Text",ExpressionUUID->"38803b53-6ccd-4824-bdcf-cc8ba9caacf0"],
Cell[3383780, 59757, 628, 14, 28, "Input",ExpressionUUID->"5d693b09-52f9-407c-a71d-859fbdd17a3e"],
Cell[3384411, 59773, 786, 16, 28, "Input",ExpressionUUID->"773c3d7a-414b-4199-bc38-515ca22083bf"],
Cell[3385200, 59791, 330, 8, 35, "Text",ExpressionUUID->"7ee17594-1123-4dbf-a2e6-d64e55f9ad83"],
Cell[3385533, 59801, 528, 10, 28, "Input",ExpressionUUID->"59d0bdaa-2ac5-4f47-ac9a-fccf670d2aa1"],
Cell[3386064, 59813, 949, 21, 28, "Input",ExpressionUUID->"f97ddff2-7a7e-4567-b86b-63311369f1ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3387050, 59839, 206, 3, 54, "Subsection",ExpressionUUID->"00eb273d-872b-49a7-be78-e075a282286c"],
Cell[3387259, 59844, 504, 9, 58, "Text",ExpressionUUID->"bd1b0af4-f1f2-45a3-9551-5f8d9ffb5691"],
Cell[CellGroupData[{
Cell[3387788, 59857, 987, 19, 162, "Input",ExpressionUUID->"2ee61717-181c-42d9-821c-82fd98155de3"],
Cell[3388778, 59878, 349759, 5851, 317, 247438, 4173, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"8ac4efc5-3796-455d-97c8-7a4116f6c5dc"]
}, Open  ]],
Cell[3738552, 65732, 1099, 26, 58, "Text",ExpressionUUID->"c2209bd6-4cc4-4819-aa86-47843f85de4f"],
Cell[3739654, 65760, 936, 22, 28, "Input",ExpressionUUID->"692a663c-283b-40b3-9a89-d281f48d2470"],
Cell[3740593, 65784, 543, 12, 35, "Text",ExpressionUUID->"762ab862-514c-4828-a6db-ce71becddb06"],
Cell[3741139, 65798, 762, 22, 28, "Input",ExpressionUUID->"c63bb179-4023-481f-939d-a18618147d98"],
Cell[3741904, 65822, 462, 12, 28, "Input",ExpressionUUID->"3c4f3741-05e5-474c-94f2-5822eb2a0dee"],
Cell[3742369, 65836, 240, 6, 35, "Text",ExpressionUUID->"0d8b7607-39f6-4ace-8486-487582ad556d"],
Cell[CellGroupData[{
Cell[3742634, 65846, 1085, 24, 28, "Input",ExpressionUUID->"d6c88616-b1d4-4505-9c64-c23556d70a65"],
Cell[3743722, 65872, 20325, 561, 336, "Output",ExpressionUUID->"b51a4812-87b3-45ea-8bec-957c1d8597c4"]
}, Open  ]],
Cell[3764062, 66436, 163, 3, 35, "Text",ExpressionUUID->"1b435fa1-3899-41a3-947e-6b3d19a4c3dd"],
Cell[3764228, 66441, 807, 16, 28, "Input",ExpressionUUID->"3e18def3-d9d2-4075-bf24-8592f17e8f85"],
Cell[CellGroupData[{
Cell[3765060, 66461, 168, 3, 45, "Subsubsection",ExpressionUUID->"beedb420-635d-44cb-a4f0-bd6bb91b2e32"],
Cell[3765231, 66466, 1037, 25, 58, "Text",ExpressionUUID->"c94d9ede-3a58-4aca-bdbe-e601d76a7f89"],
Cell[CellGroupData[{
Cell[3766293, 66495, 667, 14, 28, "Input",ExpressionUUID->"e3632868-71ce-4226-ac79-e353db21567b"],
Cell[3766963, 66511, 55068, 1066, 62, "Output",ExpressionUUID->"9ae79b10-a8b8-4907-9e1e-707a16a2e10b"]
}, Open  ]],
Cell[3822046, 67580, 688, 17, 35, "Text",ExpressionUUID->"357f7797-1983-43e7-adfa-48146443f21a"],
Cell[3822737, 67599, 745, 16, 28, "Input",ExpressionUUID->"c2c0a132-c31b-453b-903c-b9573dd46dc5"],
Cell[CellGroupData[{
Cell[3823507, 67619, 1058, 21, 31, "Input",ExpressionUUID->"618e713b-0c93-4697-add6-a19fd8f704fd"],
Cell[3824568, 67642, 38913, 704, 265, "Output",ExpressionUUID->"6be7175b-f567-4689-b6ee-6d0f073693f8"]
}, Open  ]],
Cell[3863496, 68349, 718, 12, 35, "Text",ExpressionUUID->"a0a0d16f-0b25-45b3-822e-c9b9a61c56f2"],
Cell[CellGroupData[{
Cell[3864239, 68365, 1616, 36, 53, "Input",ExpressionUUID->"134de706-f7cb-43df-8a0a-86307c5d7189"],
Cell[3865858, 68403, 67707, 1177, 267, "Output",ExpressionUUID->"8d81636d-163c-4b6a-9213-fac0c40f3a03"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3933626, 69587, 171, 3, 54, "Subsection",ExpressionUUID->"33694482-f33f-43db-a135-63406bdd13e0"],
Cell[3933800, 69592, 314, 7, 35, "Text",ExpressionUUID->"640a672d-3d35-44c9-bc07-3616f2b69a3d"],
Cell[3934117, 69601, 1074, 23, 28, "Input",ExpressionUUID->"2db2bdb7-2a79-4586-949a-d7a082372230"],
Cell[3935194, 69626, 861, 19, 28, "Input",ExpressionUUID->"37f1c067-b772-4acb-955e-b70f1381f563"],
Cell[CellGroupData[{
Cell[3936080, 69649, 168, 3, 45, "Subsubsection",ExpressionUUID->"6af2d681-15f4-4011-bf54-29d9e6e6567f"],
Cell[3936251, 69654, 481, 8, 58, "Text",ExpressionUUID->"8f31c1df-82a7-4445-83e0-9c9c6511303e"],
Cell[3936735, 69664, 971, 22, 28, "Input",ExpressionUUID->"ac3c0ce7-7319-4e59-a74e-3c6158a20ee3"],
Cell[3937709, 69688, 522, 12, 35, "Text",ExpressionUUID->"16a02a2c-fba0-403f-9a43-4e71e9e74023"],
Cell[3938234, 69702, 949, 22, 28, "Input",ExpressionUUID->"fab797b8-4bd7-4c69-ba9c-1ae47023c1cb"],
Cell[3939186, 69726, 340, 7, 35, "Text",ExpressionUUID->"a79ea780-d894-47c3-bc20-a292aed182e3"],
Cell[CellGroupData[{
Cell[3939551, 69737, 1707, 40, 53, "Input",ExpressionUUID->"cd658730-7590-4b15-a246-b1056fbb8768"],
Cell[3941261, 69779, 51597, 949, 267, "Output",ExpressionUUID->"dc34bae4-7e6e-48ed-80f7-7c121c54b721"]
}, Open  ]],
Cell[3992873, 70731, 716, 15, 35, "Text",ExpressionUUID->"4e5efa7c-23fa-4e52-baa1-c08216665c3b"],
Cell[CellGroupData[{
Cell[3993614, 70750, 2356, 59, 72, "Input",ExpressionUUID->"e21d9b01-c697-465a-a5c8-4dc22f03cc7a"],
Cell[3995973, 70811, 89805, 1574, 267, "Output",ExpressionUUID->"339c522a-3a1c-4101-a06c-ea132fdea9bc"]
}, Open  ]],
Cell[4085793, 72388, 291, 7, 35, "Text",ExpressionUUID->"d82dee24-bf5f-46bd-afb5-18e0ac5fbc67"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4086145, 72402, 528, 8, 53, "Section",ExpressionUUID->"3829808c-565c-4820-89ff-bb32d0bf7205"],
Cell[CellGroupData[{
Cell[4086698, 72414, 211, 4, 54, "Subsection",ExpressionUUID->"13f2005b-aab7-4553-998f-e8b8a44b4635"],
Cell[4086912, 72420, 390, 9, 35, "Text",ExpressionUUID->"b4d23fbc-aaf5-4274-a1ee-624c8736b1c1"],
Cell[4087305, 72431, 679, 15, 28, "Input",ExpressionUUID->"db8621bf-7c8f-4a4d-a73a-75fab247f4ca"],
Cell[4087987, 72448, 831, 17, 28, "Input",ExpressionUUID->"b783d92e-135f-4090-8931-43390273972b"],
Cell[4088821, 72467, 330, 8, 35, "Text",ExpressionUUID->"081ff5ec-023c-4811-bc55-9f4b556f709b"],
Cell[4089154, 72477, 653, 12, 28, "Input",ExpressionUUID->"01e64b66-5366-4b82-b858-eea5dcedab20"],
Cell[4089810, 72491, 1019, 22, 28, "Input",ExpressionUUID->"5df09125-a132-4498-af16-7d3171ab8213"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4090866, 72518, 232, 4, 54, "Subsection",ExpressionUUID->"afef30fb-f0db-4f46-9ae5-41da85564a36"],
Cell[4091101, 72524, 526, 9, 58, "Text",ExpressionUUID->"05c715df-5e3d-48b1-b786-592328cc5864"],
Cell[CellGroupData[{
Cell[4091652, 72537, 1063, 20, 162, "Input",ExpressionUUID->"2d209118-9a27-46a7-aeff-112480c3d7b1"],
Cell[4092718, 72559, 338185, 5582, 317, 158994, 2644, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"fb34719a-500c-4893-8516-fa5baaee05cb"]
}, Open  ]],
Cell[4430918, 78144, 706, 15, 35, "Text",ExpressionUUID->"93cfb5a1-e458-4a50-870c-9e0596489475"],
Cell[4431627, 78161, 929, 24, 124, "Input",ExpressionUUID->"5f95843c-7071-4ea7-9f82-92e4c61b255b"],
Cell[4432559, 78187, 431, 12, 35, "Text",ExpressionUUID->"e4918313-8b53-44f7-8f64-2dc246dc120a"],
Cell[4432993, 78201, 2848, 68, 67, "Input",ExpressionUUID->"1a48e53a-3659-44e8-afb4-7bf6137b034f"],
Cell[4435844, 78271, 240, 6, 35, "Text",ExpressionUUID->"99c79b3d-cfd1-4053-9b15-6fb7de0f475b"],
Cell[CellGroupData[{
Cell[4436109, 78281, 1153, 25, 28, "Input",ExpressionUUID->"96c38553-a9ee-4ced-b4bd-52dad49f8ce7"],
Cell[4437265, 78308, 8009, 196, 476, "Output",ExpressionUUID->"b4cb2171-b0d5-4165-b130-b1ebfffc5b59"]
}, Open  ]],
Cell[4445289, 78507, 163, 3, 35, "Text",ExpressionUUID->"70ad38f5-33b8-4487-bc6c-4d9bfb489d78"],
Cell[4445455, 78512, 854, 17, 28, "Input",ExpressionUUID->"3fa2996c-845a-4dfd-8f60-ea7055301787"],
Cell[CellGroupData[{
Cell[4446334, 78533, 168, 3, 45, "Subsubsection",ExpressionUUID->"a122a9fd-9794-41ae-ad2a-11a394b4d9a9"],
Cell[4446505, 78538, 1133, 28, 58, "Text",ExpressionUUID->"b637fb6d-2cf6-4291-862d-03a82b007dc1"],
Cell[4447641, 78568, 1320, 31, 67, "Input",ExpressionUUID->"022461bc-8917-4328-963a-f8edca9748bb"],
Cell[4448964, 78601, 688, 17, 35, "Text",ExpressionUUID->"2d4df2d9-e0bd-4a04-9b46-951d38255174"],
Cell[4449655, 78620, 1450, 37, 67, "Input",ExpressionUUID->"284544f6-ff42-43ba-95d8-21e8fefa99c0"],
Cell[CellGroupData[{
Cell[4451130, 78661, 1539, 36, 53, "Input",ExpressionUUID->"9d92cce4-aeaf-40eb-9213-0cb83f6bb94b"],
Cell[4452672, 78699, 119923, 2177, 271, "Output",ExpressionUUID->"de4ae2ee-8733-4927-b30b-0b3fdc2d60b3"]
}, Open  ]],
Cell[4572610, 80879, 758, 13, 35, "Text",ExpressionUUID->"bef2632d-cf0f-4f4e-a654-c81eb26e08b4"],
Cell[CellGroupData[{
Cell[4573393, 80896, 2796, 65, 129, "Input",ExpressionUUID->"a75a888b-5dd3-427a-bd30-ed9f8cfdb2a4"],
Cell[4576192, 80963, 131123, 2358, 271, "Output",ExpressionUUID->"4a54b8d5-770f-4543-934e-9c83abf32228"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4707376, 83328, 171, 3, 54, "Subsection",ExpressionUUID->"24550069-f0bd-4af7-a461-f59aa1a12f42"],
Cell[4707550, 83333, 314, 7, 35, "Text",ExpressionUUID->"5d455142-49a7-45ab-a522-3e46c5cdf0d7"],
Cell[4707867, 83342, 1103, 23, 28, "Input",ExpressionUUID->"ba5ae0b9-bb63-4838-b531-682751d509f1"],
Cell[4708973, 83367, 1156, 23, 28, "Input",ExpressionUUID->"d9b5c6a1-09fd-478f-85fc-8ed77e749d2f"],
Cell[CellGroupData[{
Cell[4710154, 83394, 168, 3, 45, "Subsubsection",ExpressionUUID->"6823ddee-ce27-4ea8-ae79-b1d8c697cf3a"],
Cell[4710325, 83399, 700, 14, 58, "Text",ExpressionUUID->"17d4e983-f296-4265-9c48-751e58024efc"],
Cell[CellGroupData[{
Cell[4711050, 83417, 2536, 63, 72, "Input",ExpressionUUID->"0be1fcdd-ffa0-4093-8a3b-20a572f8f483"],
Cell[4713589, 83482, 93673, 1672, 267, "Output",ExpressionUUID->"dc004d46-0da0-47d1-914a-8ec5ac5c7400"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4807299, 85159, 1984, 55, 72, "Input",ExpressionUUID->"27f4e9eb-54e9-4a2d-840d-6b6965753dde"],
Cell[4809286, 85216, 78353, 1432, 267, "Output",ExpressionUUID->"159895ea-b2a9-4791-a235-7acb41be3925"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4887676, 86653, 1988, 55, 72, "Input",ExpressionUUID->"1099a1c1-b7e4-4327-b2fc-e20e07831e0c"],
Cell[4889667, 86710, 67469, 1263, 267, "Output",ExpressionUUID->"0523958d-34a5-43d4-8a89-0d29085243c2"]
}, Open  ]],
Cell[4957151, 87976, 291, 7, 35, "Text",ExpressionUUID->"1b53b35b-3523-4a1c-8eb7-4bba244b9dff"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

